!=========================================================================
!  Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
! 
!  Used to support the java.utl.Date class.
!
!  File image/GbjInstant.gs
!
!=========================================================================

doit
DateAndTime subclass: 'GbjInstant'
  instVarNames: #()
  classVars: #( )
  classInstVars: #()
  poolDictionaries: #()
  inDictionary: Globals
%

doit
GbjInstant removeAllMethods.
GbjInstant class removeAllMethods.
%
set class GbjInstant
run
GbjInstant comment:
'GbjInstant is used by GBJ to represent instances of java.time.Instant .
instances in the server have a timezone offset of zero (GMT) .
Any offset stored in the instance is ignored by Java side of GBJ . '.
^ true
%

! ------------------- Class methods for GbjInstant
category: 'Instance Creation'
classmethod: 
now
  | res posixMicrosec us |
  posixMicrosec := System _timeGmtMicroSeconds .
  us := posixMicrosec - 978307200000000 . "microsecs from 2001"
  (res := self basicNew) _secondsUTC: us asFloat / 1000000.0 offsetSeconds: 0 .
  ^ res
%
classmethod:
posixSeconds: aNumber offset: aDuration 
  ^ super posixSeconds: aNumber offset: nil
%
classmethod:
posixSeconds: aNumber 
  ^ super posixSeconds: aNumber offset: nil
%
classmethod:
secondsLocal: aNumber offset: aDuration
^ super secondsLocal: aNumber offset: nil
%

classmethod:
secondsUTC: aNumber offsetSeconds: anOffset
 ^ super secondsUTC: aNumber offsetSeconds: nil
%
category : 'private' 
method:
printLocalOn: aStream 
  "print the receiver on aStream, omitting the timezone offset and using space instead of T"
  | anArray |
  anArray := self _asFloatParts.
  self printDateFrom: anArray on: aStream.
  aStream nextPut: $ .
  self printTimeFrom: anArray on: aStream.
%

method:
printLocalWithSubsecondDigits: anInteger on: aStream 
    "print the receiver on aStream, omitting the timezone offset and using space instead of T.
     Print the given number of subsecond digits, rounding or printing additional trailing 0s."
 | arr |
  anInteger == 0 ifTrue:[ arr := self _asIntegerParts ]
    ifFalse:[ arr := self _asFloatParts .
      anInteger = 6 ifFalse:[
      arr at: 7 put:(ScaledDecimal for: (arr at: 7) scale: anInteger)] ].
  self printDateFrom: arr on: aStream.
  aStream nextPut: $ .
  self printTimeFrom: arr on: aStream.
%

method: 
_asIntegerParts
  "#(year dayOfYear monthIndex dayOfMonth hour minute second)"

  ^ self partsFrom: (self asSeconds + TimeZone current secondsFromGmt) roundedNoFpe "seconds from base"
%

method: 
_asFloatParts
  "#(year dayOfYear monthIndex dayOfMonth hour minute second)"
  ^self partsFrom:
      (ScaledDecimal for: self asSeconds +  TimeZone current secondsFromGmt 
              scale: 6)   
           "seconds from base"
%

