!=========================================================================
!  Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
! 
!  methods for various server classes to support GBJ v3.2.0+
!
!=========================================================================


category:  'GBJ Support'
method: SymbolDictionary
atString: aString put: aValue

  ^ self at: aString asSymbol put: aValue
%

category:  'GBJ Support'
method:  DecimalFloat
gbjAsString
"Return the java version of this DecimalFloat name (converting the 'F' if present to an 'e').
 Sent from C code in GbjTsInterface.c , GbjGciInterface.c"
 
^ self _asString: $e
%

method: DateAndTime
gbjParts
  ^ { self asPosixSeconds asFloat . self _offsetSeconds }
%
category:  'GBJ Support'
classmethod: DateTime
posixSeconds: secsArg offsetSeconds: offset
  | parts secs2001 intSecs dt zone ofs |
  secs2001 := secsArg - 978307200 .
  intSecs := secs2001 truncated.
  parts := DateAndTimeANSI partsFrom: intSecs. "#(year dayOfYear monthIndex dayOfMonth hour minute second)"
  dt := self newGmtWithYear: (parts at: 1) 
        month: (parts at: 3)
         day: (parts at: 4)
         hours: (parts at: 5)
         minutes: (parts at: 6)
         seconds: (parts at: 7)
         ms: (( secs2001 - intSecs) * 1000) truncated  .
  zone := dt timeZone .
  ofs := zone secondsFromGmt .
  dt isDst ifTrue:[ ofs := ofs + zone secondsForDst ].
  ofs = offset ifFalse:[ dt := dt addSeconds: ofs - offset ].
  ^ dt
%

classmethod: DateAndTime
posixSeconds: secsArg offsetSeconds: offsetArg
  ^ self posixSeconds: secsArg offset: (Duration seconds: offsetArg)
%

method: DateTime
gbjParts
  | zone offset |
  zone := timeZone .
  offset := zone secondsFromGmt .
  self isDst ifTrue:[
    offset := offset + zone secondsForDst .
  ].
 ^ { self asPosixSeconds  . offset }
%

category:  'GBJ Support'
method: Object
gbjAsString
  "Signals an error if asString contains a codepoint > 127"
  | res |
  res := Unicode7 _withAll: self asString 
  res ifNil:[ Error signal:'result of asString contains codepoint(s) > 127' ].
  ^ res
%
category:  'GBJ Support'
classmethod: Fraction
fromGbjNumerator: numerArg denominator: denomArg
  "args are each either a SmallInteger or a String"
  | numer denom |
  numer := numerArg _isSmallInteger ifTrue:[ numerArg ] ifFalse:[ Integer fromString: numerArg].
  denom := denomArg _isSmallInteger ifTrue:[ denomArg ] ifFalse:[ Integer fromString: denomArg].
  ^ self numerator: numer denominator: denom
%

category:  'GBJ Support'
classmethod: ScaledDecimal
mantissaString: aString scale: scaleInt
  | mantissa |
  mantissa := Integer fromString: aString .
  ^ self mantissa: mantissa scale: scaleInt
%

category:  'GBJ Support'
method: Collection
asSortedCollectionWithSortBlockString: aBlockString 
  "aBlockString is the source code for a two argument simple block"
  | blk |
  blk := aBlockString evaluate .
  ^ self asSortedCollection: blk .
%

category:  'GBJ Support'
method: Collection
collectWithBlockString: aBlockString 
  "aBlockString is the source code for a one argument simple block"
  | blk |
  blk := aBlockString evaluate .
  ^ self collect: blk .
%

category:  'GBJ Support'
method: Collection
detectWithBlockString: aBlockString 
  "aBlockString is the source code for a one argument simple block"
  | blk |
  blk := aBlockString evaluate .
  ^ self detect: blk .
%
category:  'GBJ Support'
method: Collection
rejectWithBlockString: aBlockString 
  "aBlockString is the source code for a one argument simple block"
  | blk |
  blk := aBlockString evaluate .
  ^ self reject: blk .
%
category:  'GBJ Support'
method: Collection
selectWithBlockString: aBlockString 
  "aBlockString is the source code for a one argument simple block"
  | blk |
  blk := aBlockString evaluate .
  ^ self select: blk .
%

category:  'GBJ Support'
method: Collection
inject: anArg intoBlockString: aBlockString 
  "aBlockString is the source code for a one argument simple block"
  | blk |
  blk := aBlockString evaluate .
  ^ self inject: anArg into: blk 
%
