/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *      GbjGemStoneErrors.java  
 *
 *========================================================================
 */

package com.gemstone.gbj;

/**
 * This class provides variables for all of the error numbers associated
 * with GbjExceptions that have category GemStoneError.
 * @see com.gemstone.gbj.GbjException#kernel
 * @see com.gemstone.gbj.GbjSession#kernel
 * @see com.gemstone.gbj.GbjKernelObjects#GemStoneError
 * 
 * 
 * @version 3.1
 */

public class GbjGemStoneErrors {

// GemStone errors taken from gcierr.ht in the GS/S and GS/64 server product

/**=========================================================================
 *
 *   COMPILER ERRORS - numbered from 1001 to 1999
 *
 *    Compiler errors are reported differently than other errors.  Rather
 *    than having a single error and zero or more arguments, all compiler
 *    errors are reported as error COMPILER_ERR_STDB(defined below) .
 *    This error has either 1 or 6 arguments, as follows:
 *      1) An array of error descriptors (always present)
 *        Each error descriptor is an array of three elements:
 *         1) an error number (numbered from 002 to 999 see below) and,
 *         2) an offset into the source code string pointing to where the
 *            error was detected.
 *         3) string describing the error
 *    The following error arguments are present only if the compilation error
 *    occurred during automatic recompilation of methods for class modification.
 *      2) Source string of the compilation in error
 *      3) receiver of the recompilation method
 *      4) category of method containing the error
 *      5) symbolList used by the recompilation
 *      6) selector of the method containing the error
 *    See Behavior|recompileAllMethodsInContext:  for more details.
 *
 *=========================================================================
 */
	/** compilation errors found.  
           Arg1: Array of error descriptors, Arg2: source string object.  */

	static final public int COMPILER_ERR_STDB =                      1001;

	/** Paths are allowed only 16 elements.  
            The indicated path has too many elements.  */

	static final public int STDB_ERR_MAX_PATH =                      1002;

	/** Arrays created by #[...] constructs may only contain up to 255
 	    elements. */

	static final public int STDB_ERR_ARRAY_TOO_LARGE =               1003;

       /** Scanned to the end of the method without finding an ending prime
	   for a string literal. */

	static final public int STDB_ERR_EOF_IN_STR_LIT =                1004;

	/** Scanned to the end of the method without finding an ending quote
	    for a comment. */

	static final public int STDB_ERR_EOF_IN_COMMENT =                1005;

	/** Did not find a character after the dollar sign in a character
	    literal. */

	static final public int STDB_ERR_EOF_IN_CHR_LIT =                1006;

	/** A colon must immediately precede either an equals sign (assignment)
	    or an identifier (block parameter). [This one is neither.] */

	static final public int STDB_ERR_UNEXPECTED_COLON =              1007;

	/** A pound sign must immediately precede one of the following:
	    (, [, or a valid symbol character. [Did not find one of these.] */

	static final public int STDB_ERR_UNEXPECTED_POUND =              1008;

	/** The character found is not valid as a beginning character for a
	    token. */

	static final public int STDB_ERR_BAD_CHR =                       1009;

	/** String literals cannot be larger than 10,000 characters. */

	static final public int STDB_ERR_LIT_TOO_BIG =                   1010;

       /** The maximum radix is 36. This radix is too big. */

	static final public int STDB_ERR_BAD_RADIX =                     1011;

	/** The character included in the radixed number is out of range or
	    is an invalid character. */

	static final public int STDB_ERR_BAD_CHR_IN_RADIX_NUM =          1012;

	/** Expected a right parenthesis. Did not find it. */

	static final public int STDB_ERR_EXPECTED_RIGHT_PAREN =          1013;

	/** Expected a primary expression. */

	static final public int STDB_ERR_EXPECTED_PRIMARY =              1014;

	/** Expected a variable name. */

	static final public int STDB_ERR_EXPECTED_VAR =                  1015;

	/** Expected a selector beginning symbol for a message pattern. */

	static final public int STDB_ERR_EXPECTED_SELECTOR =             1016;

	/** Only 15 arguments are allowed in a keyword message selector. */

	static final public int STDB_ERR_MAX_ARG =                       1017;

	/** Tokens were found after the logical end of a parseable method. */

	static final public int STDB_ERR_EXPECTED_EOF =                  1018;

	/** Expected a statement beginning token. It is missing. */

	static final public int STDB_ERR_EXPECTED_STATEMENT =            1019;

	/** Expected to find the keyword "Primitive" after &lt;. 
	    It is missing. */

	static final public int STDB_ERR_EXPECTED_PRIM =                 1020;

	/** Expected to find an integer.  It is missing. */

	static final public int STDB_ERR_EXPECTED_PRIM_NUM =             1021;

	/** The maximum primitive number is 1023. 
            This number is either larger than that or less than 1. */

	static final public int STDB_ERR_BAD_PRIM_NUM =                  1022;

	/** Expected a right curly bracket to terminate a selection block. 
            It is missing. */

	static final public int STDB_ERR_EXPECTED_RIGHT_BRACE =          1023;

	/** The maximum sum of args and temps for a method or block is 2048,
           including the args and temps from any optimized block that is
           embedded in the method or block.  */

	static final public int STDB_ERR_MAX_ARGS_TEMPS =                1024;

	/** Expected a vertical bar to end a temporaries declaration. 
            It is missing. */

	static final public int STDB_ERR_EXPECTED_VERTICAL_BAR =         1025;

	/** Invalid message pattern. */

	static final public int STDB_ERR_EXPECTED_MSG_PATTERN =          1026;

	/** A primitive did not end with the expected &gt; token. */

	static final public int STDB_ERR_EXPECTED_GT =                   1027;

	/** The given exponent in the floating point number does not 
            begin with a digit or is out of range. */

	static final public int STDB_ERR_BAD_FLT =                       1028;

	/** The symbol on the right of an assignment must be either 
            an instance variable, a temporary, or a literal variable. 
            The symbol found is none of these.*/

	static final public int STDB_ERR_EXPECTED_ASSIGNABLE =           1029;

	/** The symbol is already defined as a temporary, 
            an instance variable, or a parameter. */

	static final public int STDB_ERR_ALREADY_DEFINED =               1030;

	/** The symbol is not defined before its use. */

	static final public int STDB_ERR_NOT_DEFINED =                   1031;

	/** The selection block's predicate is too complex. 
            Simplify it and recompile the method. */

	static final public int STDB_ERR_PREDICATE_TOO_BIG =             1032;


       /** Blocks can only be nested 15 levels. */

	static final public int STDB_ERR_BLOCKS_TOO_DEEP =               1033;

	/** The indicated token was totally unexpected. */

	static final public int STDB_ERR_UNEXPECTED_TOKEN =              1034;

	/** Expected a ]. Did not find it. */

	static final public int STDB_ERR_EXPECTED_RIGHT_BRACKET =        1035;

	/** The activation record requirements of the given method 
            exceed the limits of the system. Reduce the complexity 
            of the method and recompile it. */

	static final public int STDB_ERR_STACK_TOO_BIG =                 1036;

// 1037 not used

	/** The size of the compiled method exceeds the maximum allowed. 
            Reduce the size of the method, and recompile it. */

	static final public int STDB_ERR_CODE_TOO_BIG =                  1038;

	/** The maximum number of literals is 255. 
            This method has too many. */

	static final public int STDB_ERR_MAX_LITS =                      1039;


	/** The maximum number of selectors is 255. 
            The method has too many. */

	static final public int STDB_ERR_MAX_SELECTORS =           1040;

	/** You may not compile a primitive or protected method. */

	static final public int STDB_ERR_PRIM_NOT_ALLOWED =        1041;

	/** The object was not true, false or an expression. */

	static final public int STDB_ERR_EXPECTED_BOOL_OR_EXPR =   1042;

	/** The object was not a block or an expression. */

	static final public int STDB_ERR_EXPECTED_BLOCK_OR_EXPR =  1043;

	/** The object was not an Integer or expression. */

	static final public int STDB_ERR_EXPECTED_INT_OR_EXPR =    1044;

	/** The object was not a positive Integer or expression. */

	static final public int STDB_ERR_NOT_POS_INT_OR_EXPR =     1045;

	/** You may not compile a method for this selector. */

	static final public int STDB_ERR_DISALLOWED_SELECTOR =     1046;

	/** The block has the wrong number of arguments for this selector. */

	static final public int STDB_ERR_BAD_NUM_OF_ARGS =         1047;

        /** Attempt to modify an invariant literal such as EmptyString or
            EmptyArray; generated when compiling in dbf conversion mode. */

	static final public int STDB_ERR_LITERAL_INVARIANT =       1048;

	/** An operand was missing from the select block term. */

	static final public int STDB_ERR_EXPECTED_OPERAND =        1049;

	/** An unacceptable operator was given in the select block term; 
	    must be one of &lt;, &gt;, &lt;=, &gt;=, =, ~=, ==, ~~ */

	static final public int STDB_ERR_BAD_SELECT_OPERATOR =     1050;

	/** Encountered an empty select block which evaluates to nil.
  	    The select block must evaluate to a boolean. */

	static final public int STDB_ERR_EXPECTED_SELECT_TERM =    1051;

	/** The conjoined terms of the given SelectionBlock were not
	  parenthesized. */

	static final public int STDB_ERR_TERMS_NOT_PAREN =         1052;

        /** A SelectBlock was encountered that does not have one argument. */

	static final public int STDB_ERR_BAD_NUM_OF_SELECT_ARGS =  1053;

        /** The bytes of the source string are not in EUC format. */

	static final public int STDB_ERR_BAD_EUC_FORMAT =          1054;

        /** The maximum number of blocks in a method is 65536. */

	static final public int STDB_ERR_TOO_MANY_BLOCKS =         1055;

        /** the maximum number of arguments to a method or block is 255. */

	static final public int STDB_ERR_MAX_ARGS =                1056;

        /** Internal logic error in compiler. */

	static final public int STDB_ERR_CODE_GEN_LOGIC =          1057;

        /** The first term of a path in a SelectBlock cannot indicate
            search over a set-valued instance variable (cannot be '*'). */

	static final public int STDB_ERR_FIRST_TERM_CANNOT_BE_SET_VALUED = 1058;

        /** Specified primitive method cannot be a protected method. */

	static final public int STDB_ERR_ILLEGAL_PROTECTED_METHOD =  1059;

        /** Method requires either &lt;protected&gt; or &lt;unprotected&gt;. */

	static final public int STDB_ERR_PROTECTED_TOKEN_REQUIRED =  1060;

        /** reference to super not allowed in instance method for Object. */

	static final public int STDB_ERR_SUPER_NOT_ALLOWED =         1061;

        /** method or block temporary is unused. */

	static final public int STDB_ERR_UNUSED_TEMP_VAR =           1062;

        /** source string that is Double/QuadByteString has odd basic size. */

	static final public int STDB_ERR_ODD_SIZE_MB_STRING =        1063;

        /** primitive: , protected, unprotected , requiresVc  
            not allowed in pragma. */

	static final public int STDB_ERR_PRIMITIVE_IN_PRAGMA =       1064;

        /** pragma not allowed in a primitive:, 
            protected, unprotected , requiresVc method. */

	static final public int STDB_ERR_PRAGMA_IN_PRIM =            1065;

	/** The object was a literal or an expression. */

	static final public int STDB_ERR_EXPECTED_LIT_OR_EXPR =      1066;

        /** for envN: , env has no trailing digits. */

	static final public int STDB_ERR_NODIGIT_IN_ATENV =          1067;
       
        /** for envN: , env is followed by ch other than digits or :. */

	static final public int STDB_ERR_BAD_CHAR_IN_ATENV =         1068;

        /** envN:  has N &gt; 255. */

	static final public int STDB_ERR_ENV_TOO_BIG =               1069;

	/** Error in ByteArrayLitElemRange. */

	static final public int STDB_ERR_ByteArrayLitElemRange =     1070;

	/** Error in ArrayBuilder conversion. */

	static final public int STDB_ERR_ArrayBuilder_conversion =   1071;

        /** Malformed IR from parser detected by code generator. */

	static final public int STDB_ERR_COMPILER_BAD_IR =           1072;

	/** expression nesting too deep for configured 
           GEM_TEMPOBJ_SCOPES_SIZE. */

	static final public int STDB_EXPRESSION_DEPTH =              1073;

	/** source string for a method is too big, max size 1073741823. */

	static final public int STDB_METHOD_SOURCE_TOO_BIG =         1074;

	/** Malformed error in compiler. */

	static final public int STDB_MALFORMED_COMPILER_ERROR =      1075;

	/** selector or symbol literal would exceed 1024 bytes. */

	static final public int STDB_SYMBOL_TOO_BIG =                1076;

	/** invalid form of ruby selector. */

	static final public int STDB_INVALID_ATRUBY_KEYWORD =        1077;



/**========================================================================
 *
 *   Virtual Machine Errors - numbered from 2001 to 2999
 *
 *========================================================================
 */

        /** source string that is DoubleByteString has odd basic size. */

	static final public int STDB_ERR_ODD_SIZE_DB_STRING =  1063;


	/** The argument specified for transactionMode: was not valid.
           Args: (1) the invalid argument.  */

	static final public int RT_ERR_INVALID_TRANS_MODE =        2001;


	/** The user's symbol list is not a kind of Array containing
	objects that are a kind of SymbolDictionary. */

	static final public int RT_ERR_BAD_SYMBOL_LIST =           2002;

	/** An indexable object was referenced with an index that was
	out of range.  The index must be between 1 and the number of
	indexable fields.  Args: (1) the object; (2) the subscript.
		       OR
	An NSC was indexed with a subscript that was out of bounds.
	Args: (1) the NSC; (2) the subscript. */

	static final public int OBJ_ERR_BAD_OFFSET_INCOMPLETE =    2003;

        /** A subscript that was out of range or not an Integer was used 
            to index an object.  
	    Args: (1) the object; (2) the subscript. */

	static final public int RT_ERR_BAD_SUBSCRIPT =             2004;

	/** GciSendMsg was called with an inconsistent number of message
	parts.  Args: none. */

	static final public int GCI_ERR_BAD_NUM_MSG_PARTS =        2005 ;

	/** An attempt was made to change Segment authorization, but the
	number of elements in the authorization array was wrong.  The array
	should be of size 5.  Args: (1) the array. */

	static final public int RT_ERR_AUTH_ARRAY_SIZE =           2006 ;

	/** A method was invoked that has been specifically disallowed
	    in a subclass.
	    Args: (1) the receiver; (2) the selector. */

	static final public int RT_ERR_SHOULD_NOT_IMPLEMENT =      2007;

	/** A method has been invoked in an abstract superclass that 
            was designed to have been overridden in a concrete subclass.
	    Args: (1) the abstract superclass; (2) the selector */

	static final public int RT_ERR_SUBCLASS_RESPONSIBILITY =   2008;

	/** An attempt was made to create an instance of a modifiable class
	   (that is, a class still involved in schema design).  Send the
	   message "immediateInvariant" to the class to terminate class
	   modification and allow instance creation.
	   Args: (1) the class. */

	static final public int OBJ_ERR_CLASS_VARIANT =            2009;

	/** No method was found for the given selector.
	Args: (1) the  receiver; (2) the selector;
	3) an array of arguments. */

	static final public int RT_ERR_DOES_NOT_UNDERSTAND =       2010;

	/** An attempt was made to use an object that is not a segment where
	a segment was required.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_SEGMENT =              2011;

	/** An attempt was made to index an object that is not indexable.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_INDEXABLE =            2012;

       /** Cannot perform the given selector with the given arguments.
	Either the method was not found or the wrong number of arguments
	was specified.
	Args: (1) the receiver; (2) the selector; (3) array of arguments. */

	static final public int RT_ERR_CANT_PERFORM =              2013;

	/** Cannot create a subclass of the given class.  
            Args: (1) the class. */

	static final public int CLASS_ERR_SUBCLASS_DISALLOWED =    2014;

        /** Cannot find the object in designated collection. */

	static final public int OBJ_ERR_NOT_IN_COLLECTION =        2015;

	/** An object was not found in collection where it was expected.
	  Args: (1) the collection;  (2) the object not found.  */

	static final public int OBJ_ERR_NOT_IN_NSC =               2015;

	/** An attempt was made to create a new extent when the logical
           repository already has the maximum number of extents attached.
	   Args: (1) the maximum number of extents. */

	static final public int REP_ERR_MAX_EXTENTS =              2016;

	/** Illegal pattern array for string pattern matching.
	Args: (1) the pattern. */

	static final public int RT_ERR_BAD_PATTERN =               2017;

	/** An attempt was made to evaluate a block or method with the
        wrong number of arguments.
	Args: (1) the block or method; (2) the expected number of arguments;
	(3) the number of arguments used. */

	static final public int RT_ERR_BAD_BLOCK_ARG_COUNT =       2018;

       /** An attempt was made to access elements of an empty Collection.
	Args: (1) the collection. */

	static final public int OBJ_ERR_COLLECTION_EMPTY =         2019;

	/** An attempt was made to store a object other than a character
	into a string.
	Args: (1) the object to be stored. */

	static final public int RT_ERR_ARG_NOT_CHR =               2020;

	/** A reference into a dictionary using a non-existent key was made.
	Args: (1) the dictionary; (2) the key. */

	static final public int RT_ERR_KEY_NOT_FOUND =             2021;

	/** Invalid arguments given to DateTime instance creation.  
            Args: none. */

	static final public int RT_ERR_BAD_DATE_TIME_ARGS =        2022;

        /** Generic error from kernel class method.
             Args: (1) message String. */

	static final public int RT_ERR_GENERIC_KERNEL_ERROR =   2023;

	/** A breakpoint was specified for deletion that does not exist
	   in the breakpoint table.  Args: none. */

	static final public int RT_ERR_NO_SUCH_BP =                2024;

	/** The system was unable to create the given file.
	   Args: (1) the filename. */

	static final public int REP_ERR_CANT_CREATE_FILE =         2025;

       /** An attempt was made to divide an integer by zero.
  	   Args: (1) the number. */

	static final public int NUM_ERR_INT_DIVISION_BY_ZERO =     2026;

       /** An attempt was made to add a special or uncommitted object
           to the NotifySet.
           Args: (1) the object that is special or uncommitted. */

	static final public int RT_ERR_SPECIAL_OR_NOT_COMMITTED =  2027;

       /** The given extent could not be created because an attempt
	   to pre-grow the file failed for disk capacity reasons.
	   Args: (1) the filename. */

	static final public int REP_ERR_PRE_GROW_FAILURE =         2028;

       /** An attempt was made to begin a new transaction when already
          in a transaction.
          Args: none.  */

	static final public int RT_ERR_BEGIN_TRANS =              2029;


       /** An attempt was made to execute a primitive that is disallowed
          when not inside of a transaction.  Examples are commit, backup and
          restore.
          Args: none.  */

	static final public int RT_ERR_PRIM_OUTSIDE_TRANS =     2030;

	/** An attempt was made to change an invariant object.
	Args: (1) the object. */

	static final public int OBJ_ERR_INVARIANT =                2031;

	/** An attempt was made to create a method category 
            that already exists.
	Args: (1) the class; (2) the category. */

	static final public int CLASS_ERR_METH_CAT_EXISTS =        2032;

	/** A reference was made to a selector that could not be found
  	    in a class's method dictionary.
	Args: (1) the class; (2) the selector. */

	static final public int CLASS_ERR_SELECTOR_NOT_FOUND =     2033;

	/** The user is not allowed to remove a lock on an object that they
           do not have a lock on.
	Args: (1) the object for which the user 
                  was trying to remove the lock. */

	static final public int LOCK_ERR_REMOVE =                  2034;

	/** In searching a class, the specified category name was not found.
	Args: (1) the class; (2) the category. */

	static final public int CLASS_ERR_METH_CAT_NOT_FOUND =     2035;

	/** An attempt was made to create a byte subclass with instance
	variables.
	Args: (1) the superclass of the intended new class. */

	static final public int CLASS_ERR_BYTE_OBJ_INST_VARS =     2036;

	/** A constraint was specified incorrectly for subclass creation.
	A constraint must be specified as a class for Nscs or an array of
	pairs for pointer classes.
	Args: (1) the constraint argument. */

	static final public int CLASS_ERR_CONSTRAINT_NOT_CLASS =   2037;

	/** An attempt was made to create a variant subclass of an invariant
	class.  Args: none. */

	static final public int CLASS_ERR_INVARIANT_SUPERCLASS =   2038;

	/** An attempt was made to create an indexable subclass 
            of an Nsc class.
	Args: (1) the class. */

	static final public int CLASS_ERR_NSC_NOT_INDEXABLE =      2039;

	/** The given extent was not part of the logical repository.
	Args: (1) the extent name or extentId. */

	static final public int REP_ERR_EXTENT_NOT_MOUNTED =       2040;


	/** The attempt to schedule pages for scavenging failed because
	    some other session was using the commit token.  Try again later. */

	static final public int RT_ERR_PAGES_NEED_SCAVENGING =     2041;


	/** An attempt was made to create an Nsc subclass with instance
	variables.
	Args: (1) the class. */

	static final public int CLASS_ERR_NSC_INST_VARS =          2042;

	/** An attempt was made to create a new class variable with the same
	name as an existing class variable.
	Args: (1) the class; (2) the variable name. */

	static final public int CLASS_ERR_CLASS_VAR_NAME_EXISTS =  2043;

	/** An attempt was made to add a dictionary to a shared pool
	in which it was already a member.
	Args: (1) the class of the pool; (2) the dictionary. */

	static final public int CLASS_ERR_POOL_DICT_EXISTS =       2044;

	/** An attempt was made to remove a dictionary from a shared pool in
	which it was not a member.
	Args: (1) the class of the pool; (2) the dictionary. */

	static final public int CLASS_ERR_POOL_DICT_NOT_FOUND =    2045;

	/** During clamp compilation, an instance variable clamp was
	encountered for a non-existent instance variable.
        Args: (1) the class (2) the instance variable name. */

	static final public int CLAMP_ERR_NO_SUCH_INSTVAR =        2046;

	/** An object was specified for class or instance variable clamping
	that was not a class object. 
        Args: (1) the object. */

	static final public int CLAMP_ERR_NOT_A_CLASS =            2047;

	/** In an attempt to perform clamped object traversal, a
	ClampSpecification object was expected, but the specified object
	was of the wrong class.
	Args: (1) the object. */

	static final public int CLAMP_ERR_NOT_A_CLAMPSPEC =        2048;

	/** An argument to a clamp specification method had a bad size or
	implementation. 
        Args: (1) the argument object. */

	static final public int CLAMP_ERR_BAD_ARG =                2049;

	/** The given extent already has a replicate online.
	Args: (1) filename of the existing replicate. */

	static final public int REP_ERR_REPLICATE_ONLINE =         2050;

	/** The given maximum extent size is smaller than the minimum size
	   of an extent.  
        Args: (1) the invalid size, 
              (2) the minimum size allowed for an extent. */

	static final public int REP_ERR_BAD_EXTENT_SIZE =          2051;

	/** The given file could not be opened.  
        Args: (1) the name of the file. */

	static final public int REP_ERR_CANT_OPEN_FILE =           2052;

	/** An instance variable was not found in evaluating a path expression
	for an object.
	Args: (1) the object in the path where the failure occurred;
	      (2) the name of the instance variable. */

	static final public int RT_ERR_NO_SUCH_INST_VAR =          2053;

	/** An attempt was made to put a tag on a special object, which is
	   not allowed.
	Args: (1) the special object. */

	static final public int RT_ERR_TAG_NOT_ALLOWED =           2054;

	/** The tag number specified is not allowed, legal values are 1 and 2.
	Args: (1) the object on which the tag was being added;
	      (2) the tag number specified.  */

	static final public int RT_ERR_BAD_TAG_NUM =               2055;

	/** An attempt was made to add a group to a segment that already
	    recognizes four groups.
	Args: (1) the segment; (2) the group. */

	static final public int SEG_ERR_MAX_SEG_GROUPS =           2056;

	/** An attempt was made to change the authorization for a segment to an
	unrecognized value. (The only possible values are: #read, #write,
	or #none.)
	Args: (1) the segment; (2) the symbol. */

	static final public int SEG_ERR_BAD_AUTH_KIND =            2057;

	/** Unsatisified forward references exist that were created by
	    GciCreate or GciStore. This error prevents commit.
	    GciCreate must be used to create objects that satisfy 
            the references.
	Args: (1) The oop of one of the objects that was not yet created. */

	static final public int RT_ERR_UNDEF_POM_OBJ =             2058;

	/** GemStone Smalltalk execution stack overflow. 
            Not trappable in StDB .
	Args: none.  */

	static final public int RT_ERR_STACK_LIMIT =               2059     ;

	/** A negative or non-numeric was found where a positive numeric
	was expected.
	Args: (1) the value. */

	static final public int RT_ERR_ARG_NOT_POSITIVE =          2060;

	/** An argument was too large or out of range.
	Args: (1) the argument. */

	static final public int RT_ERR_ARG_OUT_OF_RANGE =          2061;

        /** A constraint cannot be changed in a Dictionary that is not empty.*/

	static final public int RT_ERR_CANT_CHANGE_CONSTRAINT =    2062;

	/** An error was signalled for which there is no message.
	Args: (1) the LanguageDictionary; (2) the error. */

	static final public int RT_ERR_NO_MESSAGE =                2063;

        /** An attempt was made to coerce an integer into 
            a kind of Character, but its value was not in range.
        Args: (1) the integer. */

	static final public int NUM_ERR_ARG_NOT_CHR =             	2064;

        /** An unrecognized float exception was specified.  Legal float
        exceptions are: 'divideByZero', 'inexactResult', 'invalidOperation',
        'overflow', and 'underflow'.
        Args: (1) the specified exception. */

	static final public int NUM_ERR_ARG_NOT_FLT_EXCEPTION =   	2065;


	/** A floating point exception has been raised.  Arg:
	 (1) The type of floating point exception (a String);
	 (2) The selector that generated the exception;
         (3) the default result;
	 (4-10) arguments to the original operation. */

	static final public int NUM_ERR_FLT_EXCEPTION =            2066;

	/** An unrecognized float rounding mode was specified.  
            Legal modes are:
	    'nearestEven', 'towardMinusInfinity', 'towardPlusInfinity', and
	    'towardZero'.
	Args: (1) the specified rounding mode. */

	static final public int NUM_ERR_ARG_NOT_ROUNDING_MODE =    2067;

	/** An attempt was made to change the segment of a special object or
        a symbol. Segment changes are not allowed for special objects or
        symbols.
	Args: (1) the object. */

	static final public int SEG_ERR_CANT_MOVE_OBJ =            2068;

	/** An attempt was made to remove an unlinked exception.
	Args: (1) the exception. */

	static final public int RT_ERR_EXCEPTION_NOT_LINKED =      2069;

        /** An invalid float status was specified.  
        Args: (1) the float status. */

	static final public int NUM_ERR_ARG_NOT_FLT_STATUS =       2070;

	/** The lock kind specified was invalid.
	Args: (1) the object upon which the lock was requested;
	      (2) kind of lock requested. */

	static final public int LOCK_ERR_UNDEFINED_LOCK =          2071;

// RT_ERR_HARD_STACK_LIMIT 2072 deleted

	/** One or more of the objects you requested had a lock error.
	Args:(1)  objects that were not locked i.e., LOCK_ERR_DENIED
		  (an Array);
	     (2)  objects that were locked but have new values
		  i.e., LOCK_ERR_OBJ_HAS_CHANGED (an Array);
	     (3)  special objects 
		  i.e., LOCK_ERR_SPECIAL (an Array). */

	static final public int LOCK_ERR_INCOMPLETE =              2073;

	/** A requested lock was granted, but the object has changed value
	   since you started this transaction.
	   Args (1) object upon which lock was requested. */

	static final public int LOCK_ERR_OBJ_HAS_CHANGED =         2074;

	/** A requested lock was denied. 
        Args (1) object upon which lock was requested;
             (2) the kind of lock requested (#read, #write, or #exclusive). */

	static final public int LOCK_ERR_DENIED =                  2075;

        /** A request to create a new clusterbucket exceeded the maximum
	   size allowed for a clusterId.
	   Args: (1) The max size. */

	static final public int RT_ERR_MAX_CLUSTER_ID =            2076;

	/** An attempt was to signal an error that has a bad format,
	   but it has a non-positive error number. 
        Args:
	   (1) the error number;
	   (2) the original error list (an Array);
           (3) the SymbolDictionary. */

	static final public int RT_ERR_BAD_ERR =                   2077;

	/** An attempt was made to add a UserProfile to a UserProfileSet that
	already has an entry with the same userId.
	Args: (1) the set; (2) the userId. */

	static final public int RT_ERR_USER_ID_ALREADY_EXISTS =    2078;

	/** GemStone Smalltalk execution could not return from the current
         activation.
        The activation or process to return to may no longer be active.
	Args: none (the Process will contain the stack in which the return
  			failed).  */

	static final public int RT_ERR_CANT_RETURN =               2079;

	/** An illegal attempt was made to change the class of an object.
	The new class must be a direct subclass of the object's class and
	have the same implementation and constraints.
	Args: (1) the object; (2) the new class. */

	static final public int RT_ERR_CANT_CHANGE_CLASS =         2080;

	/** An attempt was made to use become with an object that
           is a special object.
	Args: (1) the object. */

	static final public int RT_ERR_CANT_BECOME_SPECIAL =       2081;

	/** Attempt to run mark for collect when not the only user on the
	   system AND the concurrency mode is set for no read set. */

	static final public int RT_ERR_GARBAGE_COLLECT =           2082;

        /** a method was invoked that calls a non-existent primitive.
         Args: (1) the primitive number.  */

	static final public int RT_ERR_PRIM_NOT_FOUND =            2083;

        /** An attempt was made to directly access the instance variables of
        an object with instVarAt: or instVarAt:put:, but the object has no
        instance variables.
        Args: (1) the object. */

	static final public int RT_ERR_NO_INST_VARS =              2084;

	/** The virtual machine expected a boolean to be on top of the stack
	but found something else.
	Args: (1) the object on top of the stack. */

	static final public int RT_ERR_EXPECTED_BOOLEAN =          2085;

        /** GciDirtyObjsInit must be executed at least once 
            before GciDirtyObjs. */

	static final public int RT_ERR_DIRTY_OBJS_NEEDS_INIT =   2086;

        /** An attempt was made to change the password for another
        UserProfile with oldPassword:newPassword:.  Use password: instead.
        Args: (1) the UserProfile. */

	static final public int RT_ERR_CANT_CHANGE_PASSWORD =    	2087;

        /** The value specified for the new stack limit is smaller than
	    the current size of the execution stack.
        Args: (1) new stack limit value. */

	static final public int RT_ERR_NEW_STACK_LIMIT =   2088;

        /** An index range was specified for a sequenceable collection with the
        starting index greater than the ending index.
        Args: (1) the starting index; (2) the ending index. */

	static final public int RT_ERR_BAD_COPY_FROM_TO =          2089;

        /** An illegal attempt was made to store nil
	   as a key in a KeyValueDictionary. */

	static final public int RT_ERR_NIL_KEY_VALUE_DICT_KEY =         2090;

        /** Attempt was made to use become on two objects that both participate
	    in indexes and are not of the same class.
        Args: (1) obj1; (2) obj2. */

	static final public int RT_ERR_CANT_BECOME_BOTHIDX =     2091;

	/** The Process specified from which to continue is invalid.
	Args: (1) the Process. */

	static final public int RT_ERR_NO_PROCESS_TO_CONTINUE =    2092;

	/** An attempt was made to set the Stream position beyond the
	limits of the collection.  The position must be in the range of
	1 to collection size + 1.
	Args: (1) the stream; (2) the position. */

	static final public int RT_ERR_BAD_STREAM_POSITION =       2093;

	/** The specified object was not of the expected class kind.
	Args: (1) the object; (2) the expected class. */

	static final public int RT_ERR_BAD_ARG_KIND =              2094;

	/** An attempt was made to remove a class variable that did not exist.
	Args: (1) the class; (2) the variable name. */

	static final public int CLASS_ERR_CLASS_VAR_NOT_FOUND =    2095;

	/** detect: was sent to a collection, but no elements of the
	 collection satisfied the block.
	Args: (1) the collection; (2) the block. */

	static final public int ASSOC_ERR_NO_ELEMENTS_DETECTED =   2096;

	/** A symbol was not resolvable as a variable within a class
	(i.e., an instance variable, class variable, or pool variable).
	Args: (1) the class; (2) the symbol. */

	static final public int CLASS_ERR_NOT_A_VAR =              2097;

	/** A collection of groups was specified that held more than
	 four members.
	Args: (1) the collection.  */

	static final public int SEG_ERR_TOO_MANY_GROUPS =          2098;

	/** An attempt was made to store into a byte object something other
	than a SmallInteger in the range 0-255.
	Args: (1) the object being stored. */

	static final public int RT_ERR_EXPECTED_BYTE_VALUE =       2099;

	/** A class creation was attempted with an illegal representation.
	Args: (1) the potential class name. */

	static final public int CLASS_ERR_BAD_FORMAT =             2100;

	/** The object does not exist.  
        Args: (1) Integer value of objectId, trappable only by 
                  an Exception specifying exactly this error. */

	static final public int OBJ_ERR_DOES_NOT_EXIST =           2101;

	/** The object is not implemented as a pointer object.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_OOP_KIND =             2102;

	/** The object is not implemented as a byte object.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_BYTE_KIND =            2103;

	/** The object is not implemented as an Nsc object.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_NSC_KIND =             2104;

	/** An attempt was made to create an object that already exists.
	Args: (1) the object;
              (2) object identifier of the object. */

	static final public int OBJ_ERR_ALREADY_EXISTS =           2105;

	/** An attempt was made to store a forward reference using an oop
	  that has not been allocated to the session.
	Args: (1) the object identifier. */

	static final public int OBJ_ERR_OOP_NOT_ALLOCATED =        2106;

	/** An object of the wrong class was stored into a constrained instance
	variable.
	Args: (1) the object being modified; 
              (2) object stored;
	      (3) the highest allowable class; 
              (4) the class of the object stored. */

	static final public int OBJ_ERR_CONSTRAINT_VIOLATION =     2107;

	/** The specified object was expected to be a class but was not.
	Args: (1) the object. */

	static final public int RT_ERR_EXPECTED_CLASS =            2108;

	/** An attempt was made to create a pointer object for a class which
	    does not specify pointer object format.
	Args: (1) the class. */

	static final public int OBJ_CLASS_NOT_OOP_KIND =           2109;

        /** An object was indexed using structural access with a index
        that was out of range.  The minimum index is 1.  The maximum is
        specified by an argument.
        Args: (1) the object;
              (2) the maximum index; 
              (3) the specified index. */

	static final public int OBJ_ERR_BAD_OFFSET =               2110;

	/** An attempt was made to create an instance of a class
	that does not allow "new".
	Args: (1) the class. */

	static final public int OBJ_ERR_CANT_CREATE_INSTANCE =     2111;

	/** An attempt was made to create a byte object for a class which
	 * does not specify byte object format.
	Args: (1) the class. */

	static final public int OBJ_CLASS_NOT_BYTE_KIND =          2112;

	/** An argument to a locking primitive was too large. */

	static final public int LOCK_ERR_ARG_SIZE =               2113;

	/** The object is not implemented as a special object.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_SPECIAL_KIND =         2114;

	/** An attempt was made to read an object with insufficient
       authorization.
	Args: (1) the object; (2) its segment. */

	static final public int AUTH_ERR_SEG_READ =                2115;

      /** An attempt was made to modify an object with insufficient
	authorization.
	Args: (1) the object; (2) the segment. */

	static final public int AUTH_ERR_SEG_WRITE =               2116;

      /** An operation was attempted on an object that is legal only
	on pointer or Nsc objects.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_OOP_OR_NSC =           2117;

      /** A selector was sent to an object whose class is obsolete.
         Args: (1) the object;
               (2) the selector. */

	static final public int RT_ERR_OBSOLETE =                  2118;

        /** Attempt to use become when one object is indexed, and the
	   other object is not the same format as the indexed object.
         Args: (1) indexed object; (2) other object. */

	static final public int RT_ERR_CANT_BECOME_ONEIDX =        2119;

	/** Through the GCI, a request was made to convert a float object
	into another representation.  The object given, however, was not
	a float.
	Args: (1) the object. */

	static final public int OBJ_ERR_NOT_FLT =                  2120;

        /** Attempt to use become on an object that is used internally
           by the virtual machine.
         Args: (1) the object; (2) the class. */

	static final public int RT_ERR_CANT_BECOME_CLASSKIND =     2121;

	/** You may not create a byte subclass of the given class.
	Args: (1) the superclass of the intended new class. */

	static final public int CLASS_ERR_BYTE_SUBCLASS =     2122;

        /** an invalid swizzle transform was detected in a backup file.
          Args: (1) longTransform; (2) shortTransform. */

	static final public int REP_ERR_BAD_BKUP_SWIZZLE =  2123;

	/** The specified repository could not be created.
	Args: (1) the repository name. */

	static final public int REP_ERR_CANT_CREATE_REPOS =        2124;

	/** The given file spec was invalid.  
           (Is the logical directory defined? Is the filename in host format?)
	Args: none. */

	static final public int REP_ERR_BAD_FILE_SPEC =            2125;

	/** A file already exists with the given name.
	Args: none. */

	static final public int REP_ERR_FILE_ALREADY_EXISTS =      2126;

        /** Key already exists in a dictionary. 
        Args: (1) the dictionary; (2) the key. */

	static final public int RT_ERR_DUPLICATE_KEY =  2127;

	/** The evaluation of a selection block resulted 
            in an illegal comparison being performed.
	Args: none. */

	static final public int ASSOC_ERR_BAD_COMPARISON =         2128;

	/** The repository version does not match the version of GemStone
	    currently being run.
	Args: none. */

	static final public int REP_ERR_INCOMPATIBLE_REPOS =       2129;

	/** An attempt was made to create an index where the class of one
	    of the terms in the path is a class that is still modifiable.
	Args: 1) the class. */

	static final public int ASSOC_ERR_CLASS_MODIFIABLE =       2130;

	/** The specified constraint is not a subclass of an inherited
	    constraint for an inherited instance variable or indexable part.
	    Args: (1) the specified constraint; 
                  (2) the inherited constraint;
	          (3) the offset.  */

	static final public int CLASS_ERR_CONSTR_INHER =           2131;

	/** The constraint field was invalid in subclass creation.
	Args: none. */

	static final public int CLASS_ERR_BAD_CONSTRAINT =         2132;

        /** an incompatible file version was detected in a backup file.
          Args: (1) version. */

	static final public int REP_ERR_BAD_BKUP_VERSION =  2133;

        /** A structural access retrieval used an index
        that was out of range.  The minimum index is 1.  The maximum is
        size of object(for singular fetch) or size + 1 (for plural fetch).
        Args: (1) the object; (2) object size; (3) the specified index. */

	static final public int OBJ_ERR_BAD_FETCH_OFFSET =               2134;

        /** Attempt to use become on an object that is a kind of Bag
           while the object has indexed paths.
         Args: (1) the object.  */

	static final public int RT_ERR_CANT_BECOME_INDEXED_NSC =  2135;

        /** An index with the path was not found for the Nsc.
	  Args: (1) the path string. */

	static final public int RT_ERR_NO_INDEX_FOR_PATH =  2136;

	/** An attempt was made to create a pointer object for a class which
	    does not specify pointer object format.
	Args: (1) the class. */

	static final public int OBJ_CLASS_NOT_OOP_OR_NSC_KIND =           2137;

        /** Too many recursions from useractions to GemStone Smalltalk 
            or within object manager. */

	static final public int RT_ERR_MAX_RECURSION =                    2138;

	/** A session was specified that does not exist.
	Args: none. */

	static final public int RT_ERR_BAD_SESSION =                      2139;

	/** An operation that needs exclusive use of the system was
	 attempted when other users were logged in.
	 Args: (1) number of users logged in. */

	static final public int RT_ERR_NOT_ONLY_USER =                    2140;

	/** An attempt was made to extend an object to larger than
	the maximum allowable size.
	Args: (1) the object; (2) the maximum size; (3) the specified size. */

	static final public int OBJ_ERR_MAX_SIZE =                 2141;

        /** The virtual machine cannot execute a method 
            until it has been upgraded to a 4.0 or higher version.
        Args: (1) the invalid CompiledMethod */

	static final public int RT_ERR_INVALID_METHOD =            2142;

	/** An attempt was made to attach more repositories than can
	be on-line at one time.
	Args: none. */

	static final public int REP_ERR_MAX_ONLINE_REPOS =         2143;

        /** In attempting to reset the maxSessionId for the queue to a
           smaller value,  an entry was found that was added by a session
           whose sessionId is larger than the value currently being set.
           Remove and save all entries in the queue.  Then changeMaxSessionId
           and add the saved entries back into the queue.
	Args: none. */

	static final public int RT_ERR_RCQUEUE_ENTRIES_FOUND =  2144;

	/** The first term in an Nsc index path expression cannot indicate
            a set-valued instance variable (i.e. cannot be an asterisk). */

	static final public int RT_ERR_FIRST_PATH_TERM_SET_VALUED =     2145;

	/** The attempted GCI operation is illegal in a user action
	    when applied to a session inherited from a parent GemStone 
            Smalltalk or GCI scope. */

	static final public int GCI_ERR_PARENT_SESSION =           2146;

	/** An attempt was made to log in after the session was already
	    established.
	Args: none. */

	static final public int GCI_ERR_ALREADY_LOGGED_IN =        2147;

	/** An illegal identifier was used to name 
            an instance variable or class.
	Args: (1) the name. */

	static final public int CLASS_ERR_BAD_IDENTIFIER =         2149;


        /** Illegal attempt to constrain a private instance variable.
         Args: (1) name of the instance variable. */

	static final public int CLASS_ERR_CONSTR_PRIVATE_IV =      2150;

	/** An attempt was made to do a privileged operation for which no
	privilege had been granted.
	Args: none. */

	static final public int RT_ERR_NO_PRIV =                   2151;

	/** The btree read stream is invalid (possibly due to modifications
           to objects referenced by the stream).
	 Args: none. */

	static final public int RT_ERR_INVALID_BTREE_READ_STREAM = 	2152;

        /**  An RcPositiveCounter cannot be decremented to a negative value. */

	static final public int RT_ERR_DECR_NOT_ALLOWED =  	2153;

	/** The repository referenced is not attached.
	Args: (1) the repository. */

	static final public int REP_ERR_REPOS_NOT_ATTACHED =       2154;

	/** The repository could not be attached because it was left
	in an inconsistent state.  A recovery program must be run on it.
	Args: (1) the repository. */

	static final public int REP_ERR_REPOS_NEEDS_RECOVERY =     2155;

	/** The replicate referenced is not mounted.
	Args: (1) the replicate. */

	static final public int REP_ERR_REPLICATE_NOT_MOUNTED =    2156;

	/** A read error was detected when reading from the repository.
	Args: (1) the page number; 
              (2) the filename of the repository extent. */

	static final public int REP_ERR_REPOS_READ =               2157;

	/** A write error was detected when writing to the repository.
	Args: (1) the page number 
              (2) the filename of the repository extent. */

	static final public int REP_ERR_REPOS_WRITE =              2158;

        /** An object migration could not occur because of a constraint
           migration. 
        Args: (1) the object; 
              (2) instVar value; 
              (3) constraint on instVar value required by destination class. */

	static final public int RT_ERR_MIGRATION_CONSTRAINT =      2159;

        /** The selectiveAbort primitive was attempted on an object that
           is involved in an index.
        Args: (1) the object on which the selectiveAbort was attempted. */

	static final public int RT_ERR_SELECTIVE_ABORT =           2160;

	/** The DateTime passed is either out of range for a time_t, or
	   the julianSeconds field is not between 0 and 86399 inclusive.
	Args: none. */

	static final public int OBJ_ERR_DATETIME_OUT_OF_RANGE =    2161;

	/** The integer passed to gciIntToObject was outside the range of
	SmallIntegers.
	Args: none. */

	static final public int OBJ_ERR_LONG_NOT_SMALL_INT =       2162;

	/** gciObjectToInt was passed an object which was not a SmallInteger.
	Args: none. */

	static final public int OBJ_ERR_NOT_LONG =                 2163;

	/** The argument to a GCI object to character conversion was not
           an instance of Character, or is out of range of the result.
	  Args: none. */

	static final public int OBJ_ERR_NOT_CHR =                  2164;

        /** compress() in the zlib library failed.
        Args: (1) error code. */

	static final public int LGC_ERR_COMPRESS_FAILURE =         2165;

        /** uncompress() in the zlib library failed.
        Args: none. */

	static final public int LGC_ERR_UNCOMPRESS_FAILURE =         2167;

        /** travBuffSwizzle() in the linkgc.hc module failed.
        Args: none. */

	static final public int LGC_ERR_TRAVSWIZZ_FAILURE =         2167;

        /** The object (arg 1) is too large. 
            The maximum allowed size is (arg 2). */

	static final public int RT_ERR_ARG_TOO_LARGE =              2168;

// 2169 to 2170 not used

        /** An attempt to load a user action library failed.
        Args: (1) C string explaining why load failed. */

	static final public int RT_ERR_UALIB_LOAD_FAILED =  2171;

        /** Mismatch in size of GciObjRepHdrSType, problems with C compiler
            used to build a client GCI perhaps. 
        Args: none. */

	static final public int LGC_ERR_OBJREPHDR_SIZE =   2172;

	/** An attempt was made to write to a segment with insufficient
	   authorization.
	Args: (1) the segment. */

	static final public int AUTH_ERR_SEG_WRITE_SEG =           2173;

	/** An attempt was made to read from a segment with insufficient
	authorization.
	Args: (1) the segment. */

	static final public int AUTH_ERR_SEG_READ_SEG =            2174;

	/** A path was specified with more than 1024 characters.
	Args: (1) the path. */

	static final public int ASSOC_ERR_PATH_TOO_LONG =          2175;

	/** The filename is too large.
	Args: (1) the filename; (2) maximum size. */

	static final public int REP_ERR_FILE_NAME_TOO_BIG =        2176;

        /** A semaphore operation failed.
        Args: (1) the semaphore index;
              (2) the message returned by the underlying system routine. */

	static final public int RT_ERR_SEMAPHORE =                 2177;

	/** A password was specified with more than 255 characters.
	Args: none. */

	static final public int RT_ERR_PASSWORD_TOO_BIG =          2178;

        /** Become is not allowed because the classes of the two objects do
          not have identical class histories.
          Args: (1) anObject; (2) anObject. */

	static final public int RT_ERR_CLASS_HISTORY_MISMATCH =   2179;

	/** A Class has more than 1500 methods in its method dictionary.
	Args: (1) the class. */

	static final public int CLASS_ERR_METH_DICT_LIMIT =        2180;

        /** An error occurred while detaching from the SharedPageCache.
        Args: (1) an error message returned from the lower levels.  */

	static final public int RT_ERR_SHR_PC_DETACH =             2181 ;

	/** Unable to dispose of the replicate.
	Args: (1) the replicate name. */

	static final public int REP_ERR_CANT_DISPOSE =             2182;

        /** SYSTEM ERROR: A system runtime error was detected.
        Args: (1) the system error number; 
              (2..n) error-specific arguments. */

	static final public int RT_ERR_INTERNAL =                  2183;

        /** A stream was accessed to create an instance of a class,
        but the collection of the stream was not of the proper class kind.
        Args: (1) the class; 
              (2) the stream; 
              (3) the expected collection class kind. */

	static final public int RT_ERR_STREAM_NOT_ON_A_COLL =    	2184;

        /** An object was being read from a string or stream, but the 
            format was not correct to read an object of the specified class.
        Args: (1) the class; (2) the string or stream. */

	static final public int RT_ERR_BAD_FORMAT =          	2185;

        /** The compatibility level of the SharedPageCache Monitor does
           not match that of the executable trying to attach.
        Args: (1) compatibility level of the SharedPageCache Monitor;
              (2) compatibility level of this process. */

	static final public int RT_ERR_SHRPC_COMPATIBILITY =       2186;

	/** A group name was specified that was not in AllGroups.
	Args: (1) the group name. */

	static final public int SEG_ERR_BAD_GROUP =                2187;

	/** A privilege was specified that was not a valid privilege string.
	Args: (1) the privilege string. */

	static final public int RT_ERR_BAD_PRIV =                  2188;

	/** GciResolveSymbol failed to find the specified C string or symbol.
	Args: none. */

	static final public int RT_ERR_RESOLVE_SYM_FAILED =        2189;

	/** The specified symbol was already defined.
	Args: (1) the UserProfile of the current session;
              (2) the symbol. */

	static final public int RT_ERR_SYM_ALREADY_DEFINED =       2190;

	/** The symbol could not be found in the symbol list of the specified
 	    UserProfile.
	Args: (1) the UserProfile; (2) the symbol. */

	static final public int RT_ERR_SYM_NOT_FOUND =             2191;

	/** End-of-file was encountered on a ReadStream.
	Args: (1) the stream. */

	static final public int RT_ERR_EOF_ON_READ_STREAM =        2192;

	/** A sorting array was specified that was not 
            an even number of elements long.
	Args: (1) the array. */

	static final public int ASSOC_ERR_SORT_ODD_LENGTH_ARRAY =  2193;

	/** A sorting direction was specified that was not ASCENDING or
	DESCENDING.
	Args: (1) the direction specified. */

	static final public int ASSOC_ERR_BAD_DIRECTION =          2194;

        /** An attempt was made to modify a configuration parameter that
         * is read-only while the system is running.
         * Args: (1) name of parameter. */

	static final public int RT_ERR_CONFIG_PARM_READ_ONLY =     2195;

	/** An illegal formatting array was specified for the given class.
	Args: (1) the class; (2) the array. */

	static final public int RT_ERR_BAD_FORMAT_SPEC =           2196;

	/** The string cannot be exported to the specified file.
	Args: (1) the string; (2) the file name. */

	static final public int HOST_ERR_FILE_EXPORT =             2197;

       /** The specified file cannot be imported.
	Args: (1) the file name. */

	static final public int HOST_ERR_FILE_IMPORT =             2198;

	/** Cannot fetch the server OS directory.
	Args: (1) the directory name. */

	static final public int HOST_ERR_FILE_DIRECTORY =          2199;

	/** The specified file cannot be deleted.
	Args: (1) the file name. */

	static final public int HOST_ERR_FILE_DELETE =             2200;

	/** The specified string cannot be executed in the OS shell.
	Args: (1) the string. */

	static final public int HOST_ERR_PERFORM =                 2201;

	/** The message was too long.
	Args: (1) the message string;
              (2) the size of the string;
	      (3) the maximum size allowed. */

	static final public int RT_ERR_SIG_MSG_TOO_BIG =           2202;

	/** A GCI operation was attempted before a previous nonblocking
	   operation was completed.
	Args:  (1) an integer representing 
                   the current operation in progress. */

	static final public int GCI_ERR_OP_IN_PROGRESS = 		2203;

        /** A request was made to complete a non-blocking GCI call when
            no such call was initiated. */

	static final public int GCI_ERR_NO_START_CMD =   2204;

	/** The specified clusterId is invalid.  Cluster IDs must
	be in the range 1.. (AllClusterBuckets size).
	Args: (1) the invalid clusterId; 
              (2) possibly invalid aClusterBucket;
              (3) max allowed clusterId. */

	static final public int OBJ_ERR_BAD_CLUSTER_BUCKET =       2205;

	/** The number of elements in the array used to set the Epoch
            Garbage Collector information is incorrect. The size should be 4.
        Args: (1) the array. */

	static final public int RT_ERR_EPOCH_GC_ARRAY_SIZE =           2206 ;

	/** An attempt was made to increase the size of an NSC 
            beyond the maximum(maxSmallInt).
	Args: none. */

	static final public int OBJ_ERR_RESULT_NSC_TOO_BIG =       2207;

	/**  Host memory allocation failed; there is insufficient
            primary memory and/or swap space.  (memory allocation failure
            in the C heap space used by GemStone or GCI).  */

	static final public int HOST_ERR_MEMORY_ALLOC =            2208;

	/** A non-existent catch buffer was specified.
	Args: none. */

	static final public int GCI_ERR_CATCH_BUFF_NOT_FOUND =     2209;

	/** The catch buffer level must be in the range 0 to 20.  An invalid
	level was specified.
	Args: none. */

	static final public int GCI_ERR_CATCH_BUFF_LIMIT =         2210;

	/** gciObjectToBool was passed an object that was not either True
	or False.
	Args: none. */

	static final public int OBJ_ERR_NOT_BOOLEAN =              2211;

        /** A method is obsolete and needs to be recompiled.
        Args: (1) selector; (2) class; (3) method.  */

	static final public int RT_ERR_UNCOMPILED_METHOD =         2212;

        /** Only SystemUser is allowed to perform this operation. 
        Args: none. */

	static final public int RT_ERR_MUST_BE_SYSTEMUSER =        2213;

	/** The given password is not the password of the userProfile.
	Args: (1) the userprofile. */

        /**  Specific errors related to object traversal on the GCI client. */

	static final public int RT_ERR_BAD_PASSWORD =              2214;

	/** The given object was not found within the given traversal buffer.
	Args: none  */

	static final public int GCI_ERR_TRAV_OBJ_NOT_FOUND =       2215;

	/** There exists no valid traversal because there was no 
            prior invocation of gciTraverseObjects or there has been 
            a modification to the database.
	Args: none. */

	static final public int GCI_ERR_TRAV_COMPLETED =           2216;

	/** The given traversal buffer length must be of sufficient size
	    to report at least one object.
	Args: none. */

	static final public int GCI_ERR_TRAV_BUFF_TOO_SMALL =      2217;

        /** Path to String conversion failed due to invalid instVar offset.
        Args: (1) 1-based index of the term in the path that failed;
	      (2) the invalid offset of the named instvar;
	      (3) the class on which invalid offset was applied;
	      (4) maximum legal offset. */

	static final public int RT_ERR_PATH_TO_STR_IVNAME =        2218;

	/** In a network call fetching elements out of an object a
	    negative count was specified.  
        Args: (1) the count. */

	static final public int OBJ_ERR_NEGATIVE_COUNT =           2219;

// errors related to path access calls for GCI

    /** In GciStrToPath, GciPathToStr, the result was larger than the C
	array specified to hold the result. 
    Args: (1) size of result;
	  (2) specified max size. */

	static final public int GCI_ERR_RESULT_PATH_TOO_LARGE =    2220;


    /** A path in GciFetchPaths failed due to another GemStone error.
	OOP_ILLEGAL appears as the result for that path. 
    Args: none. */

	static final public int GCI_ERR_FETCH_PATH_FAIL =          2221  ;

    /** String to path conversion failed due to invalid instVar name.
      Args: (1) 1-based index of the term in the path that failed;
	    (2) class in which the instVar lookup failed;
	    (3) the invalid instvar name. */

	static final public int RT_ERR_STR_TO_PATH_IVNAME =        2222;

    /** String to path conversion failed due to lack of constraints.
      Args: (1) 1-based index of the term in the path that was
	    not constrained. */

	static final public int RT_ERR_STR_TO_PATH_CONSTRAINT =    2223;

	/** Given command was not processed due to a hard break. 
        Args: none. */

	static final public int GCI_ERR_BREAK_CANCELED_MSG =       2224;

	/** The first byte of the two-byte synchronization sequence
	    was wrong in the network.  
        Args: none. */

	static final public int LGC_ERR_SYNC_1 =                   2225;

	/** The second byte of the two-byte synchronization 
            sequence was wrong in the network.
        Args: none. */

	static final public int LGC_ERR_SYNC_2 =                   2226;

	/** A byte array packet was received over the network that
	    was too long. */

	static final public int LGC_ERR_BYTE_PACKET_TOO_LONG =     2227;

	/** An array argument was received on the network that had a length
	    different from that specified with the argument. 
        Args: none. */

	static final public int LGC_ERR_ARG_SIZE_INCONSISTENT =    2228;

	/** An oop array packet was received over the network
	that was too long. */

	static final public int LGC_ERR_OOP_PACKET_TOO_LONG =      2229;

	/** A packet of the wrong kind was received.  
        Args: (1) the expected kind; 
              (2) the packet kind received. */

	static final public int LGC_ERR_PACKET_KIND_BAD =          2230;

	/** A packet kind was received other than the continue packet that
            was expected.  
        Args: (1) the packet kind received. */

	static final public int LGC_ERR_EXPECTED_CONTINUE =        2231;

	/** A packet kind was received other than the end packet that
            was expected.
	Args: (1) the packet kind received. */

	static final public int LGC_ERR_EXPECTED_END =             2232;

	/** An unknown packet kind was received.
	Args: (1) the packet kind. */

	static final public int LGC_ERR_PACKET_KIND_UNKNOWN =      2233;

	/** A packet kind was received other than the command packet that
            was expected.
	Args: (1) the packet kind received. */

	static final public int LGC_ERR_EXPECTED_CMD =             2234;

	/** Log file not opened before adding messages to it.
	Args: none. */

	static final public int HOST_ERR_LOG_FILE_NOT_OPENED =     2235;

	/** Attempt to create a subclass while specifying more than 255
	    instance variables.
	Args: (1) the superClass;
              (2) the array which specifies too many instance variables. */

	static final public int CLASS_ERR_MAX_INST_VARS =          2236;

	/** System|signal:args:signalDictionary: was sent with 
            an array argument containing more than 9 elements.
	Args: (1) the number of elements. */

	static final public int RT_ERR_TOO_MANY_ERR_ARGS =         2237;

	/** An attempt was made to create an object of an illegal
  	    size or change it to an illegal size.  This error occurs
	    in non-indexable pointer objects since their size must be
	    exactly the number of named instance variables.
	Args: (1) the class; 
              (2) the size;
              (3, if available) the object. */

	static final public int OBJ_ERR_BAD_SIZE =                 2238;

	/** When using the network interface, inconsistent information
	was given about the size of an object; i.e., the size was
	specified as one value but the data given implied another size.
	Args: (1) specified size;
              (2) the implied size. */

	static final public int LGC_ERR_INCONSISTENT_SIZE =        2239;

	/** When using the network interface, inconsistent information was 
        given about the implementation of an object; i.e., one implementation
        was specified but the class of the object had a different one.
	Args: (1) the class of the object;  
              (2) the specified implementation. */

	static final public int LGC_ERR_INCONSISTENT_OBJ_KIND =    2240;

        /** A process is already running as the GC user or the process
	    attempting to run the Reclaim or EpochGc is not the Gc process.
        Args: none.  */

	static final public int RT_ERR_START_GC =                  2241;

        /** The object is not one of the expected class kinds.
	Args: (1) the object; 
              (2) an expected class; 
              (3) an expected class. */

	static final public int RT_ERR_BAD_ARG_KIND_2 =              2242;

	/** Sequence number mismatch for an IPC response packet. */

	static final public int LGC_ERR_SEQUENCE_MISMATCH =        2243;

	/** A block does not have the number of arguments required for it
           to be usable as an exception block.
	Args: (1) the block; 
              (2) the required number of arguments;
	      (3) the actual number of arguments to the block. */

	static final public int RT_ERR_EXCEPT_BLOCK_NUM_ARGS =  2244 ;

         /** An illegal GCI store into a float object was detected.
             You must use GciStoreBytesInst with the correct class argument.
         Args: (1) the object. */

	static final public int RT_ERR_GCI_STORE_FLOAT =  2245;

        /** In Gci store traversal, the class in the object report of an
            existing object does not match the actual class of that object
            in the database.
         Args: (1) object;
               (2) class in buffer;
               (3) class in database. */

	static final public int RT_ERR_GCI_CLASS_MISMATCH =  2246;

        /** Commits are disallowed because the database is being
            restored from transaction logs and restoreFromCurrentLogs has not
            completed.  */

	static final public int RT_ERR_COMMIT_DB_IN_RESTORE =  2248;

        /** Commits are disallowed because an error occurred during 
            object manager recursion to GemStone Smalltalk. This session 
            must abort this transaction.  */

	static final public int RT_ERR_COMMIT_DISALLOWED =   2249;

        /** Gem commit failed due to a Transaction Log I/O Error. */

	static final public int ERR_LOG_IO_FAILURE =  		2250;

	/** Invalid IPC packet kind. */

	static final public int LGC_ERR_PACKET_KIND =              2251;

        /** Error during loading or saving GemStone Smalltalk execution stack.
            Execution cannot continue.
        Args: none. */

	static final public int RT_ERR_LOAD_SAVE_STACK =                2252;

        /** A unknown bytecode was encountered by the GemStone 
            Smalltalk execution subsystem.  Either a compiled method 
            is corrupt or there is an internal Bug.
        Args: (1) the bytecode. */

	static final public int RT_ERR_UNKNOWN_BYTECODE =  2253;

        /** An attempt was made to send a signal to a session, but the output
            buffer from stone to the target session is full.
        Args: (1) the target session Id.  */

	static final public int ERR_SESSION_BLOCKED_ON_OUTPUT =   2254;

        /** The primitive is not supported in this executable.
        Args: (1) receiver;
              (2) selector;
              (3) executable which DOES support the primitive. */

	static final public int ERR_PRIM_NOT_SUPPORTED =           2255;

	/** No authorization to write in your current segment;
	    resetting the current segment to your default login segment.
	Args: (1) the oop of the bad segment. */

	static final public int AUTH_ERR_SEG_CURRENT_SEG =         2256;

	/** No authorization to set the current segment to the given segment.
	Args: (1) the segment oop of the bad segment. */

	static final public int AUTH_ERR_SEG_SET_CURRENT_SEG =     2257;

	/** The primitive failed for the specified selector.
            This primitive should never fail.  
        Args: (1) the receiver; 
              (2) the selector. */

	static final public int ERR_PRIM_FAILED =                  2258;

	/** Invoke the client useraction with arguments:
	   (1) the action name;
           (2) reserved for internal use;
	   (3-10) the arguments to the action routine. 
           Normally not seen as an error, since it is sent by the gem 
           to the rpc client to invoke a useraction that the client 
           has registered with the gem.  */

	static final public int GCI_ERR_EXEC_CLIENT_USERACT =      2259;

	/** You attempted to install a user action, and there are GemStone
	   sessions already active.  
        Args:  none. */

	static final public int GCI_ERR_ACTIVE_SESSIONS =          2260;

	/** The object is corrupt or inconsistent.
        Args: (1) an Integer which is the object identifer 
                  of the corrupt object; 
              (2) string describing the kind of corruption.
        Trappable only be an Exception specifying exactly this error. */

	static final public int OBJ_ERR_CORRUPT_OBJ =         2261;

	/** You are requesting too many arguments for a user action.
	Args:  (1) The number of arguments requested;
               (2) The maximum number allowed. */

	static final public int GCI_ERR_MAX_ACTION_ARGS =          2262;

        /** You invoked a method or user action with the wrong number 
            of arguments.
        Args:  (1) The name of the method or user action;
               (2) number of arguments expected;
               (3) the number of arguments actually passed. */

	static final public int GCI_ERR_BAD_NUM_ACTION_ARGS =      2263;

	/** You attempted a GCI operation that is not legal during the
	   implementation of a user action.  
        Args: (1) The name of the user action. */

	static final public int GCI_ERR_USER_ACTION_PENDING =      2264;

	/** You invoked a local user action with the wrong number of arguments.
        Args:  (1) the number of arguments expected;
	       (2) the number of arguments actually passed. */

	static final public int GCI_ERR_BAD_NUM_LCL_ACTION_ARGS =  2265;

	/** An attempt was made to add a named instance variable to a class
	    whose format is NSC. 
        Args: (1) The class. */

	static final public int RT_ERR_INSTVAR_ADD_TO_NSC =        2266;

	/** An attempt was made to constrain the indexable portion of the
	    a class whose format is Bytes. 
        Args: (1) the class. */

	static final public int RT_ERR_VARYING_CONSTR_BYTES =      2267;

	/** An attempt was made to constrain the indexable portion of a class
	    which is not indexable. 
        Args: (1) the class. */

	static final public int RT_ERR_VARYING_CONSTR_NONIDX =     2268;

	/** An attempt was made to add a named instance variable to a class
	   whose format is Bytes. 
        Args: (1) the class. */

	static final public int RT_ERR_INSTVAR_ADD_TO_BYTES =      2269;

	/** An attempt was made to modify a class that is not modifiable.
	Args: (1) the class. */

	static final public int RT_ERR_CLASS_NOT_MODIFIABLE =      2270;

	/** The name of a new instance variable would duplicate the name
	   of an already existing instance variable. 
        Args: (1) the class in which the instVar already exists;
              (2) the name. */

	static final public int RT_ERR_ADD_DUP_INSTVAR =           2271;

	/** Class 1 is neither identical to nor a subclass of Class 2.
	Args: (1) Class 1;
              (2) Class 2. */

	static final public int RT_ERR_NOT_A_SUBCLASS_OF =         2272;

	/** In class modification, a new constraint was neither identical to,
	    nor a subclass of, an inherited constraint.
	Args: (1) the new constraint; 
              (2) the inherited constraint. */

	static final public int RT_ERR_CONSTR_NOT_SUBCLASS_OF =    2273;

	/** A new constraint was specified that is not a Class.
	Args: (1) the constraint. */

	static final public int RT_ERR_CONSTR_NOT_A_CLASS =        2274;

	/** An object that should have been variant is invariant.
	Args: (1) the object. */

	static final public int RT_ERR_OBJ_INVARIANT =             2275;

	/** During subclass creation, more than one constraint was specified
	    for the indexable part of a pointer object.
	Args: (1) the first constraint;  
              (2) the second constraint. */

	static final public int CLASS_ERR_DUP_VAR_CONSTR =         2276;

	/** A restore operation requires that logins be disabled.
	Args: none. */

	static final public int BKUP_ERR_LOGINS_ENABLED =          2277;

	/** An attempt was made to remove an instance variable from a class,
	    but the specified instance variable is inherited from a superclass.
	Args: (1) the class; 
              (2) the instance variable name. */

	static final public int CLASS_ERR_REMOVE_INHER_IV =        2278;

	/** An attempt was made to change to an invalid concurrency
	   control mode. */

	static final public int CONCUR_ERR_INVALID_MODE =          2279;

        /** A message sent to an object was not found in the proper class. */

	static final public int CLASS_ERR_SELECTOR_LOOKUP =        2280;

        /** The bytes of the EUCString are not in EUC format. 
        Args: (1) the invalid EUCString. */

	static final public int RT_ERR_BAD_EUC_FORMAT =            2281;

        /** A Gaiji character was encountered, but Gaiji is not supported
            by GemStone.  
        Args: (1) the JapaneseString containing the Gaiji character. */

	static final public int RT_ERR_GAIJI_NOT_SUPPORTED =       2282;

        /** The object is not one of the expected class kinds.
        Args: (1) the invalid argument;
              (2) an Array of acceptable classes. */

	static final public int RT_ERR_INVALID_ARG_CLASS =         2283;

        /** The object was referenced with a byte index that was out of range.
        Args: (1) the object;
              (2) the byte index. */

	static final public int RT_ERR_SIZE_LIMIT =                2284;

        /** The character does not have an EUC representation.
        Args: (1) the character. */

	static final public int RT_ERR_NO_EUC_REP =                2285;

        /** The EUC value is not valid and does not correspond to a
            JISCharacter. 
        Args: (1) the EUC value. */

	static final public int RT_ERR_BAD_EUC_VALUE =             2286;

        /** The compiler language environment is invalid. 
        Args: (1) the invalid language environment. */

	static final public int RT_ERR_INVALID_LANG =              2287;

        /** The given string is an invalid term in a path expression. */

	static final public int RT_ERR_INVALID_INDEX_PATH_EXPRESSION =  2288;

        /** A dependency list was too large. */

	static final public int RT_ERR_DEPENDENCY_LIST_TOO_LARGE =  2289;

        /** There were too many attempts to recommit after failing to resolve
            RC conflicts. */

	static final public int RT_ERR_MAX_COMMIT_RETRY =  2290;

        /** Argument (1) was an invalid argument to a method. */

	static final public int RT_ERR_INVALID_ARGUMENT =  2291;

        /** A class along a constrained path does not have an inst var
            corresponding to a term in an index path. */

	static final public int RT_ERR_PATH_NOT_TRAVERSABLE =  2292;

        /** An attempt was made to read beyond the end of the stream. */

	static final public int RT_ERR_BTREE_READ_STREAM_END_OF_STREAM =  2293;

        /** The object did not have the path term in its dependency. */

	static final public int RT_ERR_OBJECT_PATH_TERM_NOT_IN_DEPENDENCY_LIST =  2294;

        /** The object does not have an instance variable 
            with the given name. */

	static final public int RT_ERR_OBJECT_INVALID_INST_VAR_OFFSET =  2295;

        /** The object does not have a dependency list. */

	static final public int RT_ERR_OBJECT_HAS_NO_DEPENDENCY_LIST =  2296;

        /** An entry for the key/term/value was not present 
            in the dictionary. */

	static final public int RT_ERR_INDEX_DICTIONARY_ENTRY_NOT_IN_DICTIONARY =  2297;

        /** An object traversed along an index path through a set-valued
           inst var was not an Nsc. */

	static final public int RT_ERR_PATH_TERM_OBJECT_NOT_AN_NSC =  2298;

        /** An attempt was made to use a range operation 
	    (&lt; &gt; = &lt;= &gt;=) on a
            path expression only supported by an identity index. */

	static final public int RT_ERR_IDENTITY_INDEX_CANNOT_INVOKE_RANGE_OPERATION =  2299;

        /** Attempt to insert a key into the btree that was
            an invalid class for which the btree was created. */

	static final public int RT_ERR_RANGE_EQUALITY_INDEX_INVALID_CLASS_KIND_FOR_BTREE =  2300;

        /** An entry for the key/value was not present in the btree. */

	static final public int RT_ERR_RANGE_EQUALITY_INDEX_OBJECT_NOT_IN_BTREE =  2301;

        /** a backup or restore continuation was attempted without having
            executed restoreFrom: or fullBackupTo:MBytes:. */

	static final public int ERR_NO_BACKUP_IN_PROGRESS =  2302;

	/** An attempt to open a file failed.  
        Args: (1) (String) the full path name of the file;
              (2) (String) whether the file was being opened for read or write;
              (3) (String) the host error string. */

	static final public int BKUP_ERR_OPEN_FAILED =       2303;

        /** The byte limit may be zero (0), or must be within the range of
            1 Mbytes to 4,194 Mbytes.  
        Args: (1) (SmallInteger) specified byteLimit; 
              (2) (SmallInteger) minimum allowable byte limit;
              (3) (SmallInteger) maximum allowable byte limit. */

	static final public int BKUP_ERR_MBYTE_LIMIT_BAD_RANGE =  2304;

	/** An attempt to write to a file failed.  
        Args: (1) (String) the full path name of the file;
              (2) (String) the host error string. */

	static final public int BKUP_ERR_WRITE_FAILED =            2305;

        /** An attempt was made to do a full backup
            but a backup is currently in progress by
            another session.  Args: none. */

	static final public int BKUP_ERR_IN_PROGRESS =             2306;

	/** An attempt to read from a file failed.
        Args: (1) reason (a string);
              (2) filename;
              (3) recordId in file string. */

	static final public int BKUP_ERR_READ_FAILED =             2307;

        /** An attempt was made to create an index along the path with no
            constraint. */

	static final public int RT_ERR_BAG_NO_CONSTRAINT_ALONG_PATH =  2308;

        /** An attempt was made to create an equality index with a class
            that does not support range operators. */

	static final public int RT_ERR_BAG_CLASS_DOES_NOT_SUPPORT_RANGE_OPERATORS =  2309;

        /** Only select blocks are allowed for selectAsStream. */

	static final public int RT_ERR_BAG_ONLY_SELECT_BLOCK_ALLOWED =           2310;

        /** Only one predicate is allowed for selectAsStream. */

	static final public int RT_ERR_BAG_ONLY_ONE_PREDICATE_ALLOWED =           2311;

        /** The path expression in the predicate for selectAsStream does
            not have a range equality index. */

	static final public int RT_ERR_BAG_NO_RANGE_INDEX_ON_PATH_EXPRESSION =           2312;

        /** The predicate for selectAsStream was invalid. */

	static final public int RT_ERR_BAG_INVALID_PREDICATE_FOR_STREAM_SELECTION =           2313;

        /** The comparison operation in the predicate for selectAsStream is
            not supported. */

	static final public int RT_ERR_BAG_OPERATION_NOT_SUPPORTED =           2314;

        /** Unable to sort using the given sort specification. */

	static final public int RT_ERR_BAG_INVALID_SORT_SPECIFICATION =           2315;

        /** An attempt was made to read the object using an index in a segment
            with insufficient authorization. */

	static final public int RT_ERR_INDEX_AUTH_ERR_SEG_READ =           2316;

        /** Given time_t is out of range; must be greater than
	   or equal to zero.
	Args: none. */

	static final public int OBJ_ERR_TIME_T_OUT_OF_RANGE =      2317;

        /** Error number available for application use.
           Args: (1) error identifier (a user-defined object);
                 (2) user defined error text;
                 (3) an array of arguments (user specified).  */

	static final public int RT_ERR_GENERIC_ERROR =   2318;

        /** An illegal attempt to execute a protected method. */

	static final public int RT_ERR_METHOD_PROTECTED =   2319;

	/** An object cannot be migrated an inst var participates in an index
            with a constraint. */

	static final public int RT_ERR_BAD_CONSTRAINT_FOR_MIGRATION =  2320;

        /** Used internally to append a message to the end of a previously
           raised error message.  The appended message indicates that the
           previous error occurred during index maintenance, and consequently
           the current transaction must be aborted. */

	static final public int RT_ERR_PREVENTING_COMMIT =  2321;

        /** The object is present on the GemStone Smalltalk stack as "self",
            and cannot participate in a "become" operation. */

	static final public int RT_ERR_CANNOT_BECOME_SELF_ON_STACK =  2322;

        /** An illegal attempt to fetch/store into a protected object. */

	static final public int RT_ERR_OBJECT_PROTECTED =   2323;

        /** An attempt to dynamically define a new transaction log directory
           failed. 
        Args: (1) reason.  */

	static final public int RT_ERR_NEW_TRANLOG_DIR_FAILED =  2324;

        /** A commit or abort was attempted while a multi-file full backup
            is in progress. Use abortFullBackup to cancel the backup and
            restore ability to commit from this session. */

	static final public int ERR_COMMIT_WHILE_BACKUP_IN_PROGRESS =  2325;


        /** The contents of the object have not been converted from a
            prior version of GemStone; the object is not compatible with
            this executable. Args (1) the object.  Example: 4.0 UserProfile or
            Segment with 4.1 executables, and dbf conversion was skipped. */

	static final public int ERR_UNCONVERTED_OBJECT =  2326;

	/** The SelectBlock must evaluate to a boolean expression. */

	static final public int RT_ERR_LAST_CONSTRAINT_NOT_BOOLEAN =  2327;

        /** An error occurred (probably during index maintenance) such that
            commits are disallowed so that indexing objects remain consistent.
            This session must abort this transaction.  */

	static final public int RT_ERR_COMMIT_PROHIBITING_ERROR =  2328;

        /** Attempted to write an object to a passive object.
            nil was written instead.  */

	static final public int RT_ERR_ATTEMPT_TO_PASSIVATE_INVALID_OBJECT =  2329;
        /** The argument to SystemRepository&gt;&gt;timeToRestoreTo:
	    was invalid,
        Args (1) reason (a String).  */

	static final public int RT_ERR_INVALID_RESTORE_TIME =  2330;

        /** Users are not allowed to lock AllSymbols.
        Args: none. */

	static final public int LOCK_ERR_ALL_SYMBOLS =         2331;

        /** User attempted to create a forward reference to a Symbol or define
           (fill in the state of) a forward reference as a Symbol
        Args: (1) oop specified for the forward reference. */

	static final public int GCI_ERR_SYMBOL_FWD_REF =       2332;

        /** Users are not allowed to change the class of an object from or to
            class Symbol.
        Args: (1) theSymbol. */

	static final public int RT_ERR_CHANGE_SYMBOL =         2333;

        /** The object is not invariant. Args: (1) the object. */

	static final public int RT_ERR_OBJ_VARIANT =  2334;

        /** disallowSubclasses is not allowed because The class 
            (Arg1) already has subclasses.  */

	static final public int RT_ERR_ALREADY_HAS_SUBCLASSES =  2335;

        /** Used to send a message to a Client. 
        Args: (1) the instance of ClientForwarder;
              (2) the receiver of the message to be forwarded;
              (3) the selector of the message to be forwarded;
              (4) an array containing the arguments to the message.
        See documentation in class ClientForwarder. */

	static final public int RT_ERR_CLIENT_FWD_SEND =   2336;

        /** Object has invalid size. 
        Args: (1) object;
              (2) required size;
              (3) actual size. */

	static final public int RT_ERR_BAD_OBJ_SIZE =  2337;

        /** Indicates that the repository is currently running below the
            freeSpaceThreshold.
        Args: none. */

	static final public int RT_ERR_FREE_SPACE_THRESHOLD =   2338;

        /** Indicates that the tranlog directories are full and that the system
            is waiting for an operator to make more space available either by
            cleaning up the existing files (copying them to archive media and
           deleting them or by adding a new tranlog directory.
        Args: none.  */

	static final public int RT_ERR_TRANLOG_DIR_FULL =   2339;

        /** constraint violation when attempting to store a new value into a
            dictionary.
         Args: (1) dictionary;
               (2) new value;
               (3) constraint;
               (4) class of new value. */

	static final public int OBJ_ERR_DICT_CONSTRAINT_VIOL =  2340;

        /** A new password would exceed the maximum password size.
         Args: (1) new password;
               (2) max size. */

	static final public int RT_ERR_MAX_PASSWORD_SIZE =  2341;

        /** A new password would be smaller than the minimum password size.
        Args: (1) new password;
              (2) min size. */

	static final public int RT_ERR_MIN_PASSWORD_SIZE =  2342;

        /** A new password would contain too many consecutive characters 
           ('abcd..').
        Args: (1) new password;
              (2) max consecutive chars allowed;
              (3) substring of new password that is in violation.  */

	static final public int RT_ERR_MAX_CONSEC_CHARS =   2343;

        /** A new password would contain too many repeating characters 
            ('aaaa..').
        Args: (1) new password;
              (2) max repeating chars allowed;
              (3) substring of new password that is in violation.  */

	static final public int RT_ERR_MAX_REPEATING_CHARS =   2344;

        /** A new password would contain too many consecutive characters 
           of a type.
        Args: (1) new password;
              (2) max consecutive chars allowed;
              (3) type ('alpha', 'numeric', etc);
              (4) substring of new password that is in violation. */

	static final public int RT_ERR_MAX_CHARS_OF_TYPE =   2345;

       /** A new password matches a word that is not allowed as a password.
       Args: (1) new password. */

	static final public int RT_ERR_DISALLOWED_PASSWORD =  2346;

        /** The password of the current UserProfile is about to expire. */

	static final public int RT_ERR_WARNING_PASSWORD_EXPIRE =  2347;

        /** The path (Arg 1) does not exist as a directory or raw device. */

	static final public int RT_ERR_LOG_DIR_NOT_EXIST =   2348;

        /** The object (arg 1) is too small. The minimum allowed size 
            is (arg 2). */

	static final public int RT_ERR_ARG_TOO_SMALL =     2349;

        /** A GCI update operation is not allowed on the target object.
        Args: (1) the object;
              (2) string describing the kind of update that is not allowed. */

	static final public int RT_ERR_NO_STRUCT_UPDATE =   2350;

        /** Class is obsolete. */

	static final public int RT_ERR_OBSOLETE_CLASS =   2351;

        /** Local session failed to commit after remote sessions 
            voted to commit. */

	static final public int RT_ERR_LOCAL_XACTION_FAILED_COMMIT =   2352;

        /** Remote session failed to commit after voting affirmative. */

	static final public int RT_ERR_REMOTE_SESSION_FAILED_COMMIT =  2353;

        /** The object Arg2 was not detected in Arg1. */

	static final public int RT_ERR_NO_ELEM_DETECTED =              2354;

        /** The resulting DateTime object would be out of range. */

	static final public int RT_ERR_DATE_TIME_OUT_OF_RANGE =        2355;

        /** The object Arg2 was not found in Arg1. */

	static final public int RT_ERR_OBJ_NOT_FOUND =                 2356;

        /** The operation should update the stone configuration file but
            the write failed. */

	static final public int RT_ERR_FAILED_STN_CFG_WRITE =          2357;

        /** Attempt to call a user action that is not registered with the gem.
        Args: (1) the action name;
              (2) reserved for internal use;
	      (3-10) the arguments to the action routine. 
        Normally not seen.  */

	static final public int GCI_ERR_NO_USER_ACTION =               2358;

	/** An attempt was made to add a UserProfile to a group when the
	UserProfile was already a member of four groups.
	Args: (1) the UserProfile; (2) the group. */

	static final public int SEG_ERR_MAX_USER_PROFILE_GROUPS =  2359;

        /** Error during GS commit list nonblocking timeout.
        Args: (1) sessionId.  */

	static final public int RT_ERR_GS_COMMIT_LIST_NB_TIMEOUT =    2360;

        /** Stone has logged GcGem Startup failures since last success.
        Args: none.  */

	static final public int RT_ERR_GCGEM_STARTUP_FAILURES =    2361;

        /** A GsSocket method failed due to a socket error.
        Args: (1) GsSocket instance or nil;
              (2) lastErrorSymbol;
              (3) lastErrorString;
              (4) lastErrorCode. */

	static final public int RT_ERR_GSSOCKET =  2362;

        /** An instance of GsSocket that was not changable was sent a
	    message that would have required it to change.
        Args: (1) GsSocket instance.  */

	static final public int RT_ERR_GSSOCKET_INVARIANT =  2363;

        /** An object that has some associated session state has lost that
            transient state. Examples of classes that use session state
            are GsSocket and GsFile.
        Args: (1) the oop of the instance that lost it session state.  */

	static final public int RT_ERR_LOST_SESSION_STATE =  2364;

        /** An interval Delay object already has a process waiting on it.
        Args: (1) the delay.  */

	static final public int RT_ERR_DELAY_IN_PROGRESS =  2365;

        /** The processor scheduler is dead locked.
        Args: (1) the processor scheduler.  */

	static final public int RT_ERR_SCHEDULER_DEADLOCKED =  2366;

	/** A primitive failed due to a system error.
	Args: (1) a string describing the system error. */

	static final public int RT_ERR_PRIMITIVE_SYSERR =  2367;

        /** The active GsProcess was sent the terminate message.
        Args: none.  */

	static final public int RT_ERR_GSPROCESS_TERMINATED =  2368;

        /** All available CBuffers are in use.
        Args: none.  */

	static final public int RT_ERR_NO_MORE_CBUFFERS =  2369;

        /** An error occurred on the remote system.
	Args: (1) the text of the error message.  */

	static final public int RT_ERR_REMOTE_ERROR =  2370;

        /** A remote login attempt failed.
        Args: (1) the error text.  */

	static final public int RT_ERR_REMOTE_LOGIN_FAILED =  2371;

        /** The client encountered an uncaught exception when a message was
            forwarded.
        Args  (1) the error number from the client;
              (2) the error message from the client;
              (3) the stack trace from the client. */

	static final public int RT_ERR_CLIENT_FWD =    2372;

        /** An attempt was made to create a GsProcess with the wrong number
            of arguments for the specified block.
	Args: (1) the block; 
              (2) the expected number of arguments;
	      (3) the number of arguments used. */

	static final public int RT_ERR_BAD_GSPROCESS_ARG_COUNT =    2373;

        /** The password for session parameters must be variant. */

	static final public int RT_ERR_PASSWORD_NOT_VARIANT =    2374;

        /** The gsprocess is not in a debuggable state.
        Args: (1) the gsprocess.  */

	static final public int RT_ERR_GSPROCESS_NOT_DEBUGGABLE =  2376;

        /** The argument to remotePerform: should be a list of pairs of
	    object/bools, of maximum size 20.
	Args: (1) the argument that was given. */

	static final public int GCI_ERR_ARG_NOT_PAIRS =  2377;

	/** An attempt was made to execute a client user action from
           a session that is not allowed to do this.
	Args:  (1) The name of the user action. */

	static final public int RT_ERR_CLIENT_ACTION_DISALLOWED =  2378;

        /** An attempt was made to remove a reserved account from
            AllUsers.
        Args: (1)  The userId of the reserved account. */

        static final public int RT_ERR_REMOVE_SPECIAL_USER = 2379;

        /** Bad GcType code passed in 
	    System&gt;&gt;_startGcSession:extentId:.
            Args: (1) the gcType. */

	static final public int RT_ERR_BAD_GC_TYPE = 2382;

        /** Bad extent Id passed in System&gt;&gt;_startGcSession:extentId:.
	    Args: (1) the extentId. */

	static final public int RT_ERR_BAD_EXTENT_ID = 2383;

       /** Either a Gc Gem of the selected type on the selected extent 
	   has already been started, or the selected type is incompatible
           with other GcGems on the system.
           Args: (1) the gcType;
   	         (2) the extentId. */

	static final public int RT_ERR_GC_SESSION_INVALID =          2384;

        /** Problem executing System&gt;&gt;_startGcSession:extentId:, 
	    probably due to some netldi problems.
          Args: (1) the gcType;
   	        (2) the extentId. */

	static final public int RT_ERR_GC_SESSION_FAILED =           2385;

	/** Backup/restore disallowed with no shared page cache.
	  Args: none. */

	static final public int BKUP_ERR_NO_SPC =                    2386;

	/** GS/32 only: Backup failed.  Args: (1) reason.
            See BKUP_ERR_NO_START for GS/64 version */

	static final public int BKUP_ERR_NO_START_32 =               2387;

	/** The system was unable to read the given file.
	    Args: (1) the filename; (2) errno. */

	static final public int RT_ERR_CANT_READ_FILE =              2388;

	/** The given file is corrupted.
	    Args: (1) the filename; (2) message. */

	static final public int RT_ERR_FILE_CORRUPT =                2389;

	/** A commit during a garbage collection operation failed. */

	static final public int RT_GC_COMMIT_FAILURE =               2390;

        /** Creation of new Symbols not allowed at this time.
	    Args: (1)  reason;  (2) symbol value. */

	static final public int RT_ERR_SYMBOL_CREATION_NOT_ALLOWED = 2391;

	/** GS/64 only: Backup failed.  Args: (1) reason.
            See BKUP_ERR_NO_START_32 for GS/S version.  */

	static final public int BKUP_ERR_NO_START =                  2392;

	/** The decoded object at offset (2) does not exist.
	   Args: (1) Integer value of objectId;
	         (2) offset in the byte array. */

	static final public int RT_ERR_DECODED_OBJ_DOES_NOT_EXIST =  2393;

	/** Attempt to create a subclass too far below Object in 
            superclass chain.
	    Args: (1) receiver; (2) max depth.  */

	static final public int RT_ERR_MAX_SUPERCLASS_DEPTH =        2394;

	/** A reclaimAll operation was attempted but at least one GC session
	  is not running.  Ensure all reclaim sessions and the Admin GC session
	  are running and try the operation again. */

	static final public int RT_ERR_RECLAIM_ALL_MISSING_GC_GEM =  2395;

        /** Cannot suspend logins. Args:(1) reason. */

	static final public int RT_ERR_CANNOT_SUSPEND_LOGINS =       2400;

        /** GciWeakDictInit() must be called before other weak dictionary
           functions.
           Args: none. */

	static final public int RT_ERR_WEAK_DICT_NEEDS_INIT =        2401;

        /** Attempt to create a symbol that is more than 1024 bytes. */

	static final public int RT_ERR_SYMBOL_TOO_LARGE  =           2402;

        /** Cannot commit. Args: (1) reason (a String). */

	static final public int RT_ERR_FLUSH_FOR_COMMIT_FAILED =     2403;

        /** GciSendMsg failed because there is no existing Symbol
            that matches the selector String. Args: (1) selector. */

	static final public int RT_ERR_NO_EXISTING_SYM =             2404;

        /** The given object is a temporary object but is required to
	    be a committed object.  
        Args: (1) the object;  (2) details. */ 

	static final public int RT_ERR_OBJ_MUST_BE_COMMITTED =       2405;

	/** The system was unable to write to the given file.
	    Args: (1) the filename; (2) errno; (3) error message. */

	static final public int RT_ERR_CANT_WRITE_FILE =             2406;

        /** Replicates not supported when using a mid-level cache. */

	static final public int RT_ERR_NOREPLICATES_WITH_MID_CACHE = 2407;

        /** Object may not be committed.
              Args: (1) an object;  (2) reason.
              Not Trappable in Gemstone Smalltalk if 
              preceeding System&gt;&gt;trapAddToClosureList:
	      had non-nil arg. */

	static final public int RT_ERR_OBJ_IS_NP =                   2407;

        /** Class may not have instances persistent because superclass is NP.
            Args: (1) a Class. */

	static final public int RT_ERR_SUPERCLASS_IS_NP =            2408;

        /** continueTransaction is not allowed. Args (1) reason (a String). */

	static final public int RT_ERR_CONTINUE_TRANS_ERROR =        2409;

// 2410 not used

        /** a Traversal buffer received over the network exceeded RPC client's
            allocated buffer size. */

	static final public int LGC_ERR_TRAV_BUFF_SIZE =             2411;

        /** A method is being run that requires an abort to function,
            however, an abort would result in lost data as there are 
            modified objects. */

	static final public int RT_ERR_ABORT_WOULD_LOSE_DATA =       2412;

        /** An attempt to continue a full backup when 
            no backup is in progress. */

	static final public int BKUP_ERR_NOT_IN_PROGRESS =           2413;

	/** The GCI call is not supported when invoked 
            from a client user action. */

	static final public int GCI_ERR_CALL_NOT_SUPPORTED =         2414;

        /** An attempt to remove all indexes has failed. */

	static final public int RT_ERR_REMOVE_ALL_INDEXES_FAILED =   2415;

	/** An attempt was made to create an index on a collection that 
            has incomplete indexes.  The incomplete indexes must be removed 
            before creating new indexes.
            Args: none. */

	static final public int RT_ERR_COLLECTION_WITH_INCOMPLETE_INDEX = 2416;

	/** No more segments can be created.  SystemRepository has reached
	    maximum size. Args: none. */

	static final public int RT_ERR_NO_MORE_OBJECT_SECURITY_POLICIES = 2417;

	/** RcRetry or Application write lock denied due to possible deadlock.
	    Args: (1) object upon which lock was requested. */

	static final public int LOCK_ERR_DEADLOCK =                       2418;

	/** RcRetry or Application write lock denied due to timeout.
	    Args: (1) object upon which lock was requested. */

	static final public int LOCK_ERR_TIMEOUT  =                       2419;

	/** RcRetry or Application write lock denied: a different object
            is already registered with the lock queue.
            Args: (1) details (String). */

	static final public int LOCK_ERR_INVALID_OBJECT =                 2420;

        /** Error in process switch. */

        static final public int AUTH_ERR_PROCESS_SWITCH =                 2421;

	/** Illegal argument to GciStoreTravDoTravRefs, one or more
            objects not found in exported set
            were not found in the referenced and/or exported set.
            Args: (1) a not-found object. */

	static final public int RT_ERR_OBJ_NOT_IN_EXPORT_SET =            2422;

        /** License does not allow use of Gci Traversal operations. */

	static final public int RT_ERR_GCI_TRAV_NOT_LICENSED =            2423;

	/** Commits are disabled until after the next abort. */

	static final public int RT_ERR_COMMIT_DISALLOWED_UNTIL_ABORT =    2424;

	/** Rollback of objects in a specific dirty list not allowed 
            after failed commit. */

	static final public int RT_ERR_ROLLBACK_DL_FAIL =                 2425;

	/** become is not allowed on this object.
            Args: (1) object;   (2) reason string. */

	static final public int RT_ERR_CANNOT_BECOME_GENERIC =            2426;

	/** The current operation is not allowed at this time.
            Args: (1) String describing the operation and reason 
                      for the error. */

	static final public int RT_ERR_OP_NOT_ALLOWED =                   2427;

	/** Ensure block already installed in the current frame. */

	static final public int RT_ERR_ExceptionAlreadyInstalled =        2480;

	/** Error in native code generator: 
            native code execution disabled for remainder of session.
        Args: (1) string.  */

	static final public int RT_ERR_NATIVE_CODE =                      2481;

	/** Breakpoints and single-step not supported in native code. */

	static final public int RT_ERR_NO_BREAK_IN_NATIVE =               2482;

	/** Cannot add or store to a Ruby dynamic instVar 
            in an object with a dependency tag. */

	static final public int RT_ERR_DYNAMIC_IV_STORE_DEPENCENCY =      2483;

	/** Error storing a dynamic instVar.
        Args: (1) reason (a String). */

	static final public int RT_ERR_DYNAMIC_IV_STORE =                 2484;

        /** VM ran out of GsScopes memory.
        Args: (1) reason (a string). */

	static final public int GS_ERR_VM_OUT_OF_GSSCOPES =               2485;

// 2486 unused

	/** Default error number for an instance of Notification. */

	static final public int RT_ERR_NOTIFICATION =                     2487;

	/** Cannot convert native stack to portable stack. */

	static final public int RT_ERR_NAT_STACK_NOT_CONVERTABLE =        2488;

	/** This user action is already defined for this application.
	    The user action name is appended to the error text. 
            This error is for GS/64 v3.0 and later, where it is no 
            longer a fatal error.
            See GCI_ERR_ACTION_DEFINED_FATAL for earlier error. */

	static final public int GCI_ERR_ACTION_DEFINED =                  2489;

        /** An attempt was made to update an RC object 
            in a continued transaction.
            The transaction must abort. */

	static final public int RT_ERR_RC_UPDATE_DISALLOWED =             2500;

        /** An operation that needs to acquire the gcLock was not able
            to get the lock within a reasonable amount of time.
            Args: none. */

	static final public int RT_ERR_GET_GC_LOCK_FAILED =               2501;

        /** GemStone Smalltalk execution stack overflow, in red zone page.
            Not Trappable in Gemstone Smalltalk. */ 

	static final public int  RT_ERR_STACK_LIMIT_RED =                 2502;
    
        /** An Integer would exceed 130144 bits. */ 

	static final public int  RT_ERR_LARGE_INT_OVERFLOW =              2503;

        /** Error in Ruby printf.
            Args: (1) aString. */

	static final public int ERR_RUBY_PRINTF_ERROR =                   2505;

	/** Error in Ruby instvar name. */

	static final public int ERR_RUBY_BAD_INSTVAR_NAME =               2506;

        /* Ruby OutOfRange.
        Args: (1) reason. */

	static final public int ERR_RangeError =                          2507;

         /** a Memory region managed by the VM is full.
         Args: (1) reason. */

	static final public int ERR_MEMORY_REGION_FULL =                  2511;
				
	/** The value was expected to be a power of 2.
	    Args: (1) the value. */

	static final public int RT_ERR_ARG_NOT_POWER_OF_TWO =             2512;

	/** The password must contain at least one character of specified type.
	    Args: (1) missing type (aSymbol). */

	static final public int RT_ERR_PASSWORD_MISSING_CHAR =            2513;

        /** An error occurred during a multi-threaded operation.
            Args: (1) string describing the error. */

	static final public int ERR_DURING_MT_OPERATION =                 2514;

	/**  Completed execution of the markForCollection method. 
          Args: (1) (long) number of live objects; 
                (2) (long) number of dead objs;
                (3) (long) number of bytes occupied by dead objects. */

	static final public int WARNING_FINISHED_MFC =                    2515;

// add new 25xx errors here

// Authentication errors , new in Gs64 v3.0

	/** The authentication scheme id is invalid.
            Args: (1) authId. */
	static final public int RT_ERR_INVALID_AUTH_SCHEME_ID =           2600;

 
	/** The authentication scheme symbol is invalid.
            Args: (1) authSymbol. */

	static final public int RT_ERR_INVALID_AUTH_SCHEME_SYMBOL =       2601;

	/** The specified UNIX user ID is invalid.
            Args: (1) unixUid. */

	static final public int RT_ERR_INVALID_UNIX_USER_ID =             2602;

	/** Illegal attempt to modify authentication scheme of 
            a special UserProfile.
            Args: (1) aUserProfile. */

	static final public int RT_ERR_ILLEGAL_AUTH_SCHEME_CHANGE =       2603;

	/** An operation for a UserProfile was attempted which is 
            disallowed under the current authentication scheme.
            Args: (1) aUserProfile;
                  (2) authScheme. */

	static final public int RT_ERR_AUTH_ILLEGAL_OPERATION =           2604;

	/** An attempt was made to change the password of a UserProfile 
            which is not using GemStone athentication.
            Args: (1) aUserProfile. */

	static final public int RT_ERR_AUTH_ILLEGAL_PASSWD_CHANGE =       2605;

        /** An attempt was made enable password expiration for 
            a special UserProfile. */

	static final public int RT_ERR_ILLEGAL_PASSWORD_EXPIRATION =      2606;

        /** The string is not a valid distinguished name or does not 
            contain the %s pattern. */

	static final public int RT_ERR_ILLEGAL_DN =                       2607;

// Do not add more errors here, use numbers before 2590 first
       
// -----------------------------------------------
// New error numbers for revised Exception hierarchy in v3.0 .
//  These error number map one-to-one to an Exception class .
//  and are also coded (via a class variable in AbstractException from bom.c)
//  into the initialize method of the class.

// Preserved error numbers for Smalltalk client compatibility

	static final public int  ERR_ClientForwarderSend = 
                                                RT_ERR_CLIENT_FWD_SEND;

	static final public int  ERR_CompileError =
                                      	        COMPILER_ERR_STDB;

	static final public int  ERR_MessageNotUnderstood = 
                                                RT_ERR_DOES_NOT_UNDERSTAND;

	static final public int  ERR_TerminateProcess =
                                                RT_ERR_GSPROCESS_TERMINATED;

	static final public int ERR_AbstractException 	= 2701;
	static final public int ERR_Exception 		= 2702;
	static final public int ERR_RubyBreakException 	= 2703;
	static final public int ERR_RubyThrowException 	= 2704;
	static final public int ERR_ControlInterrupt 	= 2705;
	static final public int ERR_Break 		= 2706;
	static final public int ERR_Breakpoint 		= 2707;
	static final public int ERR_Halt 		= 2709;
	static final public int ERR_Error 		= 2710;
	static final public int ERR_InterSessionSignal  = 2711;
	static final public int ERR_EndOfStream 	= 2712;
	static final public int ERR_ExternalError 	= 2713;
	static final public int ERR_IOError 		= 2714;
	static final public int ERR_SocketError 	= 2715;
	static final public int ERR_SystemCallError 	= 2716;
	static final public int ERR_ImproperOperation 	= 2717;
	static final public int ERR_ArgumentError 	= 2718;
	static final public int ERR_ArgumentTypeError 	= 2719;
	static final public int ERR_CannotReturn 	= 2720;
	static final public int ERR_LookupError 	= 2721;
	static final public int ERR_OffsetError 	= 2722;
	static final public int ERR_OutOfRange 		= 2723;
	static final public int ERR_FloatingPointError 	= 2724;
	static final public int ERR_RegexpError 	= 2725;
	static final public int ERR_IndexingErrorPreventingCommit = 2726;
	static final public int ERR_InternalError 	= 2727;
	static final public int ERR_GciTransportError 	= 2728;
	static final public int ERR_LockError 		= 2729;
	static final public int ERR_NameError 		= 2730;
	static final public int ERR_Warning 		= 2731;
	static final public int ERR_NumericError 	= 2732;
	static final public int ERR_ZeroDivide 		= 2733;
	static final public int ERR_RepositoryError 	= 2734;
	static final public int ERR_SecurityError 	= 2735;
	static final public int ERR_SignalBufferFull 	= 2736;
	static final public int ERR_ThreadError 	= 2737;
	static final public int ERR_TransactionError 	= 2738;
	static final public int ERR_UncontinuableError 	= 2739;
	static final public int ERR_UserDefinedError 	= 2740;
	static final public int ERR_Notification 	= 2741;
	static final public int ERR_Admonition 		= 2742;
	static final public int ERR_AlmostOutOfStack 	= 2743;
	static final public int ERR_AlmostOutOfMemory 	= 2744;
	static final public int ERR_RepositoryViewLost 	= 2745;
	static final public int ERR_Deprecated 		= 2746;
	static final public int ERR_FloatingPointException = 2747;
	static final public int ERR_ObjectsCommittedNotification = 2748;
	static final public int ERR_TransactionBacklog 	= 2750;
	static final public int ERR_TestFailure 	= 2751;
	static final public int ERR_RUBY_SystemExitError = 2752;
	static final public int LAST_ANSI_ERROR_NUM      = 2752;


/**=========================================================================
 *
 *  ABORTING ERRORS  - numbered from 3001 to 3999
 *
 *=========================================================================
 */

        /** The transaction was aborted by the user.  Only used within
	GCI internals implementation.  Not generated by a user level abort.
        Args: none. */

	static final public int RT_ERR_ABORT_TRANS =               3001;

/** errors 3002, 3003 , 3005 not used*/

/** error 3004 not used */


	/** The garbage collection process detected conflict on one of
	   the objects that it might have collected.
	   The operation was aborted and should be tried again later.
	   Args: (1) reason (aString);
                 (2) conflict code (smallInt or nil).  */

	static final public int ABORT_ERR_GARBAGE_COLLECTION =     3006;

	/** References to objects exist in Pom even though the objects have
	   not been defined in Pom.  The current transaction is aborted.
	   Args: (1) one of the objects that wasn't defined in Pom. */

	static final public int ABORT_ERR_UNDEF_POM_OBJ =          3007;

	/** The restore of a full backup file was successful.
	   Args: (1) (long) number of objects restored;
                 (2) (long) number of corrupt objects not restored;
                 (3) (string) restore status.  */

	static final public int BKUP_ERR_RESTORE_SUCCESSFUL =      3008;

	/** The backup was successful, but was not completed due to a
	   byte limit restriction.  A partial backup file was created.
	   Args: (1) (long) number of objects written to the file;
		 (2) (long) number of bytes written to the file.  */

	static final public int BKUP_ERR_BACKUP_NOT_COMPLETE =     3009;

/** error 3010 not used */

        /** A restore from a transaction log succeeded. */

	static final public int BKUP_ERR_RESTORE_LOG_SUCCESS =    3011;

        /** A restore from a transaction log failed.
        Args: (1) (string) reason. */

	static final public int BKUP_ERR_RESTORE_LOG_FAIL =    3012;

/** error 3014 not used */
/** error 3015 not used */

	/** Commit failed after restore, restore is unusable.
        Args: (1) reason (a string). */

	static final public int BKUP_ERR_RESTORE_COMMIT_FAILED =   3016;

	/**  Completed execution of the markForCollection method.
	Args: (1) (long) number of live objects; 
              (2) (long) number of dead objs;
	      (3) (long) number of bytes occupied by dead objects. */

	static final public int ABORT_ERR_FINISHED_MARK =          3020;

	/** Object audit completed.
	Args: (1) number of objects containing errors.
        This error is not trappable from GemStone Smalltalk. */

	static final public int ABORT_ERR_FINISHED_OBJ_AUDIT =     3021;

/* error numbers 3022..3030 not in use */

       /** This error indicates that while running outside of a transaction
          stone requested the gem process to abort but the gem did not respond
          in the allocated time, so stone revoked access to the object table.
          Args: none.  */

	static final public int ABORT_ERR_LOST_OT_ROOT =              3031;

	/** Object audit completed, but contained errors.  
	    Args: (1) number of objects containing errors.  
            This error is not trappable from GemStone Smalltalk. */

	static final public int ABORT_ERR_FINISHED_OBJ_AUDIT_WITH_ERRORS = 3032;

        /** A reclaimAll operation has failed.  
            Generated by quick object audit if
            possible dead object finalization is in progress when the quick
            object audit is started. */

	static final public int ABORT_ERR_RECLAIM_ALL_FAILURE =        3033;

/**=========================================================================
 *
 *   FATAL ERRORS   - numbered from 4001 to 4999
 *
 *=========================================================================
 */

	/** The root page of the repository is bad. A disk access of the
	   root page encountered a disk read error, or found corrupted data.
	   Args: none. */

	static final public int GS_ERR_BAD_ROOT_PAGE =             4001;

	/** The logical repository is full.
            If space needs originated from Gem session actions, only the
	    requesting Gem is killed; if space needs originated from Stone
	    monitor processing, Stone shuts down, 
            killing any live Gem sessions. */

	static final public int REP_ERR_REPOS_FULL =               4002;

        /** Stone was unable to find any free pages 
            after growing the repository.
        Args: (1) the repository. */

	static final public int REP_ERR_NO_FREE_PAGES =            4003;

        /** Malloc failed in such a way that execution cannot continue. The
            customer needs more swap space and/or more primary memory.
        Args: (1) string describing where in GemStone the error happened. */

	static final public int HOST_FATAL_ERR_OUT_OF_MEM =  	4004;

        /** The size of an object (usually a reserved object) in the database
        is not the size expected by the virtual machine.
        Args: (1) object;
              (2) actual size;
              (3) expected size.
        Note: you may be able to bypass this error by logging in
	as SystemUser and then repair the dbf with GemStone Smalltalk. */

	static final public int ERR_CORRUPT_OBJ_SIZE =      4005;

        /** An invalid swizzle transform was detected in a database extent.
        Args: (1) longTransform;
              (2) shortTransform. */

	static final public int REP_ERR_BAD_DBF_SWIZZLE =  4006;

	/** This user action is already defined for this application.
	    The user action name is appended to the error text.
            This version applies for GS/S 32-bit and GS/64 1.X and 2.X.
            See GCI_ERR_ACTION_DEFINED for GS/64 3.X and later version. */

	static final public int GCI_ERR_ACTION_DEFINED_FATAL =           4007;

        /** The user profile object for this session has been garbage
	collected as a result of a restore operation, or by a commit
	from another session. No args. */

	static final public int ERR_USER_PROFILE_LOST =       4008;

        /** The process detected a connection failure from the
           SharedPageCache monitor.
        Args: (1) the error text. */

	static final public int GS_ERR_SHRPC_CONNECTION_FAILURE =  4009;

        /** The process detected an unexpected read or write event
           from the SharedPageCache monitor.
        Args: (1) True indicates read operation, false is write. */

	static final public int GS_ERR_SHRPC_UNEXPECTED_NET_EVENT =  4010;

        /** The process tried to login to a Stone with the config file
	   specifying that the SharedPageCache should NOT be used when
           the Stone already has a SharedPageCache active on the host
	   machine. */

	static final public int GS_ERR_SHRPC_INVALID_CONFIG =        4011;

        /** The GcGem process received a signal that forces a shutdown. */

	static final public int GS_ERR_STOP_GC_GEM =               4012;

        /** A page owned by a Gem could not be removed from a remote cache.
           after 50 seconds of retries. */

	static final public int GS_ERR_REMOVE_FROM_CACHES =        4013;

        /** An error occurred during servicing of error 3031.
	Args: (1) The number of errors found in the global error descriptors;
	      (2) Error number for ErrorDescriptor[0];
	      (3) Error number for ErrorDescriptor[1];
	      (4) Error number for ErrorDescriptor[2]. */

	static final public int ERR_DURING_LOST_OT_SERVICE =       4031;

        /** Unable to open the next transaction log for writing.
            File open failure message giving name of log will preceed this
            error in the message log. */

	static final public int ERR_CANT_OPEN_TRAN_LOG =  4032;

/** 4033 not in use */

        /** A protocol error occurred on the Gem-Stone network connection.
        Args: (1) internal failure code (see GscNetErrEType in session.ht). */

	static final public int GS_ERR_GEM_STONE_NET_PROTOCOL =    4034;

        /** An end of file was received over the Gem-Stone network,
         indicating that the network is being shut down.
        Args: none. */

	static final public int GS_ERR_STN_NET_LOST =         	4035;

        /** Copy protection check failed.
        Contact your customer representative.  Args:  none. */

	static final public int GS_ERR_COPY_PROTECTION =      	4036;

        /** You attempted to use a feature not licensed to you.  Contact
        your customer representative.  Args:  none. */

	static final public int GS_ERR_NO_CAPABILITY =      	4037;

        /** Stone disconnected during an attempt to login, probably
           because logins are disabled or max users are already logged in. */

	static final public int GS_ERR_DISCONNECT_IN_LOGIN =     4038;

	/** Login failed because the system was full.
	Args: none.
		      OR
	Login attempt failed -
	  the maximum number of sessions are already logged in.
	Args: none.  */

	static final public int GS_ERR_MAX_SESSIONS_LIMIT =        4039;

	/** The version of the GCI is not compatible with the
  	    version of the Gem. Args: none. */

	static final public int LGC_ERR_INCOMPAT_GCI =             4040;

        /** Login failed because the session limit of the GCI has been
            reached. */

	static final public int GS_ERR_GCI_SESSIONS_LIMIT =        4041;

	/** HostFork() attempted to spawn a Gem but was unable to do so.
	Args: none. */

	static final public int HOST_ERR_CANT_SPAWN =              4042;

/** Fatal error 4043 not in use */

	/** The Gem and Stone versions are incompatible.
	Args: (1) the Gem version;
              (2) the Stone version. */

	static final public int GS_ERR_BAD_GEM_STONE_VERSION =     4044;

	/** The Gem and dbf versions are incompatible.
	Args: (1) the Gem version;
              (2) the dbf version. */

	static final public int GS_ERR_BAD_GEM_DBF_VERSION =       4045;

/** Fatal errors 4046-4049 not in use */

        /** Too many sessions already logged in with given userId.
        Args: (1) the userId. */

	static final public int GS_ERR_ACTIVE_USER_LIMIT =         4050;

	/** The login failed because of an invalid userId/password combination,
	 * or an expired password. Args: none. */

	static final public int GS_ERR_LOGIN_DENIAL =              4051;

/** 4052 not used */

	/** The login failed because all logins are currently disabled.
	Args: none. */

	static final public int GS_ERR_LOGINS_DISABLED =           4053;

/** Fatal errors 4054-4056 not in use */

	/** Stone is shutting down.  Args: none. */

	static final public int GS_ERR_STN_SHUTDOWN =              4057;

/** Fatal error 4058 not in use */

	 /** The Data Curator is shutting down this session.  Args: none. */

	static final public int GS_ERR_SESSION_SHUTDOWN =          4059;

	/** Gem is shutting down normally Args: none. */

	static final public int GS_ERR_GEM_NORMAL_SHUTDOWN =       4060;

	/** Gem did not shut down normally.  Args: none. */

	static final public int GS_ERR_GEM_FATAL_SHUTDOWN =        4061;

	/** The GemStone system ran out of oops. Args: none. */

	static final public int GS_ERR_NO_MORE_OOPS =              4062;

	/** The given GemStone does not exist.  Args: none. */

	static final public int NET_ERR_NO_SUCH_STN =              4065;

/** Fatal errors 4066-4099 not in use */

	/** The GCI was called with a SessionId that is not a legal VCID.
	Args: none. */

	static final public int GCI_ERR_BAD_SESSION_ID =           4100;

	/** An active linkable GCI session received an unexpected error
	    during processing a GCI call to another RPC session.
	    Both the linkable session and the current RPC session were killed.
	Args: none. */

	static final public int GCI_ERR_UNEXPECTED_LNK_ERR =           4101;

	/** An internal logic error was detected in the implementation of
	    an RPC GCI call. Args: none. */

	static final public int GCI_ERR_FATAL_INTERNAL_RPC =            4102;

/** Fatal errors 4102-4125 not in use */

	/** SYSTEM ERROR: A system fatal error was detected.
	Args: (1) the system error number; 
              (2..n) error-specific arguments. */

	static final public int FATAL_ERR_INTERNAL =               4126;

/** Fatal errors 4127-4135 not in use */

	/** The connection was refused - check the name of STONE.
	   System error text is appended to message. */

	static final public int NET_ERR_CONNECTION_REFUSED =       4136;

	/** An undefined network error.  
            System error text is appended to message. */

	static final public int NET_ERR =                          4137;

	/** The system repository could not be attached.  Args: none. */

	static final public int REP_ERR_SYSTEM_REP_NOT_ATTACHED =  4138;

        /** The config file specified that a shared cache was to be used, but
           the cache could not be attached.
         Args: none. */

	static final public int RT_ERR_SHR_PC_NOT_ATTACHED =       4139;

	/** No authorization to write in your default login segment.
	Args: (1) the oop of the bad segment. */

	static final public int AUTH_ERR_SEG_LOGIN_SEG =           4140;

        /** Problem encountered in creating a pageserver.
        Args: (1) reason returned from the create call. */

	static final public int RT_ERR_PGSVR_CREATION =          4141 ;

	/** The system repository could not be attached
	    because the stone could not be found.
	Args: (1) stone name; (2) reason.  */

	static final public int REP_ERR_SYSTEM_REP_NOT_ATTACHED_NO_STONE =  4142;

	/** The system repository could not be attached
	    because the extent could not be mounted.
	Args: (1) extent id; (2) reason. */

	static final public int REP_ERR_SYSTEM_REP_NOT_ATTACHED_NO_EXTENT =  4143;

	/** The system repository could not be attached
	    because the pid in the repos did not match stone pid.
	Args: none.  */

	static final public int REP_ERR_SYSTEM_REP_NOT_ATTACHED_BAD_PID =  4144;

	/** The system repository could not be attached
	    because extent is not compatible with primary extent.
	Args: (1) extent name; (2) extent id. */

	static final public int REP_ERR_SYSTEM_REP_NOT_ATTACHED_INCOMPATIBLE =  4145;

        /** Stone could not get gem's network address.
	Args: (1) reason returned from the get peer call. */

	static final public int RT_ERR_GET_NET_PEER =                   4146;

        /** GemStone/S Limited Edition does not allow remote sessions. */

	static final public int GS_ERR_REMOTE_GEMS_DISALLOWED =         4147;

        /** No free frames available from the shared page cache. */

	static final public int GS_ERR_NO_FREE_FRAMES =                 4148;

        /** connection to remote GCI client lost.  */

	static final public int ERR_LGC_NET_SHUTDOWN =                  4149;

	/** Login attempt failed - the maximum number of remote caches
	    already exist. */

	static final public int GS_ERR_MAX_REMOTE_CACHE_LIMIT =         4300;


/**=========================================================================
 *
 *   EVENT ERRORS   - numbered from 6000 to 6999
 *
 *=========================================================================
 */

	/** Execution has been halted by an Object|pause message. */

	static final public int RT_ERR_PAUSE =                     6001;


        /** You have encountered a single-step breakpoint.
	Args: (1) code object in which the breakpoint existed;
	      (2) instruction offset from first named instVar in code object.
        */

	static final public int RT_ERR_STEP =                      6002;

	/** A soft break was received.  Args: none. */

	static final public int RT_ERR_SOFT_BREAK =                6003;

	/** A hard break was received. If this occurs during
        markForCollection, fullBackupTo:,  restoreFromBackup(s):
        objectAudit, auditWithLimit:, repairWithLimit:   or
        pagesWithPercentFree, the error is fatal.
	Args: none. */

	static final public int RT_ERR_HARD_BREAK =                6004;

       /** You have encountered a method breakpoint.
       Args: (1) code object in which the breakpoint existed;
	     (2) instruction offset from first named instVar in code object.
        */

	static final public int RT_ERR_CODE_BREAKPOINT =         6005;

       /** A return from block has encountered a stack breakpoint.
           The stack breakpoint has been cleared and the return has
           been executed.  Args: none. */

	static final public int RT_ERR_STACK_BREAKPOINT =        6006 ;


	/** The transaction is about to be committed or aborted.
            (A GciContinue from the point of the error will complete the
            commit or abort.)
	    Only generated if GciDirtyObjsInit has been called.
	Args: none. */

	static final public int RT_ERR_COMMIT_ABORT_PENDING =      6007;

       /** This error indicates that a member of the notifySet has been
          committed and was added to the signaledObjects set.  This error is
          only generated if the user has executed the enableNotifyError method.
          Args: none.  */

	static final public int RT_ERR_SIGNAL_COMMIT =             6008;


       /** This error indicates that while running outside of a transaction
          stone requested the gem process to abort.  This error is only
          generated if the user has executed the enableSignalAbortError method.
          Args: none.  */

	static final public int RT_ERR_SIGNAL_ABORT =              6009;

       /** This error indicates that the session received a signal from
          another GemStone session.  The arguments are the contents
          of the message sent with the signal.
          Args: (1) the serialNumber of the session that sent the signal;
                (2) the signal value (a smallInt);
                (3) a messageString. */

	static final public int RT_ERR_SIGNAL_GEMSTONE_SESSION =   6010;

       /** An attempt was made to continue execution past an uncontinuable
           error.  */

	static final public int RT_ERR_UNCONTINUABLE_ERROR =   6011;


    //=========================================================================
    // End of Exception identifiers
    //=========================================================================

}

