/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *      GbjKernelObjects.java  
 *
 *========================================================================
 */

package com.gemstone.gbj;

/**
 * Instance of this class hold pre-defined stubs for many GemStone
 * server objects.  These stubs are tied to a particular GbjSession
 * and should not be used with another session.  Access is normally
 * through the <i>kernel</i> variable of a GbjSession, as in<br>
 * <pre>
 *      session.kernel.System.sendMsg("transactionConflicts");
 * </pre>
 *
 * @version 3.2
 */


public class GbjKernelObjects {

   /**
     * Largest possible SmallInteger
     */
    public long maxSmallInteger;
    /**
     * Smallest possible SmallInteger
     */
    public long minSmallInteger;
    /**
     * Interface class for GBJ 
     */
    public GbjObject GbjGciInterface;
    /**
     * Illegal represents a non-existant GemStone object
     */
    public GbjObject Illegal;
    /**
     * Zero represents a server "zero" object of class SmallInteger
     */
    public GbjObject Zero;
    /**
     * One represents a server "one" object of class SmallInteger
     */
    public GbjObject One;
    /**
     * True represents the server "true" object of class Boolean
     */
    public GbjObject True;
    /**
     * False represents the server "false" object of class Boolean
     */
    public GbjObject False;
    /**
     * Nil represents a server nil.  This is the Smalltalk equivalent of Java's null.
     */
    public GbjObject Nil;
    /**
     * GSGemStoneError refers to GemStone's error category dictionary.  This is
     * commonly the "category" element of a GbjException object.
     */
    public GbjObject GemStoneError;

    /**
     * System is an abstract class that has no instances.  It implements class<br>
     *  methods for object locking and for operations that are usually found in<br>
     *  traditional operating systems.  The data curator may restrict user access to<br>
     *  these messages.  For an explanation of the role of the data curator, refer to<br>
     *  your GemStone System Administration Guide.
     */
    public GbjObject System;


/* NOTE: FOLLOWING CODE AUTO-GENERATED BY THE GS CODE IN:
   GbjToolsSupport generateJavaCode

   GBJ30: 
   Most declarations have been commented out but 
   retained in case we decide to re-activate them.

/*

	/**
	 * AbstractCharacter is an abstract superclass that defines behavior common to<br>
	 *  one-byte and two-byte character classes.  Its concrete subclasses include<br>
	 *  Character and JISCharacter.
	 */
	//public GbjObject AbstractCharacter;
	/**
	 * An AbstractCollisionBucket is an Array that is used in a KeyValueDictionary to<br>
	 *  store a collection of key/value pairs for which the keys hash to the same<br>
	 *  value.
	 */
	//public GbjObject AbstractCollisionBucket;
	/**
	 * AbstractDictionary is an abstract class that provides the protocol for<br>
	 *  collections whose elements can be accessed by an associated lookup key.<br>
	 *  Concrete classes of AbstractDictionary store the key-value pairs either<br>
	 *  directly or as Associations.  See the documentation for the Dictionary and<br>
	 *  KeyValueDictionary classes for more information.
	 */
	//public GbjObject AbstractDictionary;
	/**
	 * AbstractSession is an abstract class for describing within GemStone sessions<br>
	 *  that exist either in GemStone or in some other server software.  It is<br>
	 *  intended to provide support in GemStone for two-phase commit protocols between<br>
	 *  transactions in related sessions.<br>
	 * <br>
	 *  For example, a session external to GemStone could be a session in an external<br>
	 *  database.  It could be spawned by the current GemStone session.  The GemStone<br>
	 *  session object permits access to its symbol list for name resolution within its<br>
	 *  name space, enables execution of Smalltalk code within the session, and allows<br>
	 *  control of its transaction state.
	 */
	//public GbjObject AbstractSession;
	/**
	 * An AbstractUserProfileSet is an IdentitySet whose elements must be instances of<br>
	 *  class UserProfile.  You may not create subclasses or instances of <br>
	 *  AbstractUserProfileSet.  Only one instance of AbstractUserProfileSet is<br>
	 *  permitted in a GemStone repository that was upgraded from GemStone v4.1.
	 */
	//public GbjObject AbstractUserProfileSet;

	/**
	 * Array is a concrete subclass of SequenceableCollection that capitalizes upon<br>
	 *  the indexability of its elements.  An Array permits its elements to be placed<br>
	 *  in any order, but once placed, it retains the order until changed explicitly.<br>
	 *  Integer indexes are often used to access elements directly, randomly, or in<br>
	 *  alternate or unpredictable orders not necessarily related to the sequence of<br>
	 *  the elements as placed in the collection.  Thus, an index is often used as<br>
	 *  the address for an element.<br>
	 * <br>
	 *  Uninitialized Array elements are nil.
	 */
	public GbjObject Array;
	/**
	 * An Association is a pair of associated objects: a key and a value.  A<br>
	 *  Dictionary is a collection of Associations; thus, much of the protocol that<br>
	 *  affects Associations is actually defined for instances of Dictionary.  See the<br>
	 *  description of Dictionary for details.
	 */
	public GbjObject Association;
	/**
	 * A Bag is an UnorderedCollection in which any distinct object can occur any<br>
	 *  number of times.  Adding the same (identical) object to a Bag multiple times<br>
	 *  simply causes it to occur multiple times in the Bag.<br>
	 * <br>
	 *  Since a Bag is an equality-based collection, different (non-identical) but<br>
	 *  equivalent (equal) objects are not treated as distinct from each other.  In<br>
	 *  IdentityBags, they are distinct.  Adding multiple equivalent objects to a Bag<br>
	 *  yields a Bag with multiple occurrences of the object that was added last.<br>
	 * <br>
	 */
	//public GbjObject Bag;
	/**
	 * Behavior is an abstract superclass with two concrete subclasses:<br>
	 *  Metaclass and Class.  You may not create any other subclasses of Behavior.<br>
	 * <br>
	 *  Behavior describes the protocol common to all instances of Class<br>
	 *  and Metaclass.  In other words, you can send the messages listed<br>
	 *  here to any Class or Metaclass.  In the method descriptions below,<br>
	 *  "superclass" refers to the superclass of instances of the receiver,<br>
	 *  not to the superclass of the receiver itself.
	 */
	//public GbjObject Behavior;
	/**
	 * BinaryFloat is an abstract class.  Various subclasses provide different<br>
	 *  implementations of Binary floating point.  Each subclass is expected<br>
	 *  to conform to IEEE Standard 754.
	 */
	//public GbjObject BinaryFloat;
	/**
	 * The class Block is obsolete as of GemStone version 4.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject Block;
	/**
	 * BlockClosure is an abstract superclass for all the different kinds of blocks<br>
	 *  of GemStone Smalltalk code.
	 */
	//public GbjObject BlockClosure;
	/**
	 * The only two instances of Boolean represent the two logical truth values:<br>
	 *  true and false.<br>
	 * <br>
	 *  You may not create new instances of Boolean.  You also may not create<br>
	 *  subclasses of Boolean.
	 */
	//public GbjObject Boolean;
	/**
	 * A ByteArray is a SequenceableCollection whose elements are SmallIntegers with<br>
	 *  a value between zero and 255 inclusive.  Uninitialized ByteArray elements are<br>
	 *  zero.
	 */
	//public GbjObject ByteArray;
	/**
	 * A CanonicalStringDictionary is a StringKeyValueDictionary that provides<br>
	 *  protocol that is similar to Set in addition to its dictionary protocol.
	 */
	//public GbjObject CanonicalStringDictionary;
	/**
	 * There are 65536 Characters.  You may not create new instances or subclasses of<br>
	 *  class Character.
	 */
	//public GbjObject Character;
	/**
	 * CharacterCollection is an abstract superclass for behavior that is common<br>
	 *  to all indexed collections of Characters.<br>
	 * <br>
	 *  Subclasses must reimplement the following selectors:<br>
	 * <br>
	 *  size<br>
	 *  size:<br>
	 *  at:<br>
	 *  at:put:<br>
	 *  removeFrom:to:<br>
	 *  insertAll:at:<br>
	 * <br>
	 *  However these selectors do not generate the subclass-responsibility error<br>
	 *  (error 2008) because to do so would break the Object | printString method.
	 */
	//public GbjObject CharacterCollection;
	/**
	 * Each of the classes in the GemStone kernel inherits some of its behavior from<br>
	 *  Class.<br>
	 * <br>
	 *  You may send the messages described here to any of the kernel classes<br>
	 *  (class-defining objects) defined in this manual.  However, you may not send<br>
	 *  these messages to instances of the kernel classes (that is, unless the<br>
	 *  receiver is an instance of Class).<br>
	 * <br>
	 *  Consider the following example.  The description of class SmallInteger<br>
	 *  contains two kinds of protocol: instance methods and class methods.  Instance<br>
	 *  methods are understood by SmallIntegers (instances of the class SmallInteger,<br>
	 *  which inherit their protocol from Integer, Number, Magnitude, and Object).<br>
	 *  Class methods are understood by the class-defining object SmallInteger itself<br>
	 *  (which is the single instance of the Metaclass "SmallInteger class", and<br>
	 *  inherits its protocol from Class, Behavior, and Object).  The messages<br>
	 *  described here (for Class) are understood by SmallInteger; that is, they are<br>
	 *  class methods for the class-defining object), but are not understood by<br>
	 *  instances of SmallInteger.
	 */
	//public GbjObject Class;
	/**
	 * A ClassHistory is a sequence of Class objects that logically represent the<br>
	 *  historical revisions to a Class.
	 */
	//public GbjObject ClassHistory;
	/**
	 * A ClassOrganizer collects classes from the current user's symbol list<br>
	 *  and organizes them into searchable tables that allow tools to present<br>
	 *  the classes and to perform cross-referencing and fileout.<br>
	 * <br>
	 *  An organizer can also be created to work with a subtree of another<br>
	 *  organizer's hierarchy.  Such organizers do not track categorization<br>
	 *  of classes but only the subtree of the overall hierarchy.
	 */
	//public GbjObject ClassOrganizer;
	/**
	 * A ClassSet is an IdentitySet that holds only Class objects.
	 */
	//public GbjObject ClassSet;
	/**
	 * The class ClientForwarder implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A client forwarder is an instance of the new class ClientForwarder in GemStone.<br>
	 *  When a client forwarder is sent a message during GemStone Smalltalk execution,<br>
	 *  GemBuilder for Smalltalk directs that message to the client object that<br>
	 *  corresponds to the ClientForwarder.  Arguments to the message are replicated as<br>
	 *  necessary, and when client execution completes, the result is replicated back<br>
	 *  into GemStone as the result of the message send to the ClientForwarder.<br>
	 * <br>
	 *  This class is considered private and for use by GemStone implementors only.<br>
	 *  Design of an error-handling mechanism that integrates the exception mechanisms<br>
	 *  of the client and GemStone can is deferred until a later release.<br>
	 * <br>
	 *  If the execution stack containing the forwarded send includes client<br>
	 *  stack frames down the stack from the GemStone method that invoked the send<br>
	 *  to the client, the exception handler environment in the context of the<br>
	 *  forwarded method execution will include exceptions in the previous client<br>
	 *  stack, but will not include exceptions in GemStone.  That is, exception<br>
	 *  handlers installed in the GemStone part of the stack will be ignored, and<br>
	 *  an exception handler in a previous client invocation may be invoked.<br>
	 * <br>
	 *  If an exception handler executing in a previous client stack section above<br>
	 *  the GemStone Activation that sent the forwarded message proceeds in a<br>
	 *  manner which discards stack above the frame where the exception is<br>
	 *  handled, the entire section of GemStone stack will be discarded.
	 */
	//public GbjObject ClientForwarder;
	/**
	 * A ClusterBucket describes clustering behavior.  A ClusterBucket represents<br>
	 *  an abstract collection of pages within the repository ; the collection<br>
	 *  has no defined size and cannot be enumerated.
	 */
	//public GbjObject ClusterBucket;
	/**
	 * A ClusterBucketArray is an Array whose elements are instances of ClusterBucket.<br>
	 * <br>
	 *  There is one instance of ClusterBucketArray in a fresh GemStone repository.  It<br>
	 *  can be accessed via the Globals dictionary using the following GemStone<br>
	 *  Smalltalk statement:<br>
	 * <br>
	 *  Globals at: #AllClusterBuckets.<br>
	 * <br>
	 *  GemStone uses AllClusterBuckets to translate clusterIds to cluster bucket<br>
	 *  objects:<br>
	 * <br>
	 *  classmethod: ClusterBucket<br>
	 *  bucketWithId: aSmallPositiveInt<br>
	 *    ^ AllClusterBuckets at: aSmallPositiveInt<br>
	 *  %<br>
	 * <br>
	 *  AllClusterBuckets has a reserved object identifier, to facilitate efficient<br>
	 *  access of the Array from within the object manager.  Therefore, a special C<br>
	 *  constant, OOP_ALL_CLUSTER_BUCKETS, is defined in the gcioop.ht header file to<br>
	 *  permit access to it from C.
	 */
	//public GbjObject ClusterBucketArray;
	/**
	 * Collection is an abstract superclass for all classes whose instances represent<br>
	 *  a collection of other objects that are known as their elements.  It defines<br>
	 *  methods for operating upon the elements as a whole.<br>
	 * <br>
	 *  You should not add elements to or remove elements from a Collection at the same<br>
	 *  time as you are iterating over all or part of the Collection.  Doing so may<br>
	 *  have unpredictable consequences.  For example, avoid changing a Collection<br>
	 *  within the block argument for methods like do:, collect:, select:, reject:, and<br>
	 *  their variants or extensions.
	 */
	//public GbjObject Collection;
	/**
	 * A CollisionBucket is an Array that is used in a KeyValueDictionary to store<br>
	 *  a collection of key/value pairs for which the keys hash to the same value.
	 */
	//public GbjObject CollisionBucket;
	/**
	 * CompiledMethod is an obsolete class.  Instances are methods that<br>
	 *  were compiled and committed before Gemstone/S 32bit v5.x .<br>
	 *  Any such instances must be recompiled to create instances of GsMethod<br>
	 *  before they can be executed
	 */
	//public GbjObject CompiledMethod;
	/**
	 * A ComplexBlock references a variable context to access variables in enclosing<br>
	 *  scopes.<br>
	 * <br>
	 *  The GemStone virtual machine creates all complex blocks.  When a complex block<br>
	 *  becomes active, it does not require the creation of a variable context<br>
	 *  because it has no nested blocks that refer to its arguments or temporaries.<br>
	 *  The virtual machine allocates the block's arguments and temporaries on the<br>
	 *  execution stack.
	 */
	//public GbjObject ComplexBlock;
	/**
	 * A ComplexVCBlock is a special kind of complex block that does require the<br>
	 *  creation of a variable context when it becomes active.  It contains a nested<br>
	 *  block that refers to its arguments or temporaries, which must be allocated in<br>
	 *  the variable context.
	 */
	//public GbjObject ComplexVCBlock;
	/**
	 * The class ConstrainedPathEvaluator implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  This class is not supported in this release of GSS64 (v2.1 and beyond).
	 */
	//public GbjObject ConstrainedPathEvaluator;
	/**
	 * The class ConstrainedPathTerm implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  This class is not supported in this release of GSS64 (v2.1 and beyond).
	 */
	//public GbjObject ConstrainedPathTerm;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject CriticalSection;
	/**
	 * An instance of Date describes a date after December 31, 1900.<br>
	 * <br>
	 *  You can convert a Date to a String (using Formatting instance methods), and<br>
	 *  you can convert a String to a Date (using Instance Creation class methods).<br>
	 *  Such conversions require a specification to describe the format of the String.<br>
	 *  Some methods provide for the default format, DD/MM/YYYY, which expresses the<br>
	 *  day and month (in that order) as digits.<br>
	 * <br>
	 *  Explicit string-formatting specifications take the form of an Array, described<br>
	 *  in the following table.  A specification is incorrect if it is missing an<br>
	 *  element or if an element value is not one of the acceptable values listed in<br>
	 *  the table.<br>
	 * <br>
	 *  String-formatting Specification Array for Date.<br>
	 * <br>
	 *  Element   Acceptable Value       Explanation<br>
	 * <br>
	 *  1st,      Integers 1, 2,         Determines the position of the day (1),<br>
	 *  2nd, and  and 3, in any          month (2), and year (3).<br>
	 *  3rd       order<br>
	 * <br>
	 *  4th       A Character literal    Separates year, month, and day.<br>
	 *            (such as a space, $ )<br>
	 * <br>
	 *  5th       Integer                Determines the month format to be a number (1),<br>
	 *                                   three-letter abbreviation (2), or the entire<br>
	 *                                   name (3).<br>
	 * <br>
	 *  6th       Integer                Determines the year format to be the entire<br>
	 *                                   number (1), or only the last two digits (2).
	 */
	//public GbjObject Date;
	/**
	 * This is the GemStone/S override to access System data.<br>
	 * <br>
	 * This protocol describes the behavior that is common to date <br>
	 * time objects. Date time objects represent individual points <br>
	 * in Coordinated Universal Time (UTC) as represented in an<br>
	 * implementation defined local time.<br>
	 * <br>
	 * The exact properties of local times are unspecified. Local <br>
	 * times may differ in their offset from UTC. A given local time <br>
	 * may have different offsets from UTC at different points in time.<br>
	 * <br>
	 * All dates and times in the UTC local time are in the Gregorian <br>
	 * calendar. Date times prior to the adoption of the Gregorian <br>
	 * calendar are given in the retrospective astronomical Gregorian <br>
	 * calendar. The year 1 B.C. is astronomical Gregorian year 0. <br>
	 * The year 2 B.C. is astronomical Gregorian year-1. The year 1 A.D. <br>
	 * is astronomical Gregorian year 1. The offset of the UTC local <br>
	 * time is zero.
	 */
	//public GbjObject DateAndTime;
	/**
	 * This protocol describes the behavior that is common to date <br>
	 * time objects. Date time objects represent individual points <br>
	 * in Coordinated Universal Time (UTC) as represented in an<br>
	 * implementation defined local time.<br>
	 * <br>
	 * The exact properties of local times are unspecified. Local <br>
	 * times may differ in their offset from UTC. A given local time <br>
	 * may have different offsets from UTC at different points in time.<br>
	 * <br>
	 * All dates and times in the UTC local time are in the Gregorian <br>
	 * calendar. Date times prior to the adoption of the Gregorian <br>
	 * calendar are given in the retrospective astronomical Gregorian <br>
	 * calendar. The year 1 B.C. is astronomical Gregorian year 0. <br>
	 * The year 2 B.C. is astronomical Gregorian year-1. The year 1 A.D. <br>
	 * is astronomical Gregorian year 1. The offset of the UTC local <br>
	 * time is zero.
	 */
	//public GbjObject DateAndTimeANSI;
	/**
	 * An instance of DateTime describes a moment in time (with one second resolution)<br>
	 *  on a date after December 31, 1900. All instances of DateTime are invariant.<br>
	 * <br>
	 *  The internal representation of a DateTime is based on Greenwich Mean Time.<br>
	 *  However, many methods express time in the local time zone.  ("Local" time is<br>
	 *  local to your Gem process.)  These methods automatically convert between<br>
	 *  time zones, but the internal representation remains in Greenwich Mean Time.<br>
	 *  Hence, you can interact with DateTime methods in a natural way, but DateTime<br>
	 *  objects can be safely compared to each other no matter what time zone is used<br>
	 *  to express them.<br>
	 * <br>
	 *  You can convert a DateTime to a String (using Formatting instance methods), and<br>
	 *  you can convert a String to a DateTime (using Instance Creation class methods).<br>
	 *  Such conversions require a specification to describe the format of the String.<br>
	 *  Some methods provide for the default format, DD/MM/YYYY HH:MM:SS, which<br>
	 *  expresses the day and month (in that order) as digits and uses a 24-hour clock.<br>
	 * <br>
	 *  Explicit string-formatting specifications take the form of an Array, described<br>
	 *  in the following table.  A specification is incorrect if it is missing an<br>
	 *  element or if an element value is not one of the acceptable values listed in<br>
	 *  the table.<br>
	 * <br>
	 *  String-formatting Specification Array for DateTime.<br>
	 * <br>
	 *  Element   Acceptable Value       Explanation<br>
	 * <br>
	 *  1st,      Integers 1, 2,         Determines the position of the day (1),<br>
	 *  2nd, and  and 3, in any          month (2), and year (3).<br>
	 *  3rd       order<br>
	 * <br>
	 *  4th       A Character literal    Separates year, month, and day.<br>
	 *            (such as a space, $ )<br>
	 * <br>
	 *  5th       Integer                Determines the month format to be a number (1),<br>
	 *                                   three-letter abbreviation (2), or the entire<br>
	 *                                   name (3).<br>
	 * <br>
	 *  6th       Integer                Determines the year format to be the entire<br>
	 *                                   number (1), or only the last two digits (2).<br>
	 * <br>
	 *  7th       A Character literal    Separates hours, minutes, and seconds.<br>
	 *            (such as $: or $.)<br>
	 * <br>
	 *  8th       true                   Include the time of day.<br>
	 * <br>
	 *  8th       false                  Do not include the time of day.  Ignore elements<br>
	 *                                   7, 9, and 10.  Elements 9 and 10 are optional<br>
	 *                                   in the specification.<br>
	 * <br>
	 *  9th       true                   Include seconds.<br>
	 * <br>
	 *  9th       false                  Do not include seconds.<br>
	 * <br>
	 *  10th      true                   Time is expressed in 12-hour format, with<br>
	 *                                   am or pm (such as 1:30:55 pm).  The space is<br>
	 *                                   required preceding the am or pm indicator.<br>
	 * <br>
	 *  10th      false                  Time is expressed in 24-hour format<br>
	 *                                   (such as 13:30:55).<br>
	 * <br>
	 *  11th      true                   Include the time zone information.<br>
	 * <br>
	 *  12th      true                   Use the time zone information of the time zone<br>
	 * 			          in which the DateTime was created rather than<br>
	 *                                   the local time zone.
	 */
	//public GbjObject DateTime;
	/**
	 * This class represents base 10 floating point numbers, as defined in IEEE<br>
	 *  standard 854-1987.<br>
	 * <br>
	 *  You may not create subclasses of DecimalFloat.<br>
	 * <br>
	 *  Objects of class DecimalFloat have 20 digits of precision, with an exponent in<br>
	 *  the range -15000 to +15000.  The first byte has encoded in it the sign and kind<br>
	 *  of the floating-point number.  Bit 0 is the sign bit (0=positive, 1=negative).<br>
	 *  The values in bits 1 through 3 indicate the kind of DecimalFloat:<br>
	 * <br>
	 *  * 001x = normal<br>
	 *  * 010x = subnormal<br>
	 *  * 011x = infinity<br>
	 *  * 100x = zero<br>
	 *  * 101x = quiet NaN<br>
	 *  * 110x = signaling NaN<br>
	 * <br>
	 *  Bytes 2 and 3 encode the exponent as a biased 16-bit number (byte 2 is more<br>
	 *  significant).  The actual exponent is calculated by subtracting 15000.  Bytes<br>
	 *  4 through 13 form the mantissa of the number.  Each byte holds two BCD digits,<br>
	 *  with bits 4 through 7 of byte 4 containing the most significant digit.
	 */
	//public GbjObject DecimalFloat;
	/**
	 * Delay is used in conjunction with GsProcess and ProcessorScheduler<br>
	 *  to suspend processes for specified amounts of time, and to resume <br>
	 *  processes. 
	 */
	//public GbjObject Delay;
	/**
	 * The class DependencyList implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject DependencyList;
	/**
	 * The class DepListBucket implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A DepListBucket is a collision bucket for a DepListTable.
	 */
	//public GbjObject DepListBucket;
	/**
	 * The class DepListTable implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A DepListTable is used to hold a global collection of DependencyLists that<br>
	 *  are shared by multiple objects.
	 */
	//public GbjObject DepListTable;
	/**
	 * Dictionary is a concrete subclass of AbstractDictionary.  In each Dictionary,<br>
	 *  all keys should be of the same class.<br>
	 * <br>
	 *  A Dictionary stores key-value pairs as instances of class Association, and is<br>
	 *  therefore a collection of Associations.  As a result, a Dictionary has two<br>
	 *  kinds of instance protocols:<br>
	 * <br>
	 *  * Methods that view the Dictionary as key/value pairs.<br>
	 *  * Methods that involve the Association objects themselves.<br>
	 * <br>
	 *  A Dictionary is also an equality-based collection.  That is, two keys or two<br>
	 *  values are considered to be the same if they are equivalent; they need not be<br>
	 *  identical to be the same.  Thus, if you add two key-value pairs to a Dictionary<br>
	 *  but the keys are equivalent, even if they are not identical, then the result is<br>
	 *  that the second pair overwrites the first one, because the keys are the same.<br>
	 * <br>
	 *  Some other kinds of dictionaries do not store key-value pairs as Associations.<br>
	 *  Still other kinds are identity-based rather than equality-based.  These other<br>
	 *  kinds of dictionaries exhibit better performance than Dictionary and are to be<br>
	 *  preferred where they are appropriate.<br>
	 * <br>
	 *  WARNING: do not implement subclasses of Dictionary that use the implementation<br>
	 *  of Dictionary and compare keys by Identity.  All identity based dictionary<br>
	 *  classes must be a subclass of IdentityKeyValueDictionary or IdentityDictionary<br>
	 *  in order for GemStone's Symbol canonicalization to work properly.
	 */
	//public GbjObject Dictionary;
	/**
	 * A DoubleByteString is a string for which each Character occupies two bytes.<br>
         *  the two bytes are in CPU native byte order when objects are in memory.
	 * <br>
	 */
	//public GbjObject DoubleByteString;
	/**
	 * A Smalltalk symbol may be an instance of Symbol, DoubleByteSymbol or QuadByteSymbol.
         * symbols are canonical and invariant and the persistent instances are created by the symbol gem,
         * which is started automatically by stone.
	 * <br>
	 *  EUCSymbols are obsolete and no longer supported.
	 */
	//public GbjObject DoubleByteSymbol;
	/**
	 * Represents a length of time (from ANSI).
	 */
	//public GbjObject Duration;
	/**
	 * EqualityIndexQueryEvaluator is a concrete class that implements the behavior used to <br>
	 *  evaluate queries against UnordedCollections that have equality indexes. This class is<br>
	 *  used in the internal implementation of indexing and should not be modified.
	 */
	//public GbjObject EqualityIndexQueryEvaluator;
	/**
	 * The class protocol describe the behavior of the global Error. The value <br>
	 * of the standard global Error is a class object that conforms to this <br>
	 * protocol. The class Error is explicitly specified to be subclassable in <br>
	 * a standard conforming program. Conforming implementations must implement <br>
	 * its behaviors in a non-fragile manner.<br>
	 * <br>
	 * The signaled exceptions generated by this type of object conform to the <br>
	 * protocol <Error>.<br>
	 * <br>
	 * The instance protocol describes the behavior of instances of class Error. <br>
	 * These are used to represent error conditions that prevent the normal <br>
	 * continuation of processing. Actual error exceptions used by an application <br>
	 * may be subclasses of this class.<br>
	 * <br>
	 * As Error is explicitly specified to be subclassable, conforming <br>
	 * implementations must implement its behavior in a non- fragile manner.
	 */
	//public GbjObject Error;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject ErrorDescription;
	/**
	 * EUCString is obsolete and not supported.
	 */
	//public GbjObject EUCString;
	/**
	 * EUCSymbol is obsolete and not supported
	 */
	//public GbjObject EUCSymbol;
	/**
	 * This is a simple example of a test.
	 */
	//public GbjObject ExampleSetTest;
	/**
	 * An Exception is an object that represents a state to be invoked in the event<br>
	 *  of an error.
	 */
	//public GbjObject Exception;
	/**
         * See the Smalltalk image starting at AbstractException for documentation.
	 */
	//public GbjObject ExecutableBlock;
	/**
	 * This protocol describes the behavior of objects that represent a message <br>
	 * that was sent to an object, but was not understood by that object.
	 */
	//public GbjObject FailedMessage;
	/**
	 * FastIdentityKeyValueDictionary is a subclass of GsMethodDictionary designed<br>
	 *  for customer applications.  FastIdentityKeyValueDictionary employs the same<br>
	 *  internal structure as GsMethodDictionary that is well-suited for efficient <br>
	 *  execution in smaller dictionaries.<br>
	 * <br>
	 *  The keys of FastIdentityKeyValueDictionaries must be canonical symbols <br>
	 *  (Symbols or DoubleByteSymbols).
	 */
	//public GbjObject FastIdentityKeyValueDictionary;
	/**
	 * This class represents 8-byte binary floating point numbers, as defined in IEEE<br>
	 *  standard 754.<br>
	 * <br>
	 *  You may not create subclasses of Float.<br>
	 * <br>
	 *  The mathematics package of the vendor of the machine where the Gem is running<br>
	 *  implements the numerical behavior of instances of Float.<br>
	 * <br>
	 *  Each float contains a 64 bit value.  The floats are stored on Disk and<br>
	 *  in object memory in CPU native byte order.  GemStone Smalltalk primitives and<br>
	 *  GemBuilder for C (GCI) float conversion functions automatically convert <br>
	 *  the format of a float to or from the machines' native format, as required.<br>
	 * <br>
	 *  Do not use GciFetch/StoreBytes() directly on a Float.  Use GciOopToFlt and<br>
	 *  GciFltToOop instead.  If you choose to violate this rule, and are using<br>
	 *  an Intel x86 processor, you must convert the format of a float yourself.<br>
	 * <br>
	 *  The following details are provided for application programmers who choose<br>
	 *  to access bytes of a float directly.<br>
	 * <br>
	 *  Starting from the most significant bit of the byte (self _basicAt: 1), the<br>
	 *  bits of a Float are as follows:<br>
	 * <br>
	 *  *  1 bit of sign (0 means positive, 1 means negative)<br>
	 *  * 11 bits of exponent<br>
	 *  * 52 bits of mantissa<br>
	 * <br>
	 *  Here are the 8 byte patterns of the exceptional values:<br>
	 * <br>
	 *                    byte 1                                           byte 8<br>
	 *  PlusQuietNaN       16#7f  16#ff  16#ff  16#ff  16#ff  16#ff  16#ff  16#ff<br>
	 *  MinusQuietNaN      16#ff  16#ff  16#ff  16#ff  16#ff  16#ff  16#ff  16#ff<br>
	 *  MinusInfinity      16#ff  16#f0      0      0      0      0      0      0<br>
	 *  MinusSignalingNaN  16#ff  16#f0      0      0      0      0      0      1<br>
	 *  PlusSignalingNaN   16#7f  16#f0      0      0      0      0      0      0<br>
	 *  PlusSignalingNaN   16#7f  16#f0      0      0      0      0      0      1<br>
	 * <br>
	 *  If the Float is an exceptional value (a NaN or an Infinity) then<br>
	 *  the exponent bits are all 1.  If in addition the mantissa is 0 then<br>
	 *  the float is an Infinity; if the mantissa is non-zero then the<br>
	 *  float is a NaN.  In a NaN, if the most significant bit of the<br>
	 *  Mantissa is 1 then the NaN is a quiet NaN.
	 */
	//public GbjObject Float;
	/**
	 * A Fraction is a Number represented as the ratio of two Integers.
	 */
	//public GbjObject Fraction;
	/**
	 * GciInterface is a Smalltalk representation for the functions defined<br>
	 *  in $GEMSTONE/include/gci.hf .  Using GciInteface a session may<br>
	 *  execute GCI functions in another session .
	 */
	//public GbjObject GciInterface;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject GemStoneParameters;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject GsClassDocumentation;
	/**
	 * The class GsCloneList is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject GsCloneList;
	/**
	 * The class GsCommitList implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject GsCommitList;
	/**
	 * GsCurrentSession provides a public interface to the current GemStone session.<br>
	 *  There is only one instance of GsCurrentSession in each GemStone session.<br>
	 *  The GemStone server creates it automatically when a user logs into GemStone.<br>
	 *  The instance is transient and cannot be accessed after the user logs out of<br>
	 *  GemStone.
	 */
	//public GbjObject GsCurrentSession;
	/**
	 * The class GsDocText implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A GsDocText is a unit of textual documentation.  It retains information<br>
	 *  about only one thing.  That thing may, however, be a single item of any kind,<br>
	 *  or it may be a group of items considered as an aggregate.
	 */
	//public GbjObject GsDocText;
	/**
	 * The class GsfClassDefinitionInfo implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  GsfClassDefinitionInfo is a placeholder for another related GemStone product that has not currently<br>
	 *   been installed.
	 */
	//public GbjObject GsfClassDefinitionInfo;
	/**
	 * GsFile provides the means for creating and accessing non-GemStone files.  Such<br>
	 *  files reside in the file system on either the machine that is running the<br>
	 *  current session's Gem process (the server machine) or the machine that is<br>
	 *  running the client application (the client machine).  The files may be of any<br>
	 *  type, textual or binary, though separate protocol is provided for reading and<br>
	 *  writing these types of data.<br>
	 * <br>
	 *                               Warning:<br>
	 *     Do not retain an instance of GsFile from one session to another.<br>
	 *     Instances of GsFile are intended to exist only within a given GemStone<br>
	 *     session.  GsFiles that are used across sessions always generate an error.
	 */
	//public GbjObject GsFile;
	/**
	 * The class GsfModificationLog implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  GsfModificationLog is a placeholder for another related GemStone product that has not currently<br>
	 *   been installed.
	 */
	//public GbjObject GsfModificationLog;
	/**
	 * A GsInterSessionSignal represents a signal from one session to another within<br>
	 *  a single GemStone system.
	 */
	//public GbjObject GsInterSessionSignal;
	/**
	 * A GsMethod is a compiled form of a GemStone Smalltalk method.
	 */
	//public GbjObject GsMethod;
	/**
	 * GsMethodDictionary optimizes IdentityKeyValueDictionary for use as method<br>
	 *  dictionaries in classes.  It employs a different internal structure that is<br>
	 *  well-suited for efficient execution in smaller dictionaries.  Changes to<br>
	 *  GsMethodDictionies are protected by the #CodeModification privilege, and<br>
	 *  therefore should not be used in customer applications.  For this purpose,<br>
	 *  you should use the subclass FastIdentityKeyValueDictionary.<br>
	 * <br>
	 *  The keys of method dictionaries must be canonical symbols (Symbols or<br>
	 *  DoubleByteSymbols).<br>
	 * <br>
	 *  Implementation details:<br>
	 *  Within the hash table, entries are of size two and contain key/value pairs:<br>
	 *     aSymbol, aValue<br>
	 *     nil,     SmallInteger - one-based offset of start of collision chain<br>
	 *     nil,     nil          - empty hash slot<br>
	 *  <br>
	 *  Collisions chains are linked lists within the root object itself, and<br>
	 *  are stored in the area after the hash table.  <br>
	 *  Collision list entries are triples (key, value, nextOffset):<br>
	 *     aSymbol, aValue, nextOffset - entry in chain, nextOffset is one-based<br>
	 *     aSymbol, aValue, nil        - end of chain<br>
	 *     nil,     nil,    nextOffset - empty element in collision chain, only<br>
	 *                                   removed by rebuildTable <br>
	 * 
	 */
	//public GbjObject GsMethodDictionary;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject GsPackage;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject GsPackageLibrary;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject GsPackagePolicy;
	/**
	 * A GsProcess represents a suspended GemStone Smalltalk call stack, including<br>
	 *  information needed to restart execution.
	 */
	//public GbjObject GsProcess;
	/**
	 * The class GsRdbConnection implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  GsRdbConnection supports connections between GemStone and gateway sessions to<br>
	 *  a relational database.  The GemStone session must coordinate commit protocols<br>
	 *  with the database.
	 */
	//public GbjObject GsRdbConnection;
	/**
	 * A GsSession represents a user session on the GemStone server where the<br>
	 *  instance exists.  It is a transient object that is useful only as long<br>
	 *  as the user remains logged in to GemStone.<br>
	 * <br>
	 *  A GsSession can access the UserProfile of the user who is logged in to<br>
	 *  GemStone, can provide some minimal control over session execution, and<br>
	 *  can send and receive signals with other sessions.<br>
	 * <br>
	 *  The current session is represented by a GsCurrentSession, a special<br>
	 *  subclass of GsSession.  Instances of GsSession typically represent<br>
	 *  other concurrent GemStone sessions in the same server.
	 */
	//public GbjObject GsSession;
	/**
	 * GsSessionMethodDictionary is a subclass of GsMethodDictionary to be used<br>
	 *  for storing session methods. The keys of this class are expected to be a <br>
	 *  Behavior and keys are GsMethodDictionaries.
	 */
	//public GbjObject GsSessionMethodDictionary;
	/**
	 * GsSocket provides the means for creating and binding TCP sockets through the<br>
	 *  operating system of the machine that is running the session's Gem process, and<br>
	 *  for communicating across those sockets.  Methods that block GemStone Smalltalk<br>
	 *  until the socket operation completes are interruptable by a hard break.  (You<br>
	 *  can get a hard break in Topaz by pressing the control-C key twice.  You can get<br>
	 *  a hard break in GemBuilder for C by calling the GciHardBreak function, and in<br>
	 *  GemBuilder for Smalltalk by calling the corresponding hard break method.)<br>
	 * <br>
	 *                               Warning:<br>
	 *     Do not retain an instance of GsSocket from one session to another.<br>
	 *     Instances of GsSocket are intended to exist only within a given GemStone<br>
	 *     session.  GsSockets that are used across sessions always generate an error
	 */
	//public GbjObject GsSocket;
	/**
	 * The class GsStackBuffer implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject GsStackBuffer;
	/**
	 * An IdentityBag is an UnorderedCollection in which any distinct object can occur<br>
	 *  any number of times.  Adding the same (identical) object to an IdentityBag<br>
	 *  multiple times simply causes it to occur multiple times in the IdentityBag.<br>
	 * <br>
	 *  Since an IdentityBag is an identity-based collection, different (non-identical)<br>
	 *  but equivalent (equal) objects are treated as distinct from each other.  In<br>
	 *  Bags, they are not distinct.  Adding multiple equivalent objects to an<br>
	 *  IdentityBag yields an IdentityBag with multiple objects as elements, each<br>
	 *  occurring once.
	 */
	//public GbjObject IdentityBag;
	/**
	 * The class IdentityBtreeNode implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject IdentityBtreeNode;
	/**
	 * An IdentityCollisionBucket is a CollisionBucket that is used in an<br>
	 *  IdentityKeyValueDictionary to store a collection of key/value pairs for which<br>
	 *  the keys hash to the same value.  It provides support for the identity<br>
	 *  comparisons required by IdentityKeyValueDictionaries.  The bucket is<br>
	 *  sorted by the identity of the keys. 
	 */
	//public GbjObject IdentityCollisionBucket;
	/**
	 * IdentityDictionary is a Dictionary that is identity-based rather than <br>
	 *  equality-based.<br>
	 * <br>
	 *  IdentityDictionary implements key-value pairs by storing key-Association<br>
	 *  pairs.  Each Association contains a key-value pair, and the key is <br>
	 *  duplicated in the dictionary or collision bucket for implementation reasons.<br>
	 * <br>
	 *  As with other identity-based collections, in an IdentityDictionary two keys or<br>
	 *  two values are considered to be the same only if they are identical; equivalent<br>
	 *  objects are not the same.  Thus, if you add two key-value pairs to an<br>
	 *  IdentityDictionary and the keys are equivalent but not identical, then the<br>
	 *  result is that you have two pairs in the dictionary because the keys are not<br>
	 *  the same.<br>
	 * <br>
	 *  IdentityDictionary exhibits better performance than Dictionary and is to be<br>
	 *  preferred where it is appropriate.
	 */
	//public GbjObject IdentityDictionary;
	/**
	 * The class IdentityIndex implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject IdentityIndex;
	/**
	 * IdentityIndexQueryEvaluator is a concrete class that implements the behavior used to <br>
	 *  evaluate queries against UnordedCollections that have identity indexes. This class is<br>
	 *  used in the internal implementation of indexing and should not be modified.
	 */
	//public GbjObject IdentityIndexQueryEvaluator;
	/**
	 * IdentityKeySoftValueDictionary is a subclass of KeySoftValueDictionary<br>
	 *  which uses identity comparision on keys.
	 */
	//public GbjObject IdentityKeySoftValueDictionary;
	/**
	 * An IdentityKeyValueDictionary is a KeyValueDictionary that is an identity-based<br>
	 *  collection instead of equality-based.  That is, two keys or two values are<br>
	 *  considered to be the same only if they are identical; equivalent objects are<br>
	 *  not the same.  Thus, if you add two key-value pairs to an<br>
	 *  IdentityKeyValueDictionary and the keys are equivalent but not identical, then<br>
	 *  the result is that you have two pairs in the dictionary because the keys are<br>
	 *  not the same.<br>
	 * <br>
	 *  IdentityKeyValueDictionary exhibits better performance than KeyValueDictionary<br>
	 *  and is to be preferred where it is appropriate.<br>
	 * <br>
	 *  For multiuser applications that involve a lot of concurrent use of<br>
	 *  dictionaries, use RcKeyValueDictionary.
	 */
	//public GbjObject IdentityKeyValueDictionary;
	/**
	 * An IdentitySet is an IdentityBag in which any distinct object can occur only<br>
	 *  once.  Adding the same (identical) object to an IdentitySet multiple times is<br>
	 *  redundant.  The result is the same as adding it once.<br>
	 * <br>
	 *  Since an IdentitySet is an identity-based collection, different (non-identical)<br>
	 *  but equivalent (equal) objects are treated as distinct from each other.  In<br>
	 *  Sets, they are not distinct.  Adding multiple equivalent objects to an<br>
	 *  IdentitySet yields an IdentitySet with as many elements as there are distinct<br>
	 *  equivalent objects.  In short, two different elements of an IdentitySet are<br>
	 *  never identical, but they may be equivalent.<br>
	 * <br>
	 *  You can create subclasses of IdentitySet to restrict the kind of elements it<br>
	 *  contains.  When creating a subclass of IdentitySet, you must specify a class as<br>
	 *  the aConstraint argument.  This class is called the element kind of the new<br>
	 *  subclass.  For each instance of the new subclass, the class of each element<br>
	 *  must be of the element kind.
	 */
	//public GbjObject IdentitySet;
	/**
	 * A IdentitySoftCollisionBucket is an IdentityCollisionBucket intended to<br>
	 *  store key/SoftReference pairs .<br>
	 *  key/SoftReference pairs whose SoftReferences have been cleared by <br>
	 *  the in-memory garbage collector will be removed from a <br>
	 *  IdentitySoftCollisionBucket during the next at:put: operation <br>
	 *  following a garbage collection which cleared the references.  <br>
	 *  <br>
	 *  Cleared SoftReferences will also be removed when their key matches<br>
	 *  the argument key for a lookup operation .  The lookup code will<br>
	 *  not remove cleared SoftReferences for non-matching keys.<br>
	 * <br>
	 *  Instances of IdentitySoftCollisionBucket are non-persistent and may<br>
	 *  not be committed to the repository.
	 */
	//public GbjObject IdentitySoftCollisionBucket;
	/**
	 * The class IndexDictionaryEntryHolder implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject IndexDictionaryEntryHolder;
	/**
	 * IndexedQueryEvaluator is an abstract class that implements the behavior used to <br>
	 *  evaluate queries against UnordedCollections that have been indexed. This class is<br>
	 *  used in the internal implementation of indexing and should not be modified.
	 */
	//public GbjObject IndexedQueryEvaluator;
	/**
	 * The class IndexList implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject IndexList;
	/**
	 * IndexManager is provides protocol for managing and maintaining indexed collections.<br>
	 *  The single instance of IndexManager should be accessed via the class message #current.<br>
	 *  In normal use, you will use IndexManager to turn autoCommit for index maintenance<br>
	 *  operations off and on and to define the dirtyObjectCommitThreshold and <br>
	 *  percentTempObjSpaceCommitThreshold, which are control parameters for autoCommit.<br>
	 * <br>
	 *  IndexManager current tracks all instances of UnorderedCollection that have had indexes<br>
	 *  created for them. You may use IndexManager current to #removeAllIndexes, which removes<br>
	 *  indexes from all indexed collections in the system or you may use IndexManager <br>
	 *  current to #removeAllIncompleteIndexes, which removes partial indexes from collections<br>
	 *  when index creation failed without completing.<br>
	 * <br>
	 *  Automatic garbage collection of unreferenced UnorderedCollections is _not_ preformed, so<br>
	 *  one must explicitly remove all indexes from an UnorderedCollection that is no longer used.<br>
	 * <br>
	 *  IndexManager may be subclassed.
	 */
	//public GbjObject IndexManager;
	/**
	 * IndexManagerAutoCommitPolicy implements the behavior for determining when commits should be<br>
	 *  performed when the IndexManager autoCommit feature is enabled. Commits will be performed <br>
	 *  whenever the number of persistent objects modified exceeds the dirtyObjectCommitThreshold or<br>
	 *  when the tempObjSpacePercentUsed crosses the percentTempObjSpaceCommitThreshold.
	 */
	//public GbjObject IndexManagerAutoCommitPolicy;
	/**
	 * This is an abstract superclass that establishes protocol for all GemStone<br>
	 *  Smalltalk integers.  Concrete subclasses include LargePositiveInteger,<br>
	 *  LargeNegativeInteger, and SmallInteger.
	 */
	//public GbjObject Integer;
	/**
	 * An IntegerKeyValueDictionary is a KeyValueDictionary in which the keys are<br>
	 *  Integers.<br>
	 * <br>
	 *  One useful application of IntegerKeyValueDictionary is as an implementation of<br>
	 *  a sparse Array.  If the keys to the dictionary are normal Array indexes and the<br>
	 *  Array indexes used are sparsely scattered over the range of the Array, then<br>
	 *  IntegerKeyValueDictionary can provide a fast implementation that has much lower<br>
	 *  storage costs.
	 */
	//public GbjObject IntegerKeyValueDictionary;
	/**
	 * An Interval represents a finite arithmetic sequence.
	 */
	//public GbjObject Interval;
	/**
	 * An InvariantArray is an Array that is made to be invariant (immutable) when it<br>
	 *  is committed, if it is not already invariant before then.  Unless otherwise<br>
	 *  handled explicitly, an InvariantArray that has not yet been committed is still<br>
	 *  modifiable.  Array literals are always invariant; if you assign one to a<br>
	 *  variable, then the object to which the variable refers cannot be changed.<br>
	 * <br>
	 *  Immutability implies that the Array's size, ordering of elements, and<br>
	 *  element membership cannot be changed.  Thus, if an object is an element of the<br>
	 *  Array, that same object must remain an element of the Array, and it must remain<br>
	 *  located at its current index.  Immutability does not imply that the element<br>
	 *  object itself cannot be changed, but only that its relation to the Array is<br>
	 *  immutable.
	 */
	//public GbjObject InvariantArray;
	/**
	 * This class represents an invariant Japanese string in Extended Unix Code<br>
	 *  format.
	 */
	//public GbjObject InvariantEUCString;
	/**
	 * InvariantString is a subclass of String for which all instances are<br>
	 *  immutable after they are committed.
	 */
	//public GbjObject InvariantString;
	/**
	 * ISOLatin is a subclass of String which provides means for GemStone Smalltalk<br>
	 *  applications to extend the behavior of String with native-language-specific<br>
	 *  sorting or other behavior.<br>
	 * <br>
	 *  ISOLatin inherits all of its behavior from String, and thus inherits the<br>
	 *  the English ASCII defaults for character set interpretation, as provided<br>
	 *  by the C runtime library and by Unix.<br>
	 * <br>
	 *  It is the user's responsibility to create a subclass of ISOLatin and<br>
	 *  implement appropriate comparison methods in the subclass if an application<br>
	 *  requires language-specific sorting or comparison semantics.
	 */
	//public GbjObject ISOLatin;
	/**
	 * Unicode16 and classes Unicode7, Unicode32 support the full Unicode character set<br>
	 *  and use libicu from  https://github.com/unicode-org/icu  for comparison and sorting.
	 */
	//public GbjObject Unicode16;
	/**
	 * The classes  JapaneseString, JISCharacter, JISString <br>
         * are obsolete and not supported by this version
	 */
	//public GbjObject JapaneseString;
	/**
	 * KeySoftValueDictionary is a subclass of KeyValueDictionary.<br>
	 *  Instances of KeySoftValueDictionary are non-persistent and may not be<br>
	 *  committed ot the repository.<br>
	 * <br>
	 *  All values in KeySoftValueDictionary are instances of SoftReference .<br>
	 * <br>
	 *  Various instance methods in KeySoftValueDictionary will automatically<br>
	 *  remove from a KeySoftValueDictionary any SoftReferences whose value<br>
	 *  instVar has been cleared by the in-memory garbage collector.
	 */
	//public GbjObject KeySoftValueDictionary;
	/**
	 * KeyValueDictionary is a concrete subclass of AbstractDictionary.  In a<br>
	 *  KeyValueDictionary, keys may be of mixed classes.<br>
	 * <br>
	 *  A KeyValueDictionary stores key-value pairs under an index that is generated by<br>
	 *  applying a hash function to the key; it does not use Associations.  The hashing<br>
	 *  improves retrieval speed.  However, you must observe an important restriction:<br>
	 *  after a key/value pair has been added to a KeyValueDictionary, you must not<br>
	 *  modify the key.  Doing so renders the value inaccessible.<br>
	 * <br>
	 *  A KeyValueDictionary is also an equality-based collection.  That is, two keys<br>
	 *  or two values are considered to be the same if they are equivalent; they need<br>
	 *  not be identical to be the same.  Thus, if you add two key-value pairs to a<br>
	 *  KeyValueDictionary but the keys are equivalent, even if they are not identical,<br>
	 *  then the result is that the second pair overwrites the first one, because the<br>
	 *  keys are the same.<br>
	 * <br>
	 *  Some other kinds of dictionaries are identity-based rather than equality-based.<br>
	 *  These other kinds of dictionaries exhibit better performance than<br>
	 *  KeyValueDictionary and are to be preferred where they are appropriate.<br>
	 * <br>
	 *  For multiuser applications that involve a lot of concurrent use of<br>
	 *  dictionaries, use RcKeyValueDictionary.
	 */
	//public GbjObject KeyValueDictionary;
	/**
	 * A LanguageDictionary is a SymbolDictionary designed to hold language-dependent<br>
	 *  objects.  Language symbols are used as keys, so that a user's language symbol<br>
	 *  (see UserProfile | nativeLanguage) can be used to find the appropriate object<br>
	 *  for the native language.
	 */
	//public GbjObject LanguageDictionary;
	/**
	 * Instances of LargeNegativeInteger represent negative integers whose values are<br>
	 *  less than the minimum SmallInteger ((2 to the 29th power)).  Each instance of<br>
	 *  LargeNegativeInteger is stored as an Array of bytes, where each<br>
	 *  double-byte pair represents a base 32768 digit.  The first two bytes in that<br>
	 *  Array constitute the least significant base 32768 digit, and the last two <br>
	 *  bytes are the most significant base 32768 digit.  Within each digit, the<br>
	 *  least significant byte is first, followed by the more significant byte.<br>
	 * <br>
	 *  Coercion between LargeNegativeInteger and SmallInteger occurs automatically.
	 */
	//public GbjObject LargeNegativeInteger;
	/**
	 * Instances of LargePositiveInteger represent positive integers whose values are<br>
	 *  greater than the maximum SmallInteger (2 to the 29th power minus 1).  Each<br>
	 *  instance of LargePositiveInteger is stored as an Array of bytes, where each<br>
	 *  double-byte pair represents a base 32768 digit.  The first two bytes in that<br>
	 *  Array constitute the least significant base 32768 digit, and the last two <br>
	 *  bytes are the most significant base 32768 digit.  Within each digit, the<br>
	 *  least significant byte is first, followed by the more significant byte.<br>
	 * <br>
	 *  Coercion between LargePositiveInteger and SmallInteger occurs automatically.
	 */
	//public GbjObject LargePositiveInteger;
	/**
	 *  The Locale class provides access to the host operating system Locale <br>
	 *  environment (see "man -s 5 locale" for details).<br>
	 * <br>
	 *  The current Locale is setup in System sessionState field 16, using the<br>
	 *  internal method System(class)>>_locale.  Applications should access this<br>
	 *  object using the method Locale(class)>>current, rather than calling<br>
	 *  System(class)>>_locale directly.<br>
	 * <br>
	 *  The various fields in the Locale object match those available in the<br>
	 *  C structure lconv after a localeconv() call (see "man localeconv" for <br>
	 *  details).<br>
	 * <br>
	 *  As a convenience, class-side methods allow access to the various fields<br>
	 *  of the current Locale object.  For example:<br>
	 * <br>
	 *       Locale decimalPoint<br>
	 * <br>
	 *  is the same as:<br>
	 * <br>
	 *       Locale current decimalPoint<br>
	 * <br>
	 * 
	 */
	//public GbjObject Locale;
	/**
	 * The class LogEntry implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject LogEntry;
	/**
	 * Magnitude is an abstract superclass that defines methods for kinds of objects<br>
	 *  that are ordered.  Concrete subclasses of Magnitude include Character,<br>
	 *  DateTime, and Integer.
	 */
	//public GbjObject Magnitude;
	/**
	 * The class MappingInfo implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject MappingInfo;
	/**
	 * The class protocol describe the behavior of the value of the global <br>
	 * named MessageNotUnderstood.<br>
	 * <br>
	 * This object is used to as an exception selector to catch failed message <br>
	 * sends. Message not understood exceptions are resumable so any message <br>
	 * in this protocol that signal such an exception may ultimately return <br>
	 * to their sender.<br>
	 * <br>
	 * This object is not specifed as an <exceptionSignaler> or an <br>
	 * <exceptionInstantiator>. It as assumed that message not understood <br>
	 * exceptions are signaled by the implemention dependent implementaton <br>
	 * of the message <Object> #doesNotUnderstand:.<br>
	 * <br>
	 * The instance protocol describes the behavior of exceptions that are <br>
	 * signalled if the receiver of a message does not have a method with a <br>
	 * matching selector.
	 */
	//public GbjObject MessageNotUnderstood;
	/**
	 * Each Metaclass describes the protocol of its single instance, which is a<br>
	 *  Class.  The class methods of GemStone kernel classes are actually stored as<br>
	 *  instance methods of those classes' Metaclasses.<br>
	 * <br>
	 *  For example, 3 is an instance of the class SmallInteger.  SmallInteger is<br>
	 *  an instance of the Metaclass SmallInteger class, and describes the protocol<br>
	 *  of all SmallIntegers.  SmallInteger class is itself an instance of<br>
	 *  Metaclass, and describes the protocol (that is, the class methods) of the class<br>
	 *  SmallInteger.<br>
	 * <br>
	 *  Consider the following example.  The description of class SmallInteger<br>
	 *  contains two kinds of protocol: instance methods and class methods.  Instance<br>
	 *  methods are understood by SmallIntegers (instances of class SmallInteger).<br>
	 *  Class methods are understood by the class-defining object SmallInteger itself<br>
	 *  (which is the single instance of the Metaclass SmallInteger class, and<br>
	 *  inherits its protocol from Class, Behavior, and Object).
	 */
	//public GbjObject Metaclass;
	/**
	 * The class MethodContext is obsolete as of GemStone version 4.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject MethodContext;
	/**
	 * The class protocol describe the behavior of the global Notification. <br>
	 * The value of the standard global Notification is a class object that <br>
	 * conforms to this protocol. The class Notification is explicitly specified <br>
	 * to be subclassable in a standard conforming program. Conforming <br>
	 * implementations must implement its behaviors in a non-fragile manner.<br>
	 * <br>
	 * The signaled exceptions generated by this type of object conform to <br>
	 * the protocol <Notification>.<br>
	 * <br>
	 * The instance protocol describes the behavior of instances of the class <br>
	 * Notification. These are used to represent exceptional conditions that <br>
	 * may occur but which are not considered errors. Actual notification <br>
	 * exceptions used by an application may be subclasses of this class.<br>
	 * <br>
	 * As Notification is explicitly specified to be subclassable, conforming <br>
	 * implementations must implement its behavior in a non-fragile manner.
	 */
	//public GbjObject Notification;
	/**
	 * The class NscBuilder implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  NscBuilder should only be used for transient objects.  They are not<br>
	 *  completely logged by the transaction logging subsystem!
	 */
	//public GbjObject NscBuilder;
	/**
	 * Number is an abstract superclass that establishes protocol for all GemStone<br>
	 *  Smalltalk numbers.  Concrete subclasses include Float, SmallInteger, and<br>
	 *  Fraction.
	 */
	//public GbjObject Number;
	/**
	 * Object defines the basic protocol for all objects.  Every object is an<br>
	 *  instance of Object or of some subclass of Object.
	 */
	//public GbjObject Object;
	/**
	 * The class ObsoleteClampSpecification is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  It does not make sense for clamp specifications to be persistent.<br>
	 *  Existing instances should be removed.
	 */
	//public GbjObject ObsoleteClampSpecification;
	/**
	 * The class ObsoleteDateTime is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to DateTime or otherwise processed as<br>
	 *  required, and then should be removed.<br>
	 * <br>
	 *  Each instance of ObsoleteDateTime describes a moment in time, expressed in the<br>
	 *  local time zone, with one-second resolution.  Only dates after 1 March 1583<br>
	 *  can be represented faithfully.<br>
	 * <br>
	 *  Each instance of ObsoleteDateTime is represented by two four-byte values.  The<br>
	 *  first four bytes represent the Julian Day of the instance (that is, the number<br>
	 *  of days since January 1, 4713 BC).  The second four bytes represent the number<br>
	 *  of seconds since midnight.  In each of these values, the least significant byte<br>
	 *  is stored first.
	 */
	//public GbjObject ObsoleteDateTime;
	/**
	 * An instance of ObsoleteDateTime50 describes a moment in time (with one-second resolution)<br>
	 *  on a date after December 31, 1900.<br>
	 * <br>
	 *  The internal representation of a ObsoleteDateTime50 is based on Greenwich Mean Time.<br>
	 *  However, many methods express time in the local timezone.  ("Local" time is<br>
	 *  local to your Gem process.)  These methods automatically convert between<br>
	 *  timezones, but the internal representation remains in Greenwich Mean Time.<br>
	 *  Hence, you can interact with ObsoleteDateTime50 methods in a natural way, but ObsoleteDateTime50<br>
	 *  objects can be safely compared to each other no matter what time zone is used<br>
	 *  to express them.<br>
	 * <br>
	 *  You can convert a ObsoleteDateTime50 to a String (using Formatting instance methods), and<br>
	 *  you can convert a String to a ObsoleteDateTime50 (using Instance Creation class methods).<br>
	 *  Such conversions require a specification to describe the format of the String.<br>
	 *  Some methods provide for the default format, DD/MM/YYYY HH:MM:SS, which<br>
	 *  expresses the day and month (in that order) as digits and uses a 24-hour clock.<br>
	 * <br>
	 *  Explicit string-formatting specifications take the form of an Array, described<br>
	 *  in the following table.  A specification is incorrect if it is missing an<br>
	 *  element or if an element value is not one of the acceptable values listed in<br>
	 *  the table.<br>
	 * <br>
	 *  String-formatting Specification Array for ObsoleteDateTime50.<br>
	 * <br>
	 *  Element   Acceptable Value       Explanation<br>
	 * <br>
	 *  1st,      Integers 1, 2,         Determines the position of the day (1),<br>
	 *  2nd, and  and 3, in any          month (2), and year (3).<br>
	 *  3rd       order<br>
	 * <br>
	 *  4th       A Character literal    Separates year, month, and day.<br>
	 *            (such as a space, $ )<br>
	 * <br>
	 *  5th       Integer                Determines the month format to be a number (1),<br>
	 *                                   three-letter abbreviation (2), or the entire<br>
	 *                                   name (3).<br>
	 * <br>
	 *  6th       Integer                Determines the year format to be the entire<br>
	 *                                   number (1), or only the last two digits (2).<br>
	 * <br>
	 *  7th       A Character literal    Separates hours, minutes, and seconds.<br>
	 *            (such as $: or $.)<br>
	 * <br>
	 *  8th       true                   Include the time of day.<br>
	 * <br>
	 *  8th       false                  Do not include the time of day.  Ignore elements<br>
	 *                                   7, 9, and 10.  Elements 9 and 10 are optional<br>
	 *                                   in the specification.<br>
	 * <br>
	 *  9th       true                   Include seconds.<br>
	 * <br>
	 *  9th       false                  Do not include seconds.<br>
	 * <br>
	 *  10th      true                   Time is expressed in 12-hour format, with<br>
	 *                                   am or pm (such as 1:30:55 pm).  The space is<br>
	 *                                   required preceding the am or pm indicator.<br>
	 * <br>
	 *  10th      false                  Time is expressed in 24-hour format<br>
	 *                                   (such as 13:30:55).
	 */
	//public GbjObject ObsoleteDateTime50;
	/**
	 * The class ObsoleteDictionary is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to Dictionary or otherwise processed as<br>
	 *  required, and then should be removed.
	 */
	//public GbjObject ObsoleteDictionary;
	/**
	 * The class ObsoleteGsFile is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  It does not make sense for instances of ObsoleteGsFile to be persistent.<br>
	 *  Existing instances should be removed.
	 */
	//public GbjObject ObsoleteGsFile;
	/**
	 * The class ObsoleteIdentityCollisionBucket is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to IdentityCollisionBucket or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteIdentityCollisionBucket;
	/**
	 * The class ObsoleteIdentityDictionary is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to IdentityDictionary or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteIdentityDictionary;
	/**
	 * The class ObsoleteLanguageDictionary is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to LanguageDictionary or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteLanguageDictionary;
	/**
	 * The class ObsoleteRcCollisionBucket is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to RcCollisionBucket or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteRcCollisionBucket;
	/**
	 * The class ObsoleteSymbol is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to String or Symbol or otherwise<br>
	 *  processed as required, and then should be removed.<br>
	 * <br>
	 *  An ObsoleteSymbol is a GemStone 4.1 Symbol.  It is not canonicalized.
	 */
	//public GbjObject ObsoleteSymbol;
	/**
	 * The class ObsoleteSymbolAssociation is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to SymbolAssociation or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteSymbolAssociation;
	/**
	 * The class ObsoleteSymbolDictionary is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to SymbolDictionary or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteSymbolDictionary;
	/**
	 * The class ObsoleteSymbolKeyValueDictionary is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to SymbolKeyValueDictionary or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteSymbolKeyValueDictionary;
	/**
	 * The class ObsoleteSymbolListDictionary is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to SymbolDictionary or otherwise<br>
	 *  processed as required, and then should be removed.
	 */
	//public GbjObject ObsoleteSymbolListDictionary;
	/**
	 * The class ObsoleteSymbolSet is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Existing instances should be migrated to SymbolSet or otherwise processed as<br>
	 *  required, and then should be removed.
	 */
	//public GbjObject ObsoleteSymbolSet;
	/**
	 * A ObsoleteTimeZone represents the policy for converting Greenwich Mean Time to local<br>
	 *  time.
	 */
	//public GbjObject ObsoleteTimeZone;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject OldRepository;
	/**
	 * An OrderedCollection is a SequenceableCollection that maintains the order of<br>
	 *  objects it contains.  In GemStone, OrderedCollections are very similar to<br>
	 *  Arrays.  They differ from Arrays in that they understand all of the messages<br>
	 *  that Smalltalk OrderedCollections implement.
	 */
	//public GbjObject OrderedCollection;
	/**
	 * PassiveObject provides a means for transferring data from one GemStone<br>
	 *  repository to another that is similar to VisualWorks' Binary Object Streaming<br>
	 *  Service (BOSS) and Visual Smalltalk's Object Filer.<br>
	 * <br>
	 *  For a discussion of activation of passive objects that were written by<br>
	 *  GemStone version 4.1.3 or earlier, see comments in the class method  <br>
	 *  initialize41ClassNames.<br>
	 * <br>
	 *  An instance of PassiveObject converts the form of a given GemStone object from<br>
	 *  active to passive or from passive to active.  A GemStone object is called<br>
	 *  active because it can respond to messages.  The object's passive form cannot<br>
	 *  respond to messages, but it can be written to a text file in a standard file<br>
	 *  system outside of GemStone.  A text file is the normal intermediary storage for<br>
	 *  objects that are being transferred between GemStone repositories.<br>
	 *  PassiveObjects themselves need never be transferred or committed, and are<br>
	 *  intended to exist only within a given GemStone session.<br>
	 * <br>
	 *                               Note:<br>
	 *     This class provides useful protocols, but it does not represent a full <br>
	 *     or complete inter-repository data transfer facility.  Not all GemStone<br>
	 *     objects can be converted into passive form.  Please see the GemStone<br>
	 *     Programming Guide for more background information.<br>
	 * <br>
	 * 			      Note:<br>
	 *     Objects referenced by the user defined tags (tagAt:1, tagAt:2) of<br>
	 *     an object are not included in the default passivation of an object.<br>
	 * <br>
	 *  Data transfers are ordinarily accomplished by gathering all objects to be<br>
	 *  transferred into one collection, which is then passivated and reactivated.<br>
	 *  If data is transferred piecemeal, the new repository may lose information about<br>
	 *  the connectivity of objects and produce multiple copies of an object where the<br>
	 *  original repository had only one.<br>
	 * <br>
	 *  Finally, class Object includes two methods, writeTo: and loadFrom:, that<br>
	 *  convert an object to and from its passive form.  These methods can be<br>
	 *  reimplemented to tailor the form for any given class.  The first thing any<br>
	 *  writeTo: method must do is to identify the class of the passivated object.  It<br>
	 *  does so by sending the writeClass: message to the passive object that stores<br>
	 *  it.  The loadFrom: method must send the hasRead: message to the passive object<br>
	 *  that loads it.  It then must create a new instance of the class it finds and<br>
	 *  must read all information that was written by the writeTo: method.<br>
	 * <br>
	 *  The following discussion describes some limitations of PassiveObject in<br>
	 *  detail.<br>
	 * <br>
	 *  Although certain atomic objects have the same OOP in any GemStone repository,<br>
	 *  most objects do not.  The special case that relates some atomic objects to<br>
	 *  their OOPs will be ignored hereafter.<br>
	 * <br>
	 *  Now, the identity of a GemStone object depends upon its OOP.  However, when you<br>
	 *  transfer an object from one GemStone repository to another, it is not possible<br>
	 *  to guarantee that it will have the same OOP; its OOP in the original repository<br>
	 *  may already be used by another object in the new repository.  In general, an<br>
	 *  object's OOP is lost during transfer.<br>
	 * <br>
	 *  But the interconnectivity of objects in GemStone depends upon their OOPs.<br>
	 *  Objects identify their relationships to each other by their OOP.  To preserve<br>
	 *  interconnectivity, when aPassiveObject passivates a GemStone object, it also<br>
	 *  passivates all the other objects to which it refers, and the ones to which they<br>
	 *  refer, and so on (the transitive closure of the object).  It also encodes the<br>
	 *  relationships among the objects in the transitive closure so that those<br>
	 *  relationships can be restored when the object is activated in the new<br>
	 *  repository.<br>
	 * <br>
	 *  However, each PassiveObject can passivate (the transitive closure of) only one<br>
	 *  object at a time.  If two objects are passivated, and some objects in the<br>
	 *  transitive closure of one refer to objects in the transitive closure of the<br>
	 *  other, PassiveObject has no way to capture or encode those relationships.  Upon<br>
	 *  activation, the lost interrelations between the two objects may not be<br>
	 *  evident at first because duplicate objects are created in the new repository<br>
	 *  and the same values are present.  Only subsequent updates in the duplicated<br>
	 *  objects will reveal their new independence of each other.  Such independence<br>
	 *  may well be unintended, a semantic anomaly in the data.<br>
	 * <br>
	 *  To avoid difficulties, gather all data to be transferred into one collection.<br>
	 *  Passivate the collection from the original repository, then activate it in the<br>
	 *  new repository.  Connect the data to the new repository as appropriate, then<br>
	 *  remove the collection used for passivation and commit.  If you must passivate<br>
	 *  two or more objects, passivate only one object in any file; two objects in a<br>
	 *  file virtually guarantee data transfer errors.<br>
	 * <br>
	 *  The following Characters are reserved for special use within passive objects.<br>
	 *  The special meanings do not apply within the byte contents of Strings, <br>
	 *  ByteArrays or DoubleByteStrings within a passive object:<br>
	 * <br>
	 *     $*   denotes true<br>
	 *     $~   denotes false<br>
	 *     $$   next byte is an instance of Character with value 0..255<br>
	 *     $!   next two bytes are instance of Character with value 0..65535,<br>
	 *             most significant byte is first.<br>
	 *     $.   denotes  nil<br>
	 *     $#   denotes _remoteNil<br>
	 *     $/   end of named instance variables within a Bag <br>
	 *     $"   prefix/suffix Character used to identify instance variable names<br>
	 *     $?   class prefix<br>
	 *     $:   object identifier prefix<br>
	 *     $@   global reference prefix<br>
	 *     $%   denotes Metaclass reference<br>
	 *     $    terminates a global name or string representation of an integer<br>
	 *     $(   terminates a class name<br>
	 *     $^   begins/ends the GemStone version header (not used prior to v5.0). When<br>
	 *           activating a PassiveObject, version 413 is assumed if no version<br>
	 *           header found.<br>
	 *     $&   reserved for future use by GemTalk Systems<br>
	 *     $)   reserved for future use by GemTalk Systems<br>
	 *     $=   reserved for future use by GemTalk Systems<br>
	 *     $_   reserved for customer use<br>
	 * 
	 */
	//public GbjObject PassiveObject;
	/**
	 * The class PathEvaluator implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject PathEvaluator;
	/**
	 * The class PathSorter implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject PathSorter;
	/**
	 * The class PathTerm implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject PathTerm;
	/**
	 * PositionableStream is an abstract superclass that provides additional protocol<br>
	 *  appropriate to Streams whose objects are externally named by indices.<br>
	 *  Concrete subclasses are ReadStream and WriteStream.
	 */
	//public GbjObject PositionableStream;
	/**
	 * The class PrintStream implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  PrintStream is designed for use in place of WriteStream to handle printing<br>
	 *  of mixed ASCII and JapaneseStrings.  The default size of the stream is limited<br>
	 *  to 100000 bytes.
	 */
	//public GbjObject PrintStream;
	/**
	 * The class Process is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.<br>
	 * <br>
	 *  Process has been replaced by GsProcess.
	 */
	//public GbjObject Process;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject Processor;
	/**
	 * ProcessorScheduler implements a green-threads scheduler for instances of<br>
	 *  GsProcess.  The processes all share one native thread in the virtual<br>
	 *  machine.  There is exactly one instance of ProcessorScheduler in a session;<br>
	 *  this instance is initialized by the virtual machine and may not be <br>
	 *  committed to disk. 
	 */
	//public GbjObject ProcessorScheduler;
	/**
	 * A ProfMonitor installs a timer to snapshot the execution stack at<br>
	 *  given intervals for a given period of time.  When done monitoring,<br>
	 *  the results are collected and formed into a report showing classes,<br>
	 *  method selectors and hit rates.<br>
	 *  <br>
	 *  The interval is the interval between sample points, which must be a<br>
	 *  postive integer.  Values less than 10 may not produce more frequent<br>
	 *  samples due to system-dependent OS clock resolution.  <br>
	 *  <br>
	 *  The sampleDepth is the number of levels from the top of the stack to<br>
	 *  sample.  Must be between 1 and 20 inclusive.  <br>
	 *  <br>
	 *  The results are recorded in an instance of GsFile for the gem session,<br>
	 *  in the /tmp directory, in binary machine dependent form.
	 */
	//public GbjObject ProfMonitor;
	/**
	 * The class QueryExecuter implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject QueryExecuter;
	/**
	 * The class RangeEqualityIndex implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject RangeEqualityIndex;
	/**
	 * RangeIndexReadStream, like its superclass BtreeReadStream, supports the<br>
	 *  composition of query results by providing access to a B-tree structure.  Its<br>
	 *  'next' and 'atEnd' methods are used the same way as those of<br>
	 *  BtreeReadStream in iterating through the B-tree.<br>
	 * <br>
	 *  RangeIndexReadStream differs from BtreeReadStream in that it uses the reverse<br>
	 *  mappings to B-tree nodes that are found in a RangeEqualityIndex to obtain the<br>
	 *  next entry.  You can supply that index when you create the stream, and the<br>
	 *  index identifies the ordering used to return the entries.
	 */
	//public GbjObject RangeIndexReadStream;
	/**
	 * The class RcBtreeBasicInteriorNode implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A RcBtreeBasicInteriorNode represents an interior node of a B-tree for which a<br>
	 *  binary search can be done for a key. Updates to instances of this class are <br>
	 *  logged and can  be replayed in the case of commit conflicts.
	 */
	//public GbjObject RcBtreeBasicInteriorNode;
	/**
	 * The class RcBtreeBasicLeafNode implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A RcBtreeBasicLeafNode represents an exterior node of a B-tree for which a binary<br>
	 *  search can be done for a key. Updates to instances of this class are logged and <br>
	 *  can  be replayed in the case of commit conflicts.
	 */
	//public GbjObject RcBtreeBasicLeafNode;
	/**
	 * The class RcBtreeInteriorNode implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A RcBtreeInteriorNode represents an interior node of a B-tree for which a<br>
	 *  binary search can be done for a key. Updates to instances of this class are <br>
	 *  logged and can  be replayed in the case of commit conflicts.
	 */
	//public GbjObject RcBtreeInteriorNode;
	/**
	 * The class RcBtreeLeafNode implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A RcBtreeLeafNode represents an exterior node of a B-tree for which a binary<br>
	 *  search can be done for a key. Updates to instances of this class are logged and <br>
	 *  can  be replayed in the case of commit conflicts.
	 */
	//public GbjObject RcBtreeLeafNode;
	/**
	 * The class RcCollisionBucket implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  An RcCollisionBucket is a CollisionBucket that is used in an<br>
	 *  RcKeyValueDictionary to store a collection of key/value pairs for which the<br>
	 *  keys hash to the same value.  It provides support for the reduced-conflict<br>
	 *  properties of RcKeyValueDictionaries.
	 */
	//public GbjObject RcCollisionBucket;
	/**
	 * Like any counter, an RcCounter maintains an integral value that can be<br>
	 *  incremented or decremented.<br>
	 * <br>
	 *  A single instance of RcCounter can be shared among multiple concurrent sessions<br>
	 *  without conflict.  The initial value of the RcCounter at the start of a<br>
	 *  transaction in any session is the last value that has been committed.  During<br>
	 *  their transactions, any or all sessions that share the RcCounter can modify it.<br>
	 *  Each session then sees a value for the RcCounter that reflects only the initial<br>
	 *  value from the start of its own transaction and the changes made in that<br>
	 *  transaction.<br>
	 * <br>
	 *  When a session commits the RcCounter, the cumulative changes of other<br>
	 *  transactions committed since the start of the current session's transaction<br>
	 *  are merged with those of the committing transaction.  No commit conflicts<br>
	 *  occur between the sessions.  But the count that a session sees immediately<br>
	 *  before its transaction is committed may not be the same as the count it sees<br>
	 *  immediately after.
	 */
	//public GbjObject RcCounter;
	/**
	 * The class RcCounterElement implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject RcCounterElement;
	/**
	 * An RcIdentityBag is a special kind of IdentityBag that provides for concurrent<br>
	 *  handling of an individual instance by multiple sessions.  Any or all of those<br>
	 *  sessions can modify the single instance.  When that happens, RcIdentityBag also<br>
	 *  reduces the transaction conflicts that can arise among those sessions when they<br>
	 *  attempt to commit the instance to GemStone.
	 */
	//public GbjObject RcIdentityBag;
	/**
	 * The class RcIndexBucket implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  An RcIndexBucket is an RcCollisionBucket that is used by the indexing<br>
	 *  subsystem to store a collection of key/value/pathTerm triples.  It provides<br>
	 *  reduced-conflict support for indexes.
	 */
	//public GbjObject RcIndexBucket;
	/**
	 * The class RcIndexBucketWithCache implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  An RcIndexBucketWithCache is an RcIndexBucket that is used by the indexing<br>
	 *  subsystem where appropriate to improve indexing performance.
	 */
	//public GbjObject RcIndexBucketWithCache;
	/**
	 * The class RcIndexDictionary implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject RcIndexDictionary;
	/**
	 * RcKeyValueDictionary is an AbstractDictionary that shares many of the protocols<br>
	 *  and characteristics of KeyValueDictionary.  Like all dictionaries, it stores<br>
	 *  key/value pairs.  In an RcKeyValueDictionary, keys may be of mixed classes.<br>
	 * <br>
	 *  Like KeyValueDictionary, RcKeyValueDictionary stores key/value pairs under an<br>
	 *  index that is generated by applying a hash function to the key; it does not use<br>
	 *  Associations.  The hashing improves retrieval speed.  However, you must observe<br>
	 *  an important restriction: after a key/value pair has been added to an<br>
	 *  RcKeyValueDictionary, you must not modify the key.  Doing so renders the value<br>
	 *  inaccessible.<br>
	 * <br>
	 *  An RcKeyValueDictionary is also an equality-based collection.  That is, two<br>
	 *  keys or two values are considered to be the same if they are equivalent; they<br>
	 *  need not be identical to be the same.  Thus, if you add two key-value pairs to<br>
	 *  an RcKeyValueDictionary but the keys are equivalent, even if they are not<br>
	 *  identical, then the result is that the second pair overwrites the first one,<br>
	 *  because the keys are the same.<br>
	 * <br>
	 *  However, unlike KeyValueDictionary, RcKeyValueDictionary provides for<br>
	 *  concurrent handling of an individual instance by multiple sessions.  Any or all<br>
	 *  of those sessions can modify the single instance.  When that happens,<br>
	 *  RcKeyValueDictionary also reduces (but does not eliminate) the transaction<br>
	 *  conflicts that can arise among those sessions when they attempt to commit the<br>
	 *  instance to GemStone.<br>
	 * <br>
	 *  Commit Conflicts.<br>
	 * <br>
	 *  In general, RcKeyValueDictionaries do not cause concurrency conflicts for write<br>
	 *  operations that are commutative (operations that can be performed in any order<br>
	 *  without affecting the final GemStone state).  However, under some circumstances<br>
	 *  a user may experience conflict for commutative operations when the basicSize of<br>
	 *  the dictionary is too small (relative to the number of write operations<br>
	 *  performed in a transaction).  This can be avoided by creating a larger<br>
	 *  dictionary with the new: method, or increasing an existing dictionary's size<br>
	 *  with the rebuildTable: method.<br>
	 * <br>
	 *  If multiple users change values for different keys in a single<br>
	 *  RcKeyValueDictionary, the changes do not usually cause conflicts at commit<br>
	 *  time.  However, there is a (narrow and uncommon) window of time over which<br>
	 *  users have no control during which such a set of changes could result in<br>
	 *  conflicts.
	 */
	//public GbjObject RcKeyValueDictionary;
	/**
	 * An RcQueue (reduced-conflict queue) is an implementation of a FIFO queue that<br>
	 *  provides significantly reduced concurrency conflicts when used in an<br>
	 *  environment with multiple producers (users that add elements to the queue) and<br>
	 *  a single consumer (a user that removes items from the queue).  Producers are<br>
	 *  guaranteed not to conflict with each other, nor with a single consumer.  An<br>
	 *  RcQueue is implemented as a collection of RcQueueSessionComponents, each of<br>
	 *  which contains the queue elements submitted by a particular session.
	 */
	//public GbjObject RcQueue;
	/**
	 * The class RcQueueElement implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  RcQueueElement describes an individual entry in a reduced-conflict queue.
	 */
	//public GbjObject RcQueueElement;
	/**
	 * The class RcQueueEntry implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  RcQueueEntry describes an individual entry in a reduced-conflict queue.
	 */
	//public GbjObject RcQueueEntry;
	/**
	 * The class RcQueueRemovalSeqNumbers implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  RcQueueRemovalSeqNumbers describes an Array that is constrained to contain only<br>
	 *  SmallIntegers.  It has no added protocol or instance variables and is used only<br>
	 *  to ensure the consistency of the objects used to represent RcQueues.
	 */
	//public GbjObject RcQueueRemovalSeqNumbers;
	/**
	 * The class RcQueueSessionComponent implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  An RcQueueSessionComponent is the unit within a reduced-conflict queue that<br>
	 *  holds all of the queue entries submitted by a given session.  A new RcQueue<br>
	 *  allows the same number of sessions as the GemStone system's maximum number of<br>
	 *  sessions.  You can modify this number using the changeMaxSessionId: method.
	 */
	//public GbjObject RcQueueSessionComponent;
	/**
	 * The class RcRangeEqualityIndex implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject RcRangeEqualityIndex;
	/**
	 * A ReadStream is a PositionableStream that allows its objects to be read but<br>
	 *  not written.
	 */
	//public GbjObject ReadStream;
	/**
	 * The class RedoLog implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject RedoLog;
	/**
	 * The class ReenterBlock is obsolete as of GemStone version 4.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject ReenterBlock;
	/**
	 * A Repository is an object that represents a virtual storage into which users<br>
	 *  can place their data.  Each Repository includes an Array of Segments,<br>
	 *  which represent authorization regions for the data.  <br>
	 *  Repositories are described in the GemStone Programming Guide.
	 */
	//public GbjObject Repository;
	/**
	 * This is part of the SUnitPreload package and provides<br>
	 * dialect-specific support for the remaining portable code.<br>
	 * This class supports exception handling.
	 */
	//public GbjObject ResumableTestFailure;
	/**
	 * This is a sample test.
	 */
	//public GbjObject ResumableTestFailureTestCase;
	/**
	 * ScaledDecimal stores numerical values as a rational number, represented by a<br>
	 *  numerator and denominator that are Integers.  Since the numerator and<br>
	 *  denominator can be carried to arbitrary precision, ScaledDecimal can represent<br>
	 *  any rational number without loss of precision.  It also calculates based upon<br>
	 *  fractional arithmetic, and thus produces numerical results without loss of<br>
	 *  precision.<br>
	 * <br>
	 *  ScaledDecimal also provides for automatic rounding to a fixed precision after<br>
	 *  the decimal point when converting to and from other types, such as String.<br>
	 * <br>
	 *  One useful application of this kind of number is for financial instruments,<br>
	 *  which are always rounded off, but usually need more digits than a floating<br>
	 *  number can accurately express in order not to lose precision during<br>
	 *  computation.
	 */
	//public GbjObject ScaledDecimal;
	/**
	 * Each Repository is composed of an integral number of Segments.  A Segment has<br>
	 *  the following properties:<br>
	 * <br>
	 *  * Ownership.  This is the smallest unit of ownership for accounting and<br>
	 *    authorization purposes.  Each Segment is owned by one and only one user.<br>
	 * <br>
	 *  * Authorization unit.  A user may control access to objects by placing them in<br>
	 *    a Segment with a known authorization.  Prior to reading or writing an object<br>
	 *    in a Segment, users must be authorized to perform the desired action.<br>
	 *    However, during a transaction, once a user is authorized to read one object<br>
	 *    in a Segment, that user can read any object in the same Segment.<br>
	 * <br>
	 *  Segments and Repositories are discussed in more detail in the GemStone<br>
	 *  Programming Guide.<br>
	 * <br>
	 * Text added as of Gs64 v2.2:<br>
	 *   All objects have a segmentId attribute, which is stored in the object<br>
	 *   header.  <br>
	 *   References from an object to its Segment are indirect via the<br>
	 *   SystemRepository object.  (See implementation of method Object >> segment ) <br>
	 *   In a Repository that was converted from Gs64 v1.x , v2.0 or v2.1 ,<br>
	 *   all objects created prior to the conversion will have segmentId 0 .<br>
	 * <br>
	 *   Read authorization is checked when an object is faulted or refreshed<br>
	 *   into memory , once in memory no further read authorization checks<br>
	 *   are performed.  No checks are done for an object with segmentId 0 .<br>
	 * <br>
	 *   Write authorization is checked the first time an object is written<br>
	 *   during each transaction.  No checks are done for an object<br>
	 *   with segmentId 0 .<br>
	 * <br>
	 *   Changes to Segment, UserProfile , or Group objects that affect<br>
	 *   read or write authorization checks are only guaranteed to be noticed<br>
	 *   after the next login.  This is different from Gemston/S 6.x , in which<br>
	 *   authorization changes are supposed to be noticed at the<br>
	 *   next transaction boundary.  Changes to the segmentId of an object<br>
	 *   will take effect on the next transaction boundary.<br>
	 * <br>
	 *   Creation of Segments and changes to attributes of Segments require<br>
	 *   write authorization permission to the DataCuratorSegment .<br>
	 * <br>
	 *   If you are logged in as SystemUser , no authorization errors will occur .<br>
	 * <br>
	 *   All instances of Symbol, DoubleByteSymbol must be in a segment with <br>
	 *   World read permission. By default they are on DataCuratorSegment .<br>
	 *  <br>
	 *   For logins other than SystemUser,<br>
	 *   the virtual machine requires read access to both DataCuratorSegment<br>
	 *   and SystemSegment in order to be able to bootstrap object memory<br>
	 *   as part of a session login.  Specifically , well known classes<br>
	 *   such as Metaclass, Object, etc are expected to be in SystemSegment ,<br>
	 *   and instances of Symbol and objects such as SystemRepository are<br>
	 *   expected to be in DataCuratorSegment.  To avoid infinite recursion<br>
	 *   in loading the authorization cache, the virtual machine preloads<br>
	 *   authorization for SystemSegment and DataCuratorSegment after validating<br>
	 *   the userId/password , and will generate a fatal error if it does not<br>
	 *   have read access to both DataCuratorSegment and DataCuratorSegment.<br>
	 * <br>
	 *   All instances of UserProfile,  IdentitySets representing Groups, <br>
	 *   and Segments must be in a segment with World read permission. <br>
	 *   By default they are on DataCuratorSegment.<br>
	 * <br>
	 *   During repository conversion from a prior release to Gs64 v2.2 ,<br>
	 *   if the previous size of SystemRepository was < 20 , and<br>
	 *   a  Segment will be created with segmentId 20 and world write, <br>
	 *   to handle the case where an older version of GBS clients<br>
	 *   may have created objects in a Gs64 v2.0 or v2.1 repository<br>
	 *   with segmentId 20 .<br>
	 * 
	 */
	//public GbjObject Segment;
	/**
	 * The class SegmentSet implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject SegmentSet;
	/**
	 * SelectBlock is a concrete subclass of BlockClosure that supports selection<br>
	 *  blocks for associative access.
	 */
	//public GbjObject SelectBlock;
	/**
	 * The class SelectionBlock is obsolete as of GemStone version 4.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject SelectionBlock;
	/**
	 * Instances of Semaphore are used to define critical regions in<br>
	 *  Smalltalk processes.  Only one instance of a GsProcess will<br>
	 *  may execute within a critical region at a time.  Instances of<br>
	 *  Semaphore may not be committed to disk; they exist only for the<br>
	 *  life of a session, or until garbage collected.
	 */
	//public GbjObject Semaphore;
	/**
	 * SequenceableCollection is an abstract superclass for collections that define a<br>
	 *  consistent ordering on their elements.  You can think of the elements as<br>
	 *  forming a sequence of objects, numbered from 1 to n.  You can use the Integer i<br>
	 *  as an index to refer to the ith element in that sequence.  The elements are<br>
	 *  said to be indexable.<br>
	 * <br>
	 *  The indexability of SequenceableCollections should not be confused with indexes<br>
	 *  that are specially built on UnorderedCollections to improve their performance<br>
	 *  when they search their elements (using associative access).
	 */
	//public GbjObject SequenceableCollection;
	/**
	 * Instances of SessionTemps may not be committed. The primary use of this class<br>
	 *  is via the class method #current, which returns an instance of SessionTemps<br>
	 *  that is stored in Transient Session State.
	 */
	//public GbjObject SessionTemps;
	/**
	 * A Set is an UnorderedCollection in which any distinct object can occur only<br>
	 *  once.  Adding the same (identical) object to a Set multiple times is redundant.<br>
	 *  The result is the same as adding it once.<br>
	 * <br>
	 *  Since a Set is an equality-based collection, different (non-identical) but<br>
	 *  equivalent (equal) objects are not treated as distinct from each other.  In<br>
	 *  IdentitySets, they are distinct.  Adding multiple equivalent objects to a Set<br>
	 *  yields a Set with the object that was added last.  In short, two different<br>
	 *  elements of a Set are neither identical nor equivalent.<br>
	 * <br>
	 *  You can create subclasses of Set to restrict the kind of elements it contains.<br>
	 *  When creating a subclass of Set, you must specify a class as the aConstraint<br>
	 *  argument.  This class is called the element kind of the new subclass.  For each<br>
	 *  instance of the new subclass, the class of each element must be of the element<br>
	 *  kind.
	 */
	//public GbjObject Set;
	/**
	 * The class SetValuedPathEvaluator implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  This class is not supported in this release of GSS64 (v2.1 and beyond).
	 */
	//public GbjObject SetValuedPathEvaluator;
	/**
	 * The class SetValuedPathTerm implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  This class is not supported in this release of GSS64 (v2.1 and beyond).
	 */
	//public GbjObject SetValuedPathTerm;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject SharedQueue;
	/**
	 * A SimpleBlock is an ExecutableBlock that does not refer to any enclosing scope<br>
	 *  variables.  Thus, unlike complex blocks, it needs no variable context at any<br>
	 *  time.<br>
	 * <br>
	 *  The GemStone Smalltalk compiler creates all simple blocks.
	 */
	//public GbjObject SimpleBlock;
	/**
	 * This is an example of a test resource.
	 */
	//public GbjObject SimpleTestResource;
	/**
	 * This demonstrates the use of test resources.
	 */
	//public GbjObject SimpleTestResourceTestCase;
	/**
	 * This class represents 8-byte binary floating point numbers, as defined in IEEE<br>
	 *  standard 754, but with a reduced exponent.  <br>
	 *  SmallDouble has 8 bits of exponent, compared to 11 bits of exponent in<br>
	 *  an IEEE-754 8-byte float.<br>
	 * <br>
	 *  You may not create subclasses of SmallDouble.<br>
	 * <br>
	 *  Each SmallDouble contains a 61 bit value.  The floats are stored on Disk and<br>
	 *  in object memory in CPU native byte order.  GemStone Smalltalk primitives and<br>
	 *  GemBuilder for C (GCI) float conversion functions automatically convert <br>
	 *  the format of a float to or from the machine's native format, as required.<br>
	 * <br>
	 *   An IEEE 64 bit binary float (a C double) has<br>
	 *    seeeeeee|eeeeffff|ffffffff|ffffffff|ffffffff|ffffffff|ffffffff|ffffffff<br>
	 *    If (e > 0) the double has value (-1 * s) * 2^^(e-0x3ff) * 1.f  .<br>
	 *    If (e == 0) and f != 0 ,<br>
	 *      the double has value (-1 * s) * 2^^(e-0x3fe) * 0.f  (i.e. subnormal) .<br>
	 *    zero is represented as s==0, e==0, f==0  . See Sparc V9 Arch Manual pg 28.<br>
	 * <br>
	 *   An instance of SmallDouble has this OopType format:<br>
	 *    eeeeeeee|ffffffff|ffffffff|ffffffff|ffffffff|ffffffff|ffffffff|ffffs110<br>
	 *    which is the same number of bits of mantissa as a C double, but<br>
	 *     only 8 bits of exponent as compared to 11 bits of exponent in C double.<br>
	 *   If the C double has value zero , the SmallDouble has all bits zero,<br>
	 *    otherwise the SmallDouble has non-zero exponent, and<br>
	 *      the value is (-1 * s) * 2^^(e - 0x7f ) * 1.f<br>
	 *   There are no subnormal or NaN SmallDoubles .<br>
	 *   Thus SmallDoubles can represent  C double that have value zero<br>
	 *   or that have exponent bits in range 0x381 to 0x3ff,<br>
	 *    which correspends to about 5.0e-39 to 6.0e+38 , which<br>
	 *    is also the range of  C 4-byte float  .<br>
	 *  
	 */
	//public GbjObject SmallDouble;
	/**
	 * This class represents 4 byte binary floating point numbers, as defined in IEEE<br>
	 *  standard 754.<br>
	 *  <br>
	 *  This class is deprecated.  <br>
	 *  Most numeric operations will return instances of SmallDouble or Float .<br>
	 * <br>
	 *  You may not create subclasses of SmallFloat.
	 */
	//public GbjObject SmallFloat;
	/**
	 * Instances of SmallInteger are an optimization for commonly occurring integers<br>
	 *  (between (2 to the 29 power) and (2 to the 29 power  1)).  You may not<br>
	 *  create subclasses of class SmallInteger.  You may not create any new<br>
	 *  SmallIntegers.  Note that all instances of a given SmallInteger refer to a<br>
	 *  single, unique GemStone object.  That is, they are all both equal (=) and<br>
	 *  identical (==).
	 */
	//public GbjObject SmallInteger;
	/**
	 * A SoftCollisionBucket is a CollisionBucket intended to<br>
	 *  store key/SoftReference pairs .<br>
	 *  key/SoftReference pairs whose SoftReferences have been cleared by <br>
	 *  the in-memory garbage collector will be removed from a SoftCollisionBucket <br>
	 *  during the next at:put: operation following a garbage collection which cleared<br>
	 *  the references.  <br>
	 *  <br>
	 *  Cleared SoftReferences will also be removed when their key matches<br>
	 *  the argument key for a lookup operation .  The lookup code will<br>
	 *  not remove cleared SoftReferences for non-matching keys.<br>
	 * <br>
	 *  Instances of SoftCollisionBucket are non-persistent and may<br>
	 *  not be committed to the repository.
	 */
	//public GbjObject SoftCollisionBucket;
	/**
	 * A SoftReference contains a reference to another object which may be<br>
	 *  cleared by the in-memory garbage collector.   Instances of SoftReference<br>
	 *  are non-persistent and may not be committed ot the repository .<br>
	 * <br>
	 *  A SoftReference's value instVar is only cleared if<br>
	 *  there are no strong references to the referenced value , and if<br>
	 *  the inUse instVar is not true .<br>
	 * <br>
	 *  If a SoftReference to A is cleared, all other SoftReferences<br>
	 *  to objects B such that B->A is a strong reference, are also cleared .<br>
	 *  All SoftReferences that are legal to clear are cleared before<br>
	 *  generating OutOfMemory error .<br>
	 * <br>
	 *  VM scavenge will never clear SoftReferences , and the normal stubbing of<br>
	 *  references from temporary to committed objects is not performed<br>
	 *  in SoftReferences .<br>
	 * <br>
	 *  If percentMemUsed > GEM_SOFTREF_CLEANUP_PERCENT_MEM at start of markSweep,<br>
	 *  markSweep will will attempt to clear SoftReferences as follows:<br>
	 * <br>
	 *  if percentMemUsed < 60%,<br>
	 *  markSweep will try to clear the least recently used 10% of SoftReferences.<br>
	 * <br>
	 *  if percentMemUsed >= 60% and < 90% ,<br>
	 *  markSweep will try to clear the least recently used 20% of SoftReferences.<br>
	 * <br>
	 *  if percentMemUsed >= 90%<br>
	 *  markSweep will try to clear all SoftReferences.
	 */
	//public GbjObject SoftReference;
	/**
	 * SortBlockNode is a concrete class that along with the class BlockSorter implements the <br>
	 *  behavior used to sort collections efficiently. It is an interface to an algorithm based <br>
	 *  on an efficient merge-sort.
	 */
	//public GbjObject SortBlockNode;
	/**
	 * A SortedCollection is an OrderedCollection that maintains the order of its<br>
	 *  elements based on a sort block.  In GemStone, SortedCollections are not fixed<br>
	 *  in length as in other Smalltalk systems.
	 */
	//public GbjObject SortedCollection;
	/**
	 * The class SortNode implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  A SortNode is a BtreeBasicLeafNode that can sort node entries by index path.
	 */
	//public GbjObject SortNode;
	/**
	 * The class SortNodeArray implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.<br>
	 * <br>
	 *  
	 */
	//public GbjObject SortNodeArray;
	/**
	 * The class StackBuffer is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject StackBuffer;
	/**
	 * The class StackSegment is obsolete as of GemStone version 5.0 and will be removed in a future release.  GemStone recommends that you retire or migrate your instances in this release.
	 */
	//public GbjObject StackSegment;
	/**
	 * Stream is an abstract superclass that represents the ability to maintain a<br>
	 *  position reference into a linear sequence of objects.  Concrete subclasses are<br>
	 *  ReadStream and WriteStream.
	 */
	//public GbjObject Stream;
	/**
	 * Instances of class String are indexed collections of Characters.
	 */
	//public GbjObject String;
	/**
	 * A StringKeyValueDictionary is a KeyValueDictionary in which the keys are<br>
	 *  Strings or DoubleByteStrings.  The hash function treats the strings as<br>
	 *  case-sensitive.<br>
	 * <br>
	 *  The hashing algorithm is described in<br>
	 * <br>
	 *  Pearson, Peter K.,<br>
	 *  "Fast Hashing of Variable-Length Text Strings,"<br>
	 *  Communications of the ACM, 33:6 (June 1990), 667-680.<br>
	 * <br>
	 *  The implementation employs two modifications:<br>
	 * <br>
	 *  * The hash function uses at most 2008 bytes of the string.  Strings that are<br>
	 *    identical within this range have the same hash value.<br>
	 * <br>
	 *  * In his paper, Pearson describes a technique for producing a larger number of<br>
	 *    hash values by always computing the hash function to 24 bits.  The hash<br>
	 *    value is the result of this function modulo the table size.  Therefore,<br>
	 *    there is no value in specifying a table size greater than 2 to the 24th<br>
	 *    power.
	 */
	//public GbjObject StringKeyValueDictionary;
	/**
	 * A StringPair is an Association whose key and value are both constrained<br>
	 *  to be Strings.
	 */
	//public GbjObject StringPair;
	/**
	 * A StringPairSet is an IdentitySet that contains only StringPair objects.
	 */
	//public GbjObject StringPairSet;
	/**
	 * This is part of the SUnitPreload package and provides<br>
	 * dialect-specific support for the remaining portable code.<br>
	 * This class supports delay timing.
	 */
	//public GbjObject SUnitDelay;
	/**
	 * This is part of the SUnitPreload package and provides<br>
	 * dialect-specific support for the remaining portable code.<br>
	 * This class supports global name lookup.
	 */
	//public GbjObject SUnitNameResolver;
	/**
	 * This is the abstract superclass for all tests.
	 */
	//public GbjObject SUnitTest;
	/**
	 * A Symbol is an invariant String for which all comparisons are case-sensitive.<br>
	 *  Symbols are used internally to represent variable names and selectors.  Symbols<br>
	 *  are always invariant and cannot be modified at any time after they are created.<br>
	 *  Hence, the new and new: methods are disallowed.  In the server, a symbol may
         *  be an instance of Symbol, DoubleByteSymbols or QuadByteSymbol.
         *  
	 * <br>
	 *  All Symbols are canonical, which means that it is not<br>
	 *  possible to create two of them that have the same value.  If two canonical<br>
	 * <br>
	 *  GemStone places all canonical symbols in the DataCuratorSegment.  However,<br>
	 *  GemStone does permit you to commit a canonical Symbol, even if you have no<br>
	 *  explicit write authorization for the DataCuratorSegment.  GemStone also gathers<br>
	 *  all canonical symbols into one collection (a CanonicalStringDictionary) called<br>
	 *  AllSymbols, which it also places in the DataCuratorSegment.<br>
	 * <br>
	 *  Since canonical symbols are universally visible, it is not recommended that <br>
	 *  they be used for names that should remain private or secure.  Such objects<br>
	 *  should be instances of InvariantString instead.<br>
	 * <br>
	 *  Since canonical symbols must be universally available, you cannot lock a<br>
	 *  Symbol.<br>
	 * <br>
	 *  Since each canonical symbol has a unique value, you cannot copy a Symbol.
	 *  In addition, to guarantee canonicalization, you cannot send<br>
	 *  the become: or changeClassTo: messages to a Symbol or DoubleByteSymbol.<br>
	 */
	public GbjObject Symbol;
	/**
	 * A SymbolAssociation is an Association whose key is constrained to be a<br>
	 *  canonical symbol (Symbol, DoubleByteSymbol, or QuadByteSymbol).
	 */
	//public GbjObject SymbolAssociation;
	/**
	 * A SymbolDictionary is an IdentityDictionary in which the keys are canonical<br>
	 *  Symbols and the values are SymbolAssociations.<br>
	 *  The key of each SymbolAssociation is also the key used by the SymbolDictionary<br>
	 *  to access that SymbolAssociation.<br>
	 * <br>
	 *  Only SymbolDictionaries can be used in symbol lists.
	 */
	//public GbjObject SymbolDictionary;
	/**
	 * A SymbolKeyValueDictionary is an IdentityKeyValueDictionary in which the keys<br>
	 *  are canonical Symbols .  The separate<br>
	 *  implementation is necessary in order to support canonicalization of the symbols<br>
	 *  that are used as keys.<br>
	 * <br>
	 *  SymbolKeyValueDictionaries cannot be used in symbol lists.
	 */
	//public GbjObject SymbolKeyValueDictionary;
	/**
	 * A SymbolList is an Array whose elements are instances of SymbolDictionary.<br>
	 * <br>
	 *  It is used in compilation of GemStone Smalltalk code, in order to resolve<br>
	 *  references to objects by name.  Given a Symbol as a name, the SymbolList<br>
	 *  searches its dictionary elements in order, and the first key that matches the<br>
	 *  given Symbol then resolves to the object that is the value at that key in that<br>
	 *  dictionary.<br>
	 * <br>
	 *  Constraints on indexable fields are enforced by behavior in this class.
	 */
	//public GbjObject SymbolList;
	/**
	 * A SymbolSet is an IdentitySet whose elements must be canonical symbols<br>
	 *  (Symbols or DoubleByteSymbols).
	 */
	//public GbjObject SymbolSet;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject SystemLoginNotification;
	/**
	 * This is the abstract superclass for tests.<br>
	 * It is provided by the SUnit framework.
	 */
	//public GbjObject TestCase;
	/**
	 * This is part of the SUnitPreload package and provides<br>
	 * dialect-specific support for the remaining portable code.<br>
	 * This class supports exception handling.
	 */
	//public GbjObject TestFailure;
	/**
	 * This is the abstract superclass for test resources.<br>
	 * It is provided by the SUnit framework.
	 */
	//public GbjObject TestResource;
	/**
	 * This class is internal to the SUnit test framework.
	 */
	//public GbjObject TestResult;
	/**
	 * This class is internal to the SUnit test framework.
	 */
	//public GbjObject TestSuite;
	/**
	 * An instance of Time describes a time of day with one-millisecond resolution.<br>
	 *  The class Time also provides methods for examining the system clock and for<br>
	 *  measuring the performance of a block.<br>
	 * <br>
	 *  The internal representation of a Time is based on local time.<br>
	 * <br>
	 *  You can convert a Time to a String (using Formatting instance methods), and<br>
	 *  you can convert a String to a Time (using Instance Creation class methods).<br>
	 *  Such conversions require a specification to describe the format of the String.<br>
	 *  Some methods provide for the default format, HH:MM:SS, which uses a 24-hour<br>
	 *  clock.<br>
	 * <br>
	 *  Explicit string-formatting specifications take the form of an Array, described<br>
	 *  in the following table.  A specification is incorrect if it is missing an<br>
	 *  element or if an element value is not one of the acceptable values listed in<br>
	 *  the table.<br>
	 * <br>
	 *  String-formatting Specification Array for Time.<br>
	 * <br>
	 *  Element   Acceptable Value     Explanation<br>
	 *  <br>
	 *  1st       A Character literal  Separates hours, minutes, and seconds.<br>
	 *            (such as $: or $.)<br>
	 * <br>
	 *  2nd       true                 Include seconds.<br>
	 * <br>
	 *  2nd       false                Do not include seconds.<br>
	 * <br>
	 *  3rd       true                 Time is expressed in 12-hour format, with<br>
	 *                                 am or pm (such as 1:30:55 pm).  The space is<br>
	 *                                 required preceding the am or pm indicator.<br>
	 * <br>
	 *  3rd       false                Time is expressed in 24-hour format<br>
	 *                                 (such as 13:30:55).
	 */
	//public GbjObject Time;
	/**
	 * This provides GemStone/S overrides and extensions to the<br>
	 * ANSI TimeZone behavior.
	 */
	//public GbjObject TimeZone;
	/**
	 * This is the abstract superclass that contains a dialect-independent<br>
	 * implementation of the TimeZone behavior. It reads a binary file<br>
	 * generated by the Olsen ZoneInfo database.
	 */
	//public GbjObject TimeZoneInfo;
	/**
	 * Instances of this class represent records in a ZoneInfo database.<br>
	 * It describes characteristics of a transition to/from DST.
	 */
	//public GbjObject TimeZoneTransition;
	/**
	 * refers to a class in GemStone with the same name
	 */
	//public GbjObject TransactionBoundaryDefaultPolicy;
	/**
	 * TraversalBuffer represents an instance of the C type GciTravBufType, which is<br>
	 *  defined in $GEMSTONE/include/gcicmn.ht .  Various traversal functions defined<br>
	 *  in $GEMSTONE/include/gci.hf  take a pointer to a GciTravBufType as an argument.
	 */
	//public GbjObject TraversalBuffer;
	/**
	 * This class describes the behavior of nil, the `nonexistent' object.  You may<br>
	 *  not create new instances of UndefinedObject.
	 */
	//public GbjObject UndefinedObject;
	/**
	 * The class UnimplementedFloat1 implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject UnimplementedFloat1;
	/**
	 * The class UnimplementedFloat2 implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject UnimplementedFloat2;
	/**
	 * UnorderedCollection is an abstract class for collections of objects whose<br>
	 *  elements are not logically arranged in any particular order.  The elements are<br>
	 *  also not physically stored in any fixed order.  Any implied ordering at any<br>
	 *  given time is independent of the order in which the elements were added to the<br>
	 *  collection and cannot be relied upon to persist.<br>
	 * <br>
	 *  The elements of unordered collections are all of the same kind.  Unless<br>
	 *  restricted further by a subclass, the kind of elements in unordered collections<br>
	 *  is Object.  That is, the class of each element must simply be some kind of<br>
	 *  Object.<br>
	 * <br>
	 *  You cannot add nil to any kind of unordered collection.  Attempts to do so have<br>
	 *  no effect.<br>
	 * <br>
	 *  UnorderedCollection provides for fast associative access of collection elements<br>
	 *  in searches by means of the use of indexes with selection blocks.<br>
	 *  UnorderedCollection creates each index for an individual instance, where<br>
	 *  specified, and maintains that index thereafter unless it is removed<br>
	 *  explicitly.<br>
	 * <br>
	 *  Indexing is done on instance variables, not on values returned by messages.<br>
	 *  When an index path is used as an argument to a method, it is specified by a<br>
	 *  String that consists of instance variable names separated by periods (such as<br>
	 *  the String 'instvar1.instvar2.instvar3').  The ith name in the String<br>
	 *  corresponds to the ith position in the path.  A path String may include up to<br>
	 *  16 names and is limited to a total of 1024 Characters.<br>
	 * <br>
	 *  If aPathString is an empty path (that is, a zero-length String), the method<br>
	 *  operates upon the elements of the receiver itself rather than upon the instance<br>
	 *  variables of those elements.<br>
	 * <br>
	 *  For more information about index structures and path expressions, see the<br>
	 *  GemStone Programming Guide.
	 */
	//public GbjObject UnorderedCollection;
	/**
	 * Each instance of UserProfile contains a number of characteristics associated<br>
	 *  with a given system user.  For more information, see the GemStone System<br>
	 *  Administration Guide and the GemStone Programming Guide.
	 */
	public GbjObject UserProfile;
	/**
	 * UserProfileSet is a concrete subclass of AbstractUserProfileSet that implements<br>
	 *  and enforces some account and password security features for all of its<br>
	 *  elements.<br>
	 * <br>
	 *  Only one instance of UserProfileSet, called AllUsers, is allowed to exist,<br>
	 *  and is provided with a fresh GemStone server.  All UserProfiles in GemStone <br>
	 *  belong to this set.  AllUsers supports security features for all users.  <br>
	 *  AllUsers also ensures uniqueness of userId Strings; no two UserProfiles can<br>
	 *  have the same ID.<br>
	 * <br>
	 *  GemStone, as shipped from the factory, disables all the security features<br>
	 *  supported by AllUsers.  To activate any or all of those features, an<br>
	 *  administrator with the proper privileges must execute methods on AllUsers.<br>
	 *  Activated features can also be deactivated later by reapplying the settings<br>
	 *  that do not constrain GemStone's behavior.<br>
	 * <br>
	 *  Password format constraints are applied only after an administrator commits<br>
	 *  the changes in AllUsers.  They are then enforced only when users change their<br>
	 *  own passwords with the UserProfile>>oldPassword:newPassword: method, not when<br>
	 *  administrators or other users make changes with methods that require the<br>
	 *  OtherPassword privilege.  In addition, enforcement does not apply to existing<br>
	 *  passwords created before new constraints were committed.<br>
	 * 
	 */
	//public GbjObject UserProfileSet;
	/**
	 * The class UserSecurityData implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject UserSecurityData;
	/**
	 * The class VariableContext implements only GemStone internals.  That is, it provides only functionality required by GemStone itself.  It is not intended for customer use, by creating instances or by subclassing.
	 */
	//public GbjObject VariableContext;
	/**
	 * The class protocol describe the behavior of the global Warning. <br>
	 * The value of the standard global Warning is a class object that <br>
	 * conforms to this protocol. The class Warning is explicitly specified <br>
	 * to be subclassable in a standard conforming program. Conforming <br>
	 * implementations must implement its behaviors in a non-fragile manner.<br>
	 * <br>
	 * The signaled exceptions generated by this type of object conform to <br>
	 * the protocol <Warning>.<br>
	 * <br>
	 * The instance protocol describes the behavior of instances of class <br>
	 * Warning. These are used to represent exceptional conditions that <br>
	 * might occur that are not considered errors but which should be <br>
	 * reported to the user. Typically, the actual warning exceptions <br>
	 * used by an application will be subclasses of this class.<br>
	 * <br>
	 * As Warning is explicitly specified to be subclassable, conforming <br>
	 * implementations must implement its behavior in a non-fragile manner.
	 */
	//public GbjObject Warning;
	/**
	 * A WriteStream is a PositionableStream that allows its objects to be written,<br>
	 *  but not read.
	 */
	//public GbjObject WriteStream;
	/**
	 * The class protocol describe the behavior of the global ZeroDivide. <br>
	 * It is used to as an exception selector to catch zero divide exceptions <br>
	 * and can also be used to signal that a division by zero error has <br>
	 * occured. Zero divide exceptions are resumable so any message in this <br>
	 * protocol that signal such an exception may ultimately return to their <br>
	 * sender. The signaled exceptions generated by this type of object <br>
	 * conform to the protocol <ZeroDivide>.<br>
	 * <br>
	 * The instance protocol describes the behavior of exceptions that are <br>
	 * signalled when an attempt is made to divide some number (the dividend) <br>
	 * by zero.
	 */
	//public GbjObject ZeroDivide;


        /** Constructor for GbjKernelObjects
	    @param session  GbjSession to use
	    @param kernelOop array from server with kernel oops
	 */
	public GbjKernelObjects(GbjSession session, long[] kernelOop) {   
               
		GbjGciInterface = (GbjObject)session.gbjGciInterface;

                // kernalOop array is from Java_com_gemstone_gbjgci_GbjGciInterface__1initialize 
                //   in GbjGciInterface.c
		// Illegal = GbjObject.withOop(0, session);
		Nil =             (GbjObject)session.objWithOop(kernelOop[ 0]);
		System =          (GbjObject)session.objWithOop(kernelOop[ 1]);
		GemStoneError =   (GbjObject)session.objWithOop(kernelOop[ 2]);
		Zero =            (GbjObject)session.objWithOop(kernelOop[ 3]);
		One =             (GbjObject)session.objWithOop(kernelOop[ 4]);
		maxSmallInteger = kernelOop[ 5];
		minSmallInteger = kernelOop[ 6];
		True =            (GbjObject)session.objWithOop(kernelOop[ 7]);
		False =           (GbjObject)session.objWithOop(kernelOop[ 8]);
		Symbol =          (GbjObject)session.objWithOop(kernelOop[ 9]);
		Array =           (GbjObject)session.objWithOop(kernelOop[10]);
		Association =     (GbjObject)session.objWithOop(kernelOop[11]);
		UserProfile =     (GbjObject)session.objWithOop(kernelOop[12]);
	}

}

