/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *      GbjObserver.java  
 *
 *========================================================================
 */

package com.gemstone.gbj;

import java.util.Observer;

/**
 * This interface allows objects to monitor events in GbjObservables such as
 * GbjSession instances
 */


public abstract interface GbjObserver extends Observer {


/**
 * Determine how to handle events sent to an observed GBJ object.
 * These are typically GbjSession instances.  
 * <p>
 * The following are possible notificationMessages:
 * <ul>
 * <li> Transactional activity:  "begin", "abort", "commit" 
 * <li> Object change notification: "ObjChg" 
 * <li> Gem-to-gem signalling: Other messages as coded 
 * </ul>
 *
 * @param obj GbjObservable
 * @param notificationMessage String
 * @param argument  Object
 */
    public void update(GbjObservable obj, String notificationMessage, Object argument);
}

