/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *========================================================================
 */

package com.gemstone.gbj;

/**
 *   Instances of this class are used to specify the information needed to
 *   configure a GemStone session.  Information in a GbjParameters is used
 *   for initial session configuration only.  A session must be disconnected
 *   and connected again to have it recognize changes in the GbjParameters used
 *   to configure it.

<h3> GBJ30 Changes </h3>

The following fields have been deprecated and no longer have any
effect on the session:

<ul>
<li> String brokerMachine
<li> int brokerPort
<li> int connectTimeout
<li> int timeout
</ul>

 *
 */
public class GbjParameters implements java.io.Serializable {
    
    /**
     * The SUID for this class, generated with Java's serialver program
     */
    static final long serialVersionUID = 8686259486281877156L;

    /* Oop Format Constants */

    public static final int FORMAT642 = 3;

    /** @deprecated As of GBJ30, this constant is irrelevant */
    @Deprecated
    public static final String DEFAULT_BROKER_MACHINE ="localhost";
    /** @deprecated As of GBJ30, this constant is irrelevant */
    @Deprecated
    public static final int DEFAULT_BROKER_PORT = 9090;
    /** @deprecated As of GBJ30, this constant is irrelevant */
    @Deprecated
    public static final int DEFAULT_CONNECTION_TIMEOUT = 150;
    /** @deprecated As of GBJ30, this constant is irrelevant */
    @Deprecated
    public static final int DEFAULT_TIMEOUT = 900;
    /** Constant for manual transaction mode */
    public static final int MANUAL_TRANSACTIONS = 0;
    /** Constant for automatic transaction mode */
    public static final int AUTOMATIC_TRANSACTIONS = 1;
    /** Constant for transactionless mode */
    public static final int TRANSACTIONLESS = 2;
    /** Constant for default transaction mode (manual) */
    public static final int DEFAULT_TRANSACTION_MODE = MANUAL_TRANSACTIONS;
    /** Constant for the default oop format (FORMAT32) */
    public static final int DEFAULT_FORMAT = FORMAT642;

    /**
     * The oop format for this connection. 
     * @deprecated, has no effect.
     */
    public int format;
    /**
     * The amount of time in seconds that an idle connection will remain open.
     * If zero, the connection will not time out.  
     * The default is 900 seconds (15 minutes).
     * @deprecated As of GBJ30, this parameter has no effect.
     */
    @Deprecated
    public int timeout;
    /**
     * The amount of time in seconds that may elapse before a request for 
     * connection must be fulfilled by the session broker.
     * The default is 150 seconds.  
     * The session broker running in the server should be given a connect 
     * timeout that is smaller than the value given here or the client may 
     * timeout before the server.  This will result in the loss of
     * database login failure information.
     * @deprecated As of GBJ30, this parameter has no effect.
     * 
     */
    @Deprecated
    public int connectTimeout;
    /**
     * The transaction mode.  Use the constants ManualTransactions,
     * AutomaticTransactions, or Transactionless as the value for
     * transactionMode.  This determines the way in which transactions
     * are started in a GemStone session.  The default is MANUAL_TRANSACTIONS.
     */
    public int transactionMode;
    /**
     * The NRS of the GemStone server (stone process)
     */
    public String serverName;
    /**
     * The GemStone gem service,  defaults to "gemnetobject", may not be "gcilnkobj" in this jar.
     */
    public String gemnetName;
    /**
     * The GemStone account User ID.  This is a required parameter.  Login will
     * fail if it is not set to a valid user account ID.
     */
    public String userName;
    /**
     * The GemStone account password
     */
    public transient String password;
    /**
     * The broker machine IP address or name.  This is a service that locates 
     * and configures a server session for the interface.
     * @deprecated As of GBJ30, this parameter has no effect.
     */
    @Deprecated
    public String brokerMachine;
    /**
     * The broker port number. Since Java does not support getservbyname() type
     * queries, this must be a hard-coded number instead of a service name.
     * @deprecated As of GBJ30, this parameter has no effect.
     */
    @Deprecated
    public int brokerPort;
    /**
     * A server operating system account name may be given to cause the session
     * to run in an alternate account on the server.  This may be a required
     * field in an installation.
     */
    public String serverOSUserName;
    /**
     * The server operating system account password
     */
    public transient String serverOSPassword;
    
    /**
     * Use this value in transactionMode to specify explicit (manual) 
     * transaction mode.  Transactions in this mode require a 
     * "beginTransaction" before modifying persistent objects.
     * 
     */
    public static final int ManualTransactions = 0;
    
    /**
     * Use this value in transactionMode to specify chained (automatic) 
     * transaction mode.  A transaction is started when the session connects
     * to the server and new transaction is begun after a commitTransaction 
     * or abortTransaction is processed.
     */
    public static final int AutomaticTransactions = 1;
    
    /**
     * Use this value in transactionMode to specify that the server will not
     * perform transactions.  This is intended primarily for idle sessions.
     * Applications may see an inconsistent view of the database.
     * 
     */
    public static final int Transactionless = 2;
    
    /**
     * The default parameters specify an anonymous connection with read-only
     * access and a 15 minute timeout.  The broker machine is set to 
     * "localhost" and port 9090.
     */
    public GbjParameters() {
        brokerMachine   = DEFAULT_BROKER_MACHINE;
        brokerPort      = DEFAULT_BROKER_PORT;
        connectTimeout = DEFAULT_CONNECTION_TIMEOUT;
        timeout = DEFAULT_TIMEOUT;
        transactionMode = DEFAULT_TRANSACTION_MODE;
	format = DEFAULT_FORMAT;
	gemnetName = "gemnetobject"; // 40301
    }
    
}
