package com.gemstone.gbj;
import java.util.*;
import java.lang.reflect.Method;
import java.lang.reflect.InvocationTargetException;
import java.lang.Class;
import java.lang.NoSuchMethodException;

// GBJ30: changed to java logger
//import com.gemstone.org.apache.log4j.*;
import java.util.logging.*;
import com.gemstone.gbjgci.*;

/**
 * A dispatcher of messages from the server (Smalltalk) to client (Java) objects.
 * The session creates clientInterface objects each time a message is received
 * from the server that needs to be forwarded to a client object.  This runs in
 * a separate thread to keep the DIMgr's receive thread unblocked.
 * 
 * 
 * @version 3.0
 */

class GbxClientInterface {
    Object receiver;
    String selector;
    GbjSession session;
    Object [] args;
    Class [] parameterTypes;  // 45749: make accessible
    private static Logger log;

    // static code for setting up logger
    static {
	log = GbjGciInterface.setupLogger(GbxClientInterface.class);
    }
    
    protected GbxClientInterface(GbjSession session, Object receiver,
                String selector, Object [] args) {
        this.session = session;
        this.receiver = receiver;
        this.selector = selector;
        this.args = args;
    }

    private void checkArgs(int numExpected) {
        if (numExpected != args.length) {
            throw new Error("Unable to dispatch client message.  Expected " + numExpected + " arguments but received " + args.length);
        }
    }

    private String getSelector(String arg) {
    	int index = arg.indexOf(':');
    	String result;

    	if (index == -1)
    	    return arg;
    	result = arg.substring(0, index);
	return result;
    }

    private Class getArgClass(Object arg) {
        if (arg instanceof Byte)
	        return java.lang.Byte.TYPE;
        if (arg instanceof Integer)
	        return java.lang.Integer.TYPE;
        if (arg instanceof Character)
	        return java.lang.Character.TYPE;
        if (arg instanceof Boolean)
	        return java.lang.Boolean.TYPE;
        if (arg instanceof Long)
	        return java.lang.Long.TYPE;
        if (arg instanceof Double)
	        return java.lang.Double.TYPE;
        if (arg instanceof Float)
	        return java.lang.Float.TYPE;
        return arg.getClass();
    }

    private Object dispatchGemStoneMessage() throws Throwable {
	Method method;

	parameterTypes = new Class[args.length];
	for (int i = 0; i < parameterTypes.length; i++) {
	    parameterTypes[i] = args[i].getClass();
	}
	try {
	    method = receiver.getClass().getDeclaredMethod(selector, parameterTypes);
	    return method.invoke(receiver, args);
	}
	catch (NoSuchMethodException e) {
	    return dispatchGemStoneMessage2();
	}
	catch (InvocationTargetException e) {
	    throw e.getTargetException();
	}
    }

    private Object dispatchGemStoneMessage2() throws Throwable {
	Method method;
	parameterTypes = new Class[args.length];
	for (int i = 0; i < parameterTypes.length; i++) {
	    parameterTypes[i] = getArgClass(args[i]);
	}
	try {
	    method = receiver.getClass().getDeclaredMethod(selector, parameterTypes);
	    return method.invoke(receiver, args);
	}
	catch (NoSuchMethodException e) {
	    return dispatchBasicGemStoneMessage();
	}
	catch (InvocationTargetException e) {
	    throw e.getTargetException();
	}
    }

    private Object dispatchBasicGemStoneMessage() {

        if (selector.equals("=")) {
    	    checkArgs(1);
    	    return new Boolean(receiver.equals(((GbjObject) args[0]).cachedValue()));
    	}
    	else if (selector.equals("==")) {
    	    checkArgs(1);
    	    return new Boolean(receiver == (((GbjObject) args[0]).cachedValue()));
    	}
        else if (selector.equals("getClass")) {
	    checkArgs(0);
	    return receiver.getClass();
    	}
    	else if (selector.equals("hashCode")) {
    	    checkArgs(0);
    	    return new Integer(receiver.hashCode());
    	}
    	else if (selector.equals("toString") || selector.equals("printString")) {
    	    checkArgs(0);
    	    return receiver.toString();
    	}
    	else {
	    // 45770: clean up error message
    	    throw new GbjException("Problem using client forwarder " 
				   + receiver 
				   + " selector " 
				   + selector);
	}
    }

    public Object execute() throws Throwable
 {
	GbjClientAdapter adapter;
	Object result;

	if (receiver instanceof GbjClientAdapter)
	    adapter = (GbjClientAdapter)receiver;
	else
	    adapter = session.findClientAdapter(receiver);
	    if (adapter == null) {
		this.selector = getSelector(this.selector);
		result = dispatchGemStoneMessage(); }
	    else
   		result = adapter.dispatchGemStoneMessage(session, receiver, selector, args);

	    return result;

    }
}
