/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *      GbjGciCacheStats.java  
 *
 *========================================================================
 */

package com.gemstone.gbjgci;

/** 

GbjGciCacheStats provides access to shared page 
cache statistics returned from GbjGciInterface calls to GCSI 
(GCI Cache Statistics Interface) functions.  All behavior is defined in
GbjGciInterface -- refer to GbjGciInterface documentation for details.

<p>

Like other GbjGci classes, higher level classes are available for more
application-friendly use.  See GbjCacheStats and GbjJmxCacheStats in 
the com.gemstone.gbjstats package for details.

@version 3.1

*/

public class GbjGciCacheStats {

    /** Static constant for representing an unassigned GS process type (-1)*/
    public static final int TYPE_UNASSIGNED = -1;

    /** Static constant for representing a shared page cache monitor 
        GS process type (0) */
    public static final int TYPE_SPCMONITOR = 0;

    /** Static constant for representing a stone GS process type (1)*/
    public static final int TYPE_STONE      = 1;

    /** Static constant for representing a pgsvr GS process type (2)*/
    public static final int TYPE_PGSVR      = 2;

    /** Static constant for representing a gem GS process type (3)*/
    public static final int TYPE_GEM        = 3;

    /** Static constant for representing a statmon GS process type (4)*/
    public static final int TYPE_STATMON    = 4;

    /** Static constant for representing an application GS process type (5)*/
    public static final int TYPE_APP        = 5;

    /** Static constant for representing a system GS process type (6)*/
    public static final int TYPE_SYSTEM     = 6;

    /** Type of GemStone Process providing these cache stats */
    public int type;

    /** Name of GemStone Process providing these cache stats */
    public String name;

    /** Process ID */
    public long pid;

    /** Session ID */
    public long sid;

    /** int[] field for holding 32-bit cache stats */
    public int[] stats32;

    /** long[] field for holding 64-bit cache stats */
    public long[] stats64;

}


