/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *      GbjJmxCommandInfo.java  
 *
 *========================================================================
 */

package com.gemstone.gbjstats;
import java.util.*;

/** Helper class used by GbjJmxSystemStats and GbjHypericPluginGenerator
    to hold customer-configurable information on valid JMX/Hyperic Commands.
    <p>
    No public protocol available.
 */

public class GbjJmxCommandInfo {
    /** Name of command */
    protected String name;
    /** Description of command */
    protected String description;
    /** GS/64 Smalltalk code for command */
    protected String code;

    /** Create a GbjJmxCommandInfo structure */
    protected GbjJmxCommandInfo(String n, String d, String c) {
        name = n;
        description = d;
        code = c;
    }

    /** Read JMX/Hyperic command information from the command files
        in $GBJ/server, starting with GbjJmxCommands.dat, and if not 
        available, GbjJmxCommandsTemplate.dat
     */
    protected static GbjJmxCommandInfo[] readCommandInfo( ) {

        // retrieve commands from the GbjJmxSystemStats.dat file
        GbjJmxDataFile file = null;
        try {
            file = new GbjJmxDataFile("GbjJmxCommands.dat");
        } catch (java.io.FileNotFoundException e) {
            try {
                file = new GbjJmxDataFile("GbjJmxCommandsTemplate.dat");
            } catch (java.io.FileNotFoundException e2) {
                System.err.println("Problem finding GbjJmxCommands.dat");
            }
        }
        ArrayList<GbjJmxCommandInfo> cmds = new ArrayList<GbjJmxCommandInfo>( );
        String n;
        while ((n = file.readLine( )) != null) {
            n = n.trim();
            String d  = file.readLine().trim();
            String c  = file.readLine().trim();
            cmds.add(new GbjJmxCommandInfo(n,d,c));
        }
        try { file.close( ); } catch (Exception e) { }
        GbjJmxCommandInfo[] results =
            new GbjJmxCommandInfo[cmds.size()];
        for (int i = 0; i < cmds.size(); i++) {
           results[i] = cmds.get(i);
        }
        return results;
    }
}

