/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 *      GbjJmxSystemStatInfo.java  
 *
 *========================================================================
 */

package com.gemstone.gbjstats;
import java.util.*;

/** Helper class used by GbjJmxSystemStats and GbjHypericPluginGenerator
    to hold customer-configurable information on JMX/Hyperic System Stats.
    <p>
    No public protocol available.
 */


public class GbjJmxSystemStatInfo {
    /** Name of statistic */
    protected String name;
    /** Category of stat: AVAILABILITY,THROUGHPUT,UTILIZATION,PERFORMANCE */
    protected String category;
    /** type of stat: static, dynamic, trendsup, trendsdown */
    protected String type;
    /** units for stat (optional): null,B,KB,MB,GB,TB,sec,ms,mu,ns */
    protected String units;
    /** units for rate (optional): null,1s,1m,1h */
    protected String rate;

    /** Create a GbjJmxSystemStatInfo structure */
    protected GbjJmxSystemStatInfo(String n, String c, String t, 
                                   String u, String r) {
        name = n;
        category = c;
        type = t;
        units = u;
        rate = r;
    }

    /** Read JMX/Hyperic system stat information from the stat info files
        in $GBJ/server, starting with GbjJmxSystemStats.dat, and if not 
        available, GbjJmxSystemStatsTemplate.dat
     */
    protected static GbjJmxSystemStatInfo[] readSystemStatInfo( ) {

        // retrieve from the GbjJmxSystemStats.dat file
        GbjJmxDataFile file = null;
        try {
            file = new GbjJmxDataFile("GbjJmxSystemStats.dat");
        } catch (java.io.FileNotFoundException e) {
            try {
                file = new GbjJmxDataFile("GbjJmxSystemStatsTemplate.dat");
            } catch (java.io.FileNotFoundException e2) {
                System.err.println("Problem finding GbjJmxSystemStats.dat");
            }
        }
        ArrayList<GbjJmxSystemStatInfo> stats = 
            new ArrayList<GbjJmxSystemStatInfo>( );
        while (file.readLine( ) != null) {
            String n = file.nextToken();
            String c = file.nextToken();
            String t = file.nextToken();
            String u = file.nextToken(); // can be null or "null"
            if ((u != null) && (u.equals("null"))) u = null;
            String r = file.nextToken(); // can be null or "null"
            if ((r != null) && (r.equals("null"))) r = null;
            stats.add(new GbjJmxSystemStatInfo(n,c,t,u,r));              
        }
        try { file.close( ); } catch (Exception e) { }
        GbjJmxSystemStatInfo[] result = new GbjJmxSystemStatInfo[stats.size()];
        for (int i=0; i<stats.size(); i++) {
            result[i] = stats.get(i);
        }
        return result;
    }

}

