/*
 * GbjBreakpointBrowser.java
 *
 * Created on July 11, 2002, 3:23 PM
 */

package com.gemstone.tools;

import com.gemstone.gbj.*;
import java.awt.Font;
import javax.swing.*;
import java.awt.Cursor;
import java.awt.*;
// GBJ30: replace with java logging
//import com.gemstone.org.apache.log4j.*;
import java.util.logging.*;

/**
 *
 * @author  vincef
 */
public class GbjBreakpointBrowser extends com.gemstone.tools.GbjMethodListBrowser {
    
    JButton updateButton;
    JButton removeButton;
    JButton enableButton;
    JButton disableButton;
    JPanel methodsPanel;
    JMenu breakpointMenu;
    /** Creates a new instance of GbjBreakpointBrowser 
	@param session  GbjSession
	@param launcher GbjLauncher
    */
    
    public GbjBreakpointBrowser(GbjSession session,GbjLauncher launcher){
	this.session=session;
        session_(session);
        if(launcher!=null){
            this.launcher=launcher;
        }
        initUI();
        update();
        displayWindow();
    }
    
    public void updateFont(Font font) {
        methods.setFont(font);
        workspace.setFont(font);
    }
    
    protected void initCustomMenus() {
        super.initCustomMenus();
    }
    
    protected void initUI() {
        workspace=new JTextArea();
        mainFont=workspace.getFont();
        createActionTable(workspace);
        makeActionPretty();
        initMenuBar();
        initPopupMenu();
        setJMenuBar(menuBar);
        setSize(470,450);
        content=this.getContentPane();
        content.setLayout(new BorderLayout());
        addWindowListener(this);
        addComponentListener(this);
        updateButton=new JButton("Update");
        updateButton.addActionListener(this);
        updateButton.setName("Update JButton");
        updateButton.setActionCommand("Update");
        removeButton=new JButton("Remove");
        removeButton.addActionListener(this);
        removeButton.setName("Remove JButton");
        removeButton.setActionCommand("Remove Break");
        enableButton=new JButton("Enable");
        enableButton.setName("Enable JButton");
        enableButton.addActionListener(this);
        enableButton.setActionCommand("Enable Break");
        disableButton=new JButton("Disable");
        disableButton.setName("Disable JButton");
        disableButton.setActionCommand("Disable Break");
        disableButton.addActionListener(this);
        
        buttonPanel=new JPanel();
        buttonPanel.setLayout(new FlowLayout());
        buttonPanel.add(updateButton);
        buttonPanel.add(enableButton);
        buttonPanel.add(disableButton);
        buttonPanel.add(removeButton);
        methodsPanel=new JPanel();
        methodsPanel.setLayout(new GridBagLayout());
        //GridBagConstraints constraint=new GridBagConstraints();
        //constraint.gridwidth=GridBagConstraints.REMAINDER;
        //constraint.weighty=0;
        //constraint.weightx=0;
        //methodsPanel.add(buttonPanel,constraint);
        workspace.addMouseListener(this);
        sScroll=new JScrollPane(workspace);
        symbolDictionaries=new JList();
        classes=new JList();
        protocol=new JList();
        methods=new JList();
        mScroll=new JScrollPane();
        mScroll.setViewportView(methods);
        methods.addMouseListener(this);
        methods.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        if(mainFont!=null)updateFont(mainFont);
        FontMetrics tfont=getFontMetrics(workspace.getFont());
        int fSize=(int)(tfont.getHeight()*7);
        mScroll.setPreferredSize(new Dimension(400,fSize));
        sScroll.setPreferredSize(new Dimension(400,(int)(fSize*1.5)));
        JSplitPane sPane=new JSplitPane(JSplitPane.VERTICAL_SPLIT,mScroll,sScroll);
        sPane.setDividerLocation(.20);
        sPane.setLastDividerLocation(25);
        //sPane.setOneTouchExpandable(true);
        sPane.setResizeWeight(.40);
        sPane.setDividerSize(4);
        //constraint.weighty=1;
        //constraint.weightx=1;
        //constraint.fill=GridBagConstraints.BOTH;
        //methodsPanel.add(mScroll,constraint);
        //content.add(methodsPanel,BorderLayout.NORTH);
        content.add(buttonPanel,BorderLayout.NORTH);
        //content.add(sScroll,BorderLayout.CENTER);
        content.add(sPane,BorderLayout.CENTER);
        selectedComponent=workspace;
    }
    
    protected void update() {
        /* Flush and update field list (in case elements were added or removed from this exception elsewhere) */    
        this.resetFields();
    }
    
    void removeAllBreaks() {
        try {
            this.serverSupport().removeAllBreaks();
        } catch (GbjException e) {
            processError_(e);
        }
        //"Now that we have cleared all breaks, we need to do an update."
        this.resetFields();
    }
    
    void resetText() {
        int start, stop;
        String aString;
        
        aString = this.text();
        workspace.setText(aString);
        if (this.selectedMethod() != null) {
            start = this.selectedMethod().textPosition;
            stop = this.selectedMethod().endPoint;
            //System.out.println("Start = " + start + ".  Stop = " + stop);
            if (stop >= start) {
                workspace.requestFocus();
                workspace.select(start - 1, stop);
            }
        }
    }
    
    String defaultTitle() {
        return("GemStone Breakpoint Browser on: " + this.getSession());
    }
    
    void resetFields() {
        methodList = this.getMethodList();
        this.updateListWidget_withObjects_(methods, methodList);
        this.resetText();
    }
    
    GbxMethodHolder [] getMethodList() {
        return this.methodHoldersForBreakpoints();
    }
    
    GbxMethodHolder [] methodHoldersForBreakpoints() {
        GbxMethodHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = this.serverSupport().methodHoldersForBreakpoints();
        } catch (GbjException e) {
            this.processError_(e);
            holders = new GbxMethodHolder[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    void removeBreak() {
        if (this.selectedMethod() == null) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"Remove Break",JOptionPane.WARNING_MESSAGE);
            return;
        }
        try {
            this.serverSupport().removeBreakpoint_inMethod_(this.selectedMethod().stepPoint(), this.selectedMethod().proxy());
        } catch (GbjException e) {
            processError_(e);
        }
        this.resetFields();
    }
    
    void disableAllBreaks() {
        try {
            this.serverSupport().disableAllBreaks();
        } catch (GbjException e) {
            processError_(e);
        }
        //"Now that we have cleared all breaks, we need to do an update."
        this.resetFields();
    }
    
    void disableBreak() {
        if (this.selectedMethod() == null) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"Disable Break",JOptionPane.WARNING_MESSAGE);
            return;
        }
        try {
            this.serverSupport().disableBreakpoint_inMethod_(this.selectedMethod().stepPoint(), this.selectedMethod().proxy());
        } catch (GbjException e) {
            processError_(e);
        }
        this.resetFields();
    }
    
    void enableAllBreaks() {
        try {
            this.serverSupport().enableAllBreaks();
        } catch (GbjException e) {
            processError_(e);
        }
        //"Now that we have cleared all breaks, we need to do an update."
        this.resetFields();
    }
    
    void enableBreak() {
        if (this.selectedMethod() == null) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"Enable Break",JOptionPane.WARNING_MESSAGE);
            return;
        }
        try {
            this.serverSupport().enableBreakpoint_inMethod_(this.selectedMethod().stepPoint(), this.selectedMethod().proxy());
        } catch (GbjException e) {
            processError_(e);
        }
        this.resetFields();
    }
    
    void reinitialize() {
        this.resetFields();
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String action=actionEvent.getActionCommand();
        if(action.equals("Enable Break"))
            enableBreak();
        else if(action.equals("Enable All Breaks"))
            enableAllBreaks();
        else if(action.equals("Disable Break"))
            disableBreak();
        else if(action.equals("Disable All Breaks"))
            disableAllBreaks();
        else if(action.equals("Remove Break"))
            removeBreak();
        else if(action.equals("Remove All Breaks"))
            removeAllBreaks();
        else
        super.actionPerformed(actionEvent);
    }
    
    protected void addCustomMenus() {
        super.addCustomMenus();
        breakpointMenu=new JMenu("BreakPoint");
        JMenuItem tmenu=new JMenuItem("Enable Break");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Enable Break");
        tmenu.setName("Enable Break JMenuItem");
        breakpointMenu.add(tmenu);
        tmenu=new JMenuItem("Disable Break");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Disable Break");
        tmenu.setName("Disable Break JMenuItem");
        breakpointMenu.add(tmenu);
        tmenu=new JMenuItem("Remove Break");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Remove Break");
        tmenu.setName("Remove Break JMenuItem");
        breakpointMenu.add(tmenu);
        breakpointMenu.addSeparator();
        tmenu=new JMenuItem("Enable All Breaks");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Enable All Breaks");
        tmenu.setName("Enable All Breaks JMenuItem");
        breakpointMenu.add(tmenu);
         tmenu=new JMenuItem("Disable All Breaks");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Disable All Breaks");
        tmenu.setName("Disable All Breaks JMenuItem");
        breakpointMenu.add(tmenu);
         tmenu=new JMenuItem("Remove All Breaks");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Remove All Breaks");
        tmenu.setName("Remove All Breaks JMenuItem");
        breakpointMenu.add(tmenu);
        menuBar.add(breakpointMenu);
        initOtherPopups();
    }
    
    protected void displayWindow() {
        if(launcher!=null){
            setWindowID(launcher.getGlobalWindowID());
            setTitle("GBJ Breakpoints");
            launcher.registerWindow(this);
            launcher.addWindowMenu(this);
        }else {
            setTitle("GBJ Breakpoints");
        }
        pack();
        Dimension windowSize=getSize();
        Dimension screen=java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        int x=(screen.width-windowSize.width)/2;
        int y=(screen.height-windowSize.height)/2;
        setLocation(x,y);
        setVisible(true);
    }
  
    protected void addMethodMenu() {
        JMenuItem tMenu=new JMenuItem("File Out As");
        tMenu.addActionListener(this);
        tMenu.setActionCommand("File Out As Method");
        methodMenu.add(tMenu);
        methodMenu.addSeparator();
        tMenu=new JMenuItem("Browse Method");
        tMenu.setActionCommand("Browse Method");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
        tMenu=new JMenuItem("Senders");
        tMenu.setActionCommand("Senders");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
        tMenu=new JMenuItem("Implementors");
        tMenu.setActionCommand("Implementors");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
        tMenu=new JMenuItem("Messages");
        tMenu.setActionCommand("Messages");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
         menuBar.add(methodMenu);
    }
    
    protected void initOtherPopups() {
        methodPopup=new JPopupMenu();
        JMenuItem tmenu=new JMenuItem("Enable Break");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Enable Break");
        tmenu.setName("Enable Break JMenuItem");
        methodPopup.add(tmenu);
        tmenu=new JMenuItem("Disable Break");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Disable Break");
        tmenu.setName("Disable Break JMenuItem");
        methodPopup.add(tmenu);
        tmenu=new JMenuItem("Remove Break");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Remove Break");
        tmenu.setName("Remove Break JMenuItem");
        methodPopup.add(tmenu);
        methodPopup.addSeparator();
        tmenu=new JMenuItem("Enable All Breaks");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Enable All Breaks");
        tmenu.setName("Enable All Breaks JMenuItem");
        methodPopup.add(tmenu);
         tmenu=new JMenuItem("Disable All Breaks");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Disable All Breaks");
        tmenu.setName("Disable All Breaks JMenuItem");
        methodPopup.add(tmenu);
         tmenu=new JMenuItem("Remove All Breaks");
        tmenu.addActionListener(this);
        tmenu.setActionCommand("Remove All Breaks");
        tmenu.setName("Remove All Breaks JMenuItem");
        methodPopup.add(tmenu);
    }
    
}
