/*
 * GbjClassVersionBrowser.java
 *
 * Created on May 23, 2002, 4:46 PM
 */

package com.gemstone.tools;

import com.gemstone.gbj.*;
import javax.swing.*;
import java.awt.*;

/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbjClassVersionBrowser extends com.gemstone.tools.GbjBrowser {
    
    GbjObject classHistory;
    int selectedIndex;
    
    /** Creates new GbjClassVersionBrowser 
	@param aSession  GbjSession
	@param aLauncher GbjLauncher
    */
    public GbjClassVersionBrowser(GbjSession aSession,GbjLauncher aLauncher) {
        session=aSession;
        launcher=aLauncher;
        initUI();
    }
    
    protected void initUI() {
        setTitle("GBJ Class Browser");
        workspace=new JTextArea();
        createActionTable(workspace);
        makeActionPretty();
        initMenuBar();
        initPopupMenu();
        setJMenuBar(menuBar);
        //setSize(200,100);
        content=this.getContentPane();
        content.setLayout(new BorderLayout());
        addWindowListener(this);
        methods=new JList();
        methods.addListSelectionListener(this);
        methods.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        classes=new JList();
        classes.addListSelectionListener(this);
        classes.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        protocol=new JList();
        protocol.addListSelectionListener(this);
        protocol.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        symbolDictionaries=new JList();
        sScroll=new JScrollPane(workspace);
        pScroll=new JScrollPane(protocol);
        pScroll.setViewportView(protocol);
        mScroll=new JScrollPane(methods);
        mScroll.setViewportView(methods);
        cScroll=new JScrollPane(classes);
        cScroll.setViewportView(classes);
        instOrClass=new ButtonGroup();
        instanceRB=new JRadioButton("Instance");
        classRB=new JRadioButton("Class");
        instOrClass.add(instanceRB);
        instOrClass.add(classRB);
        buttonPanel=new JPanel();
        buttonPanel.setLayout(new GridLayout(1,2));
        buttonPanel.add(instanceRB);
        buttonPanel.add(classRB);
        JPanel versionPanel=new JPanel(new BorderLayout());
        versionPanel.add(cScroll,BorderLayout.CENTER);
        versionPanel.add(buttonPanel,BorderLayout.SOUTH);
        JSplitPane s1=new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,versionPanel,pScroll);
        s1.setDividerSize(4);
        s1.setDividerLocation(.50);
        s1.setResizeWeight(.50);
        JSplitPane s2=new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,s1,mScroll);
        s2.setDividerSize(4);
        s2.setDividerLocation(.50);
        s2.setResizeWeight(.66);
        JSplitPane s3=new JSplitPane(JSplitPane.VERTICAL_SPLIT,s2,sScroll);
        s3.setDividerSize(4);
        s3.setDividerLocation(.25);
        s3.setResizeWeight(.25);
        content.add(s3,BorderLayout.CENTER);
        if(mainFont!=null)updateFont(mainFont);
        updateTabSize(tabsize);
        updateWordWrap(wrap);
        FontMetrics tfont=getFontMetrics(classes.getFont());
        int fSize=(int)(tfont.getHeight()*4);
        cScroll.setPreferredSize(new Dimension(200,fSize));
        mScroll.setPreferredSize(new Dimension(200,2*fSize));
        pScroll.setPreferredSize(new Dimension(200,(int)(1.5*fSize)));
        classes.addMouseListener(this);
        protocol.addMouseListener(this);
        methods.addMouseListener(this);
        workspace.addMouseListener(this);
        instanceRB.setActionCommand("Instance");
        classRB.setActionCommand("Class");
        instanceRB.setSelected(true);
        instanceRB.addActionListener(this);
        classRB.addActionListener(this);
        classes.setSelectedIndex(0);
        initPopupMenu();
        initOtherPopups();
        classes.setNextFocusableComponent(protocol);
        classes.addFocusListener(this);
        cScroll.setNextFocusableComponent(protocol);
        protocol.setNextFocusableComponent(methods);
        pScroll.setNextFocusableComponent(methods);
        methods.setNextFocusableComponent(classes);
        mScroll.setNextFocusableComponent(classes);
        methods.addFocusListener(this);
        protocol.addFocusListener(this);
        selectedComponent=workspace;
    }
    
    protected void addCustomMenus() {
        addClassMenu();
        addProtocolMenu();
        addMethodMenu();
    }
    
    protected void addClassMenu() {
        super.addClassMenu();
        classMenu.addSeparator();
        JMenuItem tMenu=new JMenuItem("Inspect Instances");
        tMenu.setActionCommand("Inspect Instances");
        tMenu.addActionListener(this);
        classMenu.add(tMenu);
        tMenu=new JMenuItem("Migrate Instances");
        tMenu.setActionCommand("Migrate Instances");
        tMenu.addActionListener(this);
        classMenu.add(tMenu);
    }
    
 /*
  public static class TestGbjClassVersionBrowser  extends junit.extensions.jfcunit.JFCTestCase {
        public TestGbjClassVersionBrowser(java.lang.String name) {
            super(name);
        }
  
        public void testDisplay()
        {
            GbjClassVersionBrowser sample=new GbjClassVersionBrowser();
        }
  
        public static void main(String args[]){
            junit.textui.TestRunner.run(suite());
            System.exit(0);
        }
        public static junit.framework.Test suite() {
            return new junit.framework.TestSuite(com.gemstone.tools.GbjClassVersionBrowser.TestGbjClassVersionBrowser.class);
        }
    }
  */
    
    
    GbjObject classHistory() {
        /* Return the class history currently being browsed. */
        
        return classHistory;
    }
    
    GbxClassHolder [] getClassList() {
        /* Return a list of class holders for the classes in the current class history. */
        return this.classVersionHoldersFor_(classHistory);
    }
    
    void reinitialize() {
   /* Reinitialize the browser trying to maintain current selections and taking into
   account the browser type. */        
        this.resetClassListSelecting_(this.selectedClass());
    }
    
    /**
     * @param aHistory  */
    void classHistory_(GbjObject aHistory) {
        /* Set the class history currently being browsed. */
        
        classHistory = aHistory;
    }
    
    /**
     * @return  */
    String text() {
        return this.textForClassOrMethod();
    }
    
    /**
     * @return  */
    boolean canMigrateInstances() {
        /* If greater than one class in the version history then instances can be migrated. */
        
        return this.classList().length > 1;
    }
    
    void inspectInstances() {
        GbjObject array;
        GbjInspector anInspector;
        
        if (this.selectedClass() == null) {
            //warnDialog.warn("Inspect Instances", noClassString);
            JOptionPane.showMessageDialog(this,GbxConstants.noClassString,"Inspect Instances", JOptionPane.WARNING_MESSAGE);
            return;
        }
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            array = this.serverSupport().instancesOf_(this.selectedClass().proxy());
            anInspector = new GbjInspector(array, "Inspecting Instances of " + this.selectedClass().name(), this.session(), this.launcher);
            //new GFrame(anInspector, 400, 250);
            //anInspector.addToLauncher(this.launcher());
            //anInspector.initializeFrom(array, "Inspecting Instances of " + this.selectedClass().name(), this.session(), this.launcher());
        } catch (GbjException e) {
            this.processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
    }
    
    void moveClass() {
        if (this.selectedClass() == null) {
            //warnDialog.warn("Move Class", "There is no selected class");
            JOptionPane.showMessageDialog(this,"There is no selected class","Move Class", JOptionPane.WARNING_MESSAGE);
            return;
        }
        listSelected=JOptionPane.showInputDialog(this,GbxConstants.moveVersionString,"Move Class",JOptionPane.QUESTION_MESSAGE);
        //requestDialog.request("Move Class", moveVersionString, "");
        if (listSelected!=null) {
            this.finishMoveClass();
        }
    }
    
    void finishMoveClass() {
        GbjObject targetClass;
        boolean couldWriteClass;
        
        String aString = listSelected.trim();
        if (aString == null || aString.length() == 0) {
            return;
        }
        try {
            targetClass = this.serverSupport().classNamed_(aString);
        } catch (GbjException e) {
            this.processError_(e);
            targetClass = this.getSession().kernel.Nil;
        }
        if (targetClass.isNil()) {
            //warnDialog.warn("No class named " + aString);
            JOptionPane.showMessageDialog(this,"No class names "+aString);
            return;
        }
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            couldWriteClass = this.serverSupport().makeClass_aVersionOf_(this.selectedClass().proxy(), targetClass);
        } catch (GbjException e) {
            this.processError_(e);
            /* If there is an error, don't want two dialogs coming up */
            couldWriteClass = true;
        }
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        
        if (!couldWriteClass) {
            //warnDialog.warn("The target class is not writable");
            JOptionPane.showMessageDialog(this,"The target class is not writable");
            return;
        }
        this.resetClassOrganizer();
        this.classList_class_protocolList_protocol_methodList_method_(null, null, null, null, null, null);
    }
    
    void finishRemoveClass() {
        //if (!(confirmDialog.confirmed())) {
        //return;
        //}
        if (this.selectedClass().numberOfVersions() == 1) {
            //warnDialog.warn("Cannot remove the last version in the class history");
            JOptionPane.showMessageDialog(this,"Cannot remove the last version in the class history");
            return;
        }
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            this.serverSupport().removeFromClassHistory_(this.selectedNonMetaclass());
        } catch (GbjException e) {
            this.processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        this.resetClassOrganizer();
        this.classList_class_protocolList_protocol_methodList_method_(null, null, null, null, null, null);
    }
    
    /**
     * @param newText
     * @return  */
    boolean acceptText(String newText) {
        return this.acceptClassOrMethodText(newText);
    }
    
    /**
     * @param aClass  */
    void postAcceptForClass_(GbxClassHolder aClass) {
   /* A class version browser should update its class list and try to select <aClass>
   since it may be a new version. */
        
        this.resetClassListSelecting_(aClass);
    }
    
    void migrateInstances() {
        String [] versionNames;
        
        if (this.selectedClass() == null) {
            //warnDialog.warn("Migrate Instances", noClassString);
            JOptionPane.showMessageDialog(this,GbxConstants.noClassString,"Migrate Instances",JOptionPane.WARNING_MESSAGE);
            return;
        }
        versionNames = new String[classList.length];
        for (int i = 0; i < classList.length; i++) {
            versionNames[i] = classList[i].displayString();
        }
        
        GbxListDialog listDialog=new GbxListDialog("Migrate Instances", GbxConstants.migrateInstancesString, versionNames);
        listSelected=listDialog.result();
        selectedIndex=listDialog.index();
        if (listSelected!=null) {
            this.finishMigrateInstances();
        }
    }
    
    void finishMigrateInstances() {
        GbjObject fromClass, toClass;
        
        if (this.selectedClass() == null) {
            //warnDialog.warn("There is no class selected");
            JOptionPane.showMessageDialog(this,"There is no class selected");
            return;
        }
        //int selectedIndex = listDialog.selectedIndex();
        //if (selectedIndex == -1) {
        //	return;
        //}
        if(listSelected==null)return;
        fromClass = this.selectedClass().proxy();
        toClass = this.classList()[selectedIndex].proxy();
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            this.serverSupport().migrateInstancesOf_to_(fromClass, toClass);
        } catch (GbjException e) {
            this.processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
    }
    GbxClassHolder [] classVersionHoldersFor_(GbjObject anObject) {
        GbxClassHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = this.serverSupport().classVersionHoldersFor_(anObject);
        } catch (GbjException e) {
            this.processError_(e);
            holders = new GbxClassHolder[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    /**
     * @return  */
    String defaultTitle() {
        String className;
        
        if (this.selectedClass() == null) {
            className = classList[0].name();
        } else {
            className = this.selectedClass().name();
        }
        return("GBJ Class Version Browser: " + className);
    }
    
    protected void displayWindow() {
        setWindowID(launcher.getGlobalWindowID());
        setTitle(defaultTitle());
        launcher.registerWindow(this);
        launcher.addWindowMenu(this);
        super.displayWindow();
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String action=actionEvent.getActionCommand();
        if(action.equals("Inspect Instances")){
            inspectInstances();
        }else  if(action.equals("Migrate Instances")){
            migrateInstances();
        }else
            super.actionPerformed(actionEvent);
    }
    
    protected void initOtherPopups() {
        super.initOtherPopups();
        classPopup.addSeparator();
        JMenuItem tMenu=new JMenuItem("Inspect Instances");
        tMenu.setActionCommand("Inspect Instances");
        tMenu.addActionListener(this);
        classPopup.add(tMenu);
        menuBar.add(classMenu);
        tMenu=new JMenuItem("Migrate Instances");
        tMenu.setActionCommand("Migrate Instances");
        tMenu.addActionListener(this);
        classPopup.add(tMenu);
    }
    
}
