/*
 * GbjDebugger.java
 *
 * Created on May 23, 2002, 4:48 PM
 */

package com.gemstone.tools;

import com.gemstone.gbj.*;
import javax.swing.*;
import java.awt.*;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
import java.util.logging.*;

/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbjDebugger extends com.gemstone.tools.GbjMethodListBrowser {
    
    
    GbjException exception;
    GbjObject gsProcess;
    GbjInspectorPanel contextInspector;
    GbjInspectorPanel receiverInspector;
    int maxFields;
    GbxTool sourceTool;
    boolean inspectResult = false;
    boolean printResult = false;
    
    JButton stepOverButton;
    JButton stepIntoButton;
    JButton continueButton;
    JButton trimStackButton;
    JPanel buttonPanel;
    JPanel methodsPanel;
    JMenu processMenu;
    JMenu receiverMenu;
    JMenu contextMenu;
   // JPanel inspectPanel;
    JSplitPane inspectPanel;
    JSplitPane codePanel;
    
    private Logger logger;

    private CountDownLatch finishedCounter;
    
    protected    void update() {
        /* Flush and update field list (in case elements were added or removed
         from this exception elsewhere) */
        this.resetFields();
    }
    
    void method_(GbxMethodHolder aMethodHolder) {
        super.method_(aMethodHolder);
        resetInspectors();
    }
    
    void inspectContextSelection() {
        contextInspector.inspectField();
    }
    
    void inspectReceiverSelection() {
        receiverInspector.inspectField();
    }
    
    public void moreStack() {
        maxFields = maxFields * 2;
        this.resetFields();
    }
    
    public void trimStack() {
        if (this.selectedMethod() == null) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"Trim Stack",JOptionPane.ERROR_MESSAGE);
            return;
        }
        try {
            this.serverSupport().trimStackOf_toLevel_(gsProcess, methods.getSelectedIndex() + 1);
        } catch (GbjException e) {
            this.processError_(e);
        }
        this.resetFields();
        methods.setSelectedIndex(0);
        methodSelected();
    }
    
    public void stepInto() {
        try {
            this.serverSupport().stepIntoInProcess_(gsProcess);
        } catch (GbjException e) {
    /* bug 17766 workaround: some cases may be uncatchable in server, so
     * just send the process a continue message.
     */
            if (e.number == 6002)
		// 45662: add session arg
                this.serverSupport().continueProcess_(e.process, this.getSession());
            else
                this.processError_(e);
        }
        this.resetFields();
        methods.setSelectedIndex(0);
        methodSelected();
    }
    
    public void stepOver() {
        GbjObject result;
        try {
            result = this.serverSupport().stepOverInProcess_inFrame_(gsProcess, methods.getSelectedIndex() + 1);
            if (!result.equals(gsProcess)) {
                this.processResult_(result);
                this.closeWindow();
                return;
            }
        } catch (GbjException e) {
            this.processError_(e);
        }
        this.resetFields();
        methods.setSelectedIndex(0);
        methodSelected();
    }
    
    void resetText() {
        int start, stop;
        String aString;
        
        aString = this.text();
        workspace.setText(aString);
        if (this.selectedMethod() != null) {
            start = ((GbxActivationHolder) this.selectedMethod()).textPosition;
            stop = ((GbxActivationHolder) this.selectedMethod()).endPoint;
            if (stop >= start) {
                workspace.requestFocus();
                workspace.select(start - 1, stop);
            }
        } else if (aString.length() == 0) {
            workspace.setText(exception.message);
        }
    }
    
    void resetFields() {
        methodList = this.getFieldList();
        this.updateListWidget_withObjects_(methods, methodList);
        this.selectTopOfStack();
    }
    
    public void processResult_(GbjObject result) {
        GbjInspector anInspector;
        if (inspectResult) {
            anInspector = new GbjInspector(result, null, this.session(), launcher);
        } else if (printResult) {
            if (sourceTool != null)
                sourceTool.printResult(result.stringValue());
        }
    }
    
    GbxActivationHolder [] getFieldList() {
        return exception == null ? new GbxActivationHolder [0] : this.activationHoldersFor_maxLevels_(gsProcess, maxFields);
    }

    /** Creates new GbjDebugger */
    public GbjDebugger() {
    }
    
    public GbjDebugger(GbjException anException) {
        System.out.println("GBJ Debugger A  " + anException);
        this.initializeFrom(anException, false);
    }
    
    GbjDebugger(GbjException anException, GbjLauncher aLauncher, boolean print, boolean inspect) {
        this(anException, aLauncher, print, inspect, null);
    }
    
    GbjDebugger(GbjException anException, GbjLauncher aLauncher, boolean print, boolean inspect, GbxTool aTool) {
        logger=Logger.getLogger("com.gemstone.tools");
        sourceTool = aTool;
        inspectResult = inspect;
        printResult = print;
        launcher=aLauncher;
        logger.info("GBJ Debugger ");
        logger.info("" + anException);
        System.out.println("GBJ Debugger B  " + anException);
        initializeFrom(anException, true);
    }
    
    GbjDebugger(GbjException anException, GbjLauncher aLauncher) {
        logger=Logger.getLogger("com.gemstone.tools");
        logger.info("GBJ Debugger ");
        logger.info("" + anException);
        launcher=aLauncher;
        System.out.println("GBJ Debugger C " + anException);
        initializeFrom(anException, true);
    }
    
    void resetInspectors() {
        if (selectedMethod() != null) {
            receiverInspector.inspect_(selectedObject().receiver);
            contextInspector.inspect_(selectedObject().argsAndTempNames, selectedObject().argsAndTemps);
        } else {
            receiverInspector.inspect_(null);
            contextInspector.inspect_(null, null);
        }
    }
    
    GbxActivationHolder selectedObject() {
        /* Return the currently selected activation holder. */
        
        return (GbxActivationHolder) selectedMethod();
        // return null;
    }
    
    void selectTopOfStack() {
        /* Reset to the top of stack if there is any activation */
        
        if (methodList().length > 0) {
            method_(methodList()[0]);
        } else {
            resetText();
        }
    }
    
    protected void initUI() {
        workspace=new JTextArea();
        //mainFont=workspace.getFont();
        createActionTable(workspace);
        makeActionPretty();
        initMenuBar();
        initPopupMenu();
        setJMenuBar(menuBar);
        setSize(470,450);
        content=this.getContentPane();
        content.setLayout(new BorderLayout());
        addWindowListener(this);
        addComponentListener(this);
        stepOverButton=new JButton("Step Over");
        stepOverButton.addActionListener(this);
        stepOverButton.setName("Step Over JButton");
        stepOverButton.setActionCommand("Step Over");
        stepIntoButton=new JButton("Step Into");
        stepIntoButton.addActionListener(this);
        stepIntoButton.setName("Step Into JButton");
        stepIntoButton.setActionCommand("Step Into");
        continueButton=new JButton("Continue");
        continueButton.setName("Continue JButton");
        continueButton.addActionListener(this);
        continueButton.setActionCommand("Continue");
        trimStackButton=new JButton("Trim Stack");
        trimStackButton.setName("Trim Stack JButton");
        trimStackButton.setActionCommand("Trim Stack");
        trimStackButton.addActionListener(this);
        
        buttonPanel=new JPanel();
        buttonPanel.setLayout(new FlowLayout());
        buttonPanel.add(stepOverButton);
        buttonPanel.add(stepIntoButton);
        buttonPanel.add(continueButton);
        buttonPanel.add(trimStackButton);
        //methodsPanel=new JPanel();
       // methodsPanel.setLayout(new GridBagLayout());
        GridBagConstraints constraint=new GridBagConstraints();
        constraint.gridwidth=GridBagConstraints.REMAINDER;
        constraint.weighty=0;
        constraint.weightx=0;
        //methodsPanel.add(buttonPanel,constraint);
        workspace.addMouseListener(this);
        sScroll=new JScrollPane(workspace);
        symbolDictionaries=new JList();
        classes=new JList();
        protocol=new JList();
        methods=new JList();
        mScroll=new JScrollPane();
        mScroll.setViewportView(methods);
        methods.addMouseListener(this);
        methods.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        contextInspector=new GbjInspectorPanel(session,launcher);
        receiverInspector=new  GbjInspectorPanel(session,launcher);
        if(mainFont!=null)updateFont(mainFont);       
        else mainFont=workspace.getFont();
         updateTabSize(tabsize);
        updateWordWrap(wrap);
        FontMetrics tfont=getFontMetrics(workspace.getFont());
        int fSize=(int)(tfont.getHeight()*7);
        mScroll.setPreferredSize(new Dimension(400,fSize));
        sScroll.setPreferredSize(new Dimension(400,(int)(fSize*1.5)));
        constraint.weighty=1;
        constraint.weightx=1;
        constraint.fill=GridBagConstraints.BOTH;
        //methodsPanel.add(mScroll,constraint);
        
        inspectPanel=new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,receiverInspector,contextInspector);
        inspectPanel.setDividerLocation(.50);
        //inspectPanel.setOneTouchExpandable(true);
        inspectPanel.setDividerSize(4);
        inspectPanel.setResizeWeight(.50);
        //inspectPanel=new JPanel(new FlowLayout());
       // inspectPanel.add(receiverInspector);
        //inspectPanel.add(contextInspector);
        //content.add(methodsPanel,BorderLayout.NORTH);
        codePanel=new JSplitPane(JSplitPane.VERTICAL_SPLIT,mScroll,sScroll);
        codePanel.setDividerLocation(.25);
        //codePanel.setOneTouchExpandable(true);
        codePanel.setDividerSize(4);
        codePanel.setResizeWeight(.25);
        content.add(buttonPanel,BorderLayout.NORTH);
        //content.add(sScroll,BorderLayout.CENTER);
        content.add(codePanel,BorderLayout.CENTER);
        content.add(inspectPanel,BorderLayout.SOUTH);
        //if(mainFont!=null)updateFont(mainFont);
    }
    
    void initializeFrom(GbjException anException, boolean fromGui) {
        this.session_(anException.session);
        gsProcess = anException.process;
        maxFields = 100;
        if (! fromGui) {
          finishedCounter = new CountDownLatch(1);
        }
        initUI();
        this.debug(anException);
        displayWindow();
        if (! fromGui) {
          // wait for debug window to be closed
          boolean done = false;
          while (! done) {
            try {
              done = finishedCounter.await(1000, TimeUnit.MILLISECONDS);
            } catch (InterruptedException e) { }
          }
        }
    }

    public void windowClosing(java.awt.event.WindowEvent windowEvent) {
      // typically from the X (close window) button of the window title bar
      if (finishedCounter != null) {
        finishedCounter.countDown();  
      }
      super.windowClosing(windowEvent);
    }

    public void windowClosed(java.awt.event.WindowEvent windowEvent) {
      // typically from the Continue button , via   this.closeWindow ...
      if (finishedCounter != null) {
        finishedCounter.countDown();  
      }
      super.windowClosed(windowEvent);
    }
    
    void debug(GbjException anException) {
        exception = anException;
        this.resetFields();
    }
    
    GbxActivationHolder [] activationHoldersFor_maxLevels_(GbjObject aProcess, int levels) {
        GbxActivationHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = this.serverSupport().activationHoldersFor_maxLevels_(aProcess, levels);
        } catch (GbjException e) {
            holders = new GbxActivationHolder[0];
            this.processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    String defaultTitle() {
        return("GBJ Debugger on:" + this.session().getShortName());
    }
    
    public   GbjObject contextObject() {
        if (this.selectedObject() == null) {
            return null;
        } else {
            return this.selectedObject().receiver;
        }
    }
    
    public   GbjObject doitNames() {
        if (this.selectedObject() == null) {
            return null;
        } else {
            return this.selectedObject().argsAndTempNames;
        }
    }
    
    public  GbjObject doitValues() {
        if (this.selectedObject() == null) {
            return null;
        } else {
            return this.selectedObject().argsAndTemps;
        }
    }
    
    boolean compileMethod(String aString) {
        if ((this.selectedMethod() == null) || (this.selectedMethod().remoteClass() == this.getSession().kernel.Nil)) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"Compile Method",JOptionPane.ERROR_MESSAGE);
            return false;
        }
        if (super.compileMethod(aString)) {
            this.trimStack();
            return true;
        } else {
            return false;
        }
    }
    
    void browseMethod() {
        if ((this.selectedMethod() == null) || (this.selectedMethod().remoteClass() == this.getSession().kernel.Nil)) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"Browse Method",JOptionPane.ERROR_MESSAGE);
            return;
        }
        super.browseMethod();
    }
    
    void fileOutMethod() {
        if ((this.selectedMethod() == null) || (this.selectedMethod().remoteClass() == this.getSession().kernel.Nil)) {
            JOptionPane.showMessageDialog(this,GbxConstants.noMethodString,"File Out Method",JOptionPane.ERROR_MESSAGE);
            return;
        }
        super.fileOutMethod();
    }
    
    public void continueProcess() {
        GbjObject result;
        this.closeWindow();
        try {
	    // 45662: add session arg
            result = this.serverSupport().continueProcess_(gsProcess, this.getSession());
            if (result.equals(gsProcess)) {
                exception.setMessage("Method Breakpoint Encountered");
                if (sourceTool == null) {
                    launcher.processGbjException(exception, false, inspectResult);
                } else {
                    sourceTool.processGbjException(exception, printResult, inspectResult);
                }
            } else {
                this.processResult_(result);
            }
        } catch (GbjException e) {
            if (sourceTool == null) {
                launcher.processGbjException(e, false, inspectResult);
            } else {
                sourceTool.processGbjException(e, printResult, inspectResult);
            }
        }
    }
    
    public void explainExcept() {
        methods.clearSelection();
        this.method_(null);
        
    }
    
    protected void displayWindow() {
        if(launcher !=null){
            setWindowID(launcher.getGlobalWindowID());
            setTitle(defaultTitle());
            launcher.registerWindow(this);
            launcher.addWindowMenu(this);
        }else{
            setTitle(defaultTitle());
        }
        update();
        pack();
        Dimension windowSize=getSize();
        Dimension screen=java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        int x=(screen.width-windowSize.width)/2;
        int y=(screen.height-windowSize.height)/2;
        setLocation(x,y);
        setVisible(true);
        methods.setSelectedIndex(0);
        methodSelected();
    }
    
    public void componentResized(java.awt.event.ComponentEvent componentEvent) {
        super.componentResized(componentEvent);
        int x=(getWidth()-15);
        int y=(getHeight()-35);
        FontMetrics tfont=getFontMetrics(workspace.getFont());
        int fSize=(int)(tfont.getHeight()*5);
        contextInspector.resizePanel(x/2-3,fSize);
        contextInspector.invalidate();
        receiverInspector.resizePanel(x/2-3,fSize);
        receiverInspector.invalidate();
        inspectPanel.invalidate();
        validate();
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String action=actionEvent.getActionCommand();
        if(action.equals("Step Over")){
            stepOver();
        }
        else if(action.equals("Step Into")){
            stepInto();
        }
        else if(action.equals("Continue")){
            continueProcess();
        }
        else if(action.equals("Trim Stack")){
            trimStack();
        }
        else   if(action.equals("Explain")){
            explainExcept();
        } else if(action.equals("Inspect Context")){
            inspectContextSelection();
        }else if(action.equals("Inspect Receiver")){
            inspectReceiverSelection();
        }
        
        else  if(action.equals("Copy Stack")){
            copyStack();
        }
        else
            super.actionPerformed(actionEvent);
    }
    
    protected void addMethodMenu() {
        JMenuItem tMenu=new JMenuItem("File Out As");
        tMenu.addActionListener(this);
        tMenu.setActionCommand("File Out As Method");
        methodMenu.add(tMenu);
        methodMenu.addSeparator();
        tMenu=new JMenuItem("Browse Method");
        tMenu.setActionCommand("Browse Method");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
        tMenu=new JMenuItem("Senders");
        tMenu.setActionCommand("Senders");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
        tMenu=new JMenuItem("Implementors");
        tMenu.setActionCommand("Implementors");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
        tMenu=new JMenuItem("Messages");
        tMenu.setActionCommand("Messages");
        tMenu.addActionListener(this);
        methodMenu.add(tMenu);
    }
    
    protected void addCustomMenus() {
        methodMenu= new JMenu("Method");
        methodMenu.setName("Method Menu");
        menuBar.add(methodMenu);
        addMethodMenu();
        processMenu=new JMenu("Process");
        menuBar.add(processMenu);
        JMenuItem item=new JMenuItem("Step Over");
        item.addActionListener(this);
        item.setActionCommand("Step Over");
        processMenu.add(item);
        item=new JMenuItem("Step Into");
        item.addActionListener(this);
        item.setActionCommand("Step Into");
        processMenu.add(item);
        processMenu.addSeparator();
        item=new JMenuItem("Explain");
        item.addActionListener(this);
        item.setActionCommand("Explain");
        processMenu.add(item);
        item=new JMenuItem("Continue");
        item.addActionListener(this);
        item.setActionCommand("Continue");
        processMenu.add(item);
        item=new JMenuItem("Trim Stack");
        item.addActionListener(this);
        item.setActionCommand("Trim Stack");
        processMenu.add(item);
        processMenu.addSeparator();
        item=new JMenuItem("Copy Stack");
        item.addActionListener(this);
        item.setActionCommand("Copy Stack");
        processMenu.add(item);
        receiverMenu=new JMenu("Receiver");
        menuBar.add(receiverMenu);
        item=new JMenuItem("Inspect");
        item.addActionListener(this);
        item.setActionCommand("Inspect Receiver");
        receiverMenu.add(item);
        contextMenu=new JMenu("Context");
        menuBar.add(contextMenu);
        item=new JMenuItem("Inspect");
        item.addActionListener(this);
        item.setActionCommand("Inspect Context");
        contextMenu.add(item);
    }
    
    public void updateFont(Font font) {
        super.updateFont(font);
        contextInspector.updateFont(font);
        receiverInspector.updateFont(font);
    }
    
    protected void copyStack() {
        String stack="";
        for(int x=0;x<methods.getModel().getSize();x++){
            stack=stack+(String)(methods.getModel().getElementAt(x))+"\n";
        }
        //quick and dirty hack but works
        JTextArea tt=new JTextArea();
        tt.append(stack);
        tt.selectAll();
        tt.copy();
    }
  
}  
