/*
 * GbjInspector.java
 *
 * Created on May 23, 2002, 4:50 PM
 */

package com.gemstone.tools;

import com.gemstone.gbj.*;
import java.awt.Font;
import javax.swing.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.BorderLayout;
import java.awt.Insets;
import java.awt.Cursor;
/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbjInspector extends com.gemstone.tools.GbxTool {
    
    GbjObject object;
    GbjObject argNames;
    GbjObject args;
    GbxObjectHolder [] fieldList;
    JList fields;
    int maxFields;
    JScrollPane wScroll;
    JScrollPane lScroll;
    JMenu variablesMenu;
    JPopupMenu listPopup;
    /** Creates new GbjInspector 
	@param anObject Object being inspected
	@param aLabel  Label for window
	@param aSession GbjSession
	@param aLauncher GbjLauncher
     */
    public GbjInspector(GbjObject anObject, String aLabel, GbjSession aSession, GbjLauncher aLauncher) {
        String title;
        launcher=aLauncher;
        session_(aSession);
        maxFields = 100;
        launcher.registerWindow(this);
        initUI();
        inspect_(anObject);
        if(aLabel==null)
            title=selfHolder().className;
        else
            title=aLabel;
        setWindowID(launcher.getGlobalWindowID());
        setTitle("GBJ Inspector:"+title);
        displayWindow();
        launcher.addWindowMenu(this);
    }
    
    public GbjObject contextObject() {
        return object;
    }
    
    void inspect_(GbjObject anObject) {
        object = anObject;
        this.resetFields();
    }
    
    void inspect_(GbjObject names, GbjObject values) {
        argNames = names;
        args = values;
        this.resetArgFields();
        this.resetText();
    }
    
    GbxObjectHolder [] objectHoldersForNames_values_(GbjObject names, GbjObject values) {
        GbxObjectHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = serverSupport().objectHoldersForNames_values_(names, values);
        } catch (GbjException e) {
            processError_(e);
            holders = new GbxObjectHolder[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    GbxObjectHolder [] objectHoldersFor_maxObjects_(GbjObject anObject, int max) {
        GbxObjectHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = serverSupport().objectHoldersFor_maxObjects_(anObject, max);
        } catch (GbjException e) {
            processError_(e);
            holders = new GbxObjectHolder[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    void inspectField() {
        GbjInspector anInspector;
        
        if (selectedObject() != null) {
            anInspector = new GbjInspector(selectedObject().proxy(), null, session, launcher);
        }
    }
    
    void listAction() {
        changedSelectedField();
        if (selectedObject() != null) {
            inspectField();
        }
    }
    
    void changedSelectedField() {
        resetText();
    }
    
    GbxObjectHolder selectedObject() {
        /* Return the currently selected object holder. */
        
        int index;
        
        if (fields == null) {
            return null;
        }
        index = fields.getSelectedIndex();
        return index < 0
        ? null
        : fieldList[index];
    }
    
    protected void initEditMenuAdvanced() {
        JMenuItem tmenuitem=new JMenuItem("Do-It");
        tmenuitem.setActionCommand("Do-It");
        tmenuitem.setName("Do-It JMenuItem");
        tmenuitem.addActionListener(this);
        editMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Print-It");
        tmenuitem.setActionCommand("Print-It");
        tmenuitem.setName("Print-It JMenuItem");
        tmenuitem.addActionListener(this);
        editMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Inspect-It");
        tmenuitem.setActionCommand("Inspect-It");
        tmenuitem.setName("Inspect-It JMenuItem");
        tmenuitem.addActionListener(this);
        editMenu.add(tmenuitem);
        editMenu.addSeparator();
        tmenuitem=new JMenuItem("Compile");
        tmenuitem.setActionCommand("Compile");
        tmenuitem.setName("Compile JMenuItem");
        tmenuitem.addActionListener(this);
        editMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Cancel");
        tmenuitem.setActionCommand("Cancel");
        tmenuitem.setName("Cancel JMenuItem");
        tmenuitem.addActionListener(this);
        editMenu.add(tmenuitem);
    }
    
    protected void initPopupMenu() {
        super.initPopupMenu();
        listPopup=new JPopupMenu();
        JMenuItem tmenuitem=new JMenuItem("Inspect");
        tmenuitem.setActionCommand("Inspect");
        tmenuitem.setName("Inspect JMenuItem");
        tmenuitem.addActionListener(this);
        listPopup.add(tmenuitem);
        tmenuitem=new JMenuItem("More");
        tmenuitem.setActionCommand("More");
        tmenuitem.setName("More JMenuItem");
        tmenuitem.addActionListener(this);
        listPopup.add(tmenuitem);
    }
    
    protected void initCustomMenus() {
        variablesMenu=new JMenu("Variables");
        JMenuItem tmenuitem=new JMenuItem("Inspect");
        tmenuitem.setActionCommand("Inspect");
        tmenuitem.setName("Inspect JMenuItem");
        tmenuitem.addActionListener(this);
        variablesMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("More");
        tmenuitem.setActionCommand("More");
        tmenuitem.setName("More JMenuItem");
        tmenuitem.addActionListener(this);
        variablesMenu.add(tmenuitem);
    }
    
    public void updateFont(Font font) {
        fields.setFont(font);
        workspace.setFont(font);
    }
    
    protected void initFileMenu() {
        JMenuItem tmenuitem=new JMenuItem("Update");
        tmenuitem.setActionCommand("Update");
        tmenuitem.setName("Update JMenuItem");
        tmenuitem.addActionListener(this);
        fileMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Close");
        tmenuitem.setActionCommand("Close");
        tmenuitem.setName("Close JMenuItem");
        tmenuitem.addActionListener(this);
        fileMenu.add(tmenuitem);
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String acommand=actionEvent.getActionCommand();
        if(acommand.equals("Close")){
            setVisible(false);
            launcher.deregisterWindow(this);
            dispose();
        }else if(acommand.equals("Update")){
            update();
        }else if(acommand.equals("Inspect")){
            inspectField();
        }else if(acommand.equals("More")){
            moreFields();
        }else  if(acommand.equals("Compile")){
            acceptText();
        }else  if(acommand.equals("Cancel")){
            resetText();
        }else if(acommand.equals("Do-It")){
            doIt();
        }else if(acommand.equals("Print-It")){
            printIt();
        }else if(acommand.equals("Inspect-It")){
            inspectIt();
        }else
            super.actionPerformed(actionEvent);
    }
    
    protected void initUI() {
        workspace=new JTextArea();
        createActionTable(workspace);
        makeActionPretty();
        super.initUI();
        fields=new JList();
        fields.addListSelectionListener(this);
        fields.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        wScroll=new JScrollPane(workspace);
        lScroll=new JScrollPane(fields);
        content.setLayout(new BorderLayout());
        JSplitPane split=new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,lScroll,wScroll);
        split.setDividerLocation(.25);
        split.setResizeWeight(.25);
        //split.setOneTouchExpandable(true);
        split.setDividerSize(4);
        content.add(split,BorderLayout.CENTER);
        //content.setLayout(new GridBagLayout());
        //GridBagConstraints constraint=new GridBagConstraints();
        //constraint.fill=GridBagConstraints.BOTH;
        //constraint.weightx=1;
        //constraint.weighty=1;
        //constraint.gridwidth=GridBagConstraints.RELATIVE;
        //constraint.insets=new Insets(0,0,0,2);
        //content.add(lScroll,constraint);
        //constraint=new GridBagConstraints();
        //constraint.fill=GridBagConstraints.BOTH;
        //constraint.weightx=2;
        //constraint.weighty=1;
        //constraint.gridwidth=GridBagConstraints.REMAINDER;
        //content.add(wScroll,constraint);
        fields.addMouseListener(this);
        workspace.addMouseListener(this);
        selectedComponent=workspace;
        if(mainFont!=null)updateFont(mainFont);
    }
    
    void resetText() {
        workspace.setText(this.text());
        workspace.setCaretPosition(0);
    }
    
    String text() {
        /* Returns text pane text for the currently selected field item */
        return (this.selectedObject() == null)
        ? new String()
        : this.textForSelectedObject();
    }
    
    String textForSelectedObject() {
        try {
            String value=this.serverSupport().printStringFor_(this.selectedObject().proxy());
            if((selfHolder().className).equals("String") && !(((String)fields.getSelectedValue()).equals("self"))) {
                try{
                    String value2="$"+(char)Integer.parseInt(value);
                    value=value2;
                }catch(NumberFormatException e) {
                    return value;
                }
            }
            return value;
        } catch (GbjException e) {
            this.processError_(e);
            return new String();
        }
    }
    
    void acceptText() {
        GbxObjectHolder aHolder = this.selectedObject();
        GbjObject aProxy;
        int slot;
        if (aHolder == null) {
            JOptionPane.showMessageDialog(this,"There is no selected variable");
            return;
        }
        if (aHolder == selfHolder()) {
            JOptionPane.showMessageDialog(this,"Cannot make changes to self");
            return;
        }
        workspace.selectAll();
        aProxy = this.doIt();
        if (aProxy != null) {
            slot = aHolder.namedSlot == -1 ? aHolder.indexableSlot : aHolder.namedSlot;
            try {
                this.serverSupport().storeObject_intoObject_atIndex_atKey_isNamedSlot_(aProxy, selfHolder().proxy(), slot, aHolder.slotObject, aHolder.isNamedSlot);
                aHolder.proxy_(aProxy);
                this.resetText();
            } catch (GbjException e) {
                this.processError_(e);
            }
        }
    }
    
    void update() {
        resetFields();
    }
    
    void resetFields() {
        fieldList = getFieldList();
        updateListWidget_withObjects_(fields, fieldList);
        if (!haveEntireObject()) {
            workspace.setText(
	      Integer.valueOf(selfHolder().fetchedSize).toString() +  
	      " of " + 
	      Integer.valueOf(selfHolder().remoteSize).toString() + 
	      " variable fields are visible.\n" +
	      "Use Variables>>More to retrieve more.");
            workspace.setCaretPosition(0);
        } else {
            workspace.setText("");
        }
    }
    
    boolean haveEntireObject() {
        GbxObjectHolder selfHolder = this.selfHolder();
        if (selfHolder == null) {
            return true;
        } else {
            return selfHolder.fetchedSize == selfHolder.remoteSize;
        }
    }
    
    GbxObjectHolder selfHolder() {
        return fieldList.length == 0 ? null : fieldList[0];
    }
    
    void resetArgFields() {
        fieldList = this.getArgList();
        this.updateListWidget_withObjects_(fields, fieldList);
    }
    
    GbxObjectHolder [] getFieldList() {
        return object == null ? new GbxObjectHolder[0] : this.objectHoldersFor_maxObjects_(object, maxFields);
    }
    
    GbxObjectHolder [] getArgList() {
        return args == null ? new GbxObjectHolder[0] : this.objectHoldersForNames_values_(argNames, args);
    }
    
    protected void initHelpMenu() {
        //not needed but must implement empty method
    }
    
    public void mousePressed(java.awt.event.MouseEvent mouseEvent) {
        super.mousePressed(mouseEvent);
    }
    
    public void mouseClicked(java.awt.event.MouseEvent mouseEvent) {
        if(mouseEvent.getClickCount()==1)
            changedSelectedField();
        if(mouseEvent.getClickCount()==2)
            inspectField();
    }
    
    void moreFields() {
        /* Double the number of indexable elements to show in field list */
        if (this.haveEntireObject()) {
            JOptionPane.showMessageDialog(this,"No more elements to get.","More",JOptionPane.WARNING_MESSAGE);
        } else {
            maxFields = maxFields * 2 ;
            this.resetFields();
        }
    }
    
    protected void initSessionMenu() {
        JMenuItem tmenuitem=new JMenuItem("Commit");
        tmenuitem.setActionCommand("Commit");
        tmenuitem.setName("Commit JMenuItem");
        tmenuitem.addActionListener(this);
        sessionMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Abort");
        tmenuitem.setActionCommand("Abort");
        tmenuitem.setName("Abort JMenuItem");
        tmenuitem.addActionListener(this);
        sessionMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Begin");
        tmenuitem.setActionCommand("Begin");
        tmenuitem.setName("Begin JMenuItem");
        tmenuitem.addActionListener(this);
        sessionMenu.add(tmenuitem);
    }
    
    protected void checkPopup(java.awt.event.MouseEvent e) {
        if (e.isPopupTrigger()) {
            if(fields==e.getComponent()){
                listPopup.show(e.getComponent(),e.getX(),e.getY());
            }else if(workspace==e.getComponent()){
                stdPopUp.show(e.getComponent(),e.getX(),e.getY());
            }
        }
    }
    
    protected void addCustomMenus() {
        super.addCustomMenus();
        menuBar.add(variablesMenu);
    }
    
    public void keyReleased(java.awt.event.KeyEvent keyEvent) {
    }
    
    public void keyTyped(java.awt.event.KeyEvent keyEvent) {
    }
    
    public void valueChanged(javax.swing.event.ListSelectionEvent listSelectionEvent) {
        changedSelectedField();
    }
    
}
