/*
 * GbjInspectorPanel.java
 *
 * Created on August 10, 2002, 1:04 PM
 */

package com.gemstone.tools;


import com.gemstone.gbj.*;
import java.awt.Font;
import javax.swing.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.BorderLayout;
import java.awt.Insets;
import java.awt.Cursor;
import java.awt.FontMetrics;
/**
 *
 * @author  vincef
 */
public class GbjInspectorPanel extends com.gemstone.tools.GbxToolPanel implements javax.swing.event.ListSelectionListener{
    
    
    GbjObject object;
    GbjObject argNames;
    GbjObject args;
    GbxObjectHolder [] fieldList;
    JList fields;
    int maxFields;
    JScrollPane wScroll;
    JScrollPane lScroll;
    JMenu variablesMenu;
    JPopupMenu listPopup;
    /** Creates a new instance of GbjInspectorPanel */
    public GbjInspectorPanel() {
        maxFields = 100;
        initUI();
    }
    
    public GbjInspectorPanel(GbjObject anObject, String aLabel, GbjSession aSession, GbjLauncher aLauncher) {
        launcher=aLauncher;
        session_(aSession);
        maxFields = 100;
        initUI();
        inspect_(anObject);
    }
    
    public GbjInspectorPanel(GbjSession aSession, GbjLauncher aLauncher) {
        launcher=aLauncher;
        session_(aSession);
        maxFields = 100;
        initUI();
    }
    
    public void mouseClicked(java.awt.event.MouseEvent mouseEvent) {
        if(mouseEvent.getClickCount()==1)
            changedSelectedField();
        if(mouseEvent.getClickCount()==2)
            inspectField();
    }
    
    void moreFields() {
        /* Double the number of indexable elements to show in field list */
        if (this.haveEntireObject()) {
            JOptionPane.showMessageDialog(this,"No more elements to get.","More",JOptionPane.WARNING_MESSAGE);
        } else {
            maxFields = maxFields * 2 ;
            this.resetFields();
        }
    }
    
    void update() {
        resetFields();
    }
    
    void resetFields() {
        fieldList = getFieldList();
        updateListWidget_withObjects_(fields, fieldList);
        if (!haveEntireObject()) {
            workspace.setText(
	      Integer.valueOf(selfHolder().fetchedSize).toString() +  
	      " of " + 
	      Integer.valueOf(selfHolder().remoteSize).toString() + 
	      " variable fields are visible.\n" +
	      "Use Variables>>More to retrieve more.");
        } else {
            workspace.setText("");
        }
    }
    
    boolean haveEntireObject() {
        GbxObjectHolder selfHolder = this.selfHolder();
        if (selfHolder == null) {
            return true;
        } else {
            return selfHolder.fetchedSize == selfHolder.remoteSize;
        }
    }
    
    GbxObjectHolder selfHolder() {
        return fieldList.length == 0 ? null : fieldList[0];
    }
    
    void resetArgFields() {
        fieldList = this.getArgList();
        this.updateListWidget_withObjects_(fields, fieldList);
    }
    
    GbxObjectHolder [] getFieldList() {
        return object == null ? new GbxObjectHolder[0] : this.objectHoldersFor_maxObjects_(object, maxFields);
    }
    
    GbxObjectHolder [] getArgList() {
        return args == null ? new GbxObjectHolder[0] : this.objectHoldersForNames_values_(argNames, args);
    }
    
    void resetText() {
        workspace.setText(this.text());
        workspace.setCaretPosition(0);
    }
    
    String text() {
        /* Returns text pane text for the currently selected field item */
        return (this.selectedObject() == null)
        ? new String()
        : this.textForSelectedObject();
    }
    
    String textForSelectedObject() {
        try {
            String value=this.serverSupport().printStringFor_(this.selectedObject().proxy());
            if((selfHolder().className).equals("String") && !(((String)fields.getSelectedValue()).equals("self"))) {
                try{
                    String value2="$"+(char)Integer.parseInt(value);
                    value=value2;
                }catch(NumberFormatException e) {
                    return value;
                }
            }
            return value;
        } catch (GbjException e) {
            this.processError_(e);
            return new String();
        }
    }
    
    void acceptText() {
        GbxObjectHolder aHolder = this.selectedObject();
        GbjObject aProxy;
        int slot;
        if (aHolder == null) {
            JOptionPane.showMessageDialog(this,"There is no selected variable");
            return;
        }
        if (aHolder == selfHolder()) {
            JOptionPane.showMessageDialog(this,"Cannot make changes to self");
            return;
        }
        workspace.selectAll();
        aProxy = this.doIt();
        if (aProxy != null) {
            slot = aHolder.namedSlot == -1 ? aHolder.indexableSlot : aHolder.namedSlot;
            try {
                this.serverSupport().storeObject_intoObject_atIndex_atKey_isNamedSlot_(aProxy, selfHolder().proxy(), slot, aHolder.slotObject, aHolder.isNamedSlot);
                aHolder.proxy_(aProxy);
                this.resetText();
            } catch (GbjException e) {
                this.processError_(e);
            }
        }
    }
    
    void inspect_(GbjObject anObject) {
        object = anObject;
        this.resetFields();
    }
    
    void inspect_(GbjObject names, GbjObject values) {
        argNames = names;
        args = values;
        this.resetArgFields();
        this.resetText();
    }
    
    GbxObjectHolder [] objectHoldersForNames_values_(GbjObject names, GbjObject values) {
        GbxObjectHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = serverSupport().objectHoldersForNames_values_(names, values);
        } catch (GbjException e) {
            processError_(e);
            holders = new GbxObjectHolder[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    GbxObjectHolder [] objectHoldersFor_maxObjects_(GbjObject anObject, int max) {
        GbxObjectHolder [] holders;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            holders = serverSupport().objectHoldersFor_maxObjects_(anObject, max);
        } catch (GbjException e) {
            processError_(e);
            holders = new GbxObjectHolder[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        return holders;
    }
    
    void inspectField() {
        GbjInspector anInspector;
        
        if (selectedObject() != null) {
            anInspector = new GbjInspector(selectedObject().proxy(), null, session, launcher);
        }
    }
    
    void listAction() {
        changedSelectedField();
        if (selectedObject() != null) {
            inspectField();
        }
    }
    
    void changedSelectedField() {
        resetText();
    }
    
    GbxObjectHolder selectedObject() {
        /* Return the currently selected object holder. */
        
        int index;
        
        if (fields == null) {
            return null;
        }
        index = fields.getSelectedIndex();
        return index < 0
        ? null
        : fieldList[index];
    }
    
    protected void initUI() {
        workspace=new JTextArea();
        createActionTable(workspace);
        makeActionPretty();
        super.initUI();
        fields=new JList();
        fields.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        fields.addListSelectionListener(this);
        wScroll=new JScrollPane(workspace);
        lScroll=new JScrollPane(fields);
        setLayout(new BorderLayout());
        JSplitPane split=new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,lScroll,wScroll);
        split.setDividerLocation(.5);
       split.setResizeWeight(.5);
       //split.setOneTouchExpandable(true);
       split.setDividerSize(4);
       add(split,BorderLayout.CENTER);
        //setLayout(new GridBagLayout());
        //GridBagConstraints constraint=new GridBagConstraints();
       //constraint.fill=GridBagConstraints.BOTH;
       //constraint.weightx=1;
        //constraint.weighty=1;
        //constraint.gridwidth=GridBagConstraints.RELATIVE;
       //constraint.insets=new Insets(0,0,0,2);
        //add(lScroll,constraint);
        //constraint=new GridBagConstraints();
       //constraint.fill=GridBagConstraints.BOTH;
       //constraint.weightx=2;
        //constraint.weighty=1;
        //constraint.gridwidth=GridBagConstraints.REMAINDER;
       // add(wScroll,constraint);
        fields.addMouseListener(this);
        workspace.addMouseListener(this);
        selectedComponent=workspace;
        FontMetrics tfont=getFontMetrics(fields.getFont());
        int fSize=(int)(tfont.getHeight()*4);
        wScroll.setPreferredSize(new java.awt.Dimension(100,fSize));
        lScroll.setPreferredSize(new java.awt.Dimension(100,fSize));
    }
    
    public void resizePanel(int width,int height) {
        FontMetrics tfont=getFontMetrics(fields.getFont());
        int fSize=(int)(tfont.getHeight()*5);
        wScroll.setPreferredSize(new java.awt.Dimension(width/2-3,fSize));
        lScroll.setPreferredSize(new java.awt.Dimension(width/2-3,fSize));
    }
    
    protected void initPopupMenu() {
        super.initPopupMenu();
        listPopup=new JPopupMenu();
        JMenuItem tmenuitem=new JMenuItem("Inspect");
        tmenuitem.setActionCommand("Inspect");
        tmenuitem.setName("Inspect JMenuItem");
        tmenuitem.addActionListener(this);
        listPopup.add(tmenuitem);
        tmenuitem=new JMenuItem("More");
        tmenuitem.setActionCommand("More");
        tmenuitem.setName("More JMenuItem");
        tmenuitem.addActionListener(this);
        listPopup.add(tmenuitem);
    }
    
    protected void checkPopup(java.awt.event.MouseEvent e) {
        if (e.isPopupTrigger()) {
            if(fields==e.getComponent()){
                listPopup.show(e.getComponent(),e.getX(),e.getY());
            }else if(workspace==e.getComponent()){
                stdPopUp.show(e.getComponent(),e.getX(),e.getY());
            }
        }
    }
    
    public void updateFont(Font font) {
        fields.setFont(font);
        workspace.setFont(font);
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String acommand=actionEvent.getActionCommand();
        if(acommand.equals("Inspect")){
            inspectField();
        }else if(acommand.equals("More")){
            moreFields();
        }else  if(acommand.equals("Compile")){
            acceptText();
        }else  if(acommand.equals("Cancel")){
            resetText();
        }else if(acommand.equals("Do-It")){
            doIt();
        }else if(acommand.equals("Print-It")){
            printIt();
        }else if(acommand.equals("Inspect-It")){
            inspectIt();
        }else
            super.actionPerformed(actionEvent);
    }
    
    public void valueChanged(javax.swing.event.ListSelectionEvent listSelectionEvent) {
        changedSelectedField();
    }
    
}
