/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 * Name: GbjLauncher.java
 *
 * Main top-level graphic tool 
 *
 *========================================================================
 */

package com.gemstone.tools;

import java.util.Vector;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import com.gemstone.gbj.*;
import java.util.Iterator;
import java.util.ListIterator;
// GBJ30: replace with java logging
//import com.gemstone.org.apache.log4j.*;
import java.util.logging.*;
import java.io.File;
import com.incors.plaf.kunststoff.KunststoffLookAndFeel;
import com.incors.plaf.kunststoff.*;
/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbjLauncher extends GbxTool {
    
    Vector openWindows;
    JPanel buttonPanel;
    JPanel centerPanel;
    GbxImagePanel sparkle;
    JButton loginButton;
    JButton browserButton;
    JButton workspaceButton;
    JButton sendersButton;
    JButton implementorsButton;
    JMenu toolsMenu;
    JMenu windowsMenu;
    JScrollPane transcriptScrollPanel;
    boolean clientVerbose;
    boolean serverVerbose;
    boolean autologin=false;
    boolean savePrefs=false;
    boolean savePassword=false;
    GbjParameters loginParameters;
    int windows_opened;
    Vector deadList;
    GbjSplashScreen splash;
    java.util.Properties prop;
    /** Creates new GbjLauncherS */
    
    public GbjLauncher() {
        super();
        splash=GbjSplashScreen.getInstance();
        splash.addActionMessage("GemBuilder\u00AE for Java");
        logger.info("GemBuilder\u00AE for Java");
        splash.addActionMessage("Copyright \u00A9 GemTalk Systems 1986-2024");
        splash.addActionMessage("Operating system: "+System.getProperty("os.name"));
        logger.info("Operating system: "+System.getProperty("os.name"));
        splash.addActionMessage("Operating system version: "+System.getProperty("os.version"));
        logger.info("Operating system version: "+System.getProperty("os.version"));
        splash.addActionMessage("System architecture: "+System.getProperty("os.arch"));
        logger.info("System architecture: "+System.getProperty("os.arch"));
        splash.addActionMessage("Java home: "+System.getProperty("java.home"));
        logger.info("Java home: "+System.getProperty("java.home"));
        splash.addActionMessage("Java version: "+System.getProperty("java.version"));
        logger.info("Java version: "+System.getProperty("java.version"));
        splash.addActionMessage("Java classpath: "+System.getProperty("java.class.path"));
        logger.info("Java classpath: "+System.getProperty("java.class.path"));
        splash.addActionMessage("User name: "+System.getProperty("user.name"));
        logger.info("User name: "+System.getProperty("user.name"));
        splash.addActionMessage("User home: "+System.getProperty("user.home"));
        logger.info("User home: "+System.getProperty("user.home"));
        splash.addActionMessage("Current working directory: "+System.getProperty("user.dir"));
        logger.info("Current working directory: "+System.getProperty("user.dir"));
        splash.addActionMessage("Beginning GBJ initialization");
        logger.info("Beginning GBJ initialization");
        splash.addActionMessage("Loading Fonts");
        logger.info("Loading Fonts");
        // loads system fonts into VM
        GraphicsEnvironment.getLocalGraphicsEnvironment().getAllFonts();
        launcher=this;
        loadPreferences();
        initUI();
    }
    
    //public String windowTitle( String windowType) {
     //   return (windowType+" "+(windows_opened++));
    //}
    
    public synchronized int getGlobalWindowID(){
        return (windows_opened++);
    }
    
    
    public GbjLauncher(GbjSession aSession){
        this();
        session=aSession;
        logger.info("GBJ launched  with session: "+session.toString());
	if (session.isLoggedIn( )) {  // fix 46531
	  session.mapGsToJavaClass("GbjToolsInterface", new GbxToolsSupportImpl(session));
	}
        enableUI();
    }
    
    protected void initUI() {
        workspace=new JTextArea();
        if(mainFont==null)
        mainFont=workspace.getFont();
        else updateFont(mainFont);
        createActionTable(workspace);
        makeActionPretty();
        super.initUI();
        windows_opened=0;
        openWindows=new Vector();
        deadList=new Vector();
        setTitle("GBJ Launcher");
        setName("GBJ Launcher Window");
        this.addWindowListener(this);
        buttonPanel=new JPanel();
        buttonPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc=new GridBagConstraints();
        gbc.insets=new Insets(5,5,5,5);
        gbc.fill=GridBagConstraints.HORIZONTAL;
        loginButton=new JButton("Login");
        loginButton.setActionCommand("Login");
        loginButton.addActionListener(this);
        loginButton.setName("Login Button");
        browserButton=new JButton("Browser");
        browserButton.setName("Browser Button");
        browserButton.addActionListener(this);
        browserButton.setActionCommand("Browser");
        workspaceButton=new JButton("Workspace");
        workspaceButton.setName("Workspace Button");
        workspaceButton.addActionListener(this);
        workspaceButton.setActionCommand("Workspace");
        sendersButton=new JButton("Senders...");
        sendersButton.addActionListener(this);
        sendersButton.setName("Senders Button");
        sendersButton.setActionCommand("Senders");
        implementorsButton=new JButton("Implementors");
        implementorsButton.addActionListener(this);
        implementorsButton.setName("Implementors Button");
        implementorsButton.setActionCommand("Implementors");
        buttonPanel.add( loginButton ,gbc);
        buttonPanel.add( workspaceButton,gbc );
        buttonPanel.add( browserButton,gbc );
        buttonPanel.add( sendersButton,gbc );
        buttonPanel.add( implementorsButton ,gbc);
        centerPanel=new JPanel();
        centerPanel.setLayout(new BorderLayout());
        centerPanel.add(buttonPanel,BorderLayout.NORTH);
        centerPanel.setBorder(new EmptyBorder(0,5,0,5));
        transcriptScrollPanel=new JScrollPane();
        transcriptScrollPanel.setPreferredSize(new Dimension(140,100));
        transcriptScrollPanel.setViewportView(workspace);
        centerPanel.add(transcriptScrollPanel,BorderLayout.CENTER);
        sparkle=new GbxImagePanel();
        sparkle.setPreferredSize(new Dimension(100,50));
        sparkle.bytes(GbxGifs.logoBytes);
        content.add(sparkle,BorderLayout.NORTH);
        content.add(centerPanel,BorderLayout.CENTER);
        workspace.addMouseListener(this);
        statusPanel=new JPanel();
        statusMessage=new JLabel(GbxConstants.NOT_CONNECTED);
        statusPanel.add(statusMessage);
        content.add(statusPanel,BorderLayout.SOUTH);
        statusPanel.setPreferredSize(new Dimension(150,25));
        selectedComponent=workspace;
        disableUI();
        splash.initDone();
        try{
            while(!splash.done())Thread.sleep(500);;
            Thread.sleep(5000); //for visual effect
        }catch(Exception e){}
        splash=null;
	// 40614: reverse order of displayWindow and updateApplication
	// to insure UI event dispatch thread is not running to produce
	// race conditions against the updateComponentTreeUI calls in 
	// updateApplication
        this.updateApplication();
        displayWindow();
        autoLogin();
        if(loginParameters.transactionMode==GbjParameters.AUTOMATIC_TRANSACTIONS){
            this.autoMenuItem.setSelected(true);
        }else manualMenuItem.setSelected(true);
    }
    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        if (args.length>0){
            processArguments(args);
        }else
            new GbjLauncher();
    }
    
    public void windowClosing(java.awt.event.WindowEvent windowEvent) {
        super.windowClosing(windowEvent);
        this.exitApplication();
        logger.info("Exiting GBJ");
        System.exit(0);
    }
    
    
    protected void openWorkspace() {
        GbjWorkSpace workspace;
        workspace = new GbjWorkSpace(session,this);
        workspace.setWindowID(getGlobalWindowID());
        workspace.setTitle("GBJ Workspace."+workspace.getWindowID());
        addWindowMenu(workspace);
    }
    
    protected void login() {
        if(session==null) {
            GbjLoginDialog logindialog=new GbjLoginDialog(loginParameters);
            if(logindialog.getDialogResult())
                finishLogin();
        }else {
            JOptionPane.showMessageDialog(this,"No Session created, session already exists.","Login Error",JOptionPane.ERROR_MESSAGE);
            logger.warning("Login Error - No Session created, session already exists.");
        }
        
    }
    
    protected void finishLogin() {
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        workspace.setCursor(new Cursor(Cursor.WAIT_CURSOR));
        session = new GbjSession(loginParameters);
        try {
            transcript().append("\nLogging in...");
            logger.info("Attempting login to server");
            int l=transcript().getDocument().getLength();
            transcript().setCaretPosition(l);
            session.setDebugOptions(clientVerbose, serverVerbose);
            session.addObserver(this);
            session.connect();
            transcript().append("\nDone - Successful Login\n");
            logger.info("Successful login to server to session: "+session.toString());
	    session.mapGsToJavaClass("GbjToolsInterface", new GbxToolsSupportImpl(session));
            l=transcript().getDocument().getLength();
            transcript().setCaretPosition(l);
            setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            workspace.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            enableUI();
        } 
	// fix 40300: handle *any* type of error that gets thrown
	catch (Throwable e) {
            setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            transcript().append("\nError logging into server.\n"+e.getMessage()+"\n");
            logger.info("Error logging into server.");
            logger.info(e.getMessage());
	    // dump the stack just in case user needs it for debugging..
	    e.printStackTrace();
            int l=transcript().getDocument().getLength();
            transcript().setCaretPosition(l);
            workspace.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            session = null;
            JOptionPane.showMessageDialog(this,"No Session created, error logging into server.\n"+e.getMessage(),"Login Error",JOptionPane.ERROR_MESSAGE);
        }
    }
    
    protected void logout() {
        String sessionid=session.toString();
        sessionClosed();
        transcript().append("\nLogout\n");
        int l=transcript().getDocument().getLength();
        transcript().setCaretPosition(l);
        logger.info("Logout - Session: "+sessionid);
        updateWindowsSessionsLogout();
    }
    
    protected void aboutGemstoneTools(){
        transcript().append("\nGemBuilder\u00AE for Java");
        transcript().append("\nGBJ version " + GbxConstants.VERSION_STRING);
        transcript().append("\n\nGemStone Support can be contacted at http://techsupport.gemtalksystems.com\n\n");
        
        transcript().append("This software makes use of the LGPL Kunststoff look and feel."+
        "\nThe source and binaries for Kunststoff can be found at"+ "\nhttp://kunstoff.incors.com/archive/index.php3\n\n");
        
        transcript().append("This software is copyrighted by GemTalk Systems 1986-2024 "+
        "\nexcept for the above named exception (Kunstoff Look and Feel)\n");
        
        int l=transcript().getDocument().getLength();
        transcript().setCaretPosition(l);
    }
    
    protected void autoMode(){
        if(session==null){
            JOptionPane.showMessageDialog(this,"No Session","Auto Mode",JOptionPane.WARNING_MESSAGE);
        }
        try{
            session.setAutomaticTransactionMode();
            transcript().append("\nTransaction mode set to auto for "+session);
            logger.info("Transaction mode set to auto for "+session);
            int l=transcript().getDocument().getLength();
            transcript().setCaretPosition(l);
        }catch(GbjException e){
            processError_(e);
        }
    }
    
    protected void manualMode(){
        if(session==null){
            JOptionPane.showMessageDialog(this,"No Session","Manual Mode",JOptionPane.WARNING_MESSAGE);
        }
        try{
            session.setManualTransactionMode();
            transcript().append("\nTransaction mode set to manual for "+session);
            logger.info("Transaction mode set to manual for "+session);
            int l=transcript().getDocument().getLength();
            transcript().setCaretPosition(l);
        }catch(GbjException e){
            processError_(e);
        }
    }
    
    protected void browseBreakPoints(){
        if(session==null){
            JOptionPane.showMessageDialog(this,"No Session","Browse Breakpoints",JOptionPane.WARNING_MESSAGE);
        }else{
            GbjBreakpointBrowser bbrowser= new GbjBreakpointBrowser(session,this);
        }
    }
    
    protected void browseClass(){
        if (this.session() == null) {
            JOptionPane.showMessageDialog(this,"No Session","Browse Class",JOptionPane.WARNING_MESSAGE);
        } else {
            String browseClassString=null;
            browseClassString=JOptionPane.showInputDialog(this,"Browse Class:");
            if(browseClassString!=null)browseClassString=browseClassString.trim();
            if(browseClassString==null||browseClassString.length()==0){return;}
            else{
                if(browseClassString.indexOf('*')==-1 && browseClassString.indexOf('?')==-1) {
                    browseClassNamed_(browseClassString);
                    return;
                }
                chooseClassNameMatching_dialogString_(browseClassString, GbxConstants.browseClassString);
                if(listSelected!=null)browseClassNamed_(listSelected);
            }
        }
    }
    
    protected void browseClassNamed(){
    }
    
    protected void browseHierarchy(){
        if (this.session() == null) {
            JOptionPane.showMessageDialog(this,"There is no current session","Browse Hierarchy",JOptionPane.WARNING_MESSAGE);
        } else {
            //Prompt for a class name and then browse the given class' hierarchy."
            listSelected=JOptionPane.showInputDialog(this,GbxConstants.browseHierarchyString,"Browse Hierarchy",JOptionPane.QUESTION_MESSAGE);
            if (listSelected!=null) {
                this.continueBrowseHierarchy();
            }
        }
    }
    
    protected void browseHierarchyNamed(){
    }
    
    protected void browseReferences(){
        if (this.session() == null) {
            JOptionPane.showMessageDialog(this,GbxConstants.noSessionString,"Browse References",JOptionPane.WARNING_MESSAGE);
        } else {
            listSelected=JOptionPane.showInputDialog(this,GbxConstants.browseReferencesString, "Browse References",JOptionPane.QUESTION_MESSAGE);
            if (listSelected!=null) {
                this.finishBrowseReferences();
            }
        }
    }
    
    protected void browseSenders(){
        String sel="";
        if (this.session() == null) {
            JOptionPane.showMessageDialog(this,"No Session","Browse Senders",JOptionPane.WARNING_MESSAGE);
        } else {
            sel=JOptionPane.showInputDialog(this,"Senders","Browse:",JOptionPane.PLAIN_MESSAGE);
            if(sel!=null)sel=sel.trim();
        }
        if (sel == null || sel.length() == 0) {
            return;
        }
        if (sel.equals("*")) {
            (new GbjBrowser()).browseAllCallsOn_inSession_(this, sel, session, this);
            return;
        }
        if ((sel.indexOf('*') == -1) && (sel.indexOf('?') == -1)) {
            (new GbjBrowser()).browseAllCallsOn_inSession_(this, sel, session, this);
            return;
        }
        chooseSelectorMatching_dialogString_(sel, GbxConstants.browseSendersString);
        if(listSelected==null)return;
        (new GbjBrowser()).browseAllCallsOn_inSession_(this, listSelected, this.session(), this);
    }
    
    protected void browseImplementors(){
        String sel="";
        if (session == null) {
            JOptionPane.showMessageDialog(this,"No Session","Browse Implementors",JOptionPane.WARNING_MESSAGE);
        } else {
            sel=JOptionPane.showInputDialog(this,"Implementors","Browse:",JOptionPane.PLAIN_MESSAGE);
            if(sel!=null)sel=sel.trim();
        }
        
        if (sel == null || sel.length() == 0) {
            return;
        }
        
        if (sel.equals("*")) {
            
            (new GbjBrowser()).browseAllImplementorsOf_inSession_(this, sel, session, this);
            return;
        }
        
        if ((sel.indexOf('*') == -1) && (sel.indexOf('?') == -1)) {
            (new GbjBrowser()).browseAllImplementorsOf_inSession_(this, sel, session, this);
            return;
        }
        chooseSelectorMatching_dialogString_(sel, com.gemstone.gbj.GbxConstants.browseImplementorsString);
        if(listSelected==null)return;
        (new GbjBrowser()).browseAllImplementorsOf_inSession_(this, listSelected, session, this);
    }
    
    protected void setClientVerbose(boolean verbosity){
        clientVerbose=verbosity;
	// GBJ30: change settings for java (rather than log4j) logging
        if(clientVerbose)
            logger.setLevel((Level)Level.FINE);
        else  logger.setLevel((Level)Level.WARNING);
    }
    
    protected boolean getClientVerbose(){
        return clientVerbose;
    }
    
    protected void setServerVerbose(boolean verbosity){
        serverVerbose=verbosity;
    }
    
    protected boolean getServerVerbose(){
        return serverVerbose;
    }
    
    protected void addCustomMenus() {
        toolsMenu=new JMenu("Tools");
        
        JMenuItem temp=new JMenuItem("Workspace");
        temp.setActionCommand("Workspace");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        temp=new JMenuItem("Browser");
        temp.setActionCommand("Browser");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        toolsMenu.add(new JSeparator());
        
        temp=new JMenuItem("Senders");
        temp.setActionCommand("Senders");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        temp=new JMenuItem("Implementors");
        temp.setActionCommand("Implementors");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        toolsMenu.add(new JSeparator());
        
        temp=new JMenuItem("References");
        temp.setActionCommand("References");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        temp=new JMenuItem("Find Substring");
        temp.setActionCommand("Find Substring");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        temp= new JMenuItem("Browse Class");
        temp.setActionCommand("Browse Class");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        temp=new JMenuItem("Browse Hierarchy");
        temp.setActionCommand("Browse Hierarchy");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        toolsMenu.add(new JSeparator());
        
        temp=new JMenuItem("Breakpoints");
        temp.setActionCommand("Breakpoints");
        temp.addActionListener(this);
        toolsMenu.add(temp);
        
        menuBar.add(toolsMenu);
        
        windowsMenu=new JMenu("Windows");
        
        temp=new JMenuItem("Show All");
        temp.addActionListener(this);
        temp.setActionCommand("Show All");
        windowsMenu.add(temp);
        
        temp=new JMenuItem("Hide All");
        temp.setActionCommand("Hide All");
        temp.addActionListener(this);
        windowsMenu.add(temp);
        
        windowsMenu.add(new JSeparator());
        
        menuBar.add(windowsMenu);
    }
    
    public JTextArea transcript() {
        return workspace;
    }
    
    protected void enableUI() {
        loginButton.setText("Logout");
        loginButton.setActionCommand("Logout");
        browserButton.setEnabled(true);
        sendersButton.setEnabled(true);
        implementorsButton.setEnabled(true);
        
        int x=fileMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=fileMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand.equals("File In"))temp.setEnabled(true);
            }
        }
        x=editMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=editMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("File-It In"))temp.setEnabled(true);
                    else if(actionCommand.equals("Do-It"))temp.setEnabled(true);
                    else if(actionCommand.equals("Print-It"))temp.setEnabled(true);
                    else if(actionCommand.equals("Inspect-It"))temp.setEnabled(true);
            }
        }
        MenuElement[] menuElements=stdPopUp.getSubElements();
        x=menuElements.length;
        for(int y=0;y<x;y++) {
            MenuElement temp=menuElements[y];
            if(temp instanceof JMenuItem){
                JMenuItem tempMI=(JMenuItem)temp;
                if(temp!=null){
                    String actionCommand=tempMI.getActionCommand();
                    if(actionCommand!=null)
                        if(actionCommand.equals("File-It In"))tempMI.setEnabled(true);
                        else if(actionCommand.equals("Do-It"))tempMI.setEnabled(true);
                        else if(actionCommand.equals("Print-It"))tempMI.setEnabled(true);
                        else if(actionCommand.equals("Inspect-It"))tempMI.setEnabled(true);
                }
            }
        }
        x=sessionMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=sessionMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("Logout"))temp.setEnabled(true);
                    else if(actionCommand.equals("Login"))temp.setEnabled(false);
                    else if(actionCommand.equals("Commit"))temp.setEnabled(true);
                    else if(actionCommand.equals("Abort"))temp.setEnabled(true);
                    else if(actionCommand.equals("Begin"))temp.setEnabled(true);
                    else if(actionCommand.equals("Manual"))temp.setEnabled(true);
                    else if(actionCommand.equals("Auto"))temp.setEnabled(true);
            }
        }
        x=toolsMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=toolsMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("Browser"))temp.setEnabled(true);
                    else if(actionCommand.equals("Senders"))temp.setEnabled(true);
                    else if(actionCommand.equals("Implementors"))temp.setEnabled(true);
                    else if(actionCommand.equals("References"))temp.setEnabled(true);
                    else if(actionCommand.equals("Find Substring"))temp.setEnabled(true);
                    else if(actionCommand.equals("Browse Class"))temp.setEnabled(true);
                    else if(actionCommand.equals("Browse Hierarchy"))temp.setEnabled(true);
                    else if(actionCommand.equals("Breakpoints"))temp.setEnabled(true);
            }
        }
        statusMessage.setText("Connected: "+session);
        updateWindowsSessionsLogin();
    }
    
    private void updateWindowsSessionsLogin() {
        ListIterator listit=openWindows.listIterator();
        while(listit.hasNext()) {
            GbxTool temp=(GbxTool)listit.next();
            temp.setSession(session);
            temp.enableUI();
        }
    }
    
    protected void updateWindowsSessionsLogout() {
        ListIterator listit=openWindows.listIterator();
        while(listit.hasNext()) {
            GbxTool temp=(GbxTool)listit.next();
            temp.setSession(session);
            temp.disableUI();
        }
        listit=deadList.listIterator();
        while(listit.hasNext()) {
            GbxTool temp=(GbxTool)listit.next();
            deregisterWindow(temp);
        }
        deadList.removeAllElements();
    }
    
    protected void disableUI() {
        loginButton.setText("Login");
        loginButton.setActionCommand("Login");
        browserButton.setEnabled(false);
        sendersButton.setEnabled(false);
        implementorsButton.setEnabled(false);
        int x=fileMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=fileMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand.equals("File In"))temp.setEnabled(false);
            }
        }
        x=editMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=editMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("File-It In"))temp.setEnabled(false);
                    else if(actionCommand.equals("Do-It"))temp.setEnabled(false);
                    else if(actionCommand.equals("Print-It"))temp.setEnabled(false);
                    else if(actionCommand.equals("Inspect-It"))temp.setEnabled(false);
            }
        }
        MenuElement[] menuElements=stdPopUp.getSubElements();
        x=menuElements.length;
        for(int y=0;y<x;y++) {
            MenuElement temp=menuElements[y];
            if(temp instanceof JMenuItem){
                JMenuItem tempMI=(JMenuItem)temp;
                if(temp!=null){
                    String actionCommand=tempMI.getActionCommand();
                    if(actionCommand!=null)
                        if(actionCommand.equals("File-It In"))tempMI.setEnabled(false);
                        else if(actionCommand.equals("Do-It"))tempMI.setEnabled(false);
                        else if(actionCommand.equals("Print-It"))tempMI.setEnabled(false);
                        else if(actionCommand.equals("Inspect-It"))tempMI.setEnabled(false);
                }
            }
        }
        x=sessionMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=sessionMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("Logout"))temp.setEnabled(false);
                    else if(actionCommand.equals("Login"))temp.setEnabled(true);
                    else if(actionCommand.equals("Commit"))temp.setEnabled(false);
                    else if(actionCommand.equals("Abort"))temp.setEnabled(false);
                    else if(actionCommand.equals("Begin"))temp.setEnabled(false);
                    else if(actionCommand.equals("Manual"))temp.setEnabled(false);
                    else if(actionCommand.equals("Auto"))temp.setEnabled(false);
            }
        }
        x=toolsMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=toolsMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("Browser"))temp.setEnabled(false);
                    else if(actionCommand.equals("Senders"))temp.setEnabled(false);
                    else if(actionCommand.equals("Implementors"))temp.setEnabled(false);
                    else if(actionCommand.equals("References"))temp.setEnabled(false);
                    else if(actionCommand.equals("Find Substring"))temp.setEnabled(false);
                    else if(actionCommand.equals("Browse Class"))temp.setEnabled(false);
                    else if(actionCommand.equals("Browse Hierarchy"))temp.setEnabled(false);
                    else if(actionCommand.equals("Breakpoints"))temp.setEnabled(false);
            }
        }
        statusMessage.setText("Not Connected");
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        toFront();
        String actioncommand=actionEvent.getActionCommand();
        if(actioncommand.equals("Browser")){
            openBrowser();
        }else if(actioncommand.equals("Senders")){
            browseSenders();
        }else if(actioncommand.equals("Implementors")){
            browseImplementors();
        }else if(actioncommand.equals("Login"))
            login();
        else if(actioncommand.equals("Logout"))
            logout();
        else if(actioncommand.equals("Settings"))
            appSettings();
        else if(actioncommand.equals("Auto"))
            autoMode();
        else if(actioncommand.equals("Manual"))
            manualMode();
        else if (actioncommand.equals("Workspace"))
            openWorkspace();
        else if (actioncommand.equals("About"))
            aboutGemstoneTools();
        else if (actioncommand.equals("Hide All"))
            hideWindows();
        else if (actioncommand.equals("Show All"))
            showWindows();
        else if (actioncommand.equals("Window List"))
            showWindow( ((JMenuItem)actionEvent.getSource()).getText());
        else if (actioncommand.equals("Browse Class"))
            browseClass();
        else if (actioncommand.equals("Breakpoints"))
            browseBreakPoints();
        else if (actioncommand.equals("Browse Class"))
            browseClass();
        else if (actioncommand.equals("Browse Hierarchy"))
            browseHierarchy();
        else if (actioncommand.equals("Find Substring"))
            substringSearch();
        else if (actioncommand.equals("References"))
            browseReferences();
        else super.actionPerformed(actionEvent);
        
    }
    
    public void appSettings() {
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        GbxSettingsDialog settings=new GbxSettingsDialog(mainFont,clientVerbose,serverVerbose,autologin,savePrefs,
        wrap,tabsize,savePassword);
        if(settings.resultValue()) {
            mainFont=settings.getFontUpdate();
            setClientVerbose(settings.getClientVerbose());
            setServerVerbose(settings.getServerVerbose());
            this.autologin=settings.getAutoLogin();
            this.savePrefs=settings.getPref();
            this.tabsize=settings.getTabSize();
            this.wrap=settings.getWordWrap();
            this.savePassword=settings.getSavePassword();
            updateApplication();
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
    }
    
    private void updateApplication(){
        updateFont(mainFont);
        updateLookAndFeel();
        updateTabSize(tabsize);
        updateWordWrap(wrap);
        updateWindows();
    }
    
    public void updateFont(Font font){
        if(font!=null)
            workspace.setFont(font);
    }
    
    private void updateWindows(){
        Iterator iterator=openWindows.iterator();
        while(iterator.hasNext()) {
            GbxTool local=(GbxTool)iterator.next();
            local.updateLookAndFeel();
            local.updateFont(mainFont);
            local.updateTabSize(tabsize);
            local.updateWordWrap(wrap);
        }
    }
    
    public synchronized void registerWindow(GbxTool window) {
        openWindows.add(window);
    }
    
    protected synchronized void addWindowMenu(GbxTool window){
        GbxWindowMenuItem temp=new GbxWindowMenuItem(window.getWindowID(),window.getTitle());
        temp.setActionCommand("Window List");
        temp.addActionListener(this);
        windowsMenu.add(temp);
    }
    
    private synchronized void removeWindowMenu(GbxTool window) {
        String winName=window.getTitle();
        int windowID=window.getWindowID();
        int items=windowsMenu.getItemCount();
        for (int x=0;x<items;x++) {
            if(windowsMenu.getItem(x) instanceof GbxWindowMenuItem)
                if(windowsMenu.getItem(x).getText().equals(winName)&& 
                windowID==((GbxWindowMenuItem)(windowsMenu.getItem(x))).getWindowID()) {
                    windowsMenu.remove(x);
                    break;
                }
        }
    }
    
    public synchronized void deregisterWindow(GbxTool window) {
        removeWindowMenu(window);
        openWindows.remove(window);
        if(openWindows.size()==0)windows_opened=0;
    }
    
    protected void deadWindows(GbxTool window){
        deadList.add(window);
    }
    
    public void exitApplication() {
        storePreferences();
    }
    
    public void openBrowser() {
        if (session == null) {
            JOptionPane.showMessageDialog(this,"No Session","Open Browser",JOptionPane.WARNING_MESSAGE);
        } else {
            GbjBrowser browser=new GbjBrowser(session, this);
            browser.setWindowID(getGlobalWindowID());
            browser.openOnSession();
            browser.setTitle("GBJ Browser."+browser.getWindowID());
            addWindowMenu(browser);
        }
    }
    
    public void substringSearch() {
        if (this.session() == null) {
            JOptionPane.showMessageDialog(this,GbxConstants.noSessionString,"Find Substring",JOptionPane.WARNING_MESSAGE);
        } else {
            listSelected=JOptionPane.showInputDialog(this, GbxConstants.substringSearchString, "Find Substring",JOptionPane.QUESTION_MESSAGE);
            if (listSelected!=null) {
                this.finishSubStringSearch();
            }
        }
    }
    
    public void finishSubStringSearch() {
        String substring = listSelected.trim();
        if (substring == null || substring.length() == 0) {
            return;
        }
        new GbjBrowser().browseAllMethodsWithSubstring_inSession_(this, substring, this.session(), this);
    }
    
    public void finishBrowseReferences() {
        String aSymbol = listSelected.trim();
        if (aSymbol == null || aSymbol.length() == 0) {
            return;
        }
        new GbjBrowser().browseAllMethodsReferencing_inSession_(this, aSymbol, this.session(), this);
    }
    
    public void continueBrowseHierarchy() {
        String className = listSelected.trim();
        if (className == null || className.length() == 0) {
            return;
        }
        if ((className.indexOf('*') == -1) && (className.indexOf('?') == -1)) {
            this.browseHierarchyNamed_(className);
            return;
        }
        this.chooseClassNameMatching_dialogString_(className, GbxConstants.browseHierarchyString);
        if (listSelected!=null) {
            this.finishBrowseHierarchy();
        }
    }
    
    public void finishBrowseHierarchy() {
        this.browseHierarchyNamed_(listSelected);
    }
    
    public void browseClassNamed_(java.lang.String aClassName) {
        GbjObject [] classInfoProxies;
        
        if (aClassName == null) {
            return;
        }
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            classInfoProxies = this.serverSupport().infoForClassNamed_(aClassName);
        } catch (GbjException e) {
            this.processError_(e);
            classInfoProxies = new GbjObject[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        if (classInfoProxies.length != 0) {
            GbjClassBrowser anApp;
            GbxClassHolder [] classList = new GbxClassHolder[1];
            GbxClassHolder aHolder;
            GbjObject classProxy, metaclassProxy;
            String className;
            int classVersion, classSize;           
            anApp = new GbjClassBrowser(session,this);
            anApp.isInstance_(true);
            classProxy = classInfoProxies[0];
            className = classInfoProxies[1].stringValue();
            classVersion = classInfoProxies[2].intValue();
            classSize = classInfoProxies[3].intValue();
            metaclassProxy = classInfoProxies[4];
            aHolder = new GbxClassHolder(className, classProxy, classVersion, classSize, metaclassProxy);
            classList[0] = aHolder;
            anApp.classList_class_protocolList_protocol_methodList_method_(classList, aHolder, null, null, null, null);
            anApp.displayWindow();
        } else {
            JOptionPane.showMessageDialog(this,"No class named " + aClassName,"Browse Class",JOptionPane.WARNING_MESSAGE);
        }
    }
    
    public void browseHierarchyNamed_(java.lang.String aClassName) {
        GbjObject [] classInfoProxies;
        
        if (aClassName == null) {
            return;
        }
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            classInfoProxies = this.serverSupport().infoForClassNamed_(aClassName);
        } catch (GbjException e) {
            this.processError_(e);
            classInfoProxies = new GbjObject[0];
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        if (classInfoProxies.length != 0) {
            GbjHierarchyBrowser anApp;
            GbxClassHolder aHolder;
            GbjObject classProxy, metaclassProxy;
            String className;
            int classVersion, classSize;
            
            classProxy = classInfoProxies[0];
            className = classInfoProxies[1].stringValue();
            classVersion = classInfoProxies[2].intValue();
            classSize = classInfoProxies[3].intValue();
            metaclassProxy = classInfoProxies[4];
            aHolder = new GbxClassHolder(className, classProxy, classVersion, classSize, metaclassProxy);
            
            anApp = new GbjHierarchyBrowser(session,this);
            anApp.myClass_(aHolder);
            anApp.session_(this.session());
            anApp.isInstance_(true);
            anApp.classList_class_protocolList_protocol_methodList_method_(null, aHolder, null, null, null, null);
            anApp.displayWindow();
        } else {
            JOptionPane.showMessageDialog(this,"No class named " + aClassName,"Browse Hierarchy",JOptionPane.WARNING_MESSAGE);
        }
    }
    
    public void update(GbjObservable aSession, String event, Object anObject) {
   /* The session I am attached to just did something. I might need to
   respond. */
        
        if (event.equals("message")) {
            /* There is some message from the API.  Print it to the transcript. */
            transcript().append("\n" + (String) anObject);
            int l=transcript().getDocument().getLength();
            transcript().setCaretPosition(l);
        }
        super.update(aSession, event, anObject);
    }
    
    private void hideWindows() {
        Iterator iterator=openWindows.iterator();
        while(iterator.hasNext()) {
            GbxTool local=(GbxTool)iterator.next();
            local.setVisible(false);
        }
    }
    
    private void showWindows() {
        Iterator iterator=openWindows.iterator();
        while(iterator.hasNext()) {
            GbxTool local=(GbxTool)iterator.next();
            local.setVisible(true);
            local.setState(java.awt.Frame.NORMAL);
        }
    }
    
    private void showWindow(String title){
        Iterator iterator=openWindows.iterator();
        while(iterator.hasNext()) {
            GbxTool local=(GbxTool)iterator.next();
            if(local.getTitle().equals(title)){
                local.setVisible(true);
                local.setState(java.awt.Frame.NORMAL);
                local.toFront();
            }
        }
    }
    
    private synchronized void loadPreferences() {
        loginParameters=new GbjParameters();
        prop=null;
        File prefFile=null;
        boolean noPrefFile= Boolean.getBoolean("com.gemstone.tools.NoPrefFile");
        if(!noPrefFile){
            String defaultPrefFile=System.getProperty("user.home")+"/.gbjtoolsprefs.properties";
            String userPrefFile=System.getProperty("com.gemstone.tools.UsePrefFile");
            if(userPrefFile==null)
            prefFile=new File(defaultPrefFile);
            else if(userPrefFile.equals(""))
                prefFile=new File(defaultPrefFile);
            else prefFile=new File(userPrefFile);
            if(prefFile.exists() && prefFile.isFile()){
                if(prefFile.canRead()){
                    splash.addActionMessage("Loading GBJ preferences file");
                    logger.info("Loading GBJ preferences file");
                    prop =new java.util.Properties();
                    try{
                        prop.load(new java.io.FileInputStream(prefFile));
                        loginParameters.brokerMachine=prop.getProperty("GemBrokerMachine");
                        if(loginParameters.brokerMachine==null||loginParameters.brokerMachine.equals(""))
                            loginParameters.brokerMachine=GbjParameters.DEFAULT_BROKER_MACHINE;
                        loginParameters.brokerPort=Integer.parseInt(prop.getProperty("GemBrokerPort"));
                        loginParameters.timeout=Integer.parseInt(prop.getProperty("Timeout"));
                        loginParameters.connectTimeout=Integer.parseInt(prop.getProperty("ConnectionTimeout"));
                        loginParameters.userName=prop.getProperty("GemstoneUser");
                        loginParameters.password=prop.getProperty("GemstonePassword");
                        loginParameters.serverName=prop.getProperty("GemstoneServer");
                        loginParameters.serverOSPassword=prop.getProperty("HostPassword").trim();
                        loginParameters.serverOSUserName=prop.getProperty("HostUser").trim();
			loginParameters.gemnetName=prop.getProperty("GemService").trim(); // 40301/40306
                        setClientVerbose(Boolean.valueOf(prop.getProperty("ClientVerbose")).booleanValue());
                        setServerVerbose(Boolean.valueOf(prop.getProperty("ServerVerbose")).booleanValue());
                        savePrefs=Boolean.valueOf(prop.getProperty("SavePreferences")).booleanValue();
                        savePassword=Boolean.valueOf(prop.getProperty("SavePassword")).booleanValue();
                        autologin=Boolean.valueOf(prop.getProperty("AutoLogin")).booleanValue();
                        tabsize=Integer.valueOf(prop.getProperty("TabSize")).intValue();
                        String transactionMode=prop.getProperty("TransactionMode").trim();
                        if(transactionMode.equals("MANUAL_TRANSACTIONS")||transactionMode==null||transactionMode.equals("")){
                            loginParameters.transactionMode=GbjParameters.MANUAL_TRANSACTIONS;
                        }else if (transactionMode.equals("AUTOMATIC_TRANSACTIONS")){
                            loginParameters.transactionMode=GbjParameters.AUTOMATIC_TRANSACTIONS;
                        }
                        //Font[] fonts=GraphicsEnvironment.getLocalGraphicsEnvironment().getAllFonts();
                        this.wrap=Boolean.valueOf(prop.getProperty("WordWrap")).booleanValue();
                        String fontName=prop.getProperty("Font");
                        int fontSize=Integer.parseInt(prop.getProperty("FontSize"));
                        mainFont=new Font(fontName,Font.PLAIN,fontSize);
                        String theme=prop.getProperty("Theme");
                        final UIManager.LookAndFeelInfo[] info=UIManager.getInstalledLookAndFeels();
                        if(theme!=null){
                    
                    for(int i=0; i<info.length;i++)
                        if(theme.equals(info[i].getName())) {
                            UIManager.setLookAndFeel(info[i].getClassName());
                            i=info.length;
                        }
                    if(theme.equals("Kunststoff")) {
                        KunststoffLookAndFeel kunststoff=new KunststoffLookAndFeel();
                        kunststoff.setCurrentTheme(new KunststoffTheme());
                        UIManager.setLookAndFeel(kunststoff);
                    }
                }
                    }catch( java.io.FileNotFoundException fe){
                        splash.addActionMessage("Can not read GBJ preferences file");
                        logger.warning("Can not read GBJ preferences file");
                        logger.warning("Using default preferences for start-up");
                        logger.warning(fe.toString());
                        prop=null;
                    }catch( java.io.IOException feio){
                        splash.addActionMessage("Can not read GBJ preferences file");
                        logger.warning("Can not read GBJ preferences file");
                        logger.warning("Using default preferences for start-up");
                        logger.warning(feio.toString());
                        prop=null;
                    }catch(Exception ee){
                        splash.addActionMessage("Bad Parameter in preferences file");
                        splash.addActionMessage("Using default preferences for start-up");
                        logger.warning("Bad Parameter in preferences file");
                        logger.warning("Using default preferences for start-up");
                        logger.warning(ee.toString());
                        loginParameters=new GbjParameters();  
                        mainFont=new Font("dialog",Font.PLAIN,12);
                        try{
                        UIManager.setLookAndFeel("Metal");
                        }catch(Exception ui){logger.warning(ui.toString());}
                    }
                }else{
                    splash.addActionMessage("Can not read GBJ preferences file");
                    logger.warning("Can not read GBJ preferences file");
                    logger.warning("Using default preferences for start-up");
                }
            }else{
                splash.addActionMessage("GBJ preference file missing - using default");
                logger.warning("GBJ preferences file is missing");
                logger.warning("Using default preferences for start-up");
            }
        }else{
            splash.addActionMessage("GBJ user requests not to use preference file");
            logger.warning("GBJ user requests not to use preference file");
        }
    }
    
    private synchronized void storePreferences() {
        if (this.savePrefs){
            try{
                logger.info("Storing preferences file");
                File prefFile =new File( System.getProperty("user.home")+"/.gbjtoolsprefs.properties");
                java.io.FileOutputStream output=new java.io.FileOutputStream(prefFile);
                java.util.Properties prop=new java.util.Properties();
                prop.put("Font",mainFont.getFontName());
                prop.put("FontSize",Integer.toString(mainFont.getSize()));
                prop.put("SavePreferences",new Boolean(savePrefs).toString());
                String themename=UIManager.getLookAndFeel().getName();
                prop.put("Theme",themename);
                prop.put("ClientVerbose",new Boolean(this.clientVerbose).toString());
                prop.put("ServerVerbose",new Boolean(this.serverVerbose).toString());
                prop.put("AutoLogin",new Boolean(this.autologin).toString());
                prop.put("SavePassword",new Boolean(savePassword).toString());
                prop.put("GemBrokerMachine",this.loginParameters.brokerMachine==null?"":this.loginParameters.brokerMachine);
                prop.put("GemBrokerPort",Integer.toString(this.loginParameters.brokerPort));
                prop.put("GemstoneServer",this.loginParameters.serverName==null?"":this.loginParameters.serverName);
                prop.put("GemstoneUser",this.loginParameters.userName==null?"":this.loginParameters.userName);
                if(savePassword)
                    prop.put("GemstonePassword",this.loginParameters.password==null?"":this.loginParameters.password);
                else
                    prop.put("GemstonePassword","");
                prop.put("GemService",this.loginParameters.gemnetName==null?"":this.loginParameters.gemnetName);
                prop.put("HostUser",this.loginParameters.serverOSUserName==null?"":this.loginParameters.serverOSUserName);
                if(savePassword)
                    prop.put("HostPassword",this.loginParameters.serverOSPassword==null?"":this.loginParameters.serverOSPassword);
                else
                    prop.put("HostPassword","");
                prop.put("TransactionMode",loginParameters.transactionMode==loginParameters.MANUAL_TRANSACTIONS?"MANUAL_TRANSACTIONS":"AUTOMATIC_TRANSACTIONS");
                prop.put("Timeout",Integer.toString(loginParameters.timeout));
                prop.put("ConnectionTimeout",Integer.toString(loginParameters.connectTimeout));
                prop.put("WordWrap",new Boolean(wrap).toString());
                prop.put("TabSize",Integer.toString(this.tabsize));
                prop.store(output,"GBJ Preferences");
                output.close();
            }catch(Exception e){
                logger.warning("Error writing preferences file:\n"+e.toString()+"\n");
            }
        }
    }
    
    private static final void printHelpMessage() {
        System.out.println("GBJ "+GbjSession.version+" Launcher Help Message");
        System.out.println("------------------------------------------------------------------");
        System.out.println("\njava com.gemstone.tools.GbjLauncher [options]");
        System.out.println("\nOptions");
        System.out.println("\thelp - prints this help message to stdout");
        System.out.println("\tversion - prints GBJ version information");
        System.out.println("\tNoFileLogger - send log output to stdout");
        System.out.println("\tUseLogFile <filename> - write log output to filename");
        System.out.println("\tUsePrefFile <filename> - use filename for preferences file");
        System.out.println("\tNoPrefFile - do not load or save a preferences file\n");
        System.out.println("------------------------------------------------------------------");
    }
    
    private static void processArguments(java.lang.String[] args) {
        int numargs=0;
        boolean justHelp=false;
        boolean error=false;
        while(numargs<args.length) {
            if(args[numargs].equals("h")||args[numargs].equals("help")||args[numargs].equals("?")){
                if(args.length==1)justHelp=true;
                printHelpMessage();
            }else if(args[numargs].equals("NoFileLogger")){
                java.lang.System.setProperty("com.gemstone.tools.NoFileLogger","true");
            }else if(args[numargs].equals("UseLogFile")){
                if((numargs+1)<args.length && !args[numargs+1].equals("NoFileLogger") &&
                !args[numargs+1].equals("UsePrefFile") && !args[numargs+1].equals("NoPrefFile")){
                    java.lang.System.setProperty("com.gemstone.tools.UseLogFile",args[numargs+1]);
                    numargs++;
                }else{
                    numargs=args.length;
                    System.out.println("Incorrect GBJ command usage,");
                    System.out.println("\tUseLogFile - Missing file location\n");
                    error=true;
                    printHelpMessage();
                }
            }else if(args[numargs].equals("UsePrefFile")){
                if((numargs+1)<args.length && !args[numargs+1].equals("NoFileLogger") &&
                !args[numargs+1].equals("UsePrefFile") && !args[numargs+1].equals("NoPrefFile")){
                    java.lang.System.setProperty("com.gemstone.tools.UsePrefFile",args[numargs+1]);
                    numargs++;
                }else{
                    numargs=args.length;
                    System.out.println("Incorrect GBJ command usage,");
                    System.out.println("\tUsePrefFile - Missing file location.\n");
                    error=true;
                    printHelpMessage();
                }
            }else if(args[numargs].equals("NoPrefFile")){
                java.lang.System.setProperty("com.gemstone.tools.NoPrefFile","true");
            }else if(args[numargs].equals("version")){
		System.out.println("GBJ version: " + GbxConstants.VERSION_STRING);
		justHelp = true;
            }else{               
                System.out.println("Incorrect GBJ command usage,");
                System.out.println("\t"+args[numargs]+" - Invalid command option.\n");
                error=true;
                numargs=args.length;
                printHelpMessage();
            }
            numargs++;
        }
        if(!justHelp&&!error)new GbjLauncher();
    }  
    
    private void autoLogin() {
        if(this.autologin){
        //check for valid login parameters
            if(loginParameters!=null &&
                loginParameters.brokerPort!=0 &&
                loginParameters.connectTimeout!=0 &&
                loginParameters.timeout!=0 && 
                (loginParameters.transactionMode==1 || loginParameters.transactionMode==0) &&
                (loginParameters.brokerMachine!=null && !loginParameters.brokerMachine.equals("")) &&
                (loginParameters.serverName!=null && !loginParameters.serverName.equals("")) &&
                //(loginParameters.serverOSUserName!=null && !loginParameters.serverOSUserName.equals("")) &&
                (loginParameters.userName!=null && !loginParameters.userName.equals(""))){
                 if(loginParameters.serverOSPassword==null || loginParameters.serverOSPassword.equals("") ||
                    loginParameters.password==null || loginParameters.password.equals("") ){
                        GbxAutoLoginDialog getPasswords=new GbxAutoLoginDialog();
                        if(getPasswords.getOK())
                        {
                           loginParameters.password = getPasswords.getGemstonePassword();
                           loginParameters.serverOSPassword = getPasswords.getHostPassword();
                           if(loginParameters.serverOSPassword==null||(loginParameters.serverOSPassword).equals(""))
                             logger.info("Host password not defined, assuming netldi is in guest mode");  
                           finishLogin();
                        }else{
                            logger.warning("Auto login didn't attempt login - invalid passwords or user cancelled");
                            return;
                        }
                 } else finishLogin();
            }else{
                logger.warning("Auto login failed because of bad parameters in user preference file.");
                logger.warning("loginParameters.brokerPort="+loginParameters.brokerPort);
                logger.warning("loginParameters.connectTimeout="+loginParameters.connectTimeout);
                logger.warning("loginParameters.timeout="+loginParameters.timeout);
                logger.warning("loginParameters.transactionMode="+loginParameters.transactionMode);
                logger.warning("loginParameters.brokerMachine="+loginParameters.brokerMachine);
                logger.warning("loginParameters.serverName="+loginParameters.serverName);
                logger.warning("loginParameters.serverOSUserName="+loginParameters.serverOSUserName);
                logger.warning("loginParameters.userName="+loginParameters.userName);
                transcript().append("Auto login failed - see log file");
                return;
            }
                
        }else return;
    }
    
}
