/*
 * GbjMethodListBrowser.java
 *
 * Created on May 23, 2002, 5:06 PM
 */

package com.gemstone.tools;

import com.gemstone.gbj.*;
import java.util.Vector;
import javax.swing.*;
import java.awt.*;
/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbjMethodListBrowser extends GbjMethodBrowser {
    
    /** Creates new GbjMethodListBrowser */
    String initialSelection;
    
    void initialSelection_(String aString) {
        initialSelection = aString;
    }
    
    public GbjMethodListBrowser() {
    }
    
    public GbjMethodListBrowser(GbjSession session, GbjLauncher launcher) {
        super(session,launcher);
    }
    
    
    protected void openListBrowserOn_label_initialSelection_session_launcher_(GbxMethodHolder [] aCollection, String labelString , String selector , GbjSession aSession, GbjLauncher aLauncher) {
        label=labelString;
        session_(aSession);
        initialSelection_(selector);
        on_(aCollection);
        displayWindow();
    }
    
    protected void openListBrowserOn_label_session_launcher_(GbxMethodHolder [] aCollection, String labelString, GbjSession aSession, GbjLauncher aLauncher) {
   /* Create and schedule a browser on the collection of messages aCollection.
   Label the topview labelString. */
        
        openListBrowserOn_label_initialSelection_session_launcher_(aCollection, labelString, null, aSession, aLauncher);
    }
    
    String selectedProtocol() {
   /* Return what is logically the selected protocol.  Unlike the superclass GbjBrowser,
   this is obtained from the selected method. */
        
        if (this.selectedMethod() == null) {
            return null;
        } else {
            return this.selectedMethod().protocol();
        }
    }
    
    boolean compileMethod(String aString) {
        String newSelector;
        GbjObject method;
        Vector methodInfo;
        boolean noError;
        
        /* Compile it. */
        methodInfo = this.compile_classified_class_(aString, this.selectedProtocol(), this.selectedClassOrMetaclass());
        if (methodInfo.isEmpty()) {
            return false;
        }
        noError = ((Boolean) methodInfo.elementAt(0)).booleanValue();
        if (!noError) {
            this.showCompilerErrorArray(methodInfo);
            return false;
        }
        newSelector = (String) methodInfo.elementAt(2);
        if (this.selectedMethod().selector().equals(newSelector)) {
            this.selectedMethod().proxy_((GbjObject) methodInfo.elementAt(1));
            this.selectedMethod().textPosition = -1;
        }
        return true;
    }
    
    
    protected void finishRemoveMethod() {
        try {
            this.serverSupport().removeMethod_fromClass_(this.selectedMethod().name(), this.methodClassProxy());
            methodList = (GbxMethodHolder []) this.removeMethodSelectionFromList_andArray_(methods, methodList);
        } catch (GbjException e) {
            this.processError_(e);
        }
        this.resetText();
    }
    
    void finishMoveMethod() {
        String newProtocol;
        GbjObject thisClass;
        String oldProtocol;
        
        newProtocol = listSelected.trim();
        if (newProtocol == null || newProtocol.length() == 0) {
            return;
        }
        oldProtocol = this.methodProtocol();
        MethodMoveProtocol = newProtocol;
        thisClass = this.methodClassProxy();
        try {
            if (this.protocolExists_(newProtocol)) {
                if (newProtocol.equals(oldProtocol)) {
                    return;
                }
            } else {
                this.serverSupport().addProtocol_toClass_(newProtocol, thisClass);
            }
            this.serverSupport().moveMethod_to_inClass_(this.selectedMethod().name(), newProtocol, thisClass);
        } catch (GbjException e) {
            this.processError_(e);
        }
    }
    
    protected GbxClassHolder selectedClass() {
   /* Return what is logically the selected class holder.  Unlike the superclass GbjBrowser,
   this is obtained from the selected method. */
        
        GbjObject aClass;
        String aName;
        
        if (this.selectedMethod() == null) {
            aClass = this.getSession().kernel.Nil;
            aName = "Unknown";
        } else {
            aClass = this.selectedMethod().remoteClass();
            aName = this.selectedMethod().remoteClassName();
        }
        return new GbxClassHolder(aName, aClass);
    }
    
    protected GbjObject selectedNonMetaclass() {
        /* Return the 'non-meta' class for the selected method. */
        
        GbjObject cls;
        
        if (this.selectedMethod() == null) {
            return null;
        }
        cls = this.selectedMethod().remoteClass();
        
        /* thisClass will do the right thing for a Class or Metaclass */
        try {
            return this.serverSupport().thisClass_(cls);
        } catch (GbjException e) {
            this.processError_(e);
            return null;
        }
    }
    
    GbjObject selectedClassOrMetaclass() {
        /* The selected method will have the appropriate class attached. */
        
        return this.selectedMethod().remoteClass();
    }
    
    String text() {
        /* Return the text for display in the text pane. */
        String src;
        GbxMethodHolder mthHolder = this.selectedMethod();
        
        if (mthHolder != null) {
            /* If there is no proxy then the holder has cached code that won't compile */
            if (mthHolder.proxy() == null) {
                src = mthHolder.sourceCode;
            } else {
                try {
                    src = this.serverSupport().sourceCodeForMethod_(mthHolder.proxy());
                } catch (GbjException e) {
                    this.processError_(e);
                    src = new String();
                }
            }
        } else {
            src = new String();
        }
        return src;
    }
    
    void resetText() {
        /* Reset the text in the text pane and redisplay the initial selection. */
        
        int start, stop;
        
        super.resetText();
        if (initialSelection != null && this.selectedMethod() != null) {
            start = ((GbxMethodHolder) this.selectedMethod()).textPosition;
            if (start != -1) {
                stop = initialSelection.indexOf(':');
                if (stop == -1) {
                    stop = initialSelection.length() - 1;
                }
                workspace.requestFocus();
                workspace.select(start - 1, start + stop);
            }
        }
    }
    
    void on_(GbxMethodHolder [] aList) {
        /* Initialize the receiver with aList the list of methods to be browsed. */
        
        this.methodList_method_(aList, null);
    }
    
    protected void initUI() {
        setTitle("GBJ Method List Browser");
        workspace=new JTextArea();
        createActionTable(workspace);
        makeActionPretty();
        workspace.addMouseListener(this);
        sScroll=new JScrollPane(workspace);
        symbolDictionaries=new JList();
        classes=new JList();
        protocol=new JList();
        methods=new JList();
        mScroll=new JScrollPane();
        mScroll.setViewportView(methods);
        methods.addMouseListener(this);
        methods.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        initMenuBar();
        initPopupMenu();
        setJMenuBar(menuBar);
        content=this.getContentPane();
        content.setLayout(new BorderLayout());
       // GridBagConstraints constraint=new GridBagConstraints();
       // constraint.fill=GridBagConstraints.BOTH;
        //constraint.gridwidth=GridBagConstraints.REMAINDER;
        //content.add(mScroll,BorderLayout.NORTH);
        //constraint.gridy=GridBagConstraints.RELATIVE;
        //content.add(sScroll,BorderLayout.CENTER);
        JSplitPane pane=new JSplitPane(JSplitPane.VERTICAL_SPLIT,mScroll,sScroll);
        //pane.setOneTouchExpandable(true);
        pane.setDividerLocation(.25);
        pane.setLastDividerLocation(20);
        pane.setDividerSize(4);
        addWindowListener(this);
       // addComponentListener(this);
        initOtherPopups();
        if(mainFont!=null)updateFont(mainFont);
                updateTabSize(tabsize);
        updateWordWrap(wrap);
        FontMetrics tfont=getFontMetrics(workspace.getFont());
        int fSize=(int)(tfont.getHeight()*7);
        mScroll.setPreferredSize(new Dimension(300,fSize));
        sScroll.setPreferredSize(new Dimension(300,300));
        ySize=getHeight();
        xSize=getWidth();
        content.add(pane,BorderLayout.CENTER);
    }
    
    public void componentResized(java.awt.event.ComponentEvent componentEvent) {
       /* FontMetrics tfont=getFontMetrics(workspace.getFont());
        int fSize=(int)(tfont.getHeight()*7);
        int y=getHeight();
        int x=getWidth();
        sScroll.setPreferredSize(new Dimension(x,y-fSize));
        mScroll.setPreferredSize(new Dimension(x,fSize));
        sScroll.invalidate();
        mScroll.invalidate();
        validate();
        ySize=getHeight();
        xSize=getWidth(); */
    }
    
    protected void displayWindow() {
        setWindowID(launcher.getGlobalWindowID());
        setTitle(label);
        launcher.registerWindow(this);
        launcher.addWindowMenu(this);
        super.displayWindow();
    }
    
}
