/*
 * GbjWorkSpace.java
 *
 * Created on May 6, 2002, 1:32 PM
 */

package com.gemstone.tools;

import javax.swing.*;
import java.awt.BorderLayout;
import java.awt.Dimension;
import com.gemstone.gbj.*;
import java.awt.Font;
import java.awt.event.*;

/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbjWorkSpace extends com.gemstone.tools.GbxTool {
    
    JScrollPane textScrollArea;
    
    /** Creates new GbjWorkSpace 
	@param session GbjSession
	@param launcher GbjLauncher
    */
    
    public GbjWorkSpace(GbjSession session, GbjLauncher launcher) {
        this(session);
        this.launcher=launcher;
        launcher.registerWindow(this);
    }
    
    public GbjWorkSpace(GbjSession session) {
        this();
        this.session=session;
        if(session!=null)enableUI();
        else disableUI();
    }
    
    public GbjWorkSpace() {
        initUI();
        displayWindow();
    }
    
    
    protected void initFileMenu() {
        JMenuItem tmenuitem=new JMenuItem("Open");
        tmenuitem.setName("Open MenuItem");
        fileMenu.add(tmenuitem);
        tmenuitem.addActionListener(this);
        tmenuitem.setActionCommand("Open");
        tmenuitem=new JMenuItem("Save as");
        tmenuitem.setName("Save As MenuItem");
        tmenuitem.setActionCommand("Save As");
        tmenuitem.addActionListener(this);
        fileMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("File In");
        tmenuitem.setName("File In MenuItem");
        tmenuitem.setActionCommand("File In");
        tmenuitem.addActionListener(this);
        fileMenu.add(tmenuitem);
        fileMenu.add(new JSeparator());
        tmenuitem=new JMenuItem("Close");
        tmenuitem.setName("Close MenuItem");
        tmenuitem.setActionCommand("Close");
        tmenuitem.addActionListener(this);
        fileMenu.add(tmenuitem);
    }
    
    protected void initSessionMenu() {
        JMenuItem tmenuitem=new JMenuItem("Commit");
        tmenuitem.setName("Commit MenuItem");
        tmenuitem.setActionCommand("Commit");
        tmenuitem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S,ActionEvent.CTRL_MASK+ActionEvent.SHIFT_MASK));
        tmenuitem.addActionListener(this);
        sessionMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Begin");
        tmenuitem.setActionCommand("Begin");
        tmenuitem.setName("Begin MenuItem");
        tmenuitem.addActionListener(this);
        sessionMenu.add(tmenuitem);
        tmenuitem=new JMenuItem("Abort");
        tmenuitem.setActionCommand("Abort");
        tmenuitem.setName("Abort MenuItem");
        tmenuitem.addActionListener(this);
        sessionMenu.add(tmenuitem);
    }
    
    protected void initUI() {
        workspace=new JTextArea();
        createActionTable(workspace);
        makeActionPretty();
        super.initUI();
        statusMessage=new JLabel("Not Connected");
        textScrollArea=new JScrollPane(workspace);
        textScrollArea.setPreferredSize(new Dimension(350,250));
        content.add(textScrollArea,BorderLayout.CENTER);
        statusPanel=new JPanel();
        statusPanel.add(statusMessage);
        content.add(statusPanel,BorderLayout.SOUTH);
        workspace.addMouseListener(this);
        selectedComponent=workspace;
        updateFont(mainFont);
        updateTabSize(tabsize);
        updateWordWrap(wrap);
        setName("Workspace Window");
    }
    
    public void updateFont(Font font){
        if(font!=null)
            workspace.setFont(font);
    }
    
    protected void enableUI() {
        sessionMenu.setEnabled(true);
        MenuElement[] menuElements=stdPopUp.getSubElements();
        int x;
        x=menuElements.length;
        for(int y=0;y<x;y++) {
            MenuElement temp=menuElements[y];
            if(temp instanceof JMenuItem){
                JMenuItem tempMI=(JMenuItem)temp;
                if(temp!=null){
                    String actionCommand=tempMI.getActionCommand();
                    if(actionCommand!=null)
                        if(actionCommand.equals("File-It In"))tempMI.setEnabled(true);
                        else if(actionCommand.equals("Do-It"))tempMI.setEnabled(true);
                        else if(actionCommand.equals("Print-It"))tempMI.setEnabled(true);
                        else if(actionCommand.equals("Inspect-It"))tempMI.setEnabled(true);
                }
            }
        }
        x=fileMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=fileMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand.equals("File In"))temp.setEnabled(true);
            }
        }
        x=editMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=editMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("File-It In"))temp.setEnabled(true);
                    else if(actionCommand.equals("Do-It"))temp.setEnabled(true);
                    else if(actionCommand.equals("Print-It"))temp.setEnabled(true);
                    else if(actionCommand.equals("Inspect-It"))temp.setEnabled(true);
            }
        }
        statusMessage.setText("Connected: "+session);
    }
    
    protected void disableUI() {
        sessionMenu.setEnabled(false);
        MenuElement[] menuElements=stdPopUp.getSubElements();
        int x;
        x=menuElements.length;
        for(int y=0;y<x;y++) {
            MenuElement temp=menuElements[y];
            if(temp instanceof JMenuItem){
                JMenuItem tempMI=(JMenuItem)temp;
                if(temp!=null){
                    String actionCommand=tempMI.getActionCommand();
                    if(actionCommand!=null)
                        if(actionCommand.equals("File-It In"))tempMI.setEnabled(false);
                        else if(actionCommand.equals("Do-It"))tempMI.setEnabled(false);
                        else if(actionCommand.equals("Print-It"))tempMI.setEnabled(false);
                        else if(actionCommand.equals("Inspect-It"))tempMI.setEnabled(false);
                }
            }
        }
        x=fileMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=fileMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand.equals("File In"))temp.setEnabled(false);
            }
        }
        x=editMenu.getItemCount();
        for(int y=0;y<x;y++) {
            JMenuItem temp=editMenu.getItem(y);
            if(temp!=null){
                String actionCommand=temp.getActionCommand();
                if(actionCommand!=null)
                    if(actionCommand.equals("File-It In"))temp.setEnabled(false);
                    else if(actionCommand.equals("Do-It"))temp.setEnabled(false);
                    else if(actionCommand.equals("Print-It"))temp.setEnabled(false);
                    else if(actionCommand.equals("Inspect-It"))temp.setEnabled(false);
            }
        }
        statusMessage.setText("Not Connected");
    }
    
    protected void initHelpMenu() {
    }
}


