/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 * Name - GbxClassHolder.java
 *
 *========================================================================
 */

package com.gemstone.tools;

import com.gemstone.gbj.GbjObject;

class GbxClassHolder extends GbxHolder {
    int version;
    int numberOfVersions;
    int depth;
    String instVarNames;
    boolean isSpecial;
    GbjObject metaclass;
    
    GbxClassHolder(String aName, GbjObject aProxy) {
        super(aName, aProxy);
        version = -1;
        numberOfVersions = -1;
        depth = -1;
        isSpecial = false;
    }
    
    GbxClassHolder(String aName, GbjObject aProxy, int aVersion, int classSize, GbjObject meta) {
        super(aName, aProxy);
        version = aVersion;
        numberOfVersions = classSize;
        depth = -1;
        isSpecial = false;
        metaclass = meta;
    }
    
    GbxClassHolder(String aName, GbjObject aProxy, int aVersion, int classSize, int aDepth, String ivNames, boolean special, GbjObject meta) {
        super(aName, aProxy);
        version = aVersion;
        numberOfVersions = classSize;
        depth = aDepth;
        instVarNames = ivNames;
        isSpecial = special;
        metaclass = meta;
    }
    
    int numberOfVersions() {
        return numberOfVersions;
    }
    
    String displayString() {
        String nameText;
        String versionString;
        int versionNum;
        
        nameText = super.displayString();
        /*If there is only one version and <self> represents that one version; don't display
        the version number.  This allows version [0], which can happen if a class is in a
        user's name space but the version has been removed from its class history. */
        
        versionNum = this.version();
        if ((versionNum == -1) || ((versionNum == 1) && (this.numberOfVersions() == 1))) {
            versionString = "";
        } else {
            versionString = 
	      " [" + (Integer.valueOf(versionNum)).toString() + "]";
        }
        return this.depthString() + nameText + versionString;
    }
    
    String depthString() {
        String depthText = "";
        
        if (depth != -1) {
            for (int i = 0; i < depth; i++) {
                depthText = depthText + "   ";
            }
        }
        return depthText;
    }
    
    String ivString() {
        return instVarNames == null ? "" : instVarNames;
    }
    
    int version() {
        /* Return the version of the associated class. */
        
        return version;
    }
    
    String instVarNames() {
        /* Return the names of the instance variables of the associated
        class. */
        
        return instVarNames;
    }
    
    boolean isSpecial() {
        /* Indicates whether this holder was the target of
        <showHierarchy> of <browseHierarchy>. */
        
        return isSpecial;
    }
    
    int depth() {
        /* Return the depth of the associated class in the class
        hierarchy. */
        
        return depth;
    }
    
    GbjObject metaclass() {
        return metaclass;
    }
    
    GbxClassHolder defaultCopy() {
        return new GbxClassHolder(this.name(), this.proxy(), version, numberOfVersions, metaclass);
    }
    
}
