/*
 * DebugDialog.java
 *
 * Created on July 23, 2002, 1:20 PM
 */

package com.gemstone.tools;

import javax.swing.*;
import java.awt.*;
import com.gemstone.gbj.*;
/**
 *
 * @author  vincef
 */
public class GbxDebugDialog extends javax.swing.JDialog implements java.awt.event.ActionListener{
    
    JButton continueButton;
    JButton terminateButton;
    JButton debugButton;
    JTextArea debugMessage;
    JScrollPane messageScroll;
    
    GbjLauncher launcher=null;
    
    GbjException exception;
    //GbxTool parentTool;
    boolean inspectResult = false;
    boolean printResult = false;
    GbxTool sourceTool;
    GbxToolPanel sourceToolPanel;
    
    public GbxDebugDialog(String title, GbjException anException, boolean print, boolean inspect, GbxTool aTool, GbjLauncher launch) {
        
        printResult = print;
        inspectResult = inspect;
        sourceTool = aTool;
        launcher=launch;
        initUI(title, anException);
        
    }
    
    /** Creates a new instance of DebugDialog 
	@param title  Strin
	@param anException GbjException
	@param print  boolean
	@param inspect boolean
	@param aTool GbxTool
    */
    public GbxDebugDialog(String title, GbjException anException, boolean print, boolean inspect, GbxTool aTool) {
        
        printResult = print;
        inspectResult = inspect;
        sourceTool = aTool;
        launcher=sourceTool.launcher;
        initUI(title, anException);
    }
    
    public GbxDebugDialog(String title, GbjException anException, boolean print, boolean inspect, GbxToolPanel aTool) {
        
        printResult = print;
        inspectResult = inspect;
        sourceToolPanel = aTool;
        launcher=sourceTool.launcher;
        initUI(title, anException);
    }
    
    public void initUI(String title, GbjException anException) {
        setModal(true);
        setResizable(false);
        setSize(270,150);
        setTitle(title);
        exception = anException;
        Container content=getContentPane();
        continueButton=new JButton("Continue");
        continueButton.setActionCommand("Continue");
        continueButton.setName("Continue JButton");
        continueButton.addActionListener(this);
        terminateButton=new JButton("Terminate");
        terminateButton.setActionCommand("Terminate");
        terminateButton.setName("Terminate JButton");
        terminateButton.addActionListener(this);
        debugButton=new JButton("Debug");
        debugButton.setActionCommand("Debug");
        debugButton.setName("Debug JButton");
        debugButton.addActionListener(this);
        debugMessage=new JTextArea();
        debugMessage.setEditable(false);
        debugMessage.setWrapStyleWord(true);
        debugMessage.setLineWrap(true);
        messageScroll=new JScrollPane(debugMessage);
        messageScroll.setPreferredSize(new Dimension(200,75));
        debugMessage.setText(anException.getMessage());
        content.setLayout(new GridBagLayout());
        GridBagConstraints constraint=new GridBagConstraints();
        constraint.fill=GridBagConstraints.BOTH;
        constraint.gridwidth=GridBagConstraints.REMAINDER;
        content.add(messageScroll,constraint);
        constraint.gridwidth=1;
        content.add(debugButton,constraint);
        content.add(continueButton,constraint);
        content.add(terminateButton,constraint);
        pack();
        Dimension windowSize=getSize();
        Dimension screen=java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        int x=(screen.width-windowSize.width)/2;
        int y=(screen.height-windowSize.height)/2;
        setLocation(x,y);
        debugMessage.setCaretPosition(0);
        setVisible(true);
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String action=actionEvent.getActionCommand();
        if(action.equals("Debug")){
            clickedDebugButton();
        }else if(action.equals("Terminate")){
            clickedOkButton();
        }else if(action.equals("Continue")){
            clickedContinueButton();
        }
        
    }
    
    public void clickedContinueButton() {
        this.clickedCancelButton();
        GbjObject result, gsProcess;
        gsProcess = exception.process;
        try {
	    // 45662: add session arg
            result = launcher.serverSupport().continueProcess_(gsProcess, launcher.session());
            if (result.equals(gsProcess)) {
                exception.setMessage("Method Breakpoint Encountered");
                sourceTool.processGbjException(exception, printResult, inspectResult);
            } else {
                processResult_(result);
            }
        } catch (GbjException e) {
            sourceTool.processGbjException(e, printResult, inspectResult);
        }
    }
    
    public void clickedDebugButton() {
        this.clickedCancelButton();
        new GbjDebugger(exception, launcher,
        printResult, inspectResult, sourceTool);
        dispose();
    }
    
    public void clickedCancelButton() {        
        setVisible(false);
    }
    
    public void processResult_(GbjObject result) {
        GbjInspector anInspector;
        if (inspectResult) {
            anInspector = new GbjInspector(result,null,launcher.session(),launcher);
        } else if (printResult) {
            sourceTool.printResult(result.stringValue());
        }
    }
    
    public void clickedOkButton() {
        setVisible(false);
        dispose();
    }
    
}
