/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 * Name - GbxMethodHolder.java
 *
 *========================================================================
 */

package com.gemstone.tools;

import com.gemstone.gbj.GbjObject;
import com.gemstone.gbj.GbjException;
import com.gemstone.gbj.GbjSession;

class GbxMethodHolder extends GbxHolder {
    GbjObject inClass;
    String className;
    String displayString;
    String protocol;
    int textPosition;
    int endPoint;
    int stepPoint;
    String sourceCode;
    
    GbxMethodHolder() {
        super();
    }
    
    GbxMethodHolder(String aString, GbjObject aProxy) {
        super(aString, aProxy);
    }
    
    GbxMethodHolder(String name, GbjObject aProxy, GbjObject aClass, String aClassName, String aDisplayString, String aCategory, int aPosition, String src) {
        super(name, aProxy);
        inClass = aClass;
        className = aClassName;
        displayString = aDisplayString;
        protocol = aCategory;
        textPosition = aPosition;
        sourceCode = src;
    }
    
    GbxMethodHolder(String name, GbjObject aProxy, GbjObject aClass, String aClassName, String aDisplayString, String aCategory, int aPosition, int endPosition, int aStepPoint, String src) {
        super(name, aProxy);
        inClass = aClass;
        className = aClassName;
        displayString = aDisplayString;
        protocol = aCategory;
        textPosition = aPosition;
        endPoint = endPosition;
        stepPoint = aStepPoint;
        sourceCode = src;
    }
    
    GbjObject remoteClass() {
        /* Returns a proxy representing the GemStone class of the method */
        
        return inClass;
    }
    
    String remoteClassName() {
        /* Returns the name of the GemStone class of the method */
        
        return className;
    }
    
    String protocol() {
        /* Returns a symbol representing the protocol of the method */
        
        return protocol;
    }
    
    String selector() {
        return this.name();
    }
    
    GbjSession session() {
        return proxy.getSession();
    }
    
    String displayString() {
        if (displayString == null) {
            return super.displayString();
        } else {
            return displayString;
        }
    }
    
    GbxMethodHolder defaultCopy() {
        return new GbxMethodHolder(this.name(), this.proxy(), inClass, className, null, protocol, -1, null);
    }
    
    int stepPoint() {
        return stepPoint;
    }
    
}
