

/*
 * GbxSettingsDialog.java
 *
 * Created on May 6, 2002, 10:47 AM
 */

package com.gemstone.tools;

import java.awt.event.ActionListener;
import javax.swing.*;
import java.awt.Container;
import java.awt.FlowLayout;
import com.incors.plaf.kunststoff.KunststoffLookAndFeel;
import com.incors.plaf.kunststoff.*;
import java.awt.Font;
import java.awt.GraphicsEnvironment;
import java.awt.event.MouseListener;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.util.TreeSet;
import java.awt.Dimension;
import java.awt.GridLayout;

/**
 *
 * @author  GemTalk Systems
 * @version 1.3
 */

public class GbxSettingsDialog extends JDialog
implements ActionListener, MouseListener{
    
    //GUI elements
    JComboBox lookFeelList;
    Container rootPane;
    JList fontlist;
    JList fontsize;
    JScrollPane fontScroll;
    JScrollPane fontSizeScroll;
    JButton okButton;
    JButton cancelButton;
    JCheckBox verboseClient;
    JCheckBox verboseServer;
    JCheckBox wordWrap;
    JCheckBox savePrefs;
    JCheckBox autoLogin;
    JCheckBox savePassword;
    JComboBox tabSize;
    JTextArea fontDisplay;
    JScrollPane textPane;
    
    //operational values
    private int currentFontSize;
    private String font;
    private String originalLandF;
    private Font newFont;
    private boolean result;
    private boolean cVerbose;
    private boolean sVerbose;
    private int tabsize;
    private boolean autologin;
    private boolean wrap;
    private boolean saveprefs;
    private boolean savepassword;
    
    /** Creates new GbxSettingsDialog */
    public GbxSettingsDialog() {
        this(null,false,false,false,false,false,3,false);
    }
    
    /**
     * @param currentFont Font
     * @param clientVerbose boolean
     * @param serverVerbose boolean
     * @param autologin boolean
     * @param saveprefs boolean
     * @param wrap boolean
     * @param tabsize int
     * @param spassword boolean
     */
    public GbxSettingsDialog(Font currentFont,boolean clientVerbose,boolean serverVerbose,boolean autologin
    ,boolean saveprefs,boolean wrap,int tabsize, boolean spassword) {
        result=false;
        cVerbose=clientVerbose;
        sVerbose=serverVerbose;
        setTitle("GBJ Settings");
        setModal(true);
        setResizable(false);
        fontDisplay=new JTextArea();
        fontDisplay.setEditable(false);
        textPane=new JScrollPane();
        textPane.setViewportView(fontDisplay);
        fontDisplay.setText("THE QUICK BROWN FOX JUMPED OVER THE SLOW LAZY DOG.\nthe quick brown fox jumped over the slow lazy dog.\n1 2 3 4 5 6 7 8 9 0");
        rootPane=getContentPane();
        rootPane.setLayout(new GridBagLayout());
        okButton=new JButton("OK");
        cancelButton=new JButton("Cancel");
        
        //verbose settings
        verboseClient=new JCheckBox("Client");
        verboseClient.setSelected(clientVerbose);
        verboseServer=new JCheckBox("Server");
        verboseServer.setSelected(serverVerbose);
        
        //text settings
        wordWrap=new JCheckBox("Word Wrap");
        String[] tabsizes={"1","2","3","4","5","6","7","8","9","10"};
        tabSize=new JComboBox(tabsizes) ;
        
        // Prefs
        savePrefs=new JCheckBox("Save Preferences");
        savePrefs.setSelected(saveprefs);
        savePrefs.setToolTipText("Save preferences file when GBJ Launcher shutsdown");
        autoLogin=new JCheckBox("Auto Login");
        autoLogin.setToolTipText("Attempt to automaticly login to server next start-up");
        autoLogin.setSelected(autologin);
        savePassword=new JCheckBox("Save Password");
        savePassword.setToolTipText("Use with caution -saves passwords to preference file in clear text");
        savePassword.setSelected(spassword);
        //current Look and Feel
        originalLandF=UIManager.getLookAndFeel().getName();
        //Look and Feel Combobox
        final UIManager.LookAndFeelInfo[] info=UIManager.getInstalledLookAndFeels();
        lookFeelList=new JComboBox();
        boolean kunststoffLoaded=false;
        for (int i=0;i<info.length;i++) {
            lookFeelList.addItem(info[i].getName());
            if(info[i].getName().equals("Kunststoff"))kunststoffLoaded=true; //has Kunststoff been loaded already
            if(info[i].getName().equals(originalLandF))lookFeelList.setSelectedIndex(i);
        }
        if(!kunststoffLoaded)//add Kunststoff item if not already loaded
            lookFeelList.addItem("Kunststoff");
        
        //current gbj system font
        if(currentFont!=null) {
            currentFontSize=currentFont.getSize();
            font=currentFont.getFontName();
        }else{
            currentFontSize=12;
            font=fontDisplay.getFont().getFontName();
        }
        
        //Font list - some fonts won't work in java
        Font[] fonts=GraphicsEnvironment.getLocalGraphicsEnvironment().getAllFonts();
        Object[] fontNames;
        TreeSet tempCol=new TreeSet();//use collection to sort font list and toss duplicates
        int fontSelected=0;
        for(int i=0;i<fonts.length;i++)
            tempCol.add(fonts[i].getFontName());
        fontNames=tempCol.toArray();
        for(int i=0;i<fontNames.length;i++)//find current font
            if(font.equals((fontNames[i]))){
                fontSelected=i;
                i=fontNames.length;
            }
        fontlist=new JList(fontNames);
        fontlist.setSelectionMode(javax.swing.DefaultListSelectionModel.SINGLE_SELECTION);
        fontlist.setSelectedIndex(fontSelected);
        fontScroll=new JScrollPane(fontlist);
        
        //font sizes
        String[] fontSizes={"8","9","10","12","14","18","24","32"}; //allowed font sizes in GBJ
        fontsize=new JList(fontSizes);
        fontsize.setSelectionMode(javax.swing.DefaultListSelectionModel.SINGLE_SELECTION);
        for(int i=0; i<fontSizes.length;i++) //select current font size
        {
            if(String.valueOf(currentFontSize).equals(fontSizes[i])){
                fontsize.setSelectedIndex(i);
                i=fontSizes.length;
            }
        }
        fontSizeScroll=new JScrollPane(fontsize);
        
        //build dialog
        GridBagConstraints constraint=new GridBagConstraints();
        
        //verbose
        constraint.gridwidth=GridBagConstraints.REMAINDER;
        constraint.fill=GridBagConstraints.HORIZONTAL;
        JPanel verbosePane=new JPanel(new GridLayout(1,2));
        verbosePane.setBorder(BorderFactory.createTitledBorder("Verbose"));
        verbosePane.add(verboseClient);
        verbosePane.add(verboseServer);
        rootPane.add(verbosePane,constraint);
        
        //prefs
        constraint.gridwidth=GridBagConstraints.REMAINDER;
        constraint.fill=GridBagConstraints.HORIZONTAL;
        JPanel prefPane=new JPanel(new GridLayout(2,3));
        prefPane.setBorder(BorderFactory.createTitledBorder("Preferences"));
        prefPane.add(savePrefs);
        prefPane.add(autoLogin);
        prefPane.add(savePassword);
        prefPane.add(wordWrap);
        JPanel tabPanel=new JPanel(new GridLayout(1,2));
        JLabel tabLabel=new JLabel("Tab Size:");
        tabPanel.add(tabLabel);
        tabPanel.add(tabSize);
        prefPane.add(tabPanel);
        rootPane.add(prefPane,constraint);
        
        
        //look and feel
        JPanel lookFeelPanel=new JPanel();
        lookFeelPanel.setBorder(BorderFactory.createTitledBorder("Look and Feel"));
        lookFeelPanel.add(lookFeelList);
        constraint.gridwidth=GridBagConstraints.REMAINDER;
        rootPane.add(lookFeelPanel,constraint);
        
        //fonts
        JPanel fontPanel=new JPanel();
        fontPanel.setBorder(BorderFactory.createTitledBorder("Fonts"));
        fontPanel.setLayout(new GridBagLayout());
        constraint.gridwidth=GridBagConstraints.RELATIVE;
        constraint.gridheight=2;
        fontSizeScroll.setPreferredSize(new Dimension(205,155));
        fontPanel.add(fontScroll,constraint);
        constraint.gridwidth=GridBagConstraints.REMAINDER;
        fontSizeScroll.setPreferredSize(new Dimension(80,155));
        fontPanel.add(fontSizeScroll,constraint);
        textPane.setPreferredSize(new Dimension(285,100));
        fontPanel.add(textPane,constraint);
        rootPane.add(fontPanel,constraint);
        
        
        //ok and cancel button
        JPanel buttonPanel=new JPanel();
        buttonPanel.setLayout(new FlowLayout());
        buttonPanel.add(okButton);
        buttonPanel.add(cancelButton);
        rootPane.add(buttonPanel);
        
        //listeners for events
        fontlist.addMouseListener(this);
        fontsize.addMouseListener(this);
        okButton.addActionListener(this);
        cancelButton.addActionListener(this);
        currentFontSize=Integer.parseInt((String)(fontsize.getSelectedValue()));
        font=(String)(fontlist.getSelectedValue());
        Font localFont=new Font(font,Font.PLAIN,currentFontSize);
        fontDisplay.setFont(localFont);
        this.autoLogin.setSelected(autologin);
        this.savePrefs.setSelected(saveprefs);
        this.wordWrap.setSelected(wrap);
        this.tabSize.setSelectedIndex(tabsize-1);
        JRootPane root=getRootPane();
        root.setDefaultButton(okButton);
        //prepare for display and show
        pack();
        Dimension windowSize=getSize();
        Dimension screen=java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        int x=(screen.width-windowSize.width)/2;
        int y=(screen.height-windowSize.height)/2;
        setLocation(x,y);
        show();
    }
    
    /**
     * @param actionEvent  java.awt.event.ActionEvent */
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        if(actionEvent.getSource()==okButton) {
            try{
                //create new font
                newFont=new Font(font,Font.PLAIN,currentFontSize);
                
                //set look and feel
                final UIManager.LookAndFeelInfo[] info=UIManager.getInstalledLookAndFeels();
                String lfName=(String)lookFeelList.getSelectedItem();
                if(lfName!=null){
                    
                    for(int i=0; i<info.length;i++)
                        if(lfName.equals(info[i].getName())) {
                            UIManager.setLookAndFeel(info[i].getClassName());
                            i=info.length;
                        }
                    if(lfName.equals("Kunststoff")) {
                        KunststoffLookAndFeel kunststoff=new KunststoffLookAndFeel();
                        kunststoff.setCurrentTheme(new KunststoffTheme());
                        UIManager.setLookAndFeel(kunststoff);
                    }
                }
                
                //done close dialog
                setVisible(false);
                cVerbose=verboseClient.isSelected();
                sVerbose=verboseServer.isSelected();
                autologin=autoLogin.isSelected();
                saveprefs=savePrefs.isSelected();
                savepassword=savePassword.isSelected();
                tabsize=tabSize.getSelectedIndex()+1;
                wrap=wordWrap.isSelected();
                result=true;
            }catch(javax.swing.UnsupportedLookAndFeelException e){
                JOptionPane.showMessageDialog(this,"Look and feel not supported on this platform.","Error",JOptionPane.ERROR_MESSAGE);
                for(int i=0;i<lookFeelList.getItemCount();i++) {
                    if(originalLandF.equals((String)lookFeelList.getItemAt(i))) {
                        lookFeelList.setSelectedIndex(i);
                    }
                }
            }
            catch(NullPointerException ee){
                JOptionPane.showMessageDialog(this,"Unknow Error - Contact technical support","Error",JOptionPane.ERROR_MESSAGE);
                ee.printStackTrace();}
            catch(Exception eee){
                JOptionPane.showMessageDialog(this,"Unknow Error - Contact technical support","Error",JOptionPane.ERROR_MESSAGE);
                eee.printStackTrace();}
        }else
            if (actionEvent.getSource()==cancelButton){
                setVisible(false);
                result=false;
            }
    }
    
    public boolean resultValue() {
        return result;
    }
    
    public Font getFontUpdate() {
        return newFont;
    }
    
    public boolean getClientVerbose() {
        return cVerbose;
    }
    
    public boolean getServerVerbose() {
        return sVerbose;
    }
    
    public int getTabSize(){
        return this.tabsize;
    }
    
    public boolean getWordWrap(){
        return this.wrap;
    }
    
    public boolean getPref(){
        return this.saveprefs;
    }
    
    public boolean getAutoLogin(){
        return this.autologin;
    }
    
    /**
     * @param mouseEvent  java.awt.event.MouseEvent */
    public void mouseExited(java.awt.event.MouseEvent mouseEvent) {
        //required stub
    }
    
    /**
     * @param mouseEvent  java.awt.event.MouseEvent */
    public void mouseReleased(java.awt.event.MouseEvent mouseEvent) {
        //font preview changing of font face
        if(mouseEvent.getSource()==fontlist){
            font=(String)((((JList)mouseEvent.getSource()).getSelectedValue()));
            Font localFont=new Font(font,Font.PLAIN,currentFontSize);
            fontDisplay.setFont(localFont);
        }
        //font preview changing of font size
        if(mouseEvent.getSource()==fontsize){
            currentFontSize=Integer.parseInt((String)(((JList)mouseEvent.getSource()).getSelectedValue()));
            Font localFont=new Font(font,Font.PLAIN,currentFontSize);
            fontDisplay.setFont(localFont);
        }
    }
    
    /**
     * @param mouseEvent  java.awt.event.MouseEvent */
    public void mousePressed(java.awt.event.MouseEvent mouseEvent) {
        //required stub
    }
    
    /**
     * @param mouseEvent  java.awt.event.MouseEvent */
    public void mouseClicked(java.awt.event.MouseEvent mouseEvent) {
        //required stub
    }
    
    /**
     * @param mouseEvent  java.awt.event.MouseEvent */
    public void mouseEntered(java.awt.event.MouseEvent mouseEvent) {
        //required stub
    }
    
    public boolean getSavePassword() {
        return savepassword;
    }
    
}

