

/*
 * GbxToolS.java
 *
 * Created on April 30, 2002, 1:58 PM
 */

package com.gemstone.tools;

import javax.swing.*;
import javax.swing.text.*;
import com.gemstone.gbj.*;
import com.gemstone.tools.GbxToolsSupportImpl;
import java.awt.Container;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Component;
import java.awt.Cursor;
import java.awt.event.MouseAdapter;  // 40303
import java.awt.event.KeyAdapter;    // 40303
import com.gemstone.gbj.GbjException;
import javax.swing.text.DefaultEditorKit;
import java.util.Hashtable;
import java.awt.Font;
import java.io.*;
import java.awt.event.KeyEvent;
import java.awt.event.ActionEvent;
// GBJ30: replace with java logging
//import com.gemstone.org.apache.log4j.*;
import java.util.logging.*;

/**
 *
 * @author  vincef
 * @version 1.3
 */
public class GbxTool extends javax.swing.JFrame implements java.awt.event.WindowListener, javax.swing.event.MenuListener, java.awt.event.MouseListener, java.awt.event.ActionListener, com.gemstone.gbj.GbjObserver, java.awt.event.ComponentListener, javax.swing.event.ListSelectionListener, java.awt.event.FocusListener{
    
    protected GbjSession session;
    protected JMenu fileMenu;
    protected JMenu editMenu;
    protected JMenu sessionMenu;
    protected JMenuBar menuBar;
    protected JMenu helpMenu;
    protected JPopupMenu popupMenu;
    protected JPanel statusPanel;
    protected JLabel statusMessage;
    protected Container content;
    protected JPopupMenu stdPopUp;
    protected Hashtable actions;
    protected JTextArea workspace;
    protected GbjLauncher launcher;
    protected Component selectedComponent;
    protected String listSelected;
    protected String fileName=null;
    protected static Font mainFont=null;
    protected static int tabsize=3;
    protected static boolean wrap=false;
    protected Logger logger;
    protected ButtonGroup transactionButtons;
    protected JRadioButtonMenuItem manualMenuItem;
    protected JRadioButtonMenuItem autoMenuItem;
    protected int windowID=0;
    protected JPanel glass_pane;   // 40303
    
    /** Creates new GbxToolS */
    public GbxTool() {
        super();
        logger=Logger.getLogger("com.gemstone.tools");
	initSetCursorControl(); // 40303
    }
    
    protected void createActionTable(JTextComponent textComponent) {
        actions = new Hashtable();
        Action[] actionsArray = textComponent.getActions();
        for (int i = 0; i < actionsArray.length; i++) {
            Action a = actionsArray[i];
            actions.put(a.getValue(Action.NAME), a);
        }
    }
    
    protected Action getActionByName(String name) {
	Action a = (Action)actions.get(name);
	if (a == null) {
	    // Since we renamed some of these in makeActionPretty(),
	    // check under their new names..
	    if (a.equals("cut-to-clipboard"))
		a = (Action)actions.get("Cut");
	    else if (a.equals("copy-to-clipboard"))
		a = (Action)actions.get("Copy");
	    else if (a.equals("paste-from-clipboard"))
		a = (Action)actions.get("Paste");
	    else if (a.equals("select-all"))
		a = (Action)actions.get("Select All");
	    else throw new NullPointerException();
	}
        return a;
    }
    
    protected void makeActionPretty(){
        Action a;
        try{
            a = getActionByName(DefaultEditorKit.cutAction);
            a.putValue(Action.NAME,"Cut");
            a = getActionByName(DefaultEditorKit.copyAction);
            a.putValue(Action.NAME,"Copy");
            a = getActionByName(DefaultEditorKit.pasteAction);
            a.putValue(Action.NAME,"Paste");
            a = getActionByName(DefaultEditorKit.selectAllAction);
            a.putValue(Action.NAME,"Select All");
        }catch(NullPointerException e) {
            a = getActionByName("Copy");
            if(a==null) e.printStackTrace();
            a = getActionByName("Cut");
            if(a==null) e.printStackTrace();
            a = getActionByName("Paste");
            if(a==null) e.printStackTrace();
            a = getActionByName("Select All");
            if(a==null) e.printStackTrace();
        }
    }
    
    protected GbjSession getSession() {
        return session;
    }
    
    protected void setSession(GbjSession session) {
        this.session=session;
    }
    
    protected void initMenuBar() {
        menuBar=new JMenuBar();
        fileMenu=new JMenu("File");
        initFileMenu();
        editMenu=new JMenu("Edit");
        initEditMenu();
        sessionMenu=new JMenu("Session");
        initSessionMenu();
        
        initCustomMenus();
        
        initHelpMenu();
        menuBar.add(fileMenu);
        menuBar.add(editMenu);
        menuBar.add(sessionMenu);
        addCustomMenus();
        if(helpMenu!=null)
            menuBar.add(helpMenu);
    }
    
    protected void initPopupMenu() {
        JMenuItem temp;
        stdPopUp=new JPopupMenu();
        try{
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.cutAction));
            temp.setName("Cut Popup MenuItem");
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.copyAction));
            temp.setName("Copy Popup MenuItem");
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.pasteAction));
            temp.setName("Paste Popup MenuItem");
            stdPopUp.add(new JSeparator());
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.selectAllAction));
            temp.setName("Select All Popup MenuItem");
        }catch(NullPointerException e) {
            temp=stdPopUp.add(getActionByName("Cut"));
            temp.setName("Cut Popup MenuItem");
            temp=stdPopUp.add(getActionByName("Copy"));
            temp.setName("Copy Popup MenuItem");
            temp=stdPopUp.add(getActionByName("Paste"));
            temp.setName("Paste Popup MenuItem");
            stdPopUp.add(new JSeparator());
            temp=stdPopUp.add(getActionByName("Select All"));
            temp.setName("Select All Popup MenuItem");
        }
        stdPopUp.add(new JSeparator());
        temp=new JMenuItem("Do-It");
        temp.setActionCommand("Do-It");
        temp.setName("Do It Popup MenuItem");
        temp.addActionListener(this);
        stdPopUp.add(temp);
        
        temp=new JMenuItem("Print-It");
        temp.setActionCommand("Print-It");
        temp.setName("Print-It Popup MenuItem");
        temp.addActionListener(this);
        stdPopUp.add(temp);
        
        temp=new JMenuItem("Inspect-It");
        temp.setActionCommand("Inspect-It");
        temp.setName("Inspect It Popup MenuItem");
        temp.addActionListener(this);
        stdPopUp.add(temp);
        stdPopUp.add(new JSeparator());
        temp=new JMenuItem("File-It In");
        temp.setName("File It In Popup MenuItem");
        temp.setActionCommand("File-It In");
        temp.addActionListener(this);
        stdPopUp.add(temp);
    }
    
    protected  void initFileMenu(){
        JMenuItem temp=new JMenuItem("Open");
        temp.addActionListener(this);
        fileMenu.add(temp);
        temp.setActionCommand("Open");
        temp=new JMenuItem("Save As");
        temp.addActionListener(this);
        temp.setActionCommand("Save As");
        fileMenu.add(temp);
        temp=new JMenuItem("File In");
        temp.addActionListener(this);
        temp.setActionCommand("File In");
        fileMenu.add(temp);
        fileMenu.add(new JSeparator());
        temp=new JMenuItem("Settings");
        temp.addActionListener(this);
        temp.setActionCommand("Settings");
        fileMenu.add(temp);
        fileMenu.add(new JSeparator());
        temp=new JMenuItem("Exit");
        temp.setName("Exit MenuItem");
        temp.addActionListener(this);
        temp.setActionCommand("Exit");
        fileMenu.add(temp);
        temp.addActionListener(this);
    }
    
    protected  void initEditMenu(){
        JMenuItem temp;
        try{
            temp=editMenu.add(getActionByName(DefaultEditorKit.cutAction));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_X,ActionEvent.CTRL_MASK));
            temp=editMenu.add(getActionByName(DefaultEditorKit.copyAction));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_C,ActionEvent.CTRL_MASK));
            temp=editMenu.add(getActionByName(DefaultEditorKit.pasteAction));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_V,ActionEvent.CTRL_MASK));
            editMenu.add(new JSeparator());
            temp=editMenu.add(getActionByName(DefaultEditorKit.selectAllAction));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_A,ActionEvent.CTRL_MASK));
        }catch(NullPointerException e) {
            temp=editMenu.add(getActionByName("Cut"));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_X,ActionEvent.CTRL_MASK));
            temp=editMenu.add(getActionByName("Copy"));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_C,ActionEvent.CTRL_MASK));
            temp=editMenu.add(getActionByName("Paste"));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_V,ActionEvent.CTRL_MASK));
            editMenu.add(new JSeparator());
            temp=editMenu.add(getActionByName("Select All"));
            temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_A,ActionEvent.CTRL_MASK));
        }
        editMenu.add(new JSeparator());
        initEditMenuAdvanced();
    }
    protected  void initEditMenuAdvanced() {
        JMenuItem temp=new JMenuItem("Do-It");
        temp.setActionCommand("Do-It");
        temp.addActionListener(this);
        temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_D,ActionEvent.CTRL_MASK));
        editMenu.add(temp);
        temp=new JMenuItem("Print-It");
        temp.setActionCommand("Print-It");
        temp.addActionListener(this);
        temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P,ActionEvent.CTRL_MASK));
        editMenu.add(temp);
        temp=new JMenuItem("Inspect-It");
        temp.setActionCommand("Inspect-It");
        temp.addActionListener(this);
        temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_I,ActionEvent.CTRL_MASK));
        editMenu.add(temp);
        editMenu.add(new JSeparator());
        temp=new JMenuItem("File-It In");
        temp.setActionCommand("File-It In");
        temp.addActionListener(this);
        editMenu.add(temp);
    }
    
    protected  void initSessionMenu(){
        JMenuItem temp=new JMenuItem("Login");
        temp.setActionCommand("Login");
        temp.addActionListener(this);
        sessionMenu.add(temp);
        temp=new JMenuItem("Logout");
        temp.setActionCommand("Logout");
        temp.addActionListener(this);
        sessionMenu.add(temp);
        sessionMenu.add(new JSeparator());
        temp=new JMenuItem("Commit");
        temp.setActionCommand("Commit");
        temp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S,ActionEvent.CTRL_MASK+ActionEvent.SHIFT_MASK));
        temp.addActionListener(this);
        sessionMenu.add(temp);
        temp=new JMenuItem("Abort");
        temp.setActionCommand("Abort");
        temp.addActionListener(this);
        sessionMenu.add(temp);
        temp=new JMenuItem("Begin");
        temp.setActionCommand("Begin");
        temp.addActionListener(this);
        sessionMenu.add(temp);
        sessionMenu.add(new JSeparator());
        this.transactionButtons=new ButtonGroup();
        manualMenuItem=new JRadioButtonMenuItem("Manual");
        sessionMenu.add(manualMenuItem);
        manualMenuItem.addActionListener(this);
        manualMenuItem.setActionCommand("Manual");
        transactionButtons.add(manualMenuItem);
        autoMenuItem=new JRadioButtonMenuItem("Auto");
        autoMenuItem.setActionCommand("Auto");
        sessionMenu.add(autoMenuItem);
        autoMenuItem.addActionListener(this);
        transactionButtons.add(autoMenuItem);
    }
    
    protected  void initCustomMenus(){
    }
    
    protected  void initHelpMenu(){
        helpMenu=new JMenu("Help");
        JMenuItem temp=new JMenuItem("About");
        helpMenu.add(temp);
        temp.setActionCommand("About");
        temp.addActionListener(this);
    }
    
    protected void addCustomMenus(){
    }
    
    protected void initUI() {
        initMenuBar();
        initPopupMenu();
        setJMenuBar(menuBar);
        content=this.getContentPane();
        content.setLayout(new BorderLayout());
        addWindowListener(this);
        addComponentListener(this);
    }
    
    protected void displayWindow() {
        pack();
        Dimension windowSize=getSize();
        Dimension screen=java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        int x=(screen.width-windowSize.width)/2;
        int y=(screen.height-windowSize.height)/2;
        setLocation(x,y);
        setVisible(true);
    }
    
    public void windowOpened(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowClosed(java.awt.event.WindowEvent windowEvent) {
      return;
    }
    
    public void windowDeiconified(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowClosing(java.awt.event.WindowEvent windowEvent) {
       if (launcher != null) 
          launcher.deregisterWindow(this);
    }
    
    public void windowDeactivated(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowActivated(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowIconified(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void menuSelected(javax.swing.event.MenuEvent menuEvent){
    }
    
    public void menuDeselected(javax.swing.event.MenuEvent menuEvent){
    }
    
    public void menuCanceled(javax.swing.event.MenuEvent menuEvent){
    }
    
    public void mouseExited(java.awt.event.MouseEvent mouseEvent) {
    }
    
    public void mouseReleased(java.awt.event.MouseEvent mouseEvent) {
        checkPopup(mouseEvent);
    }
    
    public void mousePressed(java.awt.event.MouseEvent mouseEvent) {
        checkPopup(mouseEvent);
    }
    
    public void mouseClicked(java.awt.event.MouseEvent mouseEvent) {
        checkPopup(mouseEvent);
    }
    
    public void mouseEntered(java.awt.event.MouseEvent mouseEvent) {
    }
    
    protected void checkPopup(java.awt.event.MouseEvent e) {
        if (e.isPopupTrigger()) {
            selectedComponent=e.getComponent();
            stdPopUp.show(e.getComponent(),e.getX(),e.getY());
        }
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String actionCommand=actionEvent.getActionCommand();
        if(actionCommand.equals("Open"))openFile();
        else if(actionCommand.equals("Exit")){
            if(session!=null){
                abortTransaction();
                sessionClosed();
            }
            exitApplication();
            logger.info("Exiting GBJ");
            System.exit(0);
        }else if(actionCommand.equals("Print-It")) printIt();
        else if (actionCommand.equals("Inspect-It")) inspectIt();
        else if (actionCommand.equals("Commit")) commitTransaction();
        else if (actionCommand.equals("Abort")) abortTransaction();
        else if (actionCommand.equals("Begin")) beginTransaction();
        else if (actionCommand.equals("File In")) fileInFile();
        else if (actionCommand.equals("Close")) closeWindow();
        else if (actionCommand.equals("Do-It"))doIt();
        else if (actionCommand.equals("Save As"))saveFileAs();
    }
    
    protected void abortTransaction(){
        if (session == null) {
            return;
        }
        try {
            resetClassOrganizer();
            session.abortTransaction();
            if (launcher != null) {
                launcher.transcript().append("\nAborted " + session+"\n");
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
        } catch (GbjException e) {
            this.processError_(e);
        }
    }
    
    protected void beginTransaction(){
        if (session == null) {
            return;
        }
        try {
            session.beginTransaction();
            if (launcher != null) {
                launcher.transcript().append("\nBegin transaction " + session);
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
        } catch (GbjException e) {
            processError_(e);
        }
    }
    
    protected void commitTransaction(){
        boolean succeeded;
        if (session == null) {
            return;
        }
        try {
            resetClassOrganizer();
            succeeded = session.commitTransaction();
            if (succeeded) {
                if (launcher != null) {
                    launcher.transcript().append("\nCommitted " + this.session);
                    int l=launcher.transcript().getDocument().getLength();
                    launcher.transcript().setCaretPosition(l);
                }
            } else {
                new GbxReportDialog(launcher);
            }
        } catch (GbjException e) {
            this.processError_(e);
        }
    }

    // 45246 -- needed for java 8
    public void update(java.util.Observable obj, Object argument) {
	update((GbjObservable)obj, "[no message]", argument);
    }
    
    public void update(GbjObservable obj, String notificationMessage, Object argument) {
        if (session != obj) {
            return;
        }
        /* We have just refreshed the view of the repository. Reinitialize the tool. */
        if ((notificationMessage.equals("abort")) || (notificationMessage.equals("commit")) || (notificationMessage.equals("begin"))) {
            this.reinitialize();
        }
        /* The session this tool is attached to has logged out - close ourself. */
        if (notificationMessage.equals("close")) {
            if(this==launcher||launcher==null)this.sessionClosed();
        }
    }
    
    void sessionClosed() {
        if (session != null) {
            session.removeObserver(this);
            session.close();
            session = null;
            if(launcher==this){
                launcher.transcript().append("The session has been closed.\n");
                logger.info("Session closed.");
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
                launcher.disableUI();
                launcher.updateWindowsSessionsLogout();
            }else{
                disableUI();
            }
        }
    }
    
    void reinitialize() {
        /* subclasses should do the right think to update the user interface */
    }
    
    public void printIt() {
        String resultText;
        
        if (session == null) {
            noSessionWarning();
            return;
        }
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            String doitCode = ((JTextComponent)textcomp).getSelectedText();
            setCursor(new Cursor(Cursor.WAIT_CURSOR));
            try {
                resultText = this.serverSupport().evaluate_inContext_names_values_printing_(doitCode, this.contextObject(), this.doitNames(), this.doitValues(), true).stringValue();
                printResult(resultText);
            } catch (GbjException e) {
                processGbjException(e, true, false);
            }
            setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        }
    }
    
    public void componentResized(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void componentShown(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void componentMoved(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void componentHidden(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void updateLookAndFeel() {
        SwingUtilities.updateComponentTreeUI(GbxTool.this);
        if(stdPopUp!=null)
            SwingUtilities.updateComponentTreeUI(stdPopUp);
       // pack();
    }
    
    public void updateFont(Font font){
        workspace.setFont(font);
    }
    
    public void updateTabSize(int size){
        workspace.setTabSize(size);
    }
    
    public void updateWordWrap(boolean wrap){
        workspace.setWrapStyleWord(wrap);
        workspace.setLineWrap(wrap);
    }
    
    public void closeWindow() {
        disableUI();
        setVisible(false);
        if(launcher!=null) launcher.deregisterWindow(this);
        dispose();
    }
    
    public void inspectIt() {
        GbjInspector anInspector;
        GbjObject result;
        
        if (this.session() == null) {
            noSessionWarning();
            return;
        }
        result = doIt(true);
        if (result != null) {
            anInspector = new GbjInspector(result,null,session,launcher);
        }
    }
    
    public GbjObject doIt() {
        return doIt(false);
    }
    
    public GbjObject doIt(boolean inspecting) {
        GbjObject aProxy = null;
        if (session == null) {
            noSessionWarning();
            return null;
        }
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            String doitCode = ((JTextComponent)textcomp).getSelectedText();
            setCursor(new Cursor(Cursor.WAIT_CURSOR));
            try {
                aProxy = this.serverSupport().evaluate_inContext_names_values_printing_(doitCode, this.contextObject(), this.doitNames(), this.doitValues(), false);
            } catch (GbjException e) {
                processGbjException(e, false, inspecting);
            }
            setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        }
        return aProxy;
    }
    
    protected void processGbjException(GbjException err) {
        processGbjException(err,false,false);
    }
    
    protected void processGbjException(GbjException err,boolean printing,boolean inspecting) {
        GbjObject [] errorArray;
        int sourceIndex;
        String errorText;
        if ((err.number / 1000) == 1) {
            try {
                errorArray = this.serverSupport().errorInfoFrom_((GbjObject) err.args[0]);
                errorText = errorArray[0].stringValue();
                sourceIndex = errorArray[1].intValue() - 1;
            } catch (GbjException e) {
                this.processError_(e);
                return;
            }
            errorText = errorText + "->";
            Object textcomp=selectedComponent;
            if (textcomp instanceof JTextComponent) {
                try{
                    sourceIndex += ((JTextComponent)textcomp).getSelectionStart();
                    ((JTextComponent)textcomp).requestFocus();
                    ((JTextArea)textcomp).insert(errorText, sourceIndex);
                    ((JTextComponent)textcomp).select(sourceIndex, sourceIndex+errorText.length());
                }catch(Exception e){}
            }
        } else {
            this.processError_message_printing_inspecting_(err, "Do It", printing, inspecting);
        }
    }
    
    public void printResult(java.lang.String resultText) {
        resultText=" "+resultText+" ";
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            try{
                JTextComponent activeTextArea=(JTextComponent)textcomp;
                activeTextArea.setCaretPosition(activeTextArea.getSelectionEnd());
                activeTextArea.getDocument().insertString(activeTextArea.getCaretPosition(),resultText,null);
                activeTextArea.moveCaretPosition(activeTextArea.getCaretPosition()-resultText.length());
            }catch(javax.swing.text.BadLocationException e){e.printStackTrace();}
        }
    }
    
    public void setBreak() {
    }
    
    public void fileInText() {
        if (session == null) {
            noSessionWarning();
            return;
        }
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            String selection = ((JTextComponent)textcomp).getSelectedText();
            fileInString(selection);
        }
    }
    
    public void fileInFile() {
        String fileText;
        if (session == null) {
            noSessionWarning();
            return;
        }
        fileText = getTextFromFile();
        fileInString(fileText);
    }
    
    public void fileInString(java.lang.String aString) {
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            if (launcher != null) {
                launcher.transcript().append("\nFiling in..."+"\n");
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
            serverSupport().fileInString_(aString);
            if (launcher != null) {
                launcher.transcript().append("\n Done \n");
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
        } catch (GbjException e) {
            processError_(e);
        }
        resetClassOrganizer();
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
    }
    
    public GbjSession session() {
        return session;
    }
    
    
    public void session_(GbjSession aGSSession) {
        session = aGSSession;
        session.addObserver(this);
    }
    
    public GbxToolsSupport serverSupport() {
        GbxToolsSupport res = (GbxToolsSupport)session.toolData_();
        if (res == null) {
            try {
               res = new GbxToolsSupportImpl(session);
               session.setToolData(res);
            } catch (GbjException e) {
                processError_(e);
            }
        }
        return res;
    }
    
    public void resetClassOrganizer() {
        try {
            serverSupport().resetClassOrganizer();
        } catch (GbjException e) {
            processError_(e);
        }
    }
    
    public void chooseSelectorMatching_dialogString_(java.lang.String sel, java.lang.String aString) {
        GbjCollection selectorCollectionProxy;
        String [] selectorCollection;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            selectorCollection = this.serverSupport().symbolsMatching_(sel);
        } catch (GbjException e) {
            selectorCollection = new String[0];
            this.processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        if (selectorCollection.length == 0) {
            JOptionPane.showMessageDialog(this,"Nobody","Warning",JOptionPane.WARNING_MESSAGE);
            listSelected=null;
            return;
        }
        GbxListDialog listDialog=new GbxListDialog("Choose selector", aString, selectorCollection);
        listSelected=listDialog.result();
    }
    
    public void chooseClassNameMatching_dialogString_(java.lang.String sel, java.lang.String aString) {
        String [] classNames;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            classNames = serverSupport().classNamesMatching_(sel);
        } catch (GbjException e) {
            classNames = new String[0];
            processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        if (classNames.length == 0) {
            JOptionPane.showMessageDialog(this,"Nobody","Warning",JOptionPane.WARNING_MESSAGE);
            listSelected=null;
            return;
        }
        GbxListDialog listDialog=new GbxListDialog("Choose class", aString, classNames);
        listSelected=listDialog.result();
    }
    
    public GbjObject doitNames() {
        return null;
    }
    
    public GbjObject doitValues() {
        return null;
    }
    
    public GbjObject contextObject() {
        return null;
    }
    
    public void saveFileAs() {
        
        try {
            this.saveTextToFile(workspace.getText(), "Save As...", fileName);
        } catch (SecurityException ex) {
            JOptionPane.showMessageDialog(this,"Security exception; unable to write the file");
        }
    }
    
    public void saveTextToFile(java.lang.String aString, java.lang.String aLabel, java.lang.String initialName) {
        String fname;
        File path;
        DataOutputStream ws = null;
        
        JFileChooser filechooser=new JFileChooser();
        int result=filechooser.showSaveDialog(this);
        if (result==JFileChooser.APPROVE_OPTION) {
            path=filechooser.getSelectedFile();
            //if (fname == null || fname.length() == 0) {
            //	return;
            //}
            //fname = fileDialog.getDirectory() + fname;
            try {
                //path = new File(fname);
                if (path.exists() && !path.canWrite()) {
                    //warnDialog.warn("Can't write " + fname);
                    JOptionPane.showMessageDialog(this,"Can't write " +path);
                    return;
                }
                ws = new DataOutputStream( new FileOutputStream(path) );
                ws.writeBytes(aString);
                ws.close();
                //fileName = fname;
            } catch (IOException ex) {
                //warnDialog.warn("Error in writing to file");
                JOptionPane.showMessageDialog(this,"Error in writing to file");
            }
        }}
    
    public void openFile() {
        if(selectedComponent instanceof JTextArea) {
            JTextArea component=(JTextArea)selectedComponent;
            String inputtext=getTextFromFile();
            if(inputtext!=null){
                component.setText(inputtext);
                component.setCaretPosition(0);
            }
        }else {
            try{
                String inputtext=getTextFromFile();
                if(inputtext!=null){
                    workspace.setText(inputtext);
                    workspace.setCaretPosition(0);
                }
            }catch(Exception e){e.printStackTrace();}
        }
    }
    
    public String getTextFromFile() {
        StringBuffer input=null;
        JFileChooser chooser=new JFileChooser();
        int result=chooser.showOpenDialog(this);
        if(result==JFileChooser.CANCEL_OPTION) return null;
        try{
            File file=chooser.getSelectedFile();
            FileReader fr=new FileReader(file);
            BufferedReader in=new BufferedReader(fr);
            input=new StringBuffer();
            String line;
            while((line=in.readLine())!=null)input.append(line).append('\n');
        } catch(Exception e) {
          e.printStackTrace();
        }
        return (input.toString());
    }
    
    public void processError_(GbjException e) {
        e.printStackTrace();
        processError_message_printing_inspecting_(e, "Error", false, false);
    }
    
    public void processError_message_printing_inspecting_(GbjException e, java.lang.String msg, boolean printing, boolean inspecting) {
        //debug process
        boolean isConnected = (e.session != null) && e.session.isConnected() ;
        
        if (isConnected && isVisible() && isDisplayable()) {
            GbxDebugDialog debugDialog=new GbxDebugDialog(msg, e, printing, inspecting, this);
        } else if (launcher != null && launcher.isVisible() && launcher.isDisplayable()) {
            // if (e.message.length() < 100) {
            JOptionPane.showMessageDialog(launcher,e.getMessage(),"Warning",JOptionPane.WARNING_MESSAGE);
            logger.info(e.getMessage());
            // } else {
            //   GbxLongWarning lWarning=new GbxLongWarning();
            // }
            
        } else {
            logger.info(e.message);
        }
    }
    
    public void showErrorMessage_title_(java.lang.String error, java.lang.String aTitle) {
        if (isDisplayable()) {
            //if ((error.length() < 100) && (error.indexOf('\n') == -1)) {
            JOptionPane.showMessageDialog(this,error,aTitle,JOptionPane.WARNING_MESSAGE);
            // } else {
            //    GbxLongWarning lWarning=new GbxLongWarning();
            // }
        } else if (launcher != null && launcher.isVisible() && launcher.isDisplayable()) {
            // if ((error.length() < 100) && (error.indexOf('\n') == -1)) {
            JOptionPane.showMessageDialog(launcher,error,aTitle,JOptionPane.WARNING_MESSAGE);
            // } else {
            //     GbxLongWarning lWarning=new GbxLongWarning();
            // }
        } else {
            logger.info(error);
        }
    }
    
    //************************************ JFC UNIT TEST ************************************************
  /*  public static class TestGbxTool extends junit.extensions.jfcunit.JFCTestCase {
   
        GbxTool testGui;
        private junit.extensions.jfcunit.JFCTestHelper helper;
   
        public TestGbxTool(String name) {
            super(name);
        }
   
        public void setUp() {
            //Start listening for window open events
            helper = new junit.extensions.jfcunit.JFCTestHelper();
        }
   
        public static junit.framework.Test suite() {
            return new junit.framework.TestSuite(TestGbxTool.class);
        }
   
        public static void main(String args[]) {
            junit.textui.TestRunner.run(TestGbxTool.suite());
            System.exit(0);
        }
   
        public void testFileOpen(){
   
         testGui=new GbxTool();
         testGui.displayWindow();
         testGui.getTextFromFile();
         awtSleep();
        }
   
        public void testWindow() {
            java.util.Set windows;
            //Run the code we are testing
            testGui=new GbxTool();
            testGui.displayWindow();
            //Let the AWT Thread show the window
            awtSleep();
            windows = helper.getWindows();
            Object[] sample=windows.toArray();
            //((GbxToolS)sample[0])
            //We should have created exactly one window
            assertEquals("Number of windows showing up is incorrect",
            1, windows.size());
        }
   
        public void testDisplayWindow(){
            java.util.Set windows;
            testGui=new GbxTool();
            testGui.initUI();
            testGui.displayWindow();
            awtSleep();
        }
    } */
    //**********************************************************************************
    protected void enableUI() {
    }
    
    protected void disableUI() {
        if(launcher!=null)
            launcher.deadWindows(this);
        setVisible(false);
        dispose();
    }
    
    protected void noSessionWarning() {
        Logger logger=Logger.getLogger("com.gemstone.tools");
        JOptionPane.showMessageDialog(this,"No Session Available","Error",JOptionPane.ERROR_MESSAGE);
        logger.warning("No Session Available");
    }
    
    public void updateListWidget_withObjects_(JList widget, Object [] objects) {
        DefaultListModel data=new DefaultListModel();
        widget.removeAll();
	if (objects == null) return;
        for (int i = 0; i < objects.length; i++) {
            data.addElement(objects[i].toString());
        }
        widget.setModel(data);
    }
    
    public int indexOf_inList_(Object anObject, Object [] aList) {
        for (int i = 0; i < aList.length; i++) {
            if (aList[i] == anObject) {
                return i;
            }
        }
        return -1;
    }
    
    public void valueChanged(javax.swing.event.ListSelectionEvent listSelectionEvent) {
    }
    
    public void focusGained(java.awt.event.FocusEvent focusEvent) {
    }
    
    public void focusLost(java.awt.event.FocusEvent focusEvent) {
    }
    
    public Logger getLogger(){
        return logger;
    }
    
     public void exitApplication() {
    }
     
   public void setWindowID(int id){
       windowID=id;
   }
   
   public int getWindowID(){
       return windowID;
   }

/*

BUGFIX 40303:  There's been a long-standing java bug on the display of
a busy cursor (Sun Development Network Bug 4132824).

Following code is an adaptation of a customer-suggested fix from dsyrstad1
submitted to the SDN site.

*/


    protected void initSetCursorControl() {
	setDefaultCloseOperation(WindowConstants.HIDE_ON_CLOSE);
	glass_pane = new JPanel() {
		public boolean isManagingFocus() {
		    return true;
		}
	    };
	glass_pane.addMouseListener(new MouseAdapter() { } );
	glass_pane.addKeyListener(new KeyAdapter() {
		public void keyPressed(KeyEvent e) {
		    e.consume();
		}
	    });
	glass_pane.setOpaque(false);
	this.setGlassPane(glass_pane);
    }

    public void setCursor(Cursor newCursor) {
	if (newCursor.getType() == Cursor.WAIT_CURSOR) {
	    super.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	    glass_pane.setVisible(true);
	    glass_pane.requestFocus();
	    glass_pane.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	    setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
	} else {
	    glass_pane.setCursor(Cursor.getDefaultCursor());
	    glass_pane.setVisible(false);
	    this.requestFocus();
	    super.setCursor(Cursor.getDefaultCursor());
	    setDefaultCloseOperation(WindowConstants.HIDE_ON_CLOSE);
	}
    }

    // END 40303 fix
	
}
