/*
 * GbxToolPanel.java
 *
 * Created on August 10, 2002, 1:02 PM
 */

package com.gemstone.tools;

import javax.swing.*;
import javax.swing.text.*;
import java.awt.*;
import com.gemstone.gbj.*;
import com.gemstone.tools.GbxToolsSupportImpl;
import java.util.*;
import java.io.*;
// GBJ30: replace with java logging
//import com.gemstone.org.apache.log4j.*;
import java.util.logging.*;
/**
 *
 * @author  vincef
 */
public class GbxToolPanel extends javax.swing.JPanel
implements java.awt.event.WindowListener, javax.swing.event.MenuListener,
java.awt.event.MouseListener, java.awt.event.ActionListener,
com.gemstone.gbj.GbjObserver, java.awt.event.ComponentListener{
    
    protected JPopupMenu popupMenu;
    protected GbjSession session;
    protected JLabel statusMessage;
    // protected Container content;
    protected JPopupMenu stdPopUp;
    protected Hashtable actions;
    protected JTextArea workspace;
    protected GbjLauncher launcher;
    protected Component selectedComponent;
    protected String listSelected;
    protected Logger logger;
    
    protected static Font mainFont=null;
    
    
    /** Creates a new instance of GbxToolPanel */
    public GbxToolPanel() {
        super();
        logger=Logger.getLogger("com.gemstone.tools");
    }
    
    public GbxToolPanel(GbjSession session, GbjLauncher launcher) {
        super();
        this.session=session;
        this.launcher=launcher;
        logger=Logger.getLogger("com.gemstone.tools");
    }
    
    protected GbjSession getSession() {
        return session;
    }
    
    protected void setSession(GbjSession session) {
        this.session=session;
    }
    
    protected void createActionTable(JTextComponent textComponent) {
        actions = new Hashtable();
        Action[] actionsArray = textComponent.getActions();
        for (int i = 0; i < actionsArray.length; i++) {
            Action a = actionsArray[i];
            actions.put(a.getValue(Action.NAME), a);
        }
    }
    
    protected Action getActionByName(String name) {
        return (Action)(actions.get(name));
    }
    
    protected void makeActionPretty(){
        Action a;
        try{
            a = getActionByName(DefaultEditorKit.cutAction);
            a.putValue(Action.NAME,"Cut");
            a = getActionByName(DefaultEditorKit.copyAction);
            a.putValue(Action.NAME,"Copy");
            a = getActionByName(DefaultEditorKit.pasteAction);
            a.putValue(Action.NAME,"Paste");
            a = getActionByName(DefaultEditorKit.selectAllAction);
            a.putValue(Action.NAME,"Select All");
        }catch(NullPointerException e) {
            a = getActionByName("Copy");
            if(a==null){
                e.printStackTrace();
                logger.warning(e.toString());
            }
            a = getActionByName("Cut");
            if(a==null){
                e.printStackTrace();
                logger.warning(e.toString());
            }
            a = getActionByName("Paste");
            if(a==null){
                e.printStackTrace();
                logger.warning(e.toString());
            }
            a = getActionByName("Select All");
            if(a==null){
                e.printStackTrace();
                logger.warning(e.toString());
            }
        }
    }
    
    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String actionCommand=actionEvent.getActionCommand();
        if(actionCommand.equals("Open"))openFile();
        else if(actionCommand.equals("Exit")){
            if(session!=null){
                abortTransaction();
                sessionClosed();
            }
            logger.info("Exiting GBJ");
            System.exit(0);
        }else if(actionCommand.equals("Print-It")) printIt();
        else if (actionCommand.equals("Inspect-It")) inspectIt();
        else if (actionCommand.equals("Commit")) commitTransaction();
        else if (actionCommand.equals("Abort")) abortTransaction();
        else if (actionCommand.equals("Begin")) beginTransaction();
        else if (actionCommand.equals("File In")) fileInFile();
        //else if (actionCommand.equals("Close")) closeWindow();
        else if (actionCommand.equals("Do-It"))doIt();
    }
    
    public void componentHidden(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void componentMoved(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void componentResized(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void componentShown(java.awt.event.ComponentEvent componentEvent) {
    }
    
    public void menuCanceled(javax.swing.event.MenuEvent menuEvent) {
    }
    
    public void menuDeselected(javax.swing.event.MenuEvent menuEvent) {
    }
    
    public void menuSelected(javax.swing.event.MenuEvent menuEvent) {
    }
    
    
    public void mouseEntered(java.awt.event.MouseEvent mouseEvent) {
    }
    
    public void mouseExited(java.awt.event.MouseEvent mouseEvent) {
    }
    
    
    public void mouseReleased(java.awt.event.MouseEvent mouseEvent) {
        checkPopup(mouseEvent);
    }
    
    public void mousePressed(java.awt.event.MouseEvent mouseEvent) {
        checkPopup(mouseEvent);
    }
    
    public void mouseClicked(java.awt.event.MouseEvent mouseEvent) {
        checkPopup(mouseEvent);
    }
    
    public void windowActivated(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowClosed(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowClosing(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowDeactivated(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowDeiconified(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowIconified(java.awt.event.WindowEvent windowEvent) {
    }
    
    public void windowOpened(java.awt.event.WindowEvent windowEvent) {
    }
    
    protected void initUI() {
        // initMenuBar();
        initPopupMenu();
        //setJMenuBar(menuBar);
        // content=this.getContentPane();
        setLayout(new BorderLayout());
        //addWindowListener(this);
        addComponentListener(this);
    }
    
    protected void checkPopup(java.awt.event.MouseEvent e) {
        if (e.isPopupTrigger()) {
            selectedComponent=e.getComponent();
            stdPopUp.show(e.getComponent(),e.getX(),e.getY());
        }
    }
    
    public void updateLookAndFeel() {
        SwingUtilities.updateComponentTreeUI(GbxToolPanel.this);
        if(stdPopUp!=null)
            SwingUtilities.updateComponentTreeUI(stdPopUp);
        //pack();
    }
    
    public void updateFont(Font font){
        workspace.setFont(font);
    }
    
    protected void enableUI() {
    }
    
    protected void disableUI() {
    }
    
    protected void noSessionWarning() {
        JOptionPane.showMessageDialog(this,"No Session Available","Error",JOptionPane.ERROR_MESSAGE);
        logger.warning("No Session Available");
    }
    
    public void updateListWidget_withObjects_(JList widget, Object [] objects) {
        DefaultListModel data=new DefaultListModel();
        widget.removeAll();
        for (int i = 0; i < objects.length; i++) {
            data.addElement(objects[i].toString());
        }
        widget.setModel(data);
    }
    
    protected void initPopupMenu() {
        JMenuItem temp;
        stdPopUp=new JPopupMenu();
        try{
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.cutAction));
            temp.setName("Cut Popup MenuItem");
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.copyAction));
            temp.setName("Copy Popup MenuItem");
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.pasteAction));
            temp.setName("Paste Popup MenuItem");
            stdPopUp.add(new JSeparator());
            temp=stdPopUp.add(getActionByName(DefaultEditorKit.selectAllAction));
            temp.setName("Select All Popup MenuItem");
        }catch(NullPointerException e) {
            temp=stdPopUp.add(getActionByName("Cut"));
            temp.setName("Cut Popup MenuItem");
            temp=stdPopUp.add(getActionByName("Copy"));
            temp.setName("Copy Popup MenuItem");
            temp=stdPopUp.add(getActionByName("Paste"));
            temp.setName("Paste Popup MenuItem");
            stdPopUp.add(new JSeparator());
            temp=stdPopUp.add(getActionByName("Select All"));
            temp.setName("Select All Popup MenuItem");
        }
        stdPopUp.add(new JSeparator());
        temp=new JMenuItem("Do-It");
        temp.setActionCommand("Do-It");
        temp.setName("Do It Popup MenuItem");
        temp.addActionListener(this);
        stdPopUp.add(temp);
        
        temp=new JMenuItem("Print-It");
        temp.setActionCommand("Print-It");
        temp.setName("Print-It Popup MenuItem");
        temp.addActionListener(this);
        stdPopUp.add(temp);
        
        temp=new JMenuItem("Inspect-It");
        temp.setActionCommand("Inspect-It");
        temp.setName("Inspect It Popup MenuItem");
        temp.addActionListener(this);
        stdPopUp.add(temp);
        stdPopUp.add(new JSeparator());
        temp=new JMenuItem("File-It In");
        temp.setName("File It In Popup MenuItem");
        temp.setActionCommand("File-It In");
        temp.addActionListener(this);
        stdPopUp.add(temp);
    }
    
    protected void abortTransaction(){
        if (session == null) {
            return;
        }
        try {
            resetClassOrganizer();
            session.abortTransaction();
            logger.info("Aborted "+session);
            if (launcher != null) {
                launcher.transcript().append("\nAborted " + session);
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
        } catch (GbjException e) {
            this.processError_(e);
        }
    }
    
    protected void beginTransaction(){
        if (session == null) {
            return;
        }
        try {
            session.beginTransaction();
            logger.info("Begin transaction "+session);
            if (launcher != null) {
                launcher.transcript().append("\nBegin transaction " + session);
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
        } catch (GbjException e) {
            processError_(e);
        }
    }
    
    protected void commitTransaction(){
        boolean succeeded;
        if (session == null) {
            return;
        }
        try {
            resetClassOrganizer();
            succeeded = session.commitTransaction();
            logger.info("Committed "+session);
            if (succeeded) {
                if (launcher != null) {
                    launcher.transcript().append("\nCommitted " + this.session);
                    int l=launcher.transcript().getDocument().getLength();
                    launcher.transcript().setCaretPosition(l);
                }
            } else {
                new GbxReportDialog(launcher);
            }
        } catch (GbjException e) {
            this.processError_(e);
        }
    }

    // 45246 -- needed for java 8
    public void update(java.util.Observable obj, Object argument) {
	update((GbjObservable)obj, "[no message]", argument);
    }
    
    public void update(GbjObservable obj, String notificationMessage, Object argument) {
        if (session != obj) {
            return;
        }
        /* We have just refreshed the view of the repository. Reinitialize the tool. */
        if ((notificationMessage.equals("abort")) || (notificationMessage.equals("commit")) || (notificationMessage.equals("begin"))) {
            this.reinitialize();
        }
        /* The session this tool is attached to has logged out - close ourself. */
        if (notificationMessage.equals("close")) {
            this.sessionClosed();
            //JOptionPane.showMessageDialog(this,"Session has been closed","Session Notice",JOptionPane.ERROR_MESSAGE);
        }
    }
    
    void sessionClosed() {
        if (session != null) {
            session.removeObserver(this);
            session = null;
            disableUI();
        }
    }
    
    void reinitialize() {
        /* subclasses should do the right think to update the user interface */
    }
    
    public void printIt() {
        String resultText;
        
        if (session == null) {
            noSessionWarning();
            return;
        }
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            String doitCode = ((JTextComponent)textcomp).getSelectedText();
            setCursor(new Cursor(Cursor.WAIT_CURSOR));
            try {
                resultText = this.serverSupport().evaluate_inContext_names_values_printing_(doitCode, this.contextObject(), this.doitNames(), this.doitValues(), true).stringValue();
                printResult(resultText);
            } catch (GbjException e) {
                processGbjException(e, true, false);
            }
            setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        }
    }
    
    public void inspectIt() {
        GbjInspector anInspector;
        GbjObject result;
        
        if (this.session() == null) {
            noSessionWarning();
            return;
        }
        result = doIt(true);
        if (result != null) {
            anInspector = new GbjInspector(result,null,session,launcher);
        }
    }
    
    public GbjObject doIt() {
        return doIt(false);
    }
    
    public GbjObject doIt(boolean inspecting) {
        GbjObject aProxy = null;
        if (session == null) {
            noSessionWarning();
            return null;
        }
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            String doitCode = ((JTextComponent)textcomp).getSelectedText();
            setCursor(new Cursor(Cursor.WAIT_CURSOR));
            try {
                aProxy = this.serverSupport().evaluate_inContext_names_values_printing_(doitCode, this.contextObject(), this.doitNames(), this.doitValues(), false);
            } catch (GbjException e) {
                processGbjException(e, false, inspecting);
            }
            setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        }
        return aProxy;
    }
    
    protected void processGbjException(GbjException err) {
        processGbjException(err,false,false);
    }
    
    protected void processGbjException(GbjException err,boolean printing,boolean inspecting) {
        GbjObject [] errorArray;
        int sourceIndex;
        String errorText;
        if ((err.number / 1000) == 1) {
            try {
                errorArray = this.serverSupport().errorInfoFrom_((GbjObject) err.args[0]);
                errorText = errorArray[0].stringValue();
                sourceIndex = errorArray[1].intValue() - 1;
            } catch (GbjException e) {
                this.processError_(e);
                return;
            }
            errorText = errorText + "->";
            Object textcomp=selectedComponent;
            if (textcomp instanceof JTextComponent) {
                try{
                    sourceIndex += ((JTextComponent)textcomp).getSelectionStart();
                    ((JTextComponent)textcomp).requestFocus();
                    ((JTextArea)textcomp).insert(errorText, sourceIndex);
                    ((JTextComponent)textcomp).select(sourceIndex, sourceIndex+errorText.length());
                }catch(Exception e){}
            }
        } else {
            this.processError_message_printing_inspecting_(err, "Do It", printing, inspecting);
        }
    }
    
    public void printResult(java.lang.String resultText) {
        resultText=" "+resultText+" ";
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            try{
                JTextComponent activeTextArea=(JTextComponent)textcomp;
                activeTextArea.setCaretPosition(activeTextArea.getSelectionEnd());
                activeTextArea.getDocument().insertString(activeTextArea.getCaretPosition(),resultText,null);
                activeTextArea.moveCaretPosition(activeTextArea.getCaretPosition()-resultText.length());
            }catch(javax.swing.text.BadLocationException e){e.printStackTrace();}
        }
    }
    
    public void setBreak() {
    }
    
    public void fileInText() {
        if (session == null) {
            noSessionWarning();
            return;
        }
        Object textcomp=selectedComponent;
        if (textcomp instanceof JTextComponent) {
            String selection = ((JTextComponent)textcomp).getSelectedText();
            fileInString(selection);
        }
    }
    
    public void fileInFile() {
        String fileText;
        if (session == null) {
            noSessionWarning();
            return;
        }
        fileText = getTextFromFile();
        fileInString(fileText);
    }
    
    public void fileInString(java.lang.String aString) {
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            if (launcher != null) {
                launcher.transcript().append("\nFiling in...");
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
            serverSupport().fileInString_(aString);
            if (launcher != null) {
                launcher.transcript().append("Done");
                int l=launcher.transcript().getDocument().getLength();
                launcher.transcript().setCaretPosition(l);
            }
        } catch (GbjException e) {
            processError_(e);
        }
        resetClassOrganizer();
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
    }
    
    public GbjSession session() {
        return session;
    }
    
    
    public void session_(GbjSession aGSSession) {
        session = aGSSession;
        session.addObserver(this);
    }
    
    public GbxToolsSupport serverSupport() {
        GbxToolsSupport res = (GbxToolsSupport)session.toolData_();
        if (res == null) {
            try {
               res = new GbxToolsSupportImpl(session);
               session.setToolData(res);
            } catch (GbjException e) {
                processError_(e);
            }
        }
        return res;
    }
    
    public void resetClassOrganizer() {
        try {
            serverSupport().resetClassOrganizer();
        } catch (GbjException e) {
            processError_(e);
        }
    }
    
    public void chooseSelectorMatching_dialogString_(java.lang.String sel, java.lang.String aString) {
        GbjCollection selectorCollectionProxy;
        String [] selectorCollection;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            selectorCollection = this.serverSupport().symbolsMatching_(sel);
        } catch (GbjException e) {
            selectorCollection = new String[0];
            this.processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        if (selectorCollection.length == 0) {
            JOptionPane.showMessageDialog(this,"Nobody","Warning",JOptionPane.WARNING_MESSAGE);
            listSelected=null;
            return;
        }
        GbxListDialog listDialog=new GbxListDialog("Choose selector", aString, selectorCollection);
        listSelected=listDialog.result();
    }
    
    public void chooseClassNameMatching_dialogString_(java.lang.String sel, java.lang.String aString) {
        String [] classNames;
        
        setCursor(new Cursor(Cursor.WAIT_CURSOR));
        try {
            classNames = serverSupport().classNamesMatching_(sel);
        } catch (GbjException e) {
            classNames = new String[0];
            processError_(e);
        }
        setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
        if (classNames.length == 0) {
            JOptionPane.showMessageDialog(this,"Nobody","Warning",JOptionPane.WARNING_MESSAGE);
            listSelected=null;
            return;
        }
        GbxListDialog listDialog=new GbxListDialog("Choose class", aString, classNames);
        listSelected=listDialog.result();
    }
    
    public GbjObject doitNames() {
        return null;
    }
    
    public GbjObject doitValues() {
        return null;
    }
    
    public GbjObject contextObject() {
        return null;
    }
    
    public void saveFileAs() {
    }
    
    public void saveTextToFile(java.lang.String aString, java.lang.String aLabel, java.lang.String initialName) {
    }
    
    public void openFile() {
        if(selectedComponent instanceof JTextArea) {
            JTextArea component=(JTextArea)selectedComponent;
            component.setText(getTextFromFile());
        }else {
            try{
                workspace.setText(getTextFromFile());
            }catch(Exception e){e.printStackTrace();}
        }
    }
    
    public String getTextFromFile() {
        StringBuffer input=null;
        JFileChooser chooser=new JFileChooser();
        int result=chooser.showOpenDialog(this);
        if(result==JFileChooser.CANCEL_OPTION) return "";
        try{
            File file=chooser.getSelectedFile();
            FileReader fr=new FileReader(file);
            BufferedReader in=new BufferedReader(fr);
            input=new StringBuffer();
            String line;
            while((line=in.readLine())!=null)input.append(line).append('\n');
        }catch(Exception e){e.printStackTrace();}
        return (input.toString());
    }
    
    public void processError_(GbjException e) {
        e.printStackTrace();
        Logger logger=Logger.getLogger("com.gemstone.tools");
        logger.info(e.toString());
        processError_message_printing_inspecting_(e, "Error", false, false);
    }
    
    public void processError_message_printing_inspecting_(GbjException e, java.lang.String msg, boolean printing, boolean inspecting) {
        //debug process
        boolean isConnected = (e.session != null) && e.session.isConnected() ;
        
        if (isConnected && isVisible() && isDisplayable()) {
            GbxDebugDialog debugDialog=new GbxDebugDialog(msg, e, printing, inspecting, this);
        } else if (launcher != null && launcher.isVisible() && launcher.isDisplayable()) {
            // if (e.message.length() < 100) {
            JOptionPane.showMessageDialog(launcher,e.getMessage(),"Warning",JOptionPane.WARNING_MESSAGE);
            // } else {
            //     GbxLongWarning lWarning=new GbxLongWarning();
            // }
            
        } else {
            logger.info(e.message);
        }
    }
    
    public void showErrorMessage_title_(java.lang.String error, java.lang.String aTitle) {
        if (isDisplayable()) {
            // if ((error.length() < 100) && (error.indexOf('\n') == -1)) {
            JOptionPane.showMessageDialog(this,error,aTitle,JOptionPane.WARNING_MESSAGE);
            // } else {
            //     GbxLongWarning lWarning=new GbxLongWarning();
            // }
        } else if (launcher != null && launcher.isVisible() && launcher.isDisplayable()) {
            // if ((error.length() < 100) && (error.indexOf('\n') == -1)) {
            JOptionPane.showMessageDialog(launcher,error,aTitle,JOptionPane.WARNING_MESSAGE);
            // } else {
            //this.launcher().bigWarnDialog.bigWarn(aTitle, error);
            // GbxLongWarning lWarning=new GbxLongWarning();
            // }
        } else {
            
            logger.info(error);
        }
    }
    
    public int indexOf_inList_(Object anObject, Object [] aList) {
        for (int i = 0; i < aList.length; i++) {
            if (aList[i] == anObject) {
                return i;
            }
        }
        return -1;
    }
    
}
