/*=========================================================================
 * Copyright (C) GemTalk Systems 1986-2024.  All Rights Reserved.
 *
 * Name - GbxToolsSupport.java
 *
 *========================================================================
 */

package com.gemstone.tools;

import com.gemstone.gbj.GbjObject;
import com.gemstone.gbj.GbjCollection;
import com.gemstone.gbj.GbjIterator;
import com.gemstone.gbj.GbjSession;
import com.gemstone.gbj.GbjException;

import java.util.Vector;

public interface GbxToolsSupport
{

GbjObject classFor_(GbjObject aClass) throws GbjException;

GbjObject classNameFor_(GbjObject anObject) throws GbjException;

String fileOutOfClass_(GbjObject aClass) throws GbjException;

String fileOutOfMethod_inClass_(String aSelector, GbjObject aClass) throws GbjException;

String fileOutOfDictionary_(GbjObject aDict) throws GbjException;

int remoteSizeOf_(GbjObject anObject) throws GbjException;

GbjObject classNamed_(String aClassName) throws GbjException;

void moveClass_fromDict_toDict_(GbjObject aClass, GbjObject fromDict, GbjObject toDict) throws GbjException;

String [] dictionaryNames() throws GbjException;

boolean isDictionary_(GbjObject anObject) throws GbjException;

boolean collection_includes_(GbjObject anObject, GbjObject element) throws GbjException;

void removeClass_fromDict_(GbjObject aClass, GbjObject aDict) throws GbjException;

void addProtocol_toClass_(String newProtocol, GbjObject aClass) throws GbjException;

void renameProtocol_to_inClass_(String oldName, String newName, GbjObject aClass) throws GbjException;

void removeProtocol_fromClass_(String aProtocol, GbjObject aClass) throws GbjException;

String [] selectorsForClass_(GbjObject aClass) throws GbjException;

String protocolForSelector_inClass_(String aSelector, GbjObject aClass) throws GbjException;

GbxMethodHolder [] methodHoldersForImplementorsOf_(String selector) throws GbjException;

GbxMethodHolder [] methodHoldersForSendersOf_(String selector) throws GbjException;

GbxMethodHolder [] methodHoldersForSubstring_(String substring) throws GbjException;

GbxMethodHolder [] methodHoldersForReferencesTo_(String aSymbol) throws GbjException;

GbxMethodHolder [] methodHoldersForRefsToInstVar_inClass_(String ivName, GbjObject aProxy) throws GbjException;

GbxMethodHolder [] methodHoldersForRefsToClassVar_inClass_(String cvName, GbjObject aProxy) throws GbjException;

GbxMethodHolder [] methodHoldersForRefsToClass_(GbjObject aProxy) throws GbjException;

String [] messagesInMethod_inClass_(String aSelector, GbjObject aClass) throws GbjException;

void moveMethod_to_inClass_(String aSelector, String newProtocol, GbjObject aClass) throws GbjException;

void removeMethod_fromClass_(String aSelector, GbjObject aClass) throws GbjException;

GbjObject [] acceptClassText_oldClass_(String aString, GbjObject oldClass) throws GbjException;

String commentForClass_(GbjObject aClass) throws GbjException;

GbxClassHolder [] classHoldersFor_(GbjObject anObject) throws GbjException;

GbxDictionaryHolder [] dictionaryHolders() throws GbjException;

GbxMethodHolder [] methodHoldersFor_inProtocol_(GbjObject anObject, String aProtocol) throws GbjException;

GbxMethodHolder [] methodHoldersFor_inProtocol_toLevel_(GbjObject anObject, String aProtocol, int aLevel) throws GbjException;

String [] protocolHoldersFor_(GbjObject anObject) throws GbjException;

String [] protocolHoldersFor_toLevel_(GbjObject anObject, int aLevel) throws GbjException;

GbxDictionaryHolder dictionaryHolderFor_(GbjObject anObject) throws GbjException;

GbjObject addDict_at_(String aString, int index) throws GbjException;

boolean renameDictionary_as_(GbjObject aDictionary, String aString) throws GbjException;

void removeDictionary_(GbjObject aProxy) throws GbjException;

String classDefinitionFor_(GbjObject anObject) throws GbjException;

String sourceCodeAt_inClass_ (String selector, GbjObject aClass) throws GbjException;

Vector compile_classified_class_(String source, String aProtocol, GbjObject aClass) throws GbjException;

GbxClassHolder [] classHierarchyHoldersFor_(GbjObject anObject) throws GbjException;

GbjObject classHistoryFor_(GbjObject aClass) throws GbjException;

GbxDictionaryHolder dictionaryForClass_(GbjObject aClassProxy) throws GbjException;

GbxClassHolder [] classVersionHoldersFor_(GbjObject anObject) throws GbjException;

String sourceStringFor_(GbjObject anObject) throws GbjException;

GbxActivationHolder [] activationHoldersFor_maxLevels_(GbjObject aProcess, int maxLevels) throws GbjException;

String printStringFor_(GbjObject anObject) throws GbjException;

GbxObjectHolder [] objectHoldersFor_maxObjects_(GbjObject anObject, int max) throws GbjException;

GbxObjectHolder [] objectHoldersForNames_values_(GbjObject names, GbjObject values) throws GbjException;

GbjObject [] infoForClassNamed_(String aClassName) throws GbjException;

String nameOf_(GbjObject anObject) throws GbjException;

GbjObject thisClass_(GbjObject aClass) throws GbjException;

GbjObject at_(GbjObject anObject, int index) throws GbjException;

void fileInString_(String aString) throws GbjException;

String [] symbolsMatching_(String sel) throws GbjException;

String [] classNamesMatching_(String aClassName) throws GbjException;

String [] stringContentsOf_(GbjCollection collectionProxy);

GbjObject evaluate_inContext_names_values_printing_(String aString, GbjObject context, GbjObject names, GbjObject values, boolean aBoolean) throws GbjException;

String sourceCodeForMethod_(GbjObject aMethod) throws GbjException;

void resetClassOrganizer() throws GbjException;

GbjObject [] errorInfoFrom_(GbjObject errorArray) throws GbjException;

GbjObject instancesOf_(GbjObject aClass) throws GbjException;

void migrateInstancesOf_to_(GbjObject fromClass, GbjObject toClass) throws GbjException;

void removeFromClassHistory_(GbjObject aClass) throws GbjException;

boolean makeClass_aVersionOf_(GbjObject aClass, GbjObject targetClass) throws GbjException;

GbjObject transactionConflicts() throws GbjException;

void storeObject_intoObject_atIndex_atKey_isNamedSlot_(GbjObject slotObject, GbjObject anObject, int slot, GbjObject aKey, boolean isNamedSlot) throws GbjException;

String [] instVarNamesInClass_(GbjObject aClass) throws GbjException;

String [] classVarNamesInClass_(GbjObject aClass) throws GbjException;

void trimStackOf_toLevel_(GbjObject aProcess, int aLevel) throws GbjException;
GbjObject continueProcess_(GbjObject aProcess, GbjSession session) throws GbjException;
GbjObject stepOverInProcess_(GbjObject aProcess) throws GbjException;
GbjObject stepOverInProcess_inFrame_(GbjObject aProcess, int aLevel) throws GbjException;
void stepIntoInProcess_(GbjObject aProcess) throws GbjException;
void setBreakIn_at_(GbjObject aMethod, int offset) throws GbjException;
GbxMethodHolder [] methodHoldersForBreakpoints() throws GbjException;
void removeAllBreaks() throws GbjException;
void enableAllBreaks() throws GbjException;
void disableAllBreaks() throws GbjException;
void removeBreakpoint_inMethod_(int stepPoint, GbjObject aMethod) throws GbjException;
void enableBreakpoint_inMethod_(int stepPoint, GbjObject aMethod) throws GbjException;
void disableBreakpoint_inMethod_(int stepPoint, GbjObject aMethod) throws GbjException;
}
